"use strict";

/***** SALAXY CORE library, See https://developers.salaxy.com for details *****/

var require;
// Source: node_modules/moment/moment.js
//! moment.js

;(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
    typeof define === 'function' && define.amd ? define(factory) :
    global.moment = factory()
}(this, (function () { 'use strict';

    var hookCallback;

    function hooks () {
        return hookCallback.apply(null, arguments);
    }

    // This is done to register the method called with moment()
    // without creating circular dependencies.
    function setHookCallback (callback) {
        hookCallback = callback;
    }

    function isArray(input) {
        return input instanceof Array || Object.prototype.toString.call(input) === '[object Array]';
    }

    function isObject(input) {
        // IE8 will treat undefined and null as object if it wasn't for
        // input != null
        return input != null && Object.prototype.toString.call(input) === '[object Object]';
    }

    function isObjectEmpty(obj) {
        if (Object.getOwnPropertyNames) {
            return (Object.getOwnPropertyNames(obj).length === 0);
        } else {
            var k;
            for (k in obj) {
                if (obj.hasOwnProperty(k)) {
                    return false;
                }
            }
            return true;
        }
    }

    function isUndefined(input) {
        return input === void 0;
    }

    function isNumber(input) {
        return typeof input === 'number' || Object.prototype.toString.call(input) === '[object Number]';
    }

    function isDate(input) {
        return input instanceof Date || Object.prototype.toString.call(input) === '[object Date]';
    }

    function map(arr, fn) {
        var res = [], i;
        for (i = 0; i < arr.length; ++i) {
            res.push(fn(arr[i], i));
        }
        return res;
    }

    function hasOwnProp(a, b) {
        return Object.prototype.hasOwnProperty.call(a, b);
    }

    function extend(a, b) {
        for (var i in b) {
            if (hasOwnProp(b, i)) {
                a[i] = b[i];
            }
        }

        if (hasOwnProp(b, 'toString')) {
            a.toString = b.toString;
        }

        if (hasOwnProp(b, 'valueOf')) {
            a.valueOf = b.valueOf;
        }

        return a;
    }

    function createUTC (input, format, locale, strict) {
        return createLocalOrUTC(input, format, locale, strict, true).utc();
    }

    function defaultParsingFlags() {
        // We need to deep clone this object.
        return {
            empty           : false,
            unusedTokens    : [],
            unusedInput     : [],
            overflow        : -2,
            charsLeftOver   : 0,
            nullInput       : false,
            invalidMonth    : null,
            invalidFormat   : false,
            userInvalidated : false,
            iso             : false,
            parsedDateParts : [],
            meridiem        : null,
            rfc2822         : false,
            weekdayMismatch : false
        };
    }

    function getParsingFlags(m) {
        if (m._pf == null) {
            m._pf = defaultParsingFlags();
        }
        return m._pf;
    }

    var some;
    if (Array.prototype.some) {
        some = Array.prototype.some;
    } else {
        some = function (fun) {
            var t = Object(this);
            var len = t.length >>> 0;

            for (var i = 0; i < len; i++) {
                if (i in t && fun.call(this, t[i], i, t)) {
                    return true;
                }
            }

            return false;
        };
    }

    function isValid(m) {
        if (m._isValid == null) {
            var flags = getParsingFlags(m);
            var parsedParts = some.call(flags.parsedDateParts, function (i) {
                return i != null;
            });
            var isNowValid = !isNaN(m._d.getTime()) &&
                flags.overflow < 0 &&
                !flags.empty &&
                !flags.invalidMonth &&
                !flags.invalidWeekday &&
                !flags.weekdayMismatch &&
                !flags.nullInput &&
                !flags.invalidFormat &&
                !flags.userInvalidated &&
                (!flags.meridiem || (flags.meridiem && parsedParts));

            if (m._strict) {
                isNowValid = isNowValid &&
                    flags.charsLeftOver === 0 &&
                    flags.unusedTokens.length === 0 &&
                    flags.bigHour === undefined;
            }

            if (Object.isFrozen == null || !Object.isFrozen(m)) {
                m._isValid = isNowValid;
            }
            else {
                return isNowValid;
            }
        }
        return m._isValid;
    }

    function createInvalid (flags) {
        var m = createUTC(NaN);
        if (flags != null) {
            extend(getParsingFlags(m), flags);
        }
        else {
            getParsingFlags(m).userInvalidated = true;
        }

        return m;
    }

    // Plugins that add properties should also add the key here (null value),
    // so we can properly clone ourselves.
    var momentProperties = hooks.momentProperties = [];

    function copyConfig(to, from) {
        var i, prop, val;

        if (!isUndefined(from._isAMomentObject)) {
            to._isAMomentObject = from._isAMomentObject;
        }
        if (!isUndefined(from._i)) {
            to._i = from._i;
        }
        if (!isUndefined(from._f)) {
            to._f = from._f;
        }
        if (!isUndefined(from._l)) {
            to._l = from._l;
        }
        if (!isUndefined(from._strict)) {
            to._strict = from._strict;
        }
        if (!isUndefined(from._tzm)) {
            to._tzm = from._tzm;
        }
        if (!isUndefined(from._isUTC)) {
            to._isUTC = from._isUTC;
        }
        if (!isUndefined(from._offset)) {
            to._offset = from._offset;
        }
        if (!isUndefined(from._pf)) {
            to._pf = getParsingFlags(from);
        }
        if (!isUndefined(from._locale)) {
            to._locale = from._locale;
        }

        if (momentProperties.length > 0) {
            for (i = 0; i < momentProperties.length; i++) {
                prop = momentProperties[i];
                val = from[prop];
                if (!isUndefined(val)) {
                    to[prop] = val;
                }
            }
        }

        return to;
    }

    var updateInProgress = false;

    // Moment prototype object
    function Moment(config) {
        copyConfig(this, config);
        this._d = new Date(config._d != null ? config._d.getTime() : NaN);
        if (!this.isValid()) {
            this._d = new Date(NaN);
        }
        // Prevent infinite loop in case updateOffset creates new moment
        // objects.
        if (updateInProgress === false) {
            updateInProgress = true;
            hooks.updateOffset(this);
            updateInProgress = false;
        }
    }

    function isMoment (obj) {
        return obj instanceof Moment || (obj != null && obj._isAMomentObject != null);
    }

    function absFloor (number) {
        if (number < 0) {
            // -0 -> 0
            return Math.ceil(number) || 0;
        } else {
            return Math.floor(number);
        }
    }

    function toInt(argumentForCoercion) {
        var coercedNumber = +argumentForCoercion,
            value = 0;

        if (coercedNumber !== 0 && isFinite(coercedNumber)) {
            value = absFloor(coercedNumber);
        }

        return value;
    }

    // compare two arrays, return the number of differences
    function compareArrays(array1, array2, dontConvert) {
        var len = Math.min(array1.length, array2.length),
            lengthDiff = Math.abs(array1.length - array2.length),
            diffs = 0,
            i;
        for (i = 0; i < len; i++) {
            if ((dontConvert && array1[i] !== array2[i]) ||
                (!dontConvert && toInt(array1[i]) !== toInt(array2[i]))) {
                diffs++;
            }
        }
        return diffs + lengthDiff;
    }

    function warn(msg) {
        if (hooks.suppressDeprecationWarnings === false &&
                (typeof console !==  'undefined') && console.warn) {
            console.warn('Deprecation warning: ' + msg);
        }
    }

    function deprecate(msg, fn) {
        var firstTime = true;

        return extend(function () {
            if (hooks.deprecationHandler != null) {
                hooks.deprecationHandler(null, msg);
            }
            if (firstTime) {
                var args = [];
                var arg;
                for (var i = 0; i < arguments.length; i++) {
                    arg = '';
                    if (typeof arguments[i] === 'object') {
                        arg += '\n[' + i + '] ';
                        for (var key in arguments[0]) {
                            arg += key + ': ' + arguments[0][key] + ', ';
                        }
                        arg = arg.slice(0, -2); // Remove trailing comma and space
                    } else {
                        arg = arguments[i];
                    }
                    args.push(arg);
                }
                warn(msg + '\nArguments: ' + Array.prototype.slice.call(args).join('') + '\n' + (new Error()).stack);
                firstTime = false;
            }
            return fn.apply(this, arguments);
        }, fn);
    }

    var deprecations = {};

    function deprecateSimple(name, msg) {
        if (hooks.deprecationHandler != null) {
            hooks.deprecationHandler(name, msg);
        }
        if (!deprecations[name]) {
            warn(msg);
            deprecations[name] = true;
        }
    }

    hooks.suppressDeprecationWarnings = false;
    hooks.deprecationHandler = null;

    function isFunction(input) {
        return input instanceof Function || Object.prototype.toString.call(input) === '[object Function]';
    }

    function set (config) {
        var prop, i;
        for (i in config) {
            prop = config[i];
            if (isFunction(prop)) {
                this[i] = prop;
            } else {
                this['_' + i] = prop;
            }
        }
        this._config = config;
        // Lenient ordinal parsing accepts just a number in addition to
        // number + (possibly) stuff coming from _dayOfMonthOrdinalParse.
        // TODO: Remove "ordinalParse" fallback in next major release.
        this._dayOfMonthOrdinalParseLenient = new RegExp(
            (this._dayOfMonthOrdinalParse.source || this._ordinalParse.source) +
                '|' + (/\d{1,2}/).source);
    }

    function mergeConfigs(parentConfig, childConfig) {
        var res = extend({}, parentConfig), prop;
        for (prop in childConfig) {
            if (hasOwnProp(childConfig, prop)) {
                if (isObject(parentConfig[prop]) && isObject(childConfig[prop])) {
                    res[prop] = {};
                    extend(res[prop], parentConfig[prop]);
                    extend(res[prop], childConfig[prop]);
                } else if (childConfig[prop] != null) {
                    res[prop] = childConfig[prop];
                } else {
                    delete res[prop];
                }
            }
        }
        for (prop in parentConfig) {
            if (hasOwnProp(parentConfig, prop) &&
                    !hasOwnProp(childConfig, prop) &&
                    isObject(parentConfig[prop])) {
                // make sure changes to properties don't modify parent config
                res[prop] = extend({}, res[prop]);
            }
        }
        return res;
    }

    function Locale(config) {
        if (config != null) {
            this.set(config);
        }
    }

    var keys;

    if (Object.keys) {
        keys = Object.keys;
    } else {
        keys = function (obj) {
            var i, res = [];
            for (i in obj) {
                if (hasOwnProp(obj, i)) {
                    res.push(i);
                }
            }
            return res;
        };
    }

    var defaultCalendar = {
        sameDay : '[Today at] LT',
        nextDay : '[Tomorrow at] LT',
        nextWeek : 'dddd [at] LT',
        lastDay : '[Yesterday at] LT',
        lastWeek : '[Last] dddd [at] LT',
        sameElse : 'L'
    };

    function calendar (key, mom, now) {
        var output = this._calendar[key] || this._calendar['sameElse'];
        return isFunction(output) ? output.call(mom, now) : output;
    }

    var defaultLongDateFormat = {
        LTS  : 'h:mm:ss A',
        LT   : 'h:mm A',
        L    : 'MM/DD/YYYY',
        LL   : 'MMMM D, YYYY',
        LLL  : 'MMMM D, YYYY h:mm A',
        LLLL : 'dddd, MMMM D, YYYY h:mm A'
    };

    function longDateFormat (key) {
        var format = this._longDateFormat[key],
            formatUpper = this._longDateFormat[key.toUpperCase()];

        if (format || !formatUpper) {
            return format;
        }

        this._longDateFormat[key] = formatUpper.replace(/MMMM|MM|DD|dddd/g, function (val) {
            return val.slice(1);
        });

        return this._longDateFormat[key];
    }

    var defaultInvalidDate = 'Invalid date';

    function invalidDate () {
        return this._invalidDate;
    }

    var defaultOrdinal = '%d';
    var defaultDayOfMonthOrdinalParse = /\d{1,2}/;

    function ordinal (number) {
        return this._ordinal.replace('%d', number);
    }

    var defaultRelativeTime = {
        future : 'in %s',
        past   : '%s ago',
        s  : 'a few seconds',
        ss : '%d seconds',
        m  : 'a minute',
        mm : '%d minutes',
        h  : 'an hour',
        hh : '%d hours',
        d  : 'a day',
        dd : '%d days',
        M  : 'a month',
        MM : '%d months',
        y  : 'a year',
        yy : '%d years'
    };

    function relativeTime (number, withoutSuffix, string, isFuture) {
        var output = this._relativeTime[string];
        return (isFunction(output)) ?
            output(number, withoutSuffix, string, isFuture) :
            output.replace(/%d/i, number);
    }

    function pastFuture (diff, output) {
        var format = this._relativeTime[diff > 0 ? 'future' : 'past'];
        return isFunction(format) ? format(output) : format.replace(/%s/i, output);
    }

    var aliases = {};

    function addUnitAlias (unit, shorthand) {
        var lowerCase = unit.toLowerCase();
        aliases[lowerCase] = aliases[lowerCase + 's'] = aliases[shorthand] = unit;
    }

    function normalizeUnits(units) {
        return typeof units === 'string' ? aliases[units] || aliases[units.toLowerCase()] : undefined;
    }

    function normalizeObjectUnits(inputObject) {
        var normalizedInput = {},
            normalizedProp,
            prop;

        for (prop in inputObject) {
            if (hasOwnProp(inputObject, prop)) {
                normalizedProp = normalizeUnits(prop);
                if (normalizedProp) {
                    normalizedInput[normalizedProp] = inputObject[prop];
                }
            }
        }

        return normalizedInput;
    }

    var priorities = {};

    function addUnitPriority(unit, priority) {
        priorities[unit] = priority;
    }

    function getPrioritizedUnits(unitsObj) {
        var units = [];
        for (var u in unitsObj) {
            units.push({unit: u, priority: priorities[u]});
        }
        units.sort(function (a, b) {
            return a.priority - b.priority;
        });
        return units;
    }

    function zeroFill(number, targetLength, forceSign) {
        var absNumber = '' + Math.abs(number),
            zerosToFill = targetLength - absNumber.length,
            sign = number >= 0;
        return (sign ? (forceSign ? '+' : '') : '-') +
            Math.pow(10, Math.max(0, zerosToFill)).toString().substr(1) + absNumber;
    }

    var formattingTokens = /(\[[^\[]*\])|(\\)?([Hh]mm(ss)?|Mo|MM?M?M?|Do|DDDo|DD?D?D?|ddd?d?|do?|w[o|w]?|W[o|W]?|Qo?|YYYYYY|YYYYY|YYYY|YY|gg(ggg?)?|GG(GGG?)?|e|E|a|A|hh?|HH?|kk?|mm?|ss?|S{1,9}|x|X|zz?|ZZ?|.)/g;

    var localFormattingTokens = /(\[[^\[]*\])|(\\)?(LTS|LT|LL?L?L?|l{1,4})/g;

    var formatFunctions = {};

    var formatTokenFunctions = {};

    // token:    'M'
    // padded:   ['MM', 2]
    // ordinal:  'Mo'
    // callback: function () { this.month() + 1 }
    function addFormatToken (token, padded, ordinal, callback) {
        var func = callback;
        if (typeof callback === 'string') {
            func = function () {
                return this[callback]();
            };
        }
        if (token) {
            formatTokenFunctions[token] = func;
        }
        if (padded) {
            formatTokenFunctions[padded[0]] = function () {
                return zeroFill(func.apply(this, arguments), padded[1], padded[2]);
            };
        }
        if (ordinal) {
            formatTokenFunctions[ordinal] = function () {
                return this.localeData().ordinal(func.apply(this, arguments), token);
            };
        }
    }

    function removeFormattingTokens(input) {
        if (input.match(/\[[\s\S]/)) {
            return input.replace(/^\[|\]$/g, '');
        }
        return input.replace(/\\/g, '');
    }

    function makeFormatFunction(format) {
        var array = format.match(formattingTokens), i, length;

        for (i = 0, length = array.length; i < length; i++) {
            if (formatTokenFunctions[array[i]]) {
                array[i] = formatTokenFunctions[array[i]];
            } else {
                array[i] = removeFormattingTokens(array[i]);
            }
        }

        return function (mom) {
            var output = '', i;
            for (i = 0; i < length; i++) {
                output += isFunction(array[i]) ? array[i].call(mom, format) : array[i];
            }
            return output;
        };
    }

    // format date using native date object
    function formatMoment(m, format) {
        if (!m.isValid()) {
            return m.localeData().invalidDate();
        }

        format = expandFormat(format, m.localeData());
        formatFunctions[format] = formatFunctions[format] || makeFormatFunction(format);

        return formatFunctions[format](m);
    }

    function expandFormat(format, locale) {
        var i = 5;

        function replaceLongDateFormatTokens(input) {
            return locale.longDateFormat(input) || input;
        }

        localFormattingTokens.lastIndex = 0;
        while (i >= 0 && localFormattingTokens.test(format)) {
            format = format.replace(localFormattingTokens, replaceLongDateFormatTokens);
            localFormattingTokens.lastIndex = 0;
            i -= 1;
        }

        return format;
    }

    var match1         = /\d/;            //       0 - 9
    var match2         = /\d\d/;          //      00 - 99
    var match3         = /\d{3}/;         //     000 - 999
    var match4         = /\d{4}/;         //    0000 - 9999
    var match6         = /[+-]?\d{6}/;    // -999999 - 999999
    var match1to2      = /\d\d?/;         //       0 - 99
    var match3to4      = /\d\d\d\d?/;     //     999 - 9999
    var match5to6      = /\d\d\d\d\d\d?/; //   99999 - 999999
    var match1to3      = /\d{1,3}/;       //       0 - 999
    var match1to4      = /\d{1,4}/;       //       0 - 9999
    var match1to6      = /[+-]?\d{1,6}/;  // -999999 - 999999

    var matchUnsigned  = /\d+/;           //       0 - inf
    var matchSigned    = /[+-]?\d+/;      //    -inf - inf

    var matchOffset    = /Z|[+-]\d\d:?\d\d/gi; // +00:00 -00:00 +0000 -0000 or Z
    var matchShortOffset = /Z|[+-]\d\d(?::?\d\d)?/gi; // +00 -00 +00:00 -00:00 +0000 -0000 or Z

    var matchTimestamp = /[+-]?\d+(\.\d{1,3})?/; // 123456789 123456789.123

    // any word (or two) characters or numbers including two/three word month in arabic.
    // includes scottish gaelic two word and hyphenated months
    var matchWord = /[0-9]{0,256}['a-z\u00A0-\u05FF\u0700-\uD7FF\uF900-\uFDCF\uFDF0-\uFF07\uFF10-\uFFEF]{1,256}|[\u0600-\u06FF\/]{1,256}(\s*?[\u0600-\u06FF]{1,256}){1,2}/i;

    var regexes = {};

    function addRegexToken (token, regex, strictRegex) {
        regexes[token] = isFunction(regex) ? regex : function (isStrict, localeData) {
            return (isStrict && strictRegex) ? strictRegex : regex;
        };
    }

    function getParseRegexForToken (token, config) {
        if (!hasOwnProp(regexes, token)) {
            return new RegExp(unescapeFormat(token));
        }

        return regexes[token](config._strict, config._locale);
    }

    // Code from http://stackoverflow.com/questions/3561493/is-there-a-regexp-escape-function-in-javascript
    function unescapeFormat(s) {
        return regexEscape(s.replace('\\', '').replace(/\\(\[)|\\(\])|\[([^\]\[]*)\]|\\(.)/g, function (matched, p1, p2, p3, p4) {
            return p1 || p2 || p3 || p4;
        }));
    }

    function regexEscape(s) {
        return s.replace(/[-\/\\^$*+?.()|[\]{}]/g, '\\$&');
    }

    var tokens = {};

    function addParseToken (token, callback) {
        var i, func = callback;
        if (typeof token === 'string') {
            token = [token];
        }
        if (isNumber(callback)) {
            func = function (input, array) {
                array[callback] = toInt(input);
            };
        }
        for (i = 0; i < token.length; i++) {
            tokens[token[i]] = func;
        }
    }

    function addWeekParseToken (token, callback) {
        addParseToken(token, function (input, array, config, token) {
            config._w = config._w || {};
            callback(input, config._w, config, token);
        });
    }

    function addTimeToArrayFromToken(token, input, config) {
        if (input != null && hasOwnProp(tokens, token)) {
            tokens[token](input, config._a, config, token);
        }
    }

    var YEAR = 0;
    var MONTH = 1;
    var DATE = 2;
    var HOUR = 3;
    var MINUTE = 4;
    var SECOND = 5;
    var MILLISECOND = 6;
    var WEEK = 7;
    var WEEKDAY = 8;

    // FORMATTING

    addFormatToken('Y', 0, 0, function () {
        var y = this.year();
        return y <= 9999 ? '' + y : '+' + y;
    });

    addFormatToken(0, ['YY', 2], 0, function () {
        return this.year() % 100;
    });

    addFormatToken(0, ['YYYY',   4],       0, 'year');
    addFormatToken(0, ['YYYYY',  5],       0, 'year');
    addFormatToken(0, ['YYYYYY', 6, true], 0, 'year');

    // ALIASES

    addUnitAlias('year', 'y');

    // PRIORITIES

    addUnitPriority('year', 1);

    // PARSING

    addRegexToken('Y',      matchSigned);
    addRegexToken('YY',     match1to2, match2);
    addRegexToken('YYYY',   match1to4, match4);
    addRegexToken('YYYYY',  match1to6, match6);
    addRegexToken('YYYYYY', match1to6, match6);

    addParseToken(['YYYYY', 'YYYYYY'], YEAR);
    addParseToken('YYYY', function (input, array) {
        array[YEAR] = input.length === 2 ? hooks.parseTwoDigitYear(input) : toInt(input);
    });
    addParseToken('YY', function (input, array) {
        array[YEAR] = hooks.parseTwoDigitYear(input);
    });
    addParseToken('Y', function (input, array) {
        array[YEAR] = parseInt(input, 10);
    });

    // HELPERS

    function daysInYear(year) {
        return isLeapYear(year) ? 366 : 365;
    }

    function isLeapYear(year) {
        return (year % 4 === 0 && year % 100 !== 0) || year % 400 === 0;
    }

    // HOOKS

    hooks.parseTwoDigitYear = function (input) {
        return toInt(input) + (toInt(input) > 68 ? 1900 : 2000);
    };

    // MOMENTS

    var getSetYear = makeGetSet('FullYear', true);

    function getIsLeapYear () {
        return isLeapYear(this.year());
    }

    function makeGetSet (unit, keepTime) {
        return function (value) {
            if (value != null) {
                set$1(this, unit, value);
                hooks.updateOffset(this, keepTime);
                return this;
            } else {
                return get(this, unit);
            }
        };
    }

    function get (mom, unit) {
        return mom.isValid() ?
            mom._d['get' + (mom._isUTC ? 'UTC' : '') + unit]() : NaN;
    }

    function set$1 (mom, unit, value) {
        if (mom.isValid() && !isNaN(value)) {
            if (unit === 'FullYear' && isLeapYear(mom.year()) && mom.month() === 1 && mom.date() === 29) {
                mom._d['set' + (mom._isUTC ? 'UTC' : '') + unit](value, mom.month(), daysInMonth(value, mom.month()));
            }
            else {
                mom._d['set' + (mom._isUTC ? 'UTC' : '') + unit](value);
            }
        }
    }

    // MOMENTS

    function stringGet (units) {
        units = normalizeUnits(units);
        if (isFunction(this[units])) {
            return this[units]();
        }
        return this;
    }


    function stringSet (units, value) {
        if (typeof units === 'object') {
            units = normalizeObjectUnits(units);
            var prioritized = getPrioritizedUnits(units);
            for (var i = 0; i < prioritized.length; i++) {
                this[prioritized[i].unit](units[prioritized[i].unit]);
            }
        } else {
            units = normalizeUnits(units);
            if (isFunction(this[units])) {
                return this[units](value);
            }
        }
        return this;
    }

    function mod(n, x) {
        return ((n % x) + x) % x;
    }

    var indexOf;

    if (Array.prototype.indexOf) {
        indexOf = Array.prototype.indexOf;
    } else {
        indexOf = function (o) {
            // I know
            var i;
            for (i = 0; i < this.length; ++i) {
                if (this[i] === o) {
                    return i;
                }
            }
            return -1;
        };
    }

    function daysInMonth(year, month) {
        if (isNaN(year) || isNaN(month)) {
            return NaN;
        }
        var modMonth = mod(month, 12);
        year += (month - modMonth) / 12;
        return modMonth === 1 ? (isLeapYear(year) ? 29 : 28) : (31 - modMonth % 7 % 2);
    }

    // FORMATTING

    addFormatToken('M', ['MM', 2], 'Mo', function () {
        return this.month() + 1;
    });

    addFormatToken('MMM', 0, 0, function (format) {
        return this.localeData().monthsShort(this, format);
    });

    addFormatToken('MMMM', 0, 0, function (format) {
        return this.localeData().months(this, format);
    });

    // ALIASES

    addUnitAlias('month', 'M');

    // PRIORITY

    addUnitPriority('month', 8);

    // PARSING

    addRegexToken('M',    match1to2);
    addRegexToken('MM',   match1to2, match2);
    addRegexToken('MMM',  function (isStrict, locale) {
        return locale.monthsShortRegex(isStrict);
    });
    addRegexToken('MMMM', function (isStrict, locale) {
        return locale.monthsRegex(isStrict);
    });

    addParseToken(['M', 'MM'], function (input, array) {
        array[MONTH] = toInt(input) - 1;
    });

    addParseToken(['MMM', 'MMMM'], function (input, array, config, token) {
        var month = config._locale.monthsParse(input, token, config._strict);
        // if we didn't find a month name, mark the date as invalid.
        if (month != null) {
            array[MONTH] = month;
        } else {
            getParsingFlags(config).invalidMonth = input;
        }
    });

    // LOCALES

    var MONTHS_IN_FORMAT = /D[oD]?(\[[^\[\]]*\]|\s)+MMMM?/;
    var defaultLocaleMonths = 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_');
    function localeMonths (m, format) {
        if (!m) {
            return isArray(this._months) ? this._months :
                this._months['standalone'];
        }
        return isArray(this._months) ? this._months[m.month()] :
            this._months[(this._months.isFormat || MONTHS_IN_FORMAT).test(format) ? 'format' : 'standalone'][m.month()];
    }

    var defaultLocaleMonthsShort = 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_');
    function localeMonthsShort (m, format) {
        if (!m) {
            return isArray(this._monthsShort) ? this._monthsShort :
                this._monthsShort['standalone'];
        }
        return isArray(this._monthsShort) ? this._monthsShort[m.month()] :
            this._monthsShort[MONTHS_IN_FORMAT.test(format) ? 'format' : 'standalone'][m.month()];
    }

    function handleStrictParse(monthName, format, strict) {
        var i, ii, mom, llc = monthName.toLocaleLowerCase();
        if (!this._monthsParse) {
            // this is not used
            this._monthsParse = [];
            this._longMonthsParse = [];
            this._shortMonthsParse = [];
            for (i = 0; i < 12; ++i) {
                mom = createUTC([2000, i]);
                this._shortMonthsParse[i] = this.monthsShort(mom, '').toLocaleLowerCase();
                this._longMonthsParse[i] = this.months(mom, '').toLocaleLowerCase();
            }
        }

        if (strict) {
            if (format === 'MMM') {
                ii = indexOf.call(this._shortMonthsParse, llc);
                return ii !== -1 ? ii : null;
            } else {
                ii = indexOf.call(this._longMonthsParse, llc);
                return ii !== -1 ? ii : null;
            }
        } else {
            if (format === 'MMM') {
                ii = indexOf.call(this._shortMonthsParse, llc);
                if (ii !== -1) {
                    return ii;
                }
                ii = indexOf.call(this._longMonthsParse, llc);
                return ii !== -1 ? ii : null;
            } else {
                ii = indexOf.call(this._longMonthsParse, llc);
                if (ii !== -1) {
                    return ii;
                }
                ii = indexOf.call(this._shortMonthsParse, llc);
                return ii !== -1 ? ii : null;
            }
        }
    }

    function localeMonthsParse (monthName, format, strict) {
        var i, mom, regex;

        if (this._monthsParseExact) {
            return handleStrictParse.call(this, monthName, format, strict);
        }

        if (!this._monthsParse) {
            this._monthsParse = [];
            this._longMonthsParse = [];
            this._shortMonthsParse = [];
        }

        // TODO: add sorting
        // Sorting makes sure if one month (or abbr) is a prefix of another
        // see sorting in computeMonthsParse
        for (i = 0; i < 12; i++) {
            // make the regex if we don't have it already
            mom = createUTC([2000, i]);
            if (strict && !this._longMonthsParse[i]) {
                this._longMonthsParse[i] = new RegExp('^' + this.months(mom, '').replace('.', '') + '$', 'i');
                this._shortMonthsParse[i] = new RegExp('^' + this.monthsShort(mom, '').replace('.', '') + '$', 'i');
            }
            if (!strict && !this._monthsParse[i]) {
                regex = '^' + this.months(mom, '') + '|^' + this.monthsShort(mom, '');
                this._monthsParse[i] = new RegExp(regex.replace('.', ''), 'i');
            }
            // test the regex
            if (strict && format === 'MMMM' && this._longMonthsParse[i].test(monthName)) {
                return i;
            } else if (strict && format === 'MMM' && this._shortMonthsParse[i].test(monthName)) {
                return i;
            } else if (!strict && this._monthsParse[i].test(monthName)) {
                return i;
            }
        }
    }

    // MOMENTS

    function setMonth (mom, value) {
        var dayOfMonth;

        if (!mom.isValid()) {
            // No op
            return mom;
        }

        if (typeof value === 'string') {
            if (/^\d+$/.test(value)) {
                value = toInt(value);
            } else {
                value = mom.localeData().monthsParse(value);
                // TODO: Another silent failure?
                if (!isNumber(value)) {
                    return mom;
                }
            }
        }

        dayOfMonth = Math.min(mom.date(), daysInMonth(mom.year(), value));
        mom._d['set' + (mom._isUTC ? 'UTC' : '') + 'Month'](value, dayOfMonth);
        return mom;
    }

    function getSetMonth (value) {
        if (value != null) {
            setMonth(this, value);
            hooks.updateOffset(this, true);
            return this;
        } else {
            return get(this, 'Month');
        }
    }

    function getDaysInMonth () {
        return daysInMonth(this.year(), this.month());
    }

    var defaultMonthsShortRegex = matchWord;
    function monthsShortRegex (isStrict) {
        if (this._monthsParseExact) {
            if (!hasOwnProp(this, '_monthsRegex')) {
                computeMonthsParse.call(this);
            }
            if (isStrict) {
                return this._monthsShortStrictRegex;
            } else {
                return this._monthsShortRegex;
            }
        } else {
            if (!hasOwnProp(this, '_monthsShortRegex')) {
                this._monthsShortRegex = defaultMonthsShortRegex;
            }
            return this._monthsShortStrictRegex && isStrict ?
                this._monthsShortStrictRegex : this._monthsShortRegex;
        }
    }

    var defaultMonthsRegex = matchWord;
    function monthsRegex (isStrict) {
        if (this._monthsParseExact) {
            if (!hasOwnProp(this, '_monthsRegex')) {
                computeMonthsParse.call(this);
            }
            if (isStrict) {
                return this._monthsStrictRegex;
            } else {
                return this._monthsRegex;
            }
        } else {
            if (!hasOwnProp(this, '_monthsRegex')) {
                this._monthsRegex = defaultMonthsRegex;
            }
            return this._monthsStrictRegex && isStrict ?
                this._monthsStrictRegex : this._monthsRegex;
        }
    }

    function computeMonthsParse () {
        function cmpLenRev(a, b) {
            return b.length - a.length;
        }

        var shortPieces = [], longPieces = [], mixedPieces = [],
            i, mom;
        for (i = 0; i < 12; i++) {
            // make the regex if we don't have it already
            mom = createUTC([2000, i]);
            shortPieces.push(this.monthsShort(mom, ''));
            longPieces.push(this.months(mom, ''));
            mixedPieces.push(this.months(mom, ''));
            mixedPieces.push(this.monthsShort(mom, ''));
        }
        // Sorting makes sure if one month (or abbr) is a prefix of another it
        // will match the longer piece.
        shortPieces.sort(cmpLenRev);
        longPieces.sort(cmpLenRev);
        mixedPieces.sort(cmpLenRev);
        for (i = 0; i < 12; i++) {
            shortPieces[i] = regexEscape(shortPieces[i]);
            longPieces[i] = regexEscape(longPieces[i]);
        }
        for (i = 0; i < 24; i++) {
            mixedPieces[i] = regexEscape(mixedPieces[i]);
        }

        this._monthsRegex = new RegExp('^(' + mixedPieces.join('|') + ')', 'i');
        this._monthsShortRegex = this._monthsRegex;
        this._monthsStrictRegex = new RegExp('^(' + longPieces.join('|') + ')', 'i');
        this._monthsShortStrictRegex = new RegExp('^(' + shortPieces.join('|') + ')', 'i');
    }

    function createDate (y, m, d, h, M, s, ms) {
        // can't just apply() to create a date:
        // https://stackoverflow.com/q/181348
        var date;
        // the date constructor remaps years 0-99 to 1900-1999
        if (y < 100 && y >= 0) {
            // preserve leap years using a full 400 year cycle, then reset
            date = new Date(y + 400, m, d, h, M, s, ms);
            if (isFinite(date.getFullYear())) {
                date.setFullYear(y);
            }
        } else {
            date = new Date(y, m, d, h, M, s, ms);
        }

        return date;
    }

    function createUTCDate (y) {
        var date;
        // the Date.UTC function remaps years 0-99 to 1900-1999
        if (y < 100 && y >= 0) {
            var args = Array.prototype.slice.call(arguments);
            // preserve leap years using a full 400 year cycle, then reset
            args[0] = y + 400;
            date = new Date(Date.UTC.apply(null, args));
            if (isFinite(date.getUTCFullYear())) {
                date.setUTCFullYear(y);
            }
        } else {
            date = new Date(Date.UTC.apply(null, arguments));
        }

        return date;
    }

    // start-of-first-week - start-of-year
    function firstWeekOffset(year, dow, doy) {
        var // first-week day -- which january is always in the first week (4 for iso, 1 for other)
            fwd = 7 + dow - doy,
            // first-week day local weekday -- which local weekday is fwd
            fwdlw = (7 + createUTCDate(year, 0, fwd).getUTCDay() - dow) % 7;

        return -fwdlw + fwd - 1;
    }

    // https://en.wikipedia.org/wiki/ISO_week_date#Calculating_a_date_given_the_year.2C_week_number_and_weekday
    function dayOfYearFromWeeks(year, week, weekday, dow, doy) {
        var localWeekday = (7 + weekday - dow) % 7,
            weekOffset = firstWeekOffset(year, dow, doy),
            dayOfYear = 1 + 7 * (week - 1) + localWeekday + weekOffset,
            resYear, resDayOfYear;

        if (dayOfYear <= 0) {
            resYear = year - 1;
            resDayOfYear = daysInYear(resYear) + dayOfYear;
        } else if (dayOfYear > daysInYear(year)) {
            resYear = year + 1;
            resDayOfYear = dayOfYear - daysInYear(year);
        } else {
            resYear = year;
            resDayOfYear = dayOfYear;
        }

        return {
            year: resYear,
            dayOfYear: resDayOfYear
        };
    }

    function weekOfYear(mom, dow, doy) {
        var weekOffset = firstWeekOffset(mom.year(), dow, doy),
            week = Math.floor((mom.dayOfYear() - weekOffset - 1) / 7) + 1,
            resWeek, resYear;

        if (week < 1) {
            resYear = mom.year() - 1;
            resWeek = week + weeksInYear(resYear, dow, doy);
        } else if (week > weeksInYear(mom.year(), dow, doy)) {
            resWeek = week - weeksInYear(mom.year(), dow, doy);
            resYear = mom.year() + 1;
        } else {
            resYear = mom.year();
            resWeek = week;
        }

        return {
            week: resWeek,
            year: resYear
        };
    }

    function weeksInYear(year, dow, doy) {
        var weekOffset = firstWeekOffset(year, dow, doy),
            weekOffsetNext = firstWeekOffset(year + 1, dow, doy);
        return (daysInYear(year) - weekOffset + weekOffsetNext) / 7;
    }

    // FORMATTING

    addFormatToken('w', ['ww', 2], 'wo', 'week');
    addFormatToken('W', ['WW', 2], 'Wo', 'isoWeek');

    // ALIASES

    addUnitAlias('week', 'w');
    addUnitAlias('isoWeek', 'W');

    // PRIORITIES

    addUnitPriority('week', 5);
    addUnitPriority('isoWeek', 5);

    // PARSING

    addRegexToken('w',  match1to2);
    addRegexToken('ww', match1to2, match2);
    addRegexToken('W',  match1to2);
    addRegexToken('WW', match1to2, match2);

    addWeekParseToken(['w', 'ww', 'W', 'WW'], function (input, week, config, token) {
        week[token.substr(0, 1)] = toInt(input);
    });

    // HELPERS

    // LOCALES

    function localeWeek (mom) {
        return weekOfYear(mom, this._week.dow, this._week.doy).week;
    }

    var defaultLocaleWeek = {
        dow : 0, // Sunday is the first day of the week.
        doy : 6  // The week that contains Jan 6th is the first week of the year.
    };

    function localeFirstDayOfWeek () {
        return this._week.dow;
    }

    function localeFirstDayOfYear () {
        return this._week.doy;
    }

    // MOMENTS

    function getSetWeek (input) {
        var week = this.localeData().week(this);
        return input == null ? week : this.add((input - week) * 7, 'd');
    }

    function getSetISOWeek (input) {
        var week = weekOfYear(this, 1, 4).week;
        return input == null ? week : this.add((input - week) * 7, 'd');
    }

    // FORMATTING

    addFormatToken('d', 0, 'do', 'day');

    addFormatToken('dd', 0, 0, function (format) {
        return this.localeData().weekdaysMin(this, format);
    });

    addFormatToken('ddd', 0, 0, function (format) {
        return this.localeData().weekdaysShort(this, format);
    });

    addFormatToken('dddd', 0, 0, function (format) {
        return this.localeData().weekdays(this, format);
    });

    addFormatToken('e', 0, 0, 'weekday');
    addFormatToken('E', 0, 0, 'isoWeekday');

    // ALIASES

    addUnitAlias('day', 'd');
    addUnitAlias('weekday', 'e');
    addUnitAlias('isoWeekday', 'E');

    // PRIORITY
    addUnitPriority('day', 11);
    addUnitPriority('weekday', 11);
    addUnitPriority('isoWeekday', 11);

    // PARSING

    addRegexToken('d',    match1to2);
    addRegexToken('e',    match1to2);
    addRegexToken('E',    match1to2);
    addRegexToken('dd',   function (isStrict, locale) {
        return locale.weekdaysMinRegex(isStrict);
    });
    addRegexToken('ddd',   function (isStrict, locale) {
        return locale.weekdaysShortRegex(isStrict);
    });
    addRegexToken('dddd',   function (isStrict, locale) {
        return locale.weekdaysRegex(isStrict);
    });

    addWeekParseToken(['dd', 'ddd', 'dddd'], function (input, week, config, token) {
        var weekday = config._locale.weekdaysParse(input, token, config._strict);
        // if we didn't get a weekday name, mark the date as invalid
        if (weekday != null) {
            week.d = weekday;
        } else {
            getParsingFlags(config).invalidWeekday = input;
        }
    });

    addWeekParseToken(['d', 'e', 'E'], function (input, week, config, token) {
        week[token] = toInt(input);
    });

    // HELPERS

    function parseWeekday(input, locale) {
        if (typeof input !== 'string') {
            return input;
        }

        if (!isNaN(input)) {
            return parseInt(input, 10);
        }

        input = locale.weekdaysParse(input);
        if (typeof input === 'number') {
            return input;
        }

        return null;
    }

    function parseIsoWeekday(input, locale) {
        if (typeof input === 'string') {
            return locale.weekdaysParse(input) % 7 || 7;
        }
        return isNaN(input) ? null : input;
    }

    // LOCALES
    function shiftWeekdays (ws, n) {
        return ws.slice(n, 7).concat(ws.slice(0, n));
    }

    var defaultLocaleWeekdays = 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_');
    function localeWeekdays (m, format) {
        var weekdays = isArray(this._weekdays) ? this._weekdays :
            this._weekdays[(m && m !== true && this._weekdays.isFormat.test(format)) ? 'format' : 'standalone'];
        return (m === true) ? shiftWeekdays(weekdays, this._week.dow)
            : (m) ? weekdays[m.day()] : weekdays;
    }

    var defaultLocaleWeekdaysShort = 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_');
    function localeWeekdaysShort (m) {
        return (m === true) ? shiftWeekdays(this._weekdaysShort, this._week.dow)
            : (m) ? this._weekdaysShort[m.day()] : this._weekdaysShort;
    }

    var defaultLocaleWeekdaysMin = 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_');
    function localeWeekdaysMin (m) {
        return (m === true) ? shiftWeekdays(this._weekdaysMin, this._week.dow)
            : (m) ? this._weekdaysMin[m.day()] : this._weekdaysMin;
    }

    function handleStrictParse$1(weekdayName, format, strict) {
        var i, ii, mom, llc = weekdayName.toLocaleLowerCase();
        if (!this._weekdaysParse) {
            this._weekdaysParse = [];
            this._shortWeekdaysParse = [];
            this._minWeekdaysParse = [];

            for (i = 0; i < 7; ++i) {
                mom = createUTC([2000, 1]).day(i);
                this._minWeekdaysParse[i] = this.weekdaysMin(mom, '').toLocaleLowerCase();
                this._shortWeekdaysParse[i] = this.weekdaysShort(mom, '').toLocaleLowerCase();
                this._weekdaysParse[i] = this.weekdays(mom, '').toLocaleLowerCase();
            }
        }

        if (strict) {
            if (format === 'dddd') {
                ii = indexOf.call(this._weekdaysParse, llc);
                return ii !== -1 ? ii : null;
            } else if (format === 'ddd') {
                ii = indexOf.call(this._shortWeekdaysParse, llc);
                return ii !== -1 ? ii : null;
            } else {
                ii = indexOf.call(this._minWeekdaysParse, llc);
                return ii !== -1 ? ii : null;
            }
        } else {
            if (format === 'dddd') {
                ii = indexOf.call(this._weekdaysParse, llc);
                if (ii !== -1) {
                    return ii;
                }
                ii = indexOf.call(this._shortWeekdaysParse, llc);
                if (ii !== -1) {
                    return ii;
                }
                ii = indexOf.call(this._minWeekdaysParse, llc);
                return ii !== -1 ? ii : null;
            } else if (format === 'ddd') {
                ii = indexOf.call(this._shortWeekdaysParse, llc);
                if (ii !== -1) {
                    return ii;
                }
                ii = indexOf.call(this._weekdaysParse, llc);
                if (ii !== -1) {
                    return ii;
                }
                ii = indexOf.call(this._minWeekdaysParse, llc);
                return ii !== -1 ? ii : null;
            } else {
                ii = indexOf.call(this._minWeekdaysParse, llc);
                if (ii !== -1) {
                    return ii;
                }
                ii = indexOf.call(this._weekdaysParse, llc);
                if (ii !== -1) {
                    return ii;
                }
                ii = indexOf.call(this._shortWeekdaysParse, llc);
                return ii !== -1 ? ii : null;
            }
        }
    }

    function localeWeekdaysParse (weekdayName, format, strict) {
        var i, mom, regex;

        if (this._weekdaysParseExact) {
            return handleStrictParse$1.call(this, weekdayName, format, strict);
        }

        if (!this._weekdaysParse) {
            this._weekdaysParse = [];
            this._minWeekdaysParse = [];
            this._shortWeekdaysParse = [];
            this._fullWeekdaysParse = [];
        }

        for (i = 0; i < 7; i++) {
            // make the regex if we don't have it already

            mom = createUTC([2000, 1]).day(i);
            if (strict && !this._fullWeekdaysParse[i]) {
                this._fullWeekdaysParse[i] = new RegExp('^' + this.weekdays(mom, '').replace('.', '\\.?') + '$', 'i');
                this._shortWeekdaysParse[i] = new RegExp('^' + this.weekdaysShort(mom, '').replace('.', '\\.?') + '$', 'i');
                this._minWeekdaysParse[i] = new RegExp('^' + this.weekdaysMin(mom, '').replace('.', '\\.?') + '$', 'i');
            }
            if (!this._weekdaysParse[i]) {
                regex = '^' + this.weekdays(mom, '') + '|^' + this.weekdaysShort(mom, '') + '|^' + this.weekdaysMin(mom, '');
                this._weekdaysParse[i] = new RegExp(regex.replace('.', ''), 'i');
            }
            // test the regex
            if (strict && format === 'dddd' && this._fullWeekdaysParse[i].test(weekdayName)) {
                return i;
            } else if (strict && format === 'ddd' && this._shortWeekdaysParse[i].test(weekdayName)) {
                return i;
            } else if (strict && format === 'dd' && this._minWeekdaysParse[i].test(weekdayName)) {
                return i;
            } else if (!strict && this._weekdaysParse[i].test(weekdayName)) {
                return i;
            }
        }
    }

    // MOMENTS

    function getSetDayOfWeek (input) {
        if (!this.isValid()) {
            return input != null ? this : NaN;
        }
        var day = this._isUTC ? this._d.getUTCDay() : this._d.getDay();
        if (input != null) {
            input = parseWeekday(input, this.localeData());
            return this.add(input - day, 'd');
        } else {
            return day;
        }
    }

    function getSetLocaleDayOfWeek (input) {
        if (!this.isValid()) {
            return input != null ? this : NaN;
        }
        var weekday = (this.day() + 7 - this.localeData()._week.dow) % 7;
        return input == null ? weekday : this.add(input - weekday, 'd');
    }

    function getSetISODayOfWeek (input) {
        if (!this.isValid()) {
            return input != null ? this : NaN;
        }

        // behaves the same as moment#day except
        // as a getter, returns 7 instead of 0 (1-7 range instead of 0-6)
        // as a setter, sunday should belong to the previous week.

        if (input != null) {
            var weekday = parseIsoWeekday(input, this.localeData());
            return this.day(this.day() % 7 ? weekday : weekday - 7);
        } else {
            return this.day() || 7;
        }
    }

    var defaultWeekdaysRegex = matchWord;
    function weekdaysRegex (isStrict) {
        if (this._weekdaysParseExact) {
            if (!hasOwnProp(this, '_weekdaysRegex')) {
                computeWeekdaysParse.call(this);
            }
            if (isStrict) {
                return this._weekdaysStrictRegex;
            } else {
                return this._weekdaysRegex;
            }
        } else {
            if (!hasOwnProp(this, '_weekdaysRegex')) {
                this._weekdaysRegex = defaultWeekdaysRegex;
            }
            return this._weekdaysStrictRegex && isStrict ?
                this._weekdaysStrictRegex : this._weekdaysRegex;
        }
    }

    var defaultWeekdaysShortRegex = matchWord;
    function weekdaysShortRegex (isStrict) {
        if (this._weekdaysParseExact) {
            if (!hasOwnProp(this, '_weekdaysRegex')) {
                computeWeekdaysParse.call(this);
            }
            if (isStrict) {
                return this._weekdaysShortStrictRegex;
            } else {
                return this._weekdaysShortRegex;
            }
        } else {
            if (!hasOwnProp(this, '_weekdaysShortRegex')) {
                this._weekdaysShortRegex = defaultWeekdaysShortRegex;
            }
            return this._weekdaysShortStrictRegex && isStrict ?
                this._weekdaysShortStrictRegex : this._weekdaysShortRegex;
        }
    }

    var defaultWeekdaysMinRegex = matchWord;
    function weekdaysMinRegex (isStrict) {
        if (this._weekdaysParseExact) {
            if (!hasOwnProp(this, '_weekdaysRegex')) {
                computeWeekdaysParse.call(this);
            }
            if (isStrict) {
                return this._weekdaysMinStrictRegex;
            } else {
                return this._weekdaysMinRegex;
            }
        } else {
            if (!hasOwnProp(this, '_weekdaysMinRegex')) {
                this._weekdaysMinRegex = defaultWeekdaysMinRegex;
            }
            return this._weekdaysMinStrictRegex && isStrict ?
                this._weekdaysMinStrictRegex : this._weekdaysMinRegex;
        }
    }


    function computeWeekdaysParse () {
        function cmpLenRev(a, b) {
            return b.length - a.length;
        }

        var minPieces = [], shortPieces = [], longPieces = [], mixedPieces = [],
            i, mom, minp, shortp, longp;
        for (i = 0; i < 7; i++) {
            // make the regex if we don't have it already
            mom = createUTC([2000, 1]).day(i);
            minp = this.weekdaysMin(mom, '');
            shortp = this.weekdaysShort(mom, '');
            longp = this.weekdays(mom, '');
            minPieces.push(minp);
            shortPieces.push(shortp);
            longPieces.push(longp);
            mixedPieces.push(minp);
            mixedPieces.push(shortp);
            mixedPieces.push(longp);
        }
        // Sorting makes sure if one weekday (or abbr) is a prefix of another it
        // will match the longer piece.
        minPieces.sort(cmpLenRev);
        shortPieces.sort(cmpLenRev);
        longPieces.sort(cmpLenRev);
        mixedPieces.sort(cmpLenRev);
        for (i = 0; i < 7; i++) {
            shortPieces[i] = regexEscape(shortPieces[i]);
            longPieces[i] = regexEscape(longPieces[i]);
            mixedPieces[i] = regexEscape(mixedPieces[i]);
        }

        this._weekdaysRegex = new RegExp('^(' + mixedPieces.join('|') + ')', 'i');
        this._weekdaysShortRegex = this._weekdaysRegex;
        this._weekdaysMinRegex = this._weekdaysRegex;

        this._weekdaysStrictRegex = new RegExp('^(' + longPieces.join('|') + ')', 'i');
        this._weekdaysShortStrictRegex = new RegExp('^(' + shortPieces.join('|') + ')', 'i');
        this._weekdaysMinStrictRegex = new RegExp('^(' + minPieces.join('|') + ')', 'i');
    }

    // FORMATTING

    function hFormat() {
        return this.hours() % 12 || 12;
    }

    function kFormat() {
        return this.hours() || 24;
    }

    addFormatToken('H', ['HH', 2], 0, 'hour');
    addFormatToken('h', ['hh', 2], 0, hFormat);
    addFormatToken('k', ['kk', 2], 0, kFormat);

    addFormatToken('hmm', 0, 0, function () {
        return '' + hFormat.apply(this) + zeroFill(this.minutes(), 2);
    });

    addFormatToken('hmmss', 0, 0, function () {
        return '' + hFormat.apply(this) + zeroFill(this.minutes(), 2) +
            zeroFill(this.seconds(), 2);
    });

    addFormatToken('Hmm', 0, 0, function () {
        return '' + this.hours() + zeroFill(this.minutes(), 2);
    });

    addFormatToken('Hmmss', 0, 0, function () {
        return '' + this.hours() + zeroFill(this.minutes(), 2) +
            zeroFill(this.seconds(), 2);
    });

    function meridiem (token, lowercase) {
        addFormatToken(token, 0, 0, function () {
            return this.localeData().meridiem(this.hours(), this.minutes(), lowercase);
        });
    }

    meridiem('a', true);
    meridiem('A', false);

    // ALIASES

    addUnitAlias('hour', 'h');

    // PRIORITY
    addUnitPriority('hour', 13);

    // PARSING

    function matchMeridiem (isStrict, locale) {
        return locale._meridiemParse;
    }

    addRegexToken('a',  matchMeridiem);
    addRegexToken('A',  matchMeridiem);
    addRegexToken('H',  match1to2);
    addRegexToken('h',  match1to2);
    addRegexToken('k',  match1to2);
    addRegexToken('HH', match1to2, match2);
    addRegexToken('hh', match1to2, match2);
    addRegexToken('kk', match1to2, match2);

    addRegexToken('hmm', match3to4);
    addRegexToken('hmmss', match5to6);
    addRegexToken('Hmm', match3to4);
    addRegexToken('Hmmss', match5to6);

    addParseToken(['H', 'HH'], HOUR);
    addParseToken(['k', 'kk'], function (input, array, config) {
        var kInput = toInt(input);
        array[HOUR] = kInput === 24 ? 0 : kInput;
    });
    addParseToken(['a', 'A'], function (input, array, config) {
        config._isPm = config._locale.isPM(input);
        config._meridiem = input;
    });
    addParseToken(['h', 'hh'], function (input, array, config) {
        array[HOUR] = toInt(input);
        getParsingFlags(config).bigHour = true;
    });
    addParseToken('hmm', function (input, array, config) {
        var pos = input.length - 2;
        array[HOUR] = toInt(input.substr(0, pos));
        array[MINUTE] = toInt(input.substr(pos));
        getParsingFlags(config).bigHour = true;
    });
    addParseToken('hmmss', function (input, array, config) {
        var pos1 = input.length - 4;
        var pos2 = input.length - 2;
        array[HOUR] = toInt(input.substr(0, pos1));
        array[MINUTE] = toInt(input.substr(pos1, 2));
        array[SECOND] = toInt(input.substr(pos2));
        getParsingFlags(config).bigHour = true;
    });
    addParseToken('Hmm', function (input, array, config) {
        var pos = input.length - 2;
        array[HOUR] = toInt(input.substr(0, pos));
        array[MINUTE] = toInt(input.substr(pos));
    });
    addParseToken('Hmmss', function (input, array, config) {
        var pos1 = input.length - 4;
        var pos2 = input.length - 2;
        array[HOUR] = toInt(input.substr(0, pos1));
        array[MINUTE] = toInt(input.substr(pos1, 2));
        array[SECOND] = toInt(input.substr(pos2));
    });

    // LOCALES

    function localeIsPM (input) {
        // IE8 Quirks Mode & IE7 Standards Mode do not allow accessing strings like arrays
        // Using charAt should be more compatible.
        return ((input + '').toLowerCase().charAt(0) === 'p');
    }

    var defaultLocaleMeridiemParse = /[ap]\.?m?\.?/i;
    function localeMeridiem (hours, minutes, isLower) {
        if (hours > 11) {
            return isLower ? 'pm' : 'PM';
        } else {
            return isLower ? 'am' : 'AM';
        }
    }


    // MOMENTS

    // Setting the hour should keep the time, because the user explicitly
    // specified which hour they want. So trying to maintain the same hour (in
    // a new timezone) makes sense. Adding/subtracting hours does not follow
    // this rule.
    var getSetHour = makeGetSet('Hours', true);

    var baseConfig = {
        calendar: defaultCalendar,
        longDateFormat: defaultLongDateFormat,
        invalidDate: defaultInvalidDate,
        ordinal: defaultOrdinal,
        dayOfMonthOrdinalParse: defaultDayOfMonthOrdinalParse,
        relativeTime: defaultRelativeTime,

        months: defaultLocaleMonths,
        monthsShort: defaultLocaleMonthsShort,

        week: defaultLocaleWeek,

        weekdays: defaultLocaleWeekdays,
        weekdaysMin: defaultLocaleWeekdaysMin,
        weekdaysShort: defaultLocaleWeekdaysShort,

        meridiemParse: defaultLocaleMeridiemParse
    };

    // internal storage for locale config files
    var locales = {};
    var localeFamilies = {};
    var globalLocale;

    function normalizeLocale(key) {
        return key ? key.toLowerCase().replace('_', '-') : key;
    }

    // pick the locale from the array
    // try ['en-au', 'en-gb'] as 'en-au', 'en-gb', 'en', as in move through the list trying each
    // substring from most specific to least, but move to the next array item if it's a more specific variant than the current root
    function chooseLocale(names) {
        var i = 0, j, next, locale, split;

        while (i < names.length) {
            split = normalizeLocale(names[i]).split('-');
            j = split.length;
            next = normalizeLocale(names[i + 1]);
            next = next ? next.split('-') : null;
            while (j > 0) {
                locale = loadLocale(split.slice(0, j).join('-'));
                if (locale) {
                    return locale;
                }
                if (next && next.length >= j && compareArrays(split, next, true) >= j - 1) {
                    //the next array item is better than a shallower substring of this one
                    break;
                }
                j--;
            }
            i++;
        }
        return globalLocale;
    }

    function loadLocale(name) {
        var oldLocale = null;
        // TODO: Find a better way to register and load all the locales in Node
        if (!locales[name] && (typeof module !== 'undefined') &&
                module && module.exports) {
            try {
                oldLocale = globalLocale._abbr;
                var aliasedRequire = require;
                aliasedRequire('./locale/' + name);
                getSetGlobalLocale(oldLocale);
            } catch (e) {}
        }
        return locales[name];
    }

    // This function will load locale and then set the global locale.  If
    // no arguments are passed in, it will simply return the current global
    // locale key.
    function getSetGlobalLocale (key, values) {
        var data;
        if (key) {
            if (isUndefined(values)) {
                data = getLocale(key);
            }
            else {
                data = defineLocale(key, values);
            }

            if (data) {
                // moment.duration._locale = moment._locale = data;
                globalLocale = data;
            }
            else {
                if ((typeof console !==  'undefined') && console.warn) {
                    //warn user if arguments are passed but the locale could not be set
                    console.warn('Locale ' + key +  ' not found. Did you forget to load it?');
                }
            }
        }

        return globalLocale._abbr;
    }

    function defineLocale (name, config) {
        if (config !== null) {
            var locale, parentConfig = baseConfig;
            config.abbr = name;
            if (locales[name] != null) {
                deprecateSimple('defineLocaleOverride',
                        'use moment.updateLocale(localeName, config) to change ' +
                        'an existing locale. moment.defineLocale(localeName, ' +
                        'config) should only be used for creating a new locale ' +
                        'See http://momentjs.com/guides/#/warnings/define-locale/ for more info.');
                parentConfig = locales[name]._config;
            } else if (config.parentLocale != null) {
                if (locales[config.parentLocale] != null) {
                    parentConfig = locales[config.parentLocale]._config;
                } else {
                    locale = loadLocale(config.parentLocale);
                    if (locale != null) {
                        parentConfig = locale._config;
                    } else {
                        if (!localeFamilies[config.parentLocale]) {
                            localeFamilies[config.parentLocale] = [];
                        }
                        localeFamilies[config.parentLocale].push({
                            name: name,
                            config: config
                        });
                        return null;
                    }
                }
            }
            locales[name] = new Locale(mergeConfigs(parentConfig, config));

            if (localeFamilies[name]) {
                localeFamilies[name].forEach(function (x) {
                    defineLocale(x.name, x.config);
                });
            }

            // backwards compat for now: also set the locale
            // make sure we set the locale AFTER all child locales have been
            // created, so we won't end up with the child locale set.
            getSetGlobalLocale(name);


            return locales[name];
        } else {
            // useful for testing
            delete locales[name];
            return null;
        }
    }

    function updateLocale(name, config) {
        if (config != null) {
            var locale, tmpLocale, parentConfig = baseConfig;
            // MERGE
            tmpLocale = loadLocale(name);
            if (tmpLocale != null) {
                parentConfig = tmpLocale._config;
            }
            config = mergeConfigs(parentConfig, config);
            locale = new Locale(config);
            locale.parentLocale = locales[name];
            locales[name] = locale;

            // backwards compat for now: also set the locale
            getSetGlobalLocale(name);
        } else {
            // pass null for config to unupdate, useful for tests
            if (locales[name] != null) {
                if (locales[name].parentLocale != null) {
                    locales[name] = locales[name].parentLocale;
                } else if (locales[name] != null) {
                    delete locales[name];
                }
            }
        }
        return locales[name];
    }

    // returns locale data
    function getLocale (key) {
        var locale;

        if (key && key._locale && key._locale._abbr) {
            key = key._locale._abbr;
        }

        if (!key) {
            return globalLocale;
        }

        if (!isArray(key)) {
            //short-circuit everything else
            locale = loadLocale(key);
            if (locale) {
                return locale;
            }
            key = [key];
        }

        return chooseLocale(key);
    }

    function listLocales() {
        return keys(locales);
    }

    function checkOverflow (m) {
        var overflow;
        var a = m._a;

        if (a && getParsingFlags(m).overflow === -2) {
            overflow =
                a[MONTH]       < 0 || a[MONTH]       > 11  ? MONTH :
                a[DATE]        < 1 || a[DATE]        > daysInMonth(a[YEAR], a[MONTH]) ? DATE :
                a[HOUR]        < 0 || a[HOUR]        > 24 || (a[HOUR] === 24 && (a[MINUTE] !== 0 || a[SECOND] !== 0 || a[MILLISECOND] !== 0)) ? HOUR :
                a[MINUTE]      < 0 || a[MINUTE]      > 59  ? MINUTE :
                a[SECOND]      < 0 || a[SECOND]      > 59  ? SECOND :
                a[MILLISECOND] < 0 || a[MILLISECOND] > 999 ? MILLISECOND :
                -1;

            if (getParsingFlags(m)._overflowDayOfYear && (overflow < YEAR || overflow > DATE)) {
                overflow = DATE;
            }
            if (getParsingFlags(m)._overflowWeeks && overflow === -1) {
                overflow = WEEK;
            }
            if (getParsingFlags(m)._overflowWeekday && overflow === -1) {
                overflow = WEEKDAY;
            }

            getParsingFlags(m).overflow = overflow;
        }

        return m;
    }

    // Pick the first defined of two or three arguments.
    function defaults(a, b, c) {
        if (a != null) {
            return a;
        }
        if (b != null) {
            return b;
        }
        return c;
    }

    function currentDateArray(config) {
        // hooks is actually the exported moment object
        var nowValue = new Date(hooks.now());
        if (config._useUTC) {
            return [nowValue.getUTCFullYear(), nowValue.getUTCMonth(), nowValue.getUTCDate()];
        }
        return [nowValue.getFullYear(), nowValue.getMonth(), nowValue.getDate()];
    }

    // convert an array to a date.
    // the array should mirror the parameters below
    // note: all values past the year are optional and will default to the lowest possible value.
    // [year, month, day , hour, minute, second, millisecond]
    function configFromArray (config) {
        var i, date, input = [], currentDate, expectedWeekday, yearToUse;

        if (config._d) {
            return;
        }

        currentDate = currentDateArray(config);

        //compute day of the year from weeks and weekdays
        if (config._w && config._a[DATE] == null && config._a[MONTH] == null) {
            dayOfYearFromWeekInfo(config);
        }

        //if the day of the year is set, figure out what it is
        if (config._dayOfYear != null) {
            yearToUse = defaults(config._a[YEAR], currentDate[YEAR]);

            if (config._dayOfYear > daysInYear(yearToUse) || config._dayOfYear === 0) {
                getParsingFlags(config)._overflowDayOfYear = true;
            }

            date = createUTCDate(yearToUse, 0, config._dayOfYear);
            config._a[MONTH] = date.getUTCMonth();
            config._a[DATE] = date.getUTCDate();
        }

        // Default to current date.
        // * if no year, month, day of month are given, default to today
        // * if day of month is given, default month and year
        // * if month is given, default only year
        // * if year is given, don't default anything
        for (i = 0; i < 3 && config._a[i] == null; ++i) {
            config._a[i] = input[i] = currentDate[i];
        }

        // Zero out whatever was not defaulted, including time
        for (; i < 7; i++) {
            config._a[i] = input[i] = (config._a[i] == null) ? (i === 2 ? 1 : 0) : config._a[i];
        }

        // Check for 24:00:00.000
        if (config._a[HOUR] === 24 &&
                config._a[MINUTE] === 0 &&
                config._a[SECOND] === 0 &&
                config._a[MILLISECOND] === 0) {
            config._nextDay = true;
            config._a[HOUR] = 0;
        }

        config._d = (config._useUTC ? createUTCDate : createDate).apply(null, input);
        expectedWeekday = config._useUTC ? config._d.getUTCDay() : config._d.getDay();

        // Apply timezone offset from input. The actual utcOffset can be changed
        // with parseZone.
        if (config._tzm != null) {
            config._d.setUTCMinutes(config._d.getUTCMinutes() - config._tzm);
        }

        if (config._nextDay) {
            config._a[HOUR] = 24;
        }

        // check for mismatching day of week
        if (config._w && typeof config._w.d !== 'undefined' && config._w.d !== expectedWeekday) {
            getParsingFlags(config).weekdayMismatch = true;
        }
    }

    function dayOfYearFromWeekInfo(config) {
        var w, weekYear, week, weekday, dow, doy, temp, weekdayOverflow;

        w = config._w;
        if (w.GG != null || w.W != null || w.E != null) {
            dow = 1;
            doy = 4;

            // TODO: We need to take the current isoWeekYear, but that depends on
            // how we interpret now (local, utc, fixed offset). So create
            // a now version of current config (take local/utc/offset flags, and
            // create now).
            weekYear = defaults(w.GG, config._a[YEAR], weekOfYear(createLocal(), 1, 4).year);
            week = defaults(w.W, 1);
            weekday = defaults(w.E, 1);
            if (weekday < 1 || weekday > 7) {
                weekdayOverflow = true;
            }
        } else {
            dow = config._locale._week.dow;
            doy = config._locale._week.doy;

            var curWeek = weekOfYear(createLocal(), dow, doy);

            weekYear = defaults(w.gg, config._a[YEAR], curWeek.year);

            // Default to current week.
            week = defaults(w.w, curWeek.week);

            if (w.d != null) {
                // weekday -- low day numbers are considered next week
                weekday = w.d;
                if (weekday < 0 || weekday > 6) {
                    weekdayOverflow = true;
                }
            } else if (w.e != null) {
                // local weekday -- counting starts from beginning of week
                weekday = w.e + dow;
                if (w.e < 0 || w.e > 6) {
                    weekdayOverflow = true;
                }
            } else {
                // default to beginning of week
                weekday = dow;
            }
        }
        if (week < 1 || week > weeksInYear(weekYear, dow, doy)) {
            getParsingFlags(config)._overflowWeeks = true;
        } else if (weekdayOverflow != null) {
            getParsingFlags(config)._overflowWeekday = true;
        } else {
            temp = dayOfYearFromWeeks(weekYear, week, weekday, dow, doy);
            config._a[YEAR] = temp.year;
            config._dayOfYear = temp.dayOfYear;
        }
    }

    // iso 8601 regex
    // 0000-00-00 0000-W00 or 0000-W00-0 + T + 00 or 00:00 or 00:00:00 or 00:00:00.000 + +00:00 or +0000 or +00)
    var extendedIsoRegex = /^\s*((?:[+-]\d{6}|\d{4})-(?:\d\d-\d\d|W\d\d-\d|W\d\d|\d\d\d|\d\d))(?:(T| )(\d\d(?::\d\d(?::\d\d(?:[.,]\d+)?)?)?)([\+\-]\d\d(?::?\d\d)?|\s*Z)?)?$/;
    var basicIsoRegex = /^\s*((?:[+-]\d{6}|\d{4})(?:\d\d\d\d|W\d\d\d|W\d\d|\d\d\d|\d\d))(?:(T| )(\d\d(?:\d\d(?:\d\d(?:[.,]\d+)?)?)?)([\+\-]\d\d(?::?\d\d)?|\s*Z)?)?$/;

    var tzRegex = /Z|[+-]\d\d(?::?\d\d)?/;

    var isoDates = [
        ['YYYYYY-MM-DD', /[+-]\d{6}-\d\d-\d\d/],
        ['YYYY-MM-DD', /\d{4}-\d\d-\d\d/],
        ['GGGG-[W]WW-E', /\d{4}-W\d\d-\d/],
        ['GGGG-[W]WW', /\d{4}-W\d\d/, false],
        ['YYYY-DDD', /\d{4}-\d{3}/],
        ['YYYY-MM', /\d{4}-\d\d/, false],
        ['YYYYYYMMDD', /[+-]\d{10}/],
        ['YYYYMMDD', /\d{8}/],
        // YYYYMM is NOT allowed by the standard
        ['GGGG[W]WWE', /\d{4}W\d{3}/],
        ['GGGG[W]WW', /\d{4}W\d{2}/, false],
        ['YYYYDDD', /\d{7}/]
    ];

    // iso time formats and regexes
    var isoTimes = [
        ['HH:mm:ss.SSSS', /\d\d:\d\d:\d\d\.\d+/],
        ['HH:mm:ss,SSSS', /\d\d:\d\d:\d\d,\d+/],
        ['HH:mm:ss', /\d\d:\d\d:\d\d/],
        ['HH:mm', /\d\d:\d\d/],
        ['HHmmss.SSSS', /\d\d\d\d\d\d\.\d+/],
        ['HHmmss,SSSS', /\d\d\d\d\d\d,\d+/],
        ['HHmmss', /\d\d\d\d\d\d/],
        ['HHmm', /\d\d\d\d/],
        ['HH', /\d\d/]
    ];

    var aspNetJsonRegex = /^\/?Date\((\-?\d+)/i;

    // date from iso format
    function configFromISO(config) {
        var i, l,
            string = config._i,
            match = extendedIsoRegex.exec(string) || basicIsoRegex.exec(string),
            allowTime, dateFormat, timeFormat, tzFormat;

        if (match) {
            getParsingFlags(config).iso = true;

            for (i = 0, l = isoDates.length; i < l; i++) {
                if (isoDates[i][1].exec(match[1])) {
                    dateFormat = isoDates[i][0];
                    allowTime = isoDates[i][2] !== false;
                    break;
                }
            }
            if (dateFormat == null) {
                config._isValid = false;
                return;
            }
            if (match[3]) {
                for (i = 0, l = isoTimes.length; i < l; i++) {
                    if (isoTimes[i][1].exec(match[3])) {
                        // match[2] should be 'T' or space
                        timeFormat = (match[2] || ' ') + isoTimes[i][0];
                        break;
                    }
                }
                if (timeFormat == null) {
                    config._isValid = false;
                    return;
                }
            }
            if (!allowTime && timeFormat != null) {
                config._isValid = false;
                return;
            }
            if (match[4]) {
                if (tzRegex.exec(match[4])) {
                    tzFormat = 'Z';
                } else {
                    config._isValid = false;
                    return;
                }
            }
            config._f = dateFormat + (timeFormat || '') + (tzFormat || '');
            configFromStringAndFormat(config);
        } else {
            config._isValid = false;
        }
    }

    // RFC 2822 regex: For details see https://tools.ietf.org/html/rfc2822#section-3.3
    var rfc2822 = /^(?:(Mon|Tue|Wed|Thu|Fri|Sat|Sun),?\s)?(\d{1,2})\s(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)\s(\d{2,4})\s(\d\d):(\d\d)(?::(\d\d))?\s(?:(UT|GMT|[ECMP][SD]T)|([Zz])|([+-]\d{4}))$/;

    function extractFromRFC2822Strings(yearStr, monthStr, dayStr, hourStr, minuteStr, secondStr) {
        var result = [
            untruncateYear(yearStr),
            defaultLocaleMonthsShort.indexOf(monthStr),
            parseInt(dayStr, 10),
            parseInt(hourStr, 10),
            parseInt(minuteStr, 10)
        ];

        if (secondStr) {
            result.push(parseInt(secondStr, 10));
        }

        return result;
    }

    function untruncateYear(yearStr) {
        var year = parseInt(yearStr, 10);
        if (year <= 49) {
            return 2000 + year;
        } else if (year <= 999) {
            return 1900 + year;
        }
        return year;
    }

    function preprocessRFC2822(s) {
        // Remove comments and folding whitespace and replace multiple-spaces with a single space
        return s.replace(/\([^)]*\)|[\n\t]/g, ' ').replace(/(\s\s+)/g, ' ').replace(/^\s\s*/, '').replace(/\s\s*$/, '');
    }

    function checkWeekday(weekdayStr, parsedInput, config) {
        if (weekdayStr) {
            // TODO: Replace the vanilla JS Date object with an indepentent day-of-week check.
            var weekdayProvided = defaultLocaleWeekdaysShort.indexOf(weekdayStr),
                weekdayActual = new Date(parsedInput[0], parsedInput[1], parsedInput[2]).getDay();
            if (weekdayProvided !== weekdayActual) {
                getParsingFlags(config).weekdayMismatch = true;
                config._isValid = false;
                return false;
            }
        }
        return true;
    }

    var obsOffsets = {
        UT: 0,
        GMT: 0,
        EDT: -4 * 60,
        EST: -5 * 60,
        CDT: -5 * 60,
        CST: -6 * 60,
        MDT: -6 * 60,
        MST: -7 * 60,
        PDT: -7 * 60,
        PST: -8 * 60
    };

    function calculateOffset(obsOffset, militaryOffset, numOffset) {
        if (obsOffset) {
            return obsOffsets[obsOffset];
        } else if (militaryOffset) {
            // the only allowed military tz is Z
            return 0;
        } else {
            var hm = parseInt(numOffset, 10);
            var m = hm % 100, h = (hm - m) / 100;
            return h * 60 + m;
        }
    }

    // date and time from ref 2822 format
    function configFromRFC2822(config) {
        var match = rfc2822.exec(preprocessRFC2822(config._i));
        if (match) {
            var parsedArray = extractFromRFC2822Strings(match[4], match[3], match[2], match[5], match[6], match[7]);
            if (!checkWeekday(match[1], parsedArray, config)) {
                return;
            }

            config._a = parsedArray;
            config._tzm = calculateOffset(match[8], match[9], match[10]);

            config._d = createUTCDate.apply(null, config._a);
            config._d.setUTCMinutes(config._d.getUTCMinutes() - config._tzm);

            getParsingFlags(config).rfc2822 = true;
        } else {
            config._isValid = false;
        }
    }

    // date from iso format or fallback
    function configFromString(config) {
        var matched = aspNetJsonRegex.exec(config._i);

        if (matched !== null) {
            config._d = new Date(+matched[1]);
            return;
        }

        configFromISO(config);
        if (config._isValid === false) {
            delete config._isValid;
        } else {
            return;
        }

        configFromRFC2822(config);
        if (config._isValid === false) {
            delete config._isValid;
        } else {
            return;
        }

        // Final attempt, use Input Fallback
        hooks.createFromInputFallback(config);
    }

    hooks.createFromInputFallback = deprecate(
        'value provided is not in a recognized RFC2822 or ISO format. moment construction falls back to js Date(), ' +
        'which is not reliable across all browsers and versions. Non RFC2822/ISO date formats are ' +
        'discouraged and will be removed in an upcoming major release. Please refer to ' +
        'http://momentjs.com/guides/#/warnings/js-date/ for more info.',
        function (config) {
            config._d = new Date(config._i + (config._useUTC ? ' UTC' : ''));
        }
    );

    // constant that refers to the ISO standard
    hooks.ISO_8601 = function () {};

    // constant that refers to the RFC 2822 form
    hooks.RFC_2822 = function () {};

    // date from string and format string
    function configFromStringAndFormat(config) {
        // TODO: Move this to another part of the creation flow to prevent circular deps
        if (config._f === hooks.ISO_8601) {
            configFromISO(config);
            return;
        }
        if (config._f === hooks.RFC_2822) {
            configFromRFC2822(config);
            return;
        }
        config._a = [];
        getParsingFlags(config).empty = true;

        // This array is used to make a Date, either with `new Date` or `Date.UTC`
        var string = '' + config._i,
            i, parsedInput, tokens, token, skipped,
            stringLength = string.length,
            totalParsedInputLength = 0;

        tokens = expandFormat(config._f, config._locale).match(formattingTokens) || [];

        for (i = 0; i < tokens.length; i++) {
            token = tokens[i];
            parsedInput = (string.match(getParseRegexForToken(token, config)) || [])[0];
            // console.log('token', token, 'parsedInput', parsedInput,
            //         'regex', getParseRegexForToken(token, config));
            if (parsedInput) {
                skipped = string.substr(0, string.indexOf(parsedInput));
                if (skipped.length > 0) {
                    getParsingFlags(config).unusedInput.push(skipped);
                }
                string = string.slice(string.indexOf(parsedInput) + parsedInput.length);
                totalParsedInputLength += parsedInput.length;
            }
            // don't parse if it's not a known token
            if (formatTokenFunctions[token]) {
                if (parsedInput) {
                    getParsingFlags(config).empty = false;
                }
                else {
                    getParsingFlags(config).unusedTokens.push(token);
                }
                addTimeToArrayFromToken(token, parsedInput, config);
            }
            else if (config._strict && !parsedInput) {
                getParsingFlags(config).unusedTokens.push(token);
            }
        }

        // add remaining unparsed input length to the string
        getParsingFlags(config).charsLeftOver = stringLength - totalParsedInputLength;
        if (string.length > 0) {
            getParsingFlags(config).unusedInput.push(string);
        }

        // clear _12h flag if hour is <= 12
        if (config._a[HOUR] <= 12 &&
            getParsingFlags(config).bigHour === true &&
            config._a[HOUR] > 0) {
            getParsingFlags(config).bigHour = undefined;
        }

        getParsingFlags(config).parsedDateParts = config._a.slice(0);
        getParsingFlags(config).meridiem = config._meridiem;
        // handle meridiem
        config._a[HOUR] = meridiemFixWrap(config._locale, config._a[HOUR], config._meridiem);

        configFromArray(config);
        checkOverflow(config);
    }


    function meridiemFixWrap (locale, hour, meridiem) {
        var isPm;

        if (meridiem == null) {
            // nothing to do
            return hour;
        }
        if (locale.meridiemHour != null) {
            return locale.meridiemHour(hour, meridiem);
        } else if (locale.isPM != null) {
            // Fallback
            isPm = locale.isPM(meridiem);
            if (isPm && hour < 12) {
                hour += 12;
            }
            if (!isPm && hour === 12) {
                hour = 0;
            }
            return hour;
        } else {
            // this is not supposed to happen
            return hour;
        }
    }

    // date from string and array of format strings
    function configFromStringAndArray(config) {
        var tempConfig,
            bestMoment,

            scoreToBeat,
            i,
            currentScore;

        if (config._f.length === 0) {
            getParsingFlags(config).invalidFormat = true;
            config._d = new Date(NaN);
            return;
        }

        for (i = 0; i < config._f.length; i++) {
            currentScore = 0;
            tempConfig = copyConfig({}, config);
            if (config._useUTC != null) {
                tempConfig._useUTC = config._useUTC;
            }
            tempConfig._f = config._f[i];
            configFromStringAndFormat(tempConfig);

            if (!isValid(tempConfig)) {
                continue;
            }

            // if there is any input that was not parsed add a penalty for that format
            currentScore += getParsingFlags(tempConfig).charsLeftOver;

            //or tokens
            currentScore += getParsingFlags(tempConfig).unusedTokens.length * 10;

            getParsingFlags(tempConfig).score = currentScore;

            if (scoreToBeat == null || currentScore < scoreToBeat) {
                scoreToBeat = currentScore;
                bestMoment = tempConfig;
            }
        }

        extend(config, bestMoment || tempConfig);
    }

    function configFromObject(config) {
        if (config._d) {
            return;
        }

        var i = normalizeObjectUnits(config._i);
        config._a = map([i.year, i.month, i.day || i.date, i.hour, i.minute, i.second, i.millisecond], function (obj) {
            return obj && parseInt(obj, 10);
        });

        configFromArray(config);
    }

    function createFromConfig (config) {
        var res = new Moment(checkOverflow(prepareConfig(config)));
        if (res._nextDay) {
            // Adding is smart enough around DST
            res.add(1, 'd');
            res._nextDay = undefined;
        }

        return res;
    }

    function prepareConfig (config) {
        var input = config._i,
            format = config._f;

        config._locale = config._locale || getLocale(config._l);

        if (input === null || (format === undefined && input === '')) {
            return createInvalid({nullInput: true});
        }

        if (typeof input === 'string') {
            config._i = input = config._locale.preparse(input);
        }

        if (isMoment(input)) {
            return new Moment(checkOverflow(input));
        } else if (isDate(input)) {
            config._d = input;
        } else if (isArray(format)) {
            configFromStringAndArray(config);
        } else if (format) {
            configFromStringAndFormat(config);
        }  else {
            configFromInput(config);
        }

        if (!isValid(config)) {
            config._d = null;
        }

        return config;
    }

    function configFromInput(config) {
        var input = config._i;
        if (isUndefined(input)) {
            config._d = new Date(hooks.now());
        } else if (isDate(input)) {
            config._d = new Date(input.valueOf());
        } else if (typeof input === 'string') {
            configFromString(config);
        } else if (isArray(input)) {
            config._a = map(input.slice(0), function (obj) {
                return parseInt(obj, 10);
            });
            configFromArray(config);
        } else if (isObject(input)) {
            configFromObject(config);
        } else if (isNumber(input)) {
            // from milliseconds
            config._d = new Date(input);
        } else {
            hooks.createFromInputFallback(config);
        }
    }

    function createLocalOrUTC (input, format, locale, strict, isUTC) {
        var c = {};

        if (locale === true || locale === false) {
            strict = locale;
            locale = undefined;
        }

        if ((isObject(input) && isObjectEmpty(input)) ||
                (isArray(input) && input.length === 0)) {
            input = undefined;
        }
        // object construction must be done this way.
        // https://github.com/moment/moment/issues/1423
        c._isAMomentObject = true;
        c._useUTC = c._isUTC = isUTC;
        c._l = locale;
        c._i = input;
        c._f = format;
        c._strict = strict;

        return createFromConfig(c);
    }

    function createLocal (input, format, locale, strict) {
        return createLocalOrUTC(input, format, locale, strict, false);
    }

    var prototypeMin = deprecate(
        'moment().min is deprecated, use moment.max instead. http://momentjs.com/guides/#/warnings/min-max/',
        function () {
            var other = createLocal.apply(null, arguments);
            if (this.isValid() && other.isValid()) {
                return other < this ? this : other;
            } else {
                return createInvalid();
            }
        }
    );

    var prototypeMax = deprecate(
        'moment().max is deprecated, use moment.min instead. http://momentjs.com/guides/#/warnings/min-max/',
        function () {
            var other = createLocal.apply(null, arguments);
            if (this.isValid() && other.isValid()) {
                return other > this ? this : other;
            } else {
                return createInvalid();
            }
        }
    );

    // Pick a moment m from moments so that m[fn](other) is true for all
    // other. This relies on the function fn to be transitive.
    //
    // moments should either be an array of moment objects or an array, whose
    // first element is an array of moment objects.
    function pickBy(fn, moments) {
        var res, i;
        if (moments.length === 1 && isArray(moments[0])) {
            moments = moments[0];
        }
        if (!moments.length) {
            return createLocal();
        }
        res = moments[0];
        for (i = 1; i < moments.length; ++i) {
            if (!moments[i].isValid() || moments[i][fn](res)) {
                res = moments[i];
            }
        }
        return res;
    }

    // TODO: Use [].sort instead?
    function min () {
        var args = [].slice.call(arguments, 0);

        return pickBy('isBefore', args);
    }

    function max () {
        var args = [].slice.call(arguments, 0);

        return pickBy('isAfter', args);
    }

    var now = function () {
        return Date.now ? Date.now() : +(new Date());
    };

    var ordering = ['year', 'quarter', 'month', 'week', 'day', 'hour', 'minute', 'second', 'millisecond'];

    function isDurationValid(m) {
        for (var key in m) {
            if (!(indexOf.call(ordering, key) !== -1 && (m[key] == null || !isNaN(m[key])))) {
                return false;
            }
        }

        var unitHasDecimal = false;
        for (var i = 0; i < ordering.length; ++i) {
            if (m[ordering[i]]) {
                if (unitHasDecimal) {
                    return false; // only allow non-integers for smallest unit
                }
                if (parseFloat(m[ordering[i]]) !== toInt(m[ordering[i]])) {
                    unitHasDecimal = true;
                }
            }
        }

        return true;
    }

    function isValid$1() {
        return this._isValid;
    }

    function createInvalid$1() {
        return createDuration(NaN);
    }

    function Duration (duration) {
        var normalizedInput = normalizeObjectUnits(duration),
            years = normalizedInput.year || 0,
            quarters = normalizedInput.quarter || 0,
            months = normalizedInput.month || 0,
            weeks = normalizedInput.week || normalizedInput.isoWeek || 0,
            days = normalizedInput.day || 0,
            hours = normalizedInput.hour || 0,
            minutes = normalizedInput.minute || 0,
            seconds = normalizedInput.second || 0,
            milliseconds = normalizedInput.millisecond || 0;

        this._isValid = isDurationValid(normalizedInput);

        // representation for dateAddRemove
        this._milliseconds = +milliseconds +
            seconds * 1e3 + // 1000
            minutes * 6e4 + // 1000 * 60
            hours * 1000 * 60 * 60; //using 1000 * 60 * 60 instead of 36e5 to avoid floating point rounding errors https://github.com/moment/moment/issues/2978
        // Because of dateAddRemove treats 24 hours as different from a
        // day when working around DST, we need to store them separately
        this._days = +days +
            weeks * 7;
        // It is impossible to translate months into days without knowing
        // which months you are are talking about, so we have to store
        // it separately.
        this._months = +months +
            quarters * 3 +
            years * 12;

        this._data = {};

        this._locale = getLocale();

        this._bubble();
    }

    function isDuration (obj) {
        return obj instanceof Duration;
    }

    function absRound (number) {
        if (number < 0) {
            return Math.round(-1 * number) * -1;
        } else {
            return Math.round(number);
        }
    }

    // FORMATTING

    function offset (token, separator) {
        addFormatToken(token, 0, 0, function () {
            var offset = this.utcOffset();
            var sign = '+';
            if (offset < 0) {
                offset = -offset;
                sign = '-';
            }
            return sign + zeroFill(~~(offset / 60), 2) + separator + zeroFill(~~(offset) % 60, 2);
        });
    }

    offset('Z', ':');
    offset('ZZ', '');

    // PARSING

    addRegexToken('Z',  matchShortOffset);
    addRegexToken('ZZ', matchShortOffset);
    addParseToken(['Z', 'ZZ'], function (input, array, config) {
        config._useUTC = true;
        config._tzm = offsetFromString(matchShortOffset, input);
    });

    // HELPERS

    // timezone chunker
    // '+10:00' > ['10',  '00']
    // '-1530'  > ['-15', '30']
    var chunkOffset = /([\+\-]|\d\d)/gi;

    function offsetFromString(matcher, string) {
        var matches = (string || '').match(matcher);

        if (matches === null) {
            return null;
        }

        var chunk   = matches[matches.length - 1] || [];
        var parts   = (chunk + '').match(chunkOffset) || ['-', 0, 0];
        var minutes = +(parts[1] * 60) + toInt(parts[2]);

        return minutes === 0 ?
          0 :
          parts[0] === '+' ? minutes : -minutes;
    }

    // Return a moment from input, that is local/utc/zone equivalent to model.
    function cloneWithOffset(input, model) {
        var res, diff;
        if (model._isUTC) {
            res = model.clone();
            diff = (isMoment(input) || isDate(input) ? input.valueOf() : createLocal(input).valueOf()) - res.valueOf();
            // Use low-level api, because this fn is low-level api.
            res._d.setTime(res._d.valueOf() + diff);
            hooks.updateOffset(res, false);
            return res;
        } else {
            return createLocal(input).local();
        }
    }

    function getDateOffset (m) {
        // On Firefox.24 Date#getTimezoneOffset returns a floating point.
        // https://github.com/moment/moment/pull/1871
        return -Math.round(m._d.getTimezoneOffset() / 15) * 15;
    }

    // HOOKS

    // This function will be called whenever a moment is mutated.
    // It is intended to keep the offset in sync with the timezone.
    hooks.updateOffset = function () {};

    // MOMENTS

    // keepLocalTime = true means only change the timezone, without
    // affecting the local hour. So 5:31:26 +0300 --[utcOffset(2, true)]-->
    // 5:31:26 +0200 It is possible that 5:31:26 doesn't exist with offset
    // +0200, so we adjust the time as needed, to be valid.
    //
    // Keeping the time actually adds/subtracts (one hour)
    // from the actual represented time. That is why we call updateOffset
    // a second time. In case it wants us to change the offset again
    // _changeInProgress == true case, then we have to adjust, because
    // there is no such time in the given timezone.
    function getSetOffset (input, keepLocalTime, keepMinutes) {
        var offset = this._offset || 0,
            localAdjust;
        if (!this.isValid()) {
            return input != null ? this : NaN;
        }
        if (input != null) {
            if (typeof input === 'string') {
                input = offsetFromString(matchShortOffset, input);
                if (input === null) {
                    return this;
                }
            } else if (Math.abs(input) < 16 && !keepMinutes) {
                input = input * 60;
            }
            if (!this._isUTC && keepLocalTime) {
                localAdjust = getDateOffset(this);
            }
            this._offset = input;
            this._isUTC = true;
            if (localAdjust != null) {
                this.add(localAdjust, 'm');
            }
            if (offset !== input) {
                if (!keepLocalTime || this._changeInProgress) {
                    addSubtract(this, createDuration(input - offset, 'm'), 1, false);
                } else if (!this._changeInProgress) {
                    this._changeInProgress = true;
                    hooks.updateOffset(this, true);
                    this._changeInProgress = null;
                }
            }
            return this;
        } else {
            return this._isUTC ? offset : getDateOffset(this);
        }
    }

    function getSetZone (input, keepLocalTime) {
        if (input != null) {
            if (typeof input !== 'string') {
                input = -input;
            }

            this.utcOffset(input, keepLocalTime);

            return this;
        } else {
            return -this.utcOffset();
        }
    }

    function setOffsetToUTC (keepLocalTime) {
        return this.utcOffset(0, keepLocalTime);
    }

    function setOffsetToLocal (keepLocalTime) {
        if (this._isUTC) {
            this.utcOffset(0, keepLocalTime);
            this._isUTC = false;

            if (keepLocalTime) {
                this.subtract(getDateOffset(this), 'm');
            }
        }
        return this;
    }

    function setOffsetToParsedOffset () {
        if (this._tzm != null) {
            this.utcOffset(this._tzm, false, true);
        } else if (typeof this._i === 'string') {
            var tZone = offsetFromString(matchOffset, this._i);
            if (tZone != null) {
                this.utcOffset(tZone);
            }
            else {
                this.utcOffset(0, true);
            }
        }
        return this;
    }

    function hasAlignedHourOffset (input) {
        if (!this.isValid()) {
            return false;
        }
        input = input ? createLocal(input).utcOffset() : 0;

        return (this.utcOffset() - input) % 60 === 0;
    }

    function isDaylightSavingTime () {
        return (
            this.utcOffset() > this.clone().month(0).utcOffset() ||
            this.utcOffset() > this.clone().month(5).utcOffset()
        );
    }

    function isDaylightSavingTimeShifted () {
        if (!isUndefined(this._isDSTShifted)) {
            return this._isDSTShifted;
        }

        var c = {};

        copyConfig(c, this);
        c = prepareConfig(c);

        if (c._a) {
            var other = c._isUTC ? createUTC(c._a) : createLocal(c._a);
            this._isDSTShifted = this.isValid() &&
                compareArrays(c._a, other.toArray()) > 0;
        } else {
            this._isDSTShifted = false;
        }

        return this._isDSTShifted;
    }

    function isLocal () {
        return this.isValid() ? !this._isUTC : false;
    }

    function isUtcOffset () {
        return this.isValid() ? this._isUTC : false;
    }

    function isUtc () {
        return this.isValid() ? this._isUTC && this._offset === 0 : false;
    }

    // ASP.NET json date format regex
    var aspNetRegex = /^(\-|\+)?(?:(\d*)[. ])?(\d+)\:(\d+)(?:\:(\d+)(\.\d*)?)?$/;

    // from http://docs.closure-library.googlecode.com/git/closure_goog_date_date.js.source.html
    // somewhat more in line with 4.4.3.2 2004 spec, but allows decimal anywhere
    // and further modified to allow for strings containing both week and day
    var isoRegex = /^(-|\+)?P(?:([-+]?[0-9,.]*)Y)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)W)?(?:([-+]?[0-9,.]*)D)?(?:T(?:([-+]?[0-9,.]*)H)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)S)?)?$/;

    function createDuration (input, key) {
        var duration = input,
            // matching against regexp is expensive, do it on demand
            match = null,
            sign,
            ret,
            diffRes;

        if (isDuration(input)) {
            duration = {
                ms : input._milliseconds,
                d  : input._days,
                M  : input._months
            };
        } else if (isNumber(input)) {
            duration = {};
            if (key) {
                duration[key] = input;
            } else {
                duration.milliseconds = input;
            }
        } else if (!!(match = aspNetRegex.exec(input))) {
            sign = (match[1] === '-') ? -1 : 1;
            duration = {
                y  : 0,
                d  : toInt(match[DATE])                         * sign,
                h  : toInt(match[HOUR])                         * sign,
                m  : toInt(match[MINUTE])                       * sign,
                s  : toInt(match[SECOND])                       * sign,
                ms : toInt(absRound(match[MILLISECOND] * 1000)) * sign // the millisecond decimal point is included in the match
            };
        } else if (!!(match = isoRegex.exec(input))) {
            sign = (match[1] === '-') ? -1 : 1;
            duration = {
                y : parseIso(match[2], sign),
                M : parseIso(match[3], sign),
                w : parseIso(match[4], sign),
                d : parseIso(match[5], sign),
                h : parseIso(match[6], sign),
                m : parseIso(match[7], sign),
                s : parseIso(match[8], sign)
            };
        } else if (duration == null) {// checks for null or undefined
            duration = {};
        } else if (typeof duration === 'object' && ('from' in duration || 'to' in duration)) {
            diffRes = momentsDifference(createLocal(duration.from), createLocal(duration.to));

            duration = {};
            duration.ms = diffRes.milliseconds;
            duration.M = diffRes.months;
        }

        ret = new Duration(duration);

        if (isDuration(input) && hasOwnProp(input, '_locale')) {
            ret._locale = input._locale;
        }

        return ret;
    }

    createDuration.fn = Duration.prototype;
    createDuration.invalid = createInvalid$1;

    function parseIso (inp, sign) {
        // We'd normally use ~~inp for this, but unfortunately it also
        // converts floats to ints.
        // inp may be undefined, so careful calling replace on it.
        var res = inp && parseFloat(inp.replace(',', '.'));
        // apply sign while we're at it
        return (isNaN(res) ? 0 : res) * sign;
    }

    function positiveMomentsDifference(base, other) {
        var res = {};

        res.months = other.month() - base.month() +
            (other.year() - base.year()) * 12;
        if (base.clone().add(res.months, 'M').isAfter(other)) {
            --res.months;
        }

        res.milliseconds = +other - +(base.clone().add(res.months, 'M'));

        return res;
    }

    function momentsDifference(base, other) {
        var res;
        if (!(base.isValid() && other.isValid())) {
            return {milliseconds: 0, months: 0};
        }

        other = cloneWithOffset(other, base);
        if (base.isBefore(other)) {
            res = positiveMomentsDifference(base, other);
        } else {
            res = positiveMomentsDifference(other, base);
            res.milliseconds = -res.milliseconds;
            res.months = -res.months;
        }

        return res;
    }

    // TODO: remove 'name' arg after deprecation is removed
    function createAdder(direction, name) {
        return function (val, period) {
            var dur, tmp;
            //invert the arguments, but complain about it
            if (period !== null && !isNaN(+period)) {
                deprecateSimple(name, 'moment().' + name  + '(period, number) is deprecated. Please use moment().' + name + '(number, period). ' +
                'See http://momentjs.com/guides/#/warnings/add-inverted-param/ for more info.');
                tmp = val; val = period; period = tmp;
            }

            val = typeof val === 'string' ? +val : val;
            dur = createDuration(val, period);
            addSubtract(this, dur, direction);
            return this;
        };
    }

    function addSubtract (mom, duration, isAdding, updateOffset) {
        var milliseconds = duration._milliseconds,
            days = absRound(duration._days),
            months = absRound(duration._months);

        if (!mom.isValid()) {
            // No op
            return;
        }

        updateOffset = updateOffset == null ? true : updateOffset;

        if (months) {
            setMonth(mom, get(mom, 'Month') + months * isAdding);
        }
        if (days) {
            set$1(mom, 'Date', get(mom, 'Date') + days * isAdding);
        }
        if (milliseconds) {
            mom._d.setTime(mom._d.valueOf() + milliseconds * isAdding);
        }
        if (updateOffset) {
            hooks.updateOffset(mom, days || months);
        }
    }

    var add      = createAdder(1, 'add');
    var subtract = createAdder(-1, 'subtract');

    function getCalendarFormat(myMoment, now) {
        var diff = myMoment.diff(now, 'days', true);
        return diff < -6 ? 'sameElse' :
                diff < -1 ? 'lastWeek' :
                diff < 0 ? 'lastDay' :
                diff < 1 ? 'sameDay' :
                diff < 2 ? 'nextDay' :
                diff < 7 ? 'nextWeek' : 'sameElse';
    }

    function calendar$1 (time, formats) {
        // We want to compare the start of today, vs this.
        // Getting start-of-today depends on whether we're local/utc/offset or not.
        var now = time || createLocal(),
            sod = cloneWithOffset(now, this).startOf('day'),
            format = hooks.calendarFormat(this, sod) || 'sameElse';

        var output = formats && (isFunction(formats[format]) ? formats[format].call(this, now) : formats[format]);

        return this.format(output || this.localeData().calendar(format, this, createLocal(now)));
    }

    function clone () {
        return new Moment(this);
    }

    function isAfter (input, units) {
        var localInput = isMoment(input) ? input : createLocal(input);
        if (!(this.isValid() && localInput.isValid())) {
            return false;
        }
        units = normalizeUnits(units) || 'millisecond';
        if (units === 'millisecond') {
            return this.valueOf() > localInput.valueOf();
        } else {
            return localInput.valueOf() < this.clone().startOf(units).valueOf();
        }
    }

    function isBefore (input, units) {
        var localInput = isMoment(input) ? input : createLocal(input);
        if (!(this.isValid() && localInput.isValid())) {
            return false;
        }
        units = normalizeUnits(units) || 'millisecond';
        if (units === 'millisecond') {
            return this.valueOf() < localInput.valueOf();
        } else {
            return this.clone().endOf(units).valueOf() < localInput.valueOf();
        }
    }

    function isBetween (from, to, units, inclusivity) {
        var localFrom = isMoment(from) ? from : createLocal(from),
            localTo = isMoment(to) ? to : createLocal(to);
        if (!(this.isValid() && localFrom.isValid() && localTo.isValid())) {
            return false;
        }
        inclusivity = inclusivity || '()';
        return (inclusivity[0] === '(' ? this.isAfter(localFrom, units) : !this.isBefore(localFrom, units)) &&
            (inclusivity[1] === ')' ? this.isBefore(localTo, units) : !this.isAfter(localTo, units));
    }

    function isSame (input, units) {
        var localInput = isMoment(input) ? input : createLocal(input),
            inputMs;
        if (!(this.isValid() && localInput.isValid())) {
            return false;
        }
        units = normalizeUnits(units) || 'millisecond';
        if (units === 'millisecond') {
            return this.valueOf() === localInput.valueOf();
        } else {
            inputMs = localInput.valueOf();
            return this.clone().startOf(units).valueOf() <= inputMs && inputMs <= this.clone().endOf(units).valueOf();
        }
    }

    function isSameOrAfter (input, units) {
        return this.isSame(input, units) || this.isAfter(input, units);
    }

    function isSameOrBefore (input, units) {
        return this.isSame(input, units) || this.isBefore(input, units);
    }

    function diff (input, units, asFloat) {
        var that,
            zoneDelta,
            output;

        if (!this.isValid()) {
            return NaN;
        }

        that = cloneWithOffset(input, this);

        if (!that.isValid()) {
            return NaN;
        }

        zoneDelta = (that.utcOffset() - this.utcOffset()) * 6e4;

        units = normalizeUnits(units);

        switch (units) {
            case 'year': output = monthDiff(this, that) / 12; break;
            case 'month': output = monthDiff(this, that); break;
            case 'quarter': output = monthDiff(this, that) / 3; break;
            case 'second': output = (this - that) / 1e3; break; // 1000
            case 'minute': output = (this - that) / 6e4; break; // 1000 * 60
            case 'hour': output = (this - that) / 36e5; break; // 1000 * 60 * 60
            case 'day': output = (this - that - zoneDelta) / 864e5; break; // 1000 * 60 * 60 * 24, negate dst
            case 'week': output = (this - that - zoneDelta) / 6048e5; break; // 1000 * 60 * 60 * 24 * 7, negate dst
            default: output = this - that;
        }

        return asFloat ? output : absFloor(output);
    }

    function monthDiff (a, b) {
        // difference in months
        var wholeMonthDiff = ((b.year() - a.year()) * 12) + (b.month() - a.month()),
            // b is in (anchor - 1 month, anchor + 1 month)
            anchor = a.clone().add(wholeMonthDiff, 'months'),
            anchor2, adjust;

        if (b - anchor < 0) {
            anchor2 = a.clone().add(wholeMonthDiff - 1, 'months');
            // linear across the month
            adjust = (b - anchor) / (anchor - anchor2);
        } else {
            anchor2 = a.clone().add(wholeMonthDiff + 1, 'months');
            // linear across the month
            adjust = (b - anchor) / (anchor2 - anchor);
        }

        //check for negative zero, return zero if negative zero
        return -(wholeMonthDiff + adjust) || 0;
    }

    hooks.defaultFormat = 'YYYY-MM-DDTHH:mm:ssZ';
    hooks.defaultFormatUtc = 'YYYY-MM-DDTHH:mm:ss[Z]';

    function toString () {
        return this.clone().locale('en').format('ddd MMM DD YYYY HH:mm:ss [GMT]ZZ');
    }

    function toISOString(keepOffset) {
        if (!this.isValid()) {
            return null;
        }
        var utc = keepOffset !== true;
        var m = utc ? this.clone().utc() : this;
        if (m.year() < 0 || m.year() > 9999) {
            return formatMoment(m, utc ? 'YYYYYY-MM-DD[T]HH:mm:ss.SSS[Z]' : 'YYYYYY-MM-DD[T]HH:mm:ss.SSSZ');
        }
        if (isFunction(Date.prototype.toISOString)) {
            // native implementation is ~50x faster, use it when we can
            if (utc) {
                return this.toDate().toISOString();
            } else {
                return new Date(this.valueOf() + this.utcOffset() * 60 * 1000).toISOString().replace('Z', formatMoment(m, 'Z'));
            }
        }
        return formatMoment(m, utc ? 'YYYY-MM-DD[T]HH:mm:ss.SSS[Z]' : 'YYYY-MM-DD[T]HH:mm:ss.SSSZ');
    }

    /**
     * Return a human readable representation of a moment that can
     * also be evaluated to get a new moment which is the same
     *
     * @link https://nodejs.org/dist/latest/docs/api/util.html#util_custom_inspect_function_on_objects
     */
    function inspect () {
        if (!this.isValid()) {
            return 'moment.invalid(/* ' + this._i + ' */)';
        }
        var func = 'moment';
        var zone = '';
        if (!this.isLocal()) {
            func = this.utcOffset() === 0 ? 'moment.utc' : 'moment.parseZone';
            zone = 'Z';
        }
        var prefix = '[' + func + '("]';
        var year = (0 <= this.year() && this.year() <= 9999) ? 'YYYY' : 'YYYYYY';
        var datetime = '-MM-DD[T]HH:mm:ss.SSS';
        var suffix = zone + '[")]';

        return this.format(prefix + year + datetime + suffix);
    }

    function format (inputString) {
        if (!inputString) {
            inputString = this.isUtc() ? hooks.defaultFormatUtc : hooks.defaultFormat;
        }
        var output = formatMoment(this, inputString);
        return this.localeData().postformat(output);
    }

    function from (time, withoutSuffix) {
        if (this.isValid() &&
                ((isMoment(time) && time.isValid()) ||
                 createLocal(time).isValid())) {
            return createDuration({to: this, from: time}).locale(this.locale()).humanize(!withoutSuffix);
        } else {
            return this.localeData().invalidDate();
        }
    }

    function fromNow (withoutSuffix) {
        return this.from(createLocal(), withoutSuffix);
    }

    function to (time, withoutSuffix) {
        if (this.isValid() &&
                ((isMoment(time) && time.isValid()) ||
                 createLocal(time).isValid())) {
            return createDuration({from: this, to: time}).locale(this.locale()).humanize(!withoutSuffix);
        } else {
            return this.localeData().invalidDate();
        }
    }

    function toNow (withoutSuffix) {
        return this.to(createLocal(), withoutSuffix);
    }

    // If passed a locale key, it will set the locale for this
    // instance.  Otherwise, it will return the locale configuration
    // variables for this instance.
    function locale (key) {
        var newLocaleData;

        if (key === undefined) {
            return this._locale._abbr;
        } else {
            newLocaleData = getLocale(key);
            if (newLocaleData != null) {
                this._locale = newLocaleData;
            }
            return this;
        }
    }

    var lang = deprecate(
        'moment().lang() is deprecated. Instead, use moment().localeData() to get the language configuration. Use moment().locale() to change languages.',
        function (key) {
            if (key === undefined) {
                return this.localeData();
            } else {
                return this.locale(key);
            }
        }
    );

    function localeData () {
        return this._locale;
    }

    var MS_PER_SECOND = 1000;
    var MS_PER_MINUTE = 60 * MS_PER_SECOND;
    var MS_PER_HOUR = 60 * MS_PER_MINUTE;
    var MS_PER_400_YEARS = (365 * 400 + 97) * 24 * MS_PER_HOUR;

    // actual modulo - handles negative numbers (for dates before 1970):
    function mod$1(dividend, divisor) {
        return (dividend % divisor + divisor) % divisor;
    }

    function localStartOfDate(y, m, d) {
        // the date constructor remaps years 0-99 to 1900-1999
        if (y < 100 && y >= 0) {
            // preserve leap years using a full 400 year cycle, then reset
            return new Date(y + 400, m, d) - MS_PER_400_YEARS;
        } else {
            return new Date(y, m, d).valueOf();
        }
    }

    function utcStartOfDate(y, m, d) {
        // Date.UTC remaps years 0-99 to 1900-1999
        if (y < 100 && y >= 0) {
            // preserve leap years using a full 400 year cycle, then reset
            return Date.UTC(y + 400, m, d) - MS_PER_400_YEARS;
        } else {
            return Date.UTC(y, m, d);
        }
    }

    function startOf (units) {
        var time;
        units = normalizeUnits(units);
        if (units === undefined || units === 'millisecond' || !this.isValid()) {
            return this;
        }

        var startOfDate = this._isUTC ? utcStartOfDate : localStartOfDate;

        switch (units) {
            case 'year':
                time = startOfDate(this.year(), 0, 1);
                break;
            case 'quarter':
                time = startOfDate(this.year(), this.month() - this.month() % 3, 1);
                break;
            case 'month':
                time = startOfDate(this.year(), this.month(), 1);
                break;
            case 'week':
                time = startOfDate(this.year(), this.month(), this.date() - this.weekday());
                break;
            case 'isoWeek':
                time = startOfDate(this.year(), this.month(), this.date() - (this.isoWeekday() - 1));
                break;
            case 'day':
            case 'date':
                time = startOfDate(this.year(), this.month(), this.date());
                break;
            case 'hour':
                time = this._d.valueOf();
                time -= mod$1(time + (this._isUTC ? 0 : this.utcOffset() * MS_PER_MINUTE), MS_PER_HOUR);
                break;
            case 'minute':
                time = this._d.valueOf();
                time -= mod$1(time, MS_PER_MINUTE);
                break;
            case 'second':
                time = this._d.valueOf();
                time -= mod$1(time, MS_PER_SECOND);
                break;
        }

        this._d.setTime(time);
        hooks.updateOffset(this, true);
        return this;
    }

    function endOf (units) {
        var time;
        units = normalizeUnits(units);
        if (units === undefined || units === 'millisecond' || !this.isValid()) {
            return this;
        }

        var startOfDate = this._isUTC ? utcStartOfDate : localStartOfDate;

        switch (units) {
            case 'year':
                time = startOfDate(this.year() + 1, 0, 1) - 1;
                break;
            case 'quarter':
                time = startOfDate(this.year(), this.month() - this.month() % 3 + 3, 1) - 1;
                break;
            case 'month':
                time = startOfDate(this.year(), this.month() + 1, 1) - 1;
                break;
            case 'week':
                time = startOfDate(this.year(), this.month(), this.date() - this.weekday() + 7) - 1;
                break;
            case 'isoWeek':
                time = startOfDate(this.year(), this.month(), this.date() - (this.isoWeekday() - 1) + 7) - 1;
                break;
            case 'day':
            case 'date':
                time = startOfDate(this.year(), this.month(), this.date() + 1) - 1;
                break;
            case 'hour':
                time = this._d.valueOf();
                time += MS_PER_HOUR - mod$1(time + (this._isUTC ? 0 : this.utcOffset() * MS_PER_MINUTE), MS_PER_HOUR) - 1;
                break;
            case 'minute':
                time = this._d.valueOf();
                time += MS_PER_MINUTE - mod$1(time, MS_PER_MINUTE) - 1;
                break;
            case 'second':
                time = this._d.valueOf();
                time += MS_PER_SECOND - mod$1(time, MS_PER_SECOND) - 1;
                break;
        }

        this._d.setTime(time);
        hooks.updateOffset(this, true);
        return this;
    }

    function valueOf () {
        return this._d.valueOf() - ((this._offset || 0) * 60000);
    }

    function unix () {
        return Math.floor(this.valueOf() / 1000);
    }

    function toDate () {
        return new Date(this.valueOf());
    }

    function toArray () {
        var m = this;
        return [m.year(), m.month(), m.date(), m.hour(), m.minute(), m.second(), m.millisecond()];
    }

    function toObject () {
        var m = this;
        return {
            years: m.year(),
            months: m.month(),
            date: m.date(),
            hours: m.hours(),
            minutes: m.minutes(),
            seconds: m.seconds(),
            milliseconds: m.milliseconds()
        };
    }

    function toJSON () {
        // new Date(NaN).toJSON() === null
        return this.isValid() ? this.toISOString() : null;
    }

    function isValid$2 () {
        return isValid(this);
    }

    function parsingFlags () {
        return extend({}, getParsingFlags(this));
    }

    function invalidAt () {
        return getParsingFlags(this).overflow;
    }

    function creationData() {
        return {
            input: this._i,
            format: this._f,
            locale: this._locale,
            isUTC: this._isUTC,
            strict: this._strict
        };
    }

    // FORMATTING

    addFormatToken(0, ['gg', 2], 0, function () {
        return this.weekYear() % 100;
    });

    addFormatToken(0, ['GG', 2], 0, function () {
        return this.isoWeekYear() % 100;
    });

    function addWeekYearFormatToken (token, getter) {
        addFormatToken(0, [token, token.length], 0, getter);
    }

    addWeekYearFormatToken('gggg',     'weekYear');
    addWeekYearFormatToken('ggggg',    'weekYear');
    addWeekYearFormatToken('GGGG',  'isoWeekYear');
    addWeekYearFormatToken('GGGGG', 'isoWeekYear');

    // ALIASES

    addUnitAlias('weekYear', 'gg');
    addUnitAlias('isoWeekYear', 'GG');

    // PRIORITY

    addUnitPriority('weekYear', 1);
    addUnitPriority('isoWeekYear', 1);


    // PARSING

    addRegexToken('G',      matchSigned);
    addRegexToken('g',      matchSigned);
    addRegexToken('GG',     match1to2, match2);
    addRegexToken('gg',     match1to2, match2);
    addRegexToken('GGGG',   match1to4, match4);
    addRegexToken('gggg',   match1to4, match4);
    addRegexToken('GGGGG',  match1to6, match6);
    addRegexToken('ggggg',  match1to6, match6);

    addWeekParseToken(['gggg', 'ggggg', 'GGGG', 'GGGGG'], function (input, week, config, token) {
        week[token.substr(0, 2)] = toInt(input);
    });

    addWeekParseToken(['gg', 'GG'], function (input, week, config, token) {
        week[token] = hooks.parseTwoDigitYear(input);
    });

    // MOMENTS

    function getSetWeekYear (input) {
        return getSetWeekYearHelper.call(this,
                input,
                this.week(),
                this.weekday(),
                this.localeData()._week.dow,
                this.localeData()._week.doy);
    }

    function getSetISOWeekYear (input) {
        return getSetWeekYearHelper.call(this,
                input, this.isoWeek(), this.isoWeekday(), 1, 4);
    }

    function getISOWeeksInYear () {
        return weeksInYear(this.year(), 1, 4);
    }

    function getWeeksInYear () {
        var weekInfo = this.localeData()._week;
        return weeksInYear(this.year(), weekInfo.dow, weekInfo.doy);
    }

    function getSetWeekYearHelper(input, week, weekday, dow, doy) {
        var weeksTarget;
        if (input == null) {
            return weekOfYear(this, dow, doy).year;
        } else {
            weeksTarget = weeksInYear(input, dow, doy);
            if (week > weeksTarget) {
                week = weeksTarget;
            }
            return setWeekAll.call(this, input, week, weekday, dow, doy);
        }
    }

    function setWeekAll(weekYear, week, weekday, dow, doy) {
        var dayOfYearData = dayOfYearFromWeeks(weekYear, week, weekday, dow, doy),
            date = createUTCDate(dayOfYearData.year, 0, dayOfYearData.dayOfYear);

        this.year(date.getUTCFullYear());
        this.month(date.getUTCMonth());
        this.date(date.getUTCDate());
        return this;
    }

    // FORMATTING

    addFormatToken('Q', 0, 'Qo', 'quarter');

    // ALIASES

    addUnitAlias('quarter', 'Q');

    // PRIORITY

    addUnitPriority('quarter', 7);

    // PARSING

    addRegexToken('Q', match1);
    addParseToken('Q', function (input, array) {
        array[MONTH] = (toInt(input) - 1) * 3;
    });

    // MOMENTS

    function getSetQuarter (input) {
        return input == null ? Math.ceil((this.month() + 1) / 3) : this.month((input - 1) * 3 + this.month() % 3);
    }

    // FORMATTING

    addFormatToken('D', ['DD', 2], 'Do', 'date');

    // ALIASES

    addUnitAlias('date', 'D');

    // PRIORITY
    addUnitPriority('date', 9);

    // PARSING

    addRegexToken('D',  match1to2);
    addRegexToken('DD', match1to2, match2);
    addRegexToken('Do', function (isStrict, locale) {
        // TODO: Remove "ordinalParse" fallback in next major release.
        return isStrict ?
          (locale._dayOfMonthOrdinalParse || locale._ordinalParse) :
          locale._dayOfMonthOrdinalParseLenient;
    });

    addParseToken(['D', 'DD'], DATE);
    addParseToken('Do', function (input, array) {
        array[DATE] = toInt(input.match(match1to2)[0]);
    });

    // MOMENTS

    var getSetDayOfMonth = makeGetSet('Date', true);

    // FORMATTING

    addFormatToken('DDD', ['DDDD', 3], 'DDDo', 'dayOfYear');

    // ALIASES

    addUnitAlias('dayOfYear', 'DDD');

    // PRIORITY
    addUnitPriority('dayOfYear', 4);

    // PARSING

    addRegexToken('DDD',  match1to3);
    addRegexToken('DDDD', match3);
    addParseToken(['DDD', 'DDDD'], function (input, array, config) {
        config._dayOfYear = toInt(input);
    });

    // HELPERS

    // MOMENTS

    function getSetDayOfYear (input) {
        var dayOfYear = Math.round((this.clone().startOf('day') - this.clone().startOf('year')) / 864e5) + 1;
        return input == null ? dayOfYear : this.add((input - dayOfYear), 'd');
    }

    // FORMATTING

    addFormatToken('m', ['mm', 2], 0, 'minute');

    // ALIASES

    addUnitAlias('minute', 'm');

    // PRIORITY

    addUnitPriority('minute', 14);

    // PARSING

    addRegexToken('m',  match1to2);
    addRegexToken('mm', match1to2, match2);
    addParseToken(['m', 'mm'], MINUTE);

    // MOMENTS

    var getSetMinute = makeGetSet('Minutes', false);

    // FORMATTING

    addFormatToken('s', ['ss', 2], 0, 'second');

    // ALIASES

    addUnitAlias('second', 's');

    // PRIORITY

    addUnitPriority('second', 15);

    // PARSING

    addRegexToken('s',  match1to2);
    addRegexToken('ss', match1to2, match2);
    addParseToken(['s', 'ss'], SECOND);

    // MOMENTS

    var getSetSecond = makeGetSet('Seconds', false);

    // FORMATTING

    addFormatToken('S', 0, 0, function () {
        return ~~(this.millisecond() / 100);
    });

    addFormatToken(0, ['SS', 2], 0, function () {
        return ~~(this.millisecond() / 10);
    });

    addFormatToken(0, ['SSS', 3], 0, 'millisecond');
    addFormatToken(0, ['SSSS', 4], 0, function () {
        return this.millisecond() * 10;
    });
    addFormatToken(0, ['SSSSS', 5], 0, function () {
        return this.millisecond() * 100;
    });
    addFormatToken(0, ['SSSSSS', 6], 0, function () {
        return this.millisecond() * 1000;
    });
    addFormatToken(0, ['SSSSSSS', 7], 0, function () {
        return this.millisecond() * 10000;
    });
    addFormatToken(0, ['SSSSSSSS', 8], 0, function () {
        return this.millisecond() * 100000;
    });
    addFormatToken(0, ['SSSSSSSSS', 9], 0, function () {
        return this.millisecond() * 1000000;
    });


    // ALIASES

    addUnitAlias('millisecond', 'ms');

    // PRIORITY

    addUnitPriority('millisecond', 16);

    // PARSING

    addRegexToken('S',    match1to3, match1);
    addRegexToken('SS',   match1to3, match2);
    addRegexToken('SSS',  match1to3, match3);

    var token;
    for (token = 'SSSS'; token.length <= 9; token += 'S') {
        addRegexToken(token, matchUnsigned);
    }

    function parseMs(input, array) {
        array[MILLISECOND] = toInt(('0.' + input) * 1000);
    }

    for (token = 'S'; token.length <= 9; token += 'S') {
        addParseToken(token, parseMs);
    }
    // MOMENTS

    var getSetMillisecond = makeGetSet('Milliseconds', false);

    // FORMATTING

    addFormatToken('z',  0, 0, 'zoneAbbr');
    addFormatToken('zz', 0, 0, 'zoneName');

    // MOMENTS

    function getZoneAbbr () {
        return this._isUTC ? 'UTC' : '';
    }

    function getZoneName () {
        return this._isUTC ? 'Coordinated Universal Time' : '';
    }

    var proto = Moment.prototype;

    proto.add               = add;
    proto.calendar          = calendar$1;
    proto.clone             = clone;
    proto.diff              = diff;
    proto.endOf             = endOf;
    proto.format            = format;
    proto.from              = from;
    proto.fromNow           = fromNow;
    proto.to                = to;
    proto.toNow             = toNow;
    proto.get               = stringGet;
    proto.invalidAt         = invalidAt;
    proto.isAfter           = isAfter;
    proto.isBefore          = isBefore;
    proto.isBetween         = isBetween;
    proto.isSame            = isSame;
    proto.isSameOrAfter     = isSameOrAfter;
    proto.isSameOrBefore    = isSameOrBefore;
    proto.isValid           = isValid$2;
    proto.lang              = lang;
    proto.locale            = locale;
    proto.localeData        = localeData;
    proto.max               = prototypeMax;
    proto.min               = prototypeMin;
    proto.parsingFlags      = parsingFlags;
    proto.set               = stringSet;
    proto.startOf           = startOf;
    proto.subtract          = subtract;
    proto.toArray           = toArray;
    proto.toObject          = toObject;
    proto.toDate            = toDate;
    proto.toISOString       = toISOString;
    proto.inspect           = inspect;
    proto.toJSON            = toJSON;
    proto.toString          = toString;
    proto.unix              = unix;
    proto.valueOf           = valueOf;
    proto.creationData      = creationData;
    proto.year       = getSetYear;
    proto.isLeapYear = getIsLeapYear;
    proto.weekYear    = getSetWeekYear;
    proto.isoWeekYear = getSetISOWeekYear;
    proto.quarter = proto.quarters = getSetQuarter;
    proto.month       = getSetMonth;
    proto.daysInMonth = getDaysInMonth;
    proto.week           = proto.weeks        = getSetWeek;
    proto.isoWeek        = proto.isoWeeks     = getSetISOWeek;
    proto.weeksInYear    = getWeeksInYear;
    proto.isoWeeksInYear = getISOWeeksInYear;
    proto.date       = getSetDayOfMonth;
    proto.day        = proto.days             = getSetDayOfWeek;
    proto.weekday    = getSetLocaleDayOfWeek;
    proto.isoWeekday = getSetISODayOfWeek;
    proto.dayOfYear  = getSetDayOfYear;
    proto.hour = proto.hours = getSetHour;
    proto.minute = proto.minutes = getSetMinute;
    proto.second = proto.seconds = getSetSecond;
    proto.millisecond = proto.milliseconds = getSetMillisecond;
    proto.utcOffset            = getSetOffset;
    proto.utc                  = setOffsetToUTC;
    proto.local                = setOffsetToLocal;
    proto.parseZone            = setOffsetToParsedOffset;
    proto.hasAlignedHourOffset = hasAlignedHourOffset;
    proto.isDST                = isDaylightSavingTime;
    proto.isLocal              = isLocal;
    proto.isUtcOffset          = isUtcOffset;
    proto.isUtc                = isUtc;
    proto.isUTC                = isUtc;
    proto.zoneAbbr = getZoneAbbr;
    proto.zoneName = getZoneName;
    proto.dates  = deprecate('dates accessor is deprecated. Use date instead.', getSetDayOfMonth);
    proto.months = deprecate('months accessor is deprecated. Use month instead', getSetMonth);
    proto.years  = deprecate('years accessor is deprecated. Use year instead', getSetYear);
    proto.zone   = deprecate('moment().zone is deprecated, use moment().utcOffset instead. http://momentjs.com/guides/#/warnings/zone/', getSetZone);
    proto.isDSTShifted = deprecate('isDSTShifted is deprecated. See http://momentjs.com/guides/#/warnings/dst-shifted/ for more information', isDaylightSavingTimeShifted);

    function createUnix (input) {
        return createLocal(input * 1000);
    }

    function createInZone () {
        return createLocal.apply(null, arguments).parseZone();
    }

    function preParsePostFormat (string) {
        return string;
    }

    var proto$1 = Locale.prototype;

    proto$1.calendar        = calendar;
    proto$1.longDateFormat  = longDateFormat;
    proto$1.invalidDate     = invalidDate;
    proto$1.ordinal         = ordinal;
    proto$1.preparse        = preParsePostFormat;
    proto$1.postformat      = preParsePostFormat;
    proto$1.relativeTime    = relativeTime;
    proto$1.pastFuture      = pastFuture;
    proto$1.set             = set;

    proto$1.months            =        localeMonths;
    proto$1.monthsShort       =        localeMonthsShort;
    proto$1.monthsParse       =        localeMonthsParse;
    proto$1.monthsRegex       = monthsRegex;
    proto$1.monthsShortRegex  = monthsShortRegex;
    proto$1.week = localeWeek;
    proto$1.firstDayOfYear = localeFirstDayOfYear;
    proto$1.firstDayOfWeek = localeFirstDayOfWeek;

    proto$1.weekdays       =        localeWeekdays;
    proto$1.weekdaysMin    =        localeWeekdaysMin;
    proto$1.weekdaysShort  =        localeWeekdaysShort;
    proto$1.weekdaysParse  =        localeWeekdaysParse;

    proto$1.weekdaysRegex       =        weekdaysRegex;
    proto$1.weekdaysShortRegex  =        weekdaysShortRegex;
    proto$1.weekdaysMinRegex    =        weekdaysMinRegex;

    proto$1.isPM = localeIsPM;
    proto$1.meridiem = localeMeridiem;

    function get$1 (format, index, field, setter) {
        var locale = getLocale();
        var utc = createUTC().set(setter, index);
        return locale[field](utc, format);
    }

    function listMonthsImpl (format, index, field) {
        if (isNumber(format)) {
            index = format;
            format = undefined;
        }

        format = format || '';

        if (index != null) {
            return get$1(format, index, field, 'month');
        }

        var i;
        var out = [];
        for (i = 0; i < 12; i++) {
            out[i] = get$1(format, i, field, 'month');
        }
        return out;
    }

    // ()
    // (5)
    // (fmt, 5)
    // (fmt)
    // (true)
    // (true, 5)
    // (true, fmt, 5)
    // (true, fmt)
    function listWeekdaysImpl (localeSorted, format, index, field) {
        if (typeof localeSorted === 'boolean') {
            if (isNumber(format)) {
                index = format;
                format = undefined;
            }

            format = format || '';
        } else {
            format = localeSorted;
            index = format;
            localeSorted = false;

            if (isNumber(format)) {
                index = format;
                format = undefined;
            }

            format = format || '';
        }

        var locale = getLocale(),
            shift = localeSorted ? locale._week.dow : 0;

        if (index != null) {
            return get$1(format, (index + shift) % 7, field, 'day');
        }

        var i;
        var out = [];
        for (i = 0; i < 7; i++) {
            out[i] = get$1(format, (i + shift) % 7, field, 'day');
        }
        return out;
    }

    function listMonths (format, index) {
        return listMonthsImpl(format, index, 'months');
    }

    function listMonthsShort (format, index) {
        return listMonthsImpl(format, index, 'monthsShort');
    }

    function listWeekdays (localeSorted, format, index) {
        return listWeekdaysImpl(localeSorted, format, index, 'weekdays');
    }

    function listWeekdaysShort (localeSorted, format, index) {
        return listWeekdaysImpl(localeSorted, format, index, 'weekdaysShort');
    }

    function listWeekdaysMin (localeSorted, format, index) {
        return listWeekdaysImpl(localeSorted, format, index, 'weekdaysMin');
    }

    getSetGlobalLocale('en', {
        dayOfMonthOrdinalParse: /\d{1,2}(th|st|nd|rd)/,
        ordinal : function (number) {
            var b = number % 10,
                output = (toInt(number % 100 / 10) === 1) ? 'th' :
                (b === 1) ? 'st' :
                (b === 2) ? 'nd' :
                (b === 3) ? 'rd' : 'th';
            return number + output;
        }
    });

    // Side effect imports

    hooks.lang = deprecate('moment.lang is deprecated. Use moment.locale instead.', getSetGlobalLocale);
    hooks.langData = deprecate('moment.langData is deprecated. Use moment.localeData instead.', getLocale);

    var mathAbs = Math.abs;

    function abs () {
        var data           = this._data;

        this._milliseconds = mathAbs(this._milliseconds);
        this._days         = mathAbs(this._days);
        this._months       = mathAbs(this._months);

        data.milliseconds  = mathAbs(data.milliseconds);
        data.seconds       = mathAbs(data.seconds);
        data.minutes       = mathAbs(data.minutes);
        data.hours         = mathAbs(data.hours);
        data.months        = mathAbs(data.months);
        data.years         = mathAbs(data.years);

        return this;
    }

    function addSubtract$1 (duration, input, value, direction) {
        var other = createDuration(input, value);

        duration._milliseconds += direction * other._milliseconds;
        duration._days         += direction * other._days;
        duration._months       += direction * other._months;

        return duration._bubble();
    }

    // supports only 2.0-style add(1, 's') or add(duration)
    function add$1 (input, value) {
        return addSubtract$1(this, input, value, 1);
    }

    // supports only 2.0-style subtract(1, 's') or subtract(duration)
    function subtract$1 (input, value) {
        return addSubtract$1(this, input, value, -1);
    }

    function absCeil (number) {
        if (number < 0) {
            return Math.floor(number);
        } else {
            return Math.ceil(number);
        }
    }

    function bubble () {
        var milliseconds = this._milliseconds;
        var days         = this._days;
        var months       = this._months;
        var data         = this._data;
        var seconds, minutes, hours, years, monthsFromDays;

        // if we have a mix of positive and negative values, bubble down first
        // check: https://github.com/moment/moment/issues/2166
        if (!((milliseconds >= 0 && days >= 0 && months >= 0) ||
                (milliseconds <= 0 && days <= 0 && months <= 0))) {
            milliseconds += absCeil(monthsToDays(months) + days) * 864e5;
            days = 0;
            months = 0;
        }

        // The following code bubbles up values, see the tests for
        // examples of what that means.
        data.milliseconds = milliseconds % 1000;

        seconds           = absFloor(milliseconds / 1000);
        data.seconds      = seconds % 60;

        minutes           = absFloor(seconds / 60);
        data.minutes      = minutes % 60;

        hours             = absFloor(minutes / 60);
        data.hours        = hours % 24;

        days += absFloor(hours / 24);

        // convert days to months
        monthsFromDays = absFloor(daysToMonths(days));
        months += monthsFromDays;
        days -= absCeil(monthsToDays(monthsFromDays));

        // 12 months -> 1 year
        years = absFloor(months / 12);
        months %= 12;

        data.days   = days;
        data.months = months;
        data.years  = years;

        return this;
    }

    function daysToMonths (days) {
        // 400 years have 146097 days (taking into account leap year rules)
        // 400 years have 12 months === 4800
        return days * 4800 / 146097;
    }

    function monthsToDays (months) {
        // the reverse of daysToMonths
        return months * 146097 / 4800;
    }

    function as (units) {
        if (!this.isValid()) {
            return NaN;
        }
        var days;
        var months;
        var milliseconds = this._milliseconds;

        units = normalizeUnits(units);

        if (units === 'month' || units === 'quarter' || units === 'year') {
            days = this._days + milliseconds / 864e5;
            months = this._months + daysToMonths(days);
            switch (units) {
                case 'month':   return months;
                case 'quarter': return months / 3;
                case 'year':    return months / 12;
            }
        } else {
            // handle milliseconds separately because of floating point math errors (issue #1867)
            days = this._days + Math.round(monthsToDays(this._months));
            switch (units) {
                case 'week'   : return days / 7     + milliseconds / 6048e5;
                case 'day'    : return days         + milliseconds / 864e5;
                case 'hour'   : return days * 24    + milliseconds / 36e5;
                case 'minute' : return days * 1440  + milliseconds / 6e4;
                case 'second' : return days * 86400 + milliseconds / 1000;
                // Math.floor prevents floating point math errors here
                case 'millisecond': return Math.floor(days * 864e5) + milliseconds;
                default: throw new Error('Unknown unit ' + units);
            }
        }
    }

    // TODO: Use this.as('ms')?
    function valueOf$1 () {
        if (!this.isValid()) {
            return NaN;
        }
        return (
            this._milliseconds +
            this._days * 864e5 +
            (this._months % 12) * 2592e6 +
            toInt(this._months / 12) * 31536e6
        );
    }

    function makeAs (alias) {
        return function () {
            return this.as(alias);
        };
    }

    var asMilliseconds = makeAs('ms');
    var asSeconds      = makeAs('s');
    var asMinutes      = makeAs('m');
    var asHours        = makeAs('h');
    var asDays         = makeAs('d');
    var asWeeks        = makeAs('w');
    var asMonths       = makeAs('M');
    var asQuarters     = makeAs('Q');
    var asYears        = makeAs('y');

    function clone$1 () {
        return createDuration(this);
    }

    function get$2 (units) {
        units = normalizeUnits(units);
        return this.isValid() ? this[units + 's']() : NaN;
    }

    function makeGetter(name) {
        return function () {
            return this.isValid() ? this._data[name] : NaN;
        };
    }

    var milliseconds = makeGetter('milliseconds');
    var seconds      = makeGetter('seconds');
    var minutes      = makeGetter('minutes');
    var hours        = makeGetter('hours');
    var days         = makeGetter('days');
    var months       = makeGetter('months');
    var years        = makeGetter('years');

    function weeks () {
        return absFloor(this.days() / 7);
    }

    var round = Math.round;
    var thresholds = {
        ss: 44,         // a few seconds to seconds
        s : 45,         // seconds to minute
        m : 45,         // minutes to hour
        h : 22,         // hours to day
        d : 26,         // days to month
        M : 11          // months to year
    };

    // helper function for moment.fn.from, moment.fn.fromNow, and moment.duration.fn.humanize
    function substituteTimeAgo(string, number, withoutSuffix, isFuture, locale) {
        return locale.relativeTime(number || 1, !!withoutSuffix, string, isFuture);
    }

    function relativeTime$1 (posNegDuration, withoutSuffix, locale) {
        var duration = createDuration(posNegDuration).abs();
        var seconds  = round(duration.as('s'));
        var minutes  = round(duration.as('m'));
        var hours    = round(duration.as('h'));
        var days     = round(duration.as('d'));
        var months   = round(duration.as('M'));
        var years    = round(duration.as('y'));

        var a = seconds <= thresholds.ss && ['s', seconds]  ||
                seconds < thresholds.s   && ['ss', seconds] ||
                minutes <= 1             && ['m']           ||
                minutes < thresholds.m   && ['mm', minutes] ||
                hours   <= 1             && ['h']           ||
                hours   < thresholds.h   && ['hh', hours]   ||
                days    <= 1             && ['d']           ||
                days    < thresholds.d   && ['dd', days]    ||
                months  <= 1             && ['M']           ||
                months  < thresholds.M   && ['MM', months]  ||
                years   <= 1             && ['y']           || ['yy', years];

        a[2] = withoutSuffix;
        a[3] = +posNegDuration > 0;
        a[4] = locale;
        return substituteTimeAgo.apply(null, a);
    }

    // This function allows you to set the rounding function for relative time strings
    function getSetRelativeTimeRounding (roundingFunction) {
        if (roundingFunction === undefined) {
            return round;
        }
        if (typeof(roundingFunction) === 'function') {
            round = roundingFunction;
            return true;
        }
        return false;
    }

    // This function allows you to set a threshold for relative time strings
    function getSetRelativeTimeThreshold (threshold, limit) {
        if (thresholds[threshold] === undefined) {
            return false;
        }
        if (limit === undefined) {
            return thresholds[threshold];
        }
        thresholds[threshold] = limit;
        if (threshold === 's') {
            thresholds.ss = limit - 1;
        }
        return true;
    }

    function humanize (withSuffix) {
        if (!this.isValid()) {
            return this.localeData().invalidDate();
        }

        var locale = this.localeData();
        var output = relativeTime$1(this, !withSuffix, locale);

        if (withSuffix) {
            output = locale.pastFuture(+this, output);
        }

        return locale.postformat(output);
    }

    var abs$1 = Math.abs;

    function sign(x) {
        return ((x > 0) - (x < 0)) || +x;
    }

    function toISOString$1() {
        // for ISO strings we do not use the normal bubbling rules:
        //  * milliseconds bubble up until they become hours
        //  * days do not bubble at all
        //  * months bubble up until they become years
        // This is because there is no context-free conversion between hours and days
        // (think of clock changes)
        // and also not between days and months (28-31 days per month)
        if (!this.isValid()) {
            return this.localeData().invalidDate();
        }

        var seconds = abs$1(this._milliseconds) / 1000;
        var days         = abs$1(this._days);
        var months       = abs$1(this._months);
        var minutes, hours, years;

        // 3600 seconds -> 60 minutes -> 1 hour
        minutes           = absFloor(seconds / 60);
        hours             = absFloor(minutes / 60);
        seconds %= 60;
        minutes %= 60;

        // 12 months -> 1 year
        years  = absFloor(months / 12);
        months %= 12;


        // inspired by https://github.com/dordille/moment-isoduration/blob/master/moment.isoduration.js
        var Y = years;
        var M = months;
        var D = days;
        var h = hours;
        var m = minutes;
        var s = seconds ? seconds.toFixed(3).replace(/\.?0+$/, '') : '';
        var total = this.asSeconds();

        if (!total) {
            // this is the same as C#'s (Noda) and python (isodate)...
            // but not other JS (goog.date)
            return 'P0D';
        }

        var totalSign = total < 0 ? '-' : '';
        var ymSign = sign(this._months) !== sign(total) ? '-' : '';
        var daysSign = sign(this._days) !== sign(total) ? '-' : '';
        var hmsSign = sign(this._milliseconds) !== sign(total) ? '-' : '';

        return totalSign + 'P' +
            (Y ? ymSign + Y + 'Y' : '') +
            (M ? ymSign + M + 'M' : '') +
            (D ? daysSign + D + 'D' : '') +
            ((h || m || s) ? 'T' : '') +
            (h ? hmsSign + h + 'H' : '') +
            (m ? hmsSign + m + 'M' : '') +
            (s ? hmsSign + s + 'S' : '');
    }

    var proto$2 = Duration.prototype;

    proto$2.isValid        = isValid$1;
    proto$2.abs            = abs;
    proto$2.add            = add$1;
    proto$2.subtract       = subtract$1;
    proto$2.as             = as;
    proto$2.asMilliseconds = asMilliseconds;
    proto$2.asSeconds      = asSeconds;
    proto$2.asMinutes      = asMinutes;
    proto$2.asHours        = asHours;
    proto$2.asDays         = asDays;
    proto$2.asWeeks        = asWeeks;
    proto$2.asMonths       = asMonths;
    proto$2.asQuarters     = asQuarters;
    proto$2.asYears        = asYears;
    proto$2.valueOf        = valueOf$1;
    proto$2._bubble        = bubble;
    proto$2.clone          = clone$1;
    proto$2.get            = get$2;
    proto$2.milliseconds   = milliseconds;
    proto$2.seconds        = seconds;
    proto$2.minutes        = minutes;
    proto$2.hours          = hours;
    proto$2.days           = days;
    proto$2.weeks          = weeks;
    proto$2.months         = months;
    proto$2.years          = years;
    proto$2.humanize       = humanize;
    proto$2.toISOString    = toISOString$1;
    proto$2.toString       = toISOString$1;
    proto$2.toJSON         = toISOString$1;
    proto$2.locale         = locale;
    proto$2.localeData     = localeData;

    proto$2.toIsoString = deprecate('toIsoString() is deprecated. Please use toISOString() instead (notice the capitals)', toISOString$1);
    proto$2.lang = lang;

    // Side effect imports

    // FORMATTING

    addFormatToken('X', 0, 0, 'unix');
    addFormatToken('x', 0, 0, 'valueOf');

    // PARSING

    addRegexToken('x', matchSigned);
    addRegexToken('X', matchTimestamp);
    addParseToken('X', function (input, array, config) {
        config._d = new Date(parseFloat(input, 10) * 1000);
    });
    addParseToken('x', function (input, array, config) {
        config._d = new Date(toInt(input));
    });

    // Side effect imports


    hooks.version = '2.24.0';

    setHookCallback(createLocal);

    hooks.fn                    = proto;
    hooks.min                   = min;
    hooks.max                   = max;
    hooks.now                   = now;
    hooks.utc                   = createUTC;
    hooks.unix                  = createUnix;
    hooks.months                = listMonths;
    hooks.isDate                = isDate;
    hooks.locale                = getSetGlobalLocale;
    hooks.invalid               = createInvalid;
    hooks.duration              = createDuration;
    hooks.isMoment              = isMoment;
    hooks.weekdays              = listWeekdays;
    hooks.parseZone             = createInZone;
    hooks.localeData            = getLocale;
    hooks.isDuration            = isDuration;
    hooks.monthsShort           = listMonthsShort;
    hooks.weekdaysMin           = listWeekdaysMin;
    hooks.defineLocale          = defineLocale;
    hooks.updateLocale          = updateLocale;
    hooks.locales               = listLocales;
    hooks.weekdaysShort         = listWeekdaysShort;
    hooks.normalizeUnits        = normalizeUnits;
    hooks.relativeTimeRounding  = getSetRelativeTimeRounding;
    hooks.relativeTimeThreshold = getSetRelativeTimeThreshold;
    hooks.calendarFormat        = getCalendarFormat;
    hooks.prototype             = proto;

    // currently HTML5 input type only supports 24-hour formats
    hooks.HTML5_FMT = {
        DATETIME_LOCAL: 'YYYY-MM-DDTHH:mm',             // <input type="datetime-local" />
        DATETIME_LOCAL_SECONDS: 'YYYY-MM-DDTHH:mm:ss',  // <input type="datetime-local" step="1" />
        DATETIME_LOCAL_MS: 'YYYY-MM-DDTHH:mm:ss.SSS',   // <input type="datetime-local" step="0.001" />
        DATE: 'YYYY-MM-DD',                             // <input type="date" />
        TIME: 'HH:mm',                                  // <input type="time" />
        TIME_SECONDS: 'HH:mm:ss',                       // <input type="time" step="1" />
        TIME_MS: 'HH:mm:ss.SSS',                        // <input type="time" step="0.001" />
        WEEK: 'GGGG-[W]WW',                             // <input type="week" />
        MONTH: 'YYYY-MM'                                // <input type="month" />
    };

    return hooks;

})));

// Source: node_modules/babel-polyfill/dist/polyfill.js
(function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(_dereq_,module,exports){
(function (global){
_dereq_(327);

_dereq_(328);

_dereq_(2);

if (global._babelPolyfill) {
  throw new Error("only one instance of babel-polyfill is allowed");
}
global._babelPolyfill = true;

var DEFINE_PROPERTY = "defineProperty";
function define(O, key, value) {
  O[key] || Object[DEFINE_PROPERTY](O, key, {
    writable: true,
    configurable: true,
    value: value
  });
}

define(String.prototype, "padLeft", "".padStart);
define(String.prototype, "padRight", "".padEnd);

"pop,reverse,shift,keys,values,entries,indexOf,every,some,forEach,map,filter,find,findIndex,includes,join,slice,concat,push,splice,unshift,sort,lastIndexOf,reduce,reduceRight,copyWithin,fill".split(",").forEach(function (key) {
  [][key] && define(Array, key, Function.call.bind([][key]));
});
}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})
},{"2":2,"327":327,"328":328}],2:[function(_dereq_,module,exports){
_dereq_(130);
module.exports = _dereq_(23).RegExp.escape;

},{"130":130,"23":23}],3:[function(_dereq_,module,exports){
module.exports = function (it) {
  if (typeof it != 'function') throw TypeError(it + ' is not a function!');
  return it;
};

},{}],4:[function(_dereq_,module,exports){
var cof = _dereq_(18);
module.exports = function (it, msg) {
  if (typeof it != 'number' && cof(it) != 'Number') throw TypeError(msg);
  return +it;
};

},{"18":18}],5:[function(_dereq_,module,exports){
// 22.1.3.31 Array.prototype[@@unscopables]
var UNSCOPABLES = _dereq_(128)('unscopables');
var ArrayProto = Array.prototype;
if (ArrayProto[UNSCOPABLES] == undefined) _dereq_(42)(ArrayProto, UNSCOPABLES, {});
module.exports = function (key) {
  ArrayProto[UNSCOPABLES][key] = true;
};

},{"128":128,"42":42}],6:[function(_dereq_,module,exports){
module.exports = function (it, Constructor, name, forbiddenField) {
  if (!(it instanceof Constructor) || (forbiddenField !== undefined && forbiddenField in it)) {
    throw TypeError(name + ': incorrect invocation!');
  } return it;
};

},{}],7:[function(_dereq_,module,exports){
var isObject = _dereq_(51);
module.exports = function (it) {
  if (!isObject(it)) throw TypeError(it + ' is not an object!');
  return it;
};

},{"51":51}],8:[function(_dereq_,module,exports){
// 22.1.3.3 Array.prototype.copyWithin(target, start, end = this.length)
var toObject = _dereq_(119);
var toAbsoluteIndex = _dereq_(114);
var toLength = _dereq_(118);

module.exports = [].copyWithin || function copyWithin(target /* = 0 */, start /* = 0, end = @length */) {
  var O = toObject(this);
  var len = toLength(O.length);
  var to = toAbsoluteIndex(target, len);
  var from = toAbsoluteIndex(start, len);
  var end = arguments.length > 2 ? arguments[2] : undefined;
  var count = Math.min((end === undefined ? len : toAbsoluteIndex(end, len)) - from, len - to);
  var inc = 1;
  if (from < to && to < from + count) {
    inc = -1;
    from += count - 1;
    to += count - 1;
  }
  while (count-- > 0) {
    if (from in O) O[to] = O[from];
    else delete O[to];
    to += inc;
    from += inc;
  } return O;
};

},{"114":114,"118":118,"119":119}],9:[function(_dereq_,module,exports){
// 22.1.3.6 Array.prototype.fill(value, start = 0, end = this.length)
var toObject = _dereq_(119);
var toAbsoluteIndex = _dereq_(114);
var toLength = _dereq_(118);
module.exports = function fill(value /* , start = 0, end = @length */) {
  var O = toObject(this);
  var length = toLength(O.length);
  var aLen = arguments.length;
  var index = toAbsoluteIndex(aLen > 1 ? arguments[1] : undefined, length);
  var end = aLen > 2 ? arguments[2] : undefined;
  var endPos = end === undefined ? length : toAbsoluteIndex(end, length);
  while (endPos > index) O[index++] = value;
  return O;
};

},{"114":114,"118":118,"119":119}],10:[function(_dereq_,module,exports){
var forOf = _dereq_(39);

module.exports = function (iter, ITERATOR) {
  var result = [];
  forOf(iter, false, result.push, result, ITERATOR);
  return result;
};

},{"39":39}],11:[function(_dereq_,module,exports){
// false -> Array#indexOf
// true  -> Array#includes
var toIObject = _dereq_(117);
var toLength = _dereq_(118);
var toAbsoluteIndex = _dereq_(114);
module.exports = function (IS_INCLUDES) {
  return function ($this, el, fromIndex) {
    var O = toIObject($this);
    var length = toLength(O.length);
    var index = toAbsoluteIndex(fromIndex, length);
    var value;
    // Array#includes uses SameValueZero equality algorithm
    // eslint-disable-next-line no-self-compare
    if (IS_INCLUDES && el != el) while (length > index) {
      value = O[index++];
      // eslint-disable-next-line no-self-compare
      if (value != value) return true;
    // Array#indexOf ignores holes, Array#includes - not
    } else for (;length > index; index++) if (IS_INCLUDES || index in O) {
      if (O[index] === el) return IS_INCLUDES || index || 0;
    } return !IS_INCLUDES && -1;
  };
};

},{"114":114,"117":117,"118":118}],12:[function(_dereq_,module,exports){
// 0 -> Array#forEach
// 1 -> Array#map
// 2 -> Array#filter
// 3 -> Array#some
// 4 -> Array#every
// 5 -> Array#find
// 6 -> Array#findIndex
var ctx = _dereq_(25);
var IObject = _dereq_(47);
var toObject = _dereq_(119);
var toLength = _dereq_(118);
var asc = _dereq_(15);
module.exports = function (TYPE, $create) {
  var IS_MAP = TYPE == 1;
  var IS_FILTER = TYPE == 2;
  var IS_SOME = TYPE == 3;
  var IS_EVERY = TYPE == 4;
  var IS_FIND_INDEX = TYPE == 6;
  var NO_HOLES = TYPE == 5 || IS_FIND_INDEX;
  var create = $create || asc;
  return function ($this, callbackfn, that) {
    var O = toObject($this);
    var self = IObject(O);
    var f = ctx(callbackfn, that, 3);
    var length = toLength(self.length);
    var index = 0;
    var result = IS_MAP ? create($this, length) : IS_FILTER ? create($this, 0) : undefined;
    var val, res;
    for (;length > index; index++) if (NO_HOLES || index in self) {
      val = self[index];
      res = f(val, index, O);
      if (TYPE) {
        if (IS_MAP) result[index] = res;   // map
        else if (res) switch (TYPE) {
          case 3: return true;             // some
          case 5: return val;              // find
          case 6: return index;            // findIndex
          case 2: result.push(val);        // filter
        } else if (IS_EVERY) return false; // every
      }
    }
    return IS_FIND_INDEX ? -1 : IS_SOME || IS_EVERY ? IS_EVERY : result;
  };
};

},{"118":118,"119":119,"15":15,"25":25,"47":47}],13:[function(_dereq_,module,exports){
var aFunction = _dereq_(3);
var toObject = _dereq_(119);
var IObject = _dereq_(47);
var toLength = _dereq_(118);

module.exports = function (that, callbackfn, aLen, memo, isRight) {
  aFunction(callbackfn);
  var O = toObject(that);
  var self = IObject(O);
  var length = toLength(O.length);
  var index = isRight ? length - 1 : 0;
  var i = isRight ? -1 : 1;
  if (aLen < 2) for (;;) {
    if (index in self) {
      memo = self[index];
      index += i;
      break;
    }
    index += i;
    if (isRight ? index < 0 : length <= index) {
      throw TypeError('Reduce of empty array with no initial value');
    }
  }
  for (;isRight ? index >= 0 : length > index; index += i) if (index in self) {
    memo = callbackfn(memo, self[index], index, O);
  }
  return memo;
};

},{"118":118,"119":119,"3":3,"47":47}],14:[function(_dereq_,module,exports){
var isObject = _dereq_(51);
var isArray = _dereq_(49);
var SPECIES = _dereq_(128)('species');

module.exports = function (original) {
  var C;
  if (isArray(original)) {
    C = original.constructor;
    // cross-realm fallback
    if (typeof C == 'function' && (C === Array || isArray(C.prototype))) C = undefined;
    if (isObject(C)) {
      C = C[SPECIES];
      if (C === null) C = undefined;
    }
  } return C === undefined ? Array : C;
};

},{"128":128,"49":49,"51":51}],15:[function(_dereq_,module,exports){
// 9.4.2.3 ArraySpeciesCreate(originalArray, length)
var speciesConstructor = _dereq_(14);

module.exports = function (original, length) {
  return new (speciesConstructor(original))(length);
};

},{"14":14}],16:[function(_dereq_,module,exports){
var aFunction = _dereq_(3);
var isObject = _dereq_(51);
var invoke = _dereq_(46);
var arraySlice = [].slice;
var factories = {};

var construct = function (F, len, args) {
  if (!(len in factories)) {
    for (var n = [], i = 0; i < len; i++) n[i] = 'a[' + i + ']';
    // eslint-disable-next-line no-new-func
    factories[len] = Function('F,a', 'return new F(' + n.join(',') + ')');
  } return factories[len](F, args);
};

module.exports = Function.bind || function bind(that /* , ...args */) {
  var fn = aFunction(this);
  var partArgs = arraySlice.call(arguments, 1);
  var bound = function (/* args... */) {
    var args = partArgs.concat(arraySlice.call(arguments));
    return this instanceof bound ? construct(fn, args.length, args) : invoke(fn, args, that);
  };
  if (isObject(fn.prototype)) bound.prototype = fn.prototype;
  return bound;
};

},{"3":3,"46":46,"51":51}],17:[function(_dereq_,module,exports){
// getting tag from 19.1.3.6 Object.prototype.toString()
var cof = _dereq_(18);
var TAG = _dereq_(128)('toStringTag');
// ES3 wrong here
var ARG = cof(function () { return arguments; }()) == 'Arguments';

// fallback for IE11 Script Access Denied error
var tryGet = function (it, key) {
  try {
    return it[key];
  } catch (e) { /* empty */ }
};

module.exports = function (it) {
  var O, T, B;
  return it === undefined ? 'Undefined' : it === null ? 'Null'
    // @@toStringTag case
    : typeof (T = tryGet(O = Object(it), TAG)) == 'string' ? T
    // builtinTag case
    : ARG ? cof(O)
    // ES3 arguments fallback
    : (B = cof(O)) == 'Object' && typeof O.callee == 'function' ? 'Arguments' : B;
};

},{"128":128,"18":18}],18:[function(_dereq_,module,exports){
var toString = {}.toString;

module.exports = function (it) {
  return toString.call(it).slice(8, -1);
};

},{}],19:[function(_dereq_,module,exports){
var dP = _dereq_(72).f;
var create = _dereq_(71);
var redefineAll = _dereq_(93);
var ctx = _dereq_(25);
var anInstance = _dereq_(6);
var forOf = _dereq_(39);
var $iterDefine = _dereq_(55);
var step = _dereq_(57);
var setSpecies = _dereq_(100);
var DESCRIPTORS = _dereq_(29);
var fastKey = _dereq_(66).fastKey;
var validate = _dereq_(125);
var SIZE = DESCRIPTORS ? '_s' : 'size';

var getEntry = function (that, key) {
  // fast case
  var index = fastKey(key);
  var entry;
  if (index !== 'F') return that._i[index];
  // frozen object case
  for (entry = that._f; entry; entry = entry.n) {
    if (entry.k == key) return entry;
  }
};

module.exports = {
  getConstructor: function (wrapper, NAME, IS_MAP, ADDER) {
    var C = wrapper(function (that, iterable) {
      anInstance(that, C, NAME, '_i');
      that._t = NAME;         // collection type
      that._i = create(null); // index
      that._f = undefined;    // first entry
      that._l = undefined;    // last entry
      that[SIZE] = 0;         // size
      if (iterable != undefined) forOf(iterable, IS_MAP, that[ADDER], that);
    });
    redefineAll(C.prototype, {
      // 23.1.3.1 Map.prototype.clear()
      // 23.2.3.2 Set.prototype.clear()
      clear: function clear() {
        for (var that = validate(this, NAME), data = that._i, entry = that._f; entry; entry = entry.n) {
          entry.r = true;
          if (entry.p) entry.p = entry.p.n = undefined;
          delete data[entry.i];
        }
        that._f = that._l = undefined;
        that[SIZE] = 0;
      },
      // 23.1.3.3 Map.prototype.delete(key)
      // 23.2.3.4 Set.prototype.delete(value)
      'delete': function (key) {
        var that = validate(this, NAME);
        var entry = getEntry(that, key);
        if (entry) {
          var next = entry.n;
          var prev = entry.p;
          delete that._i[entry.i];
          entry.r = true;
          if (prev) prev.n = next;
          if (next) next.p = prev;
          if (that._f == entry) that._f = next;
          if (that._l == entry) that._l = prev;
          that[SIZE]--;
        } return !!entry;
      },
      // 23.2.3.6 Set.prototype.forEach(callbackfn, thisArg = undefined)
      // 23.1.3.5 Map.prototype.forEach(callbackfn, thisArg = undefined)
      forEach: function forEach(callbackfn /* , that = undefined */) {
        validate(this, NAME);
        var f = ctx(callbackfn, arguments.length > 1 ? arguments[1] : undefined, 3);
        var entry;
        while (entry = entry ? entry.n : this._f) {
          f(entry.v, entry.k, this);
          // revert to the last existing entry
          while (entry && entry.r) entry = entry.p;
        }
      },
      // 23.1.3.7 Map.prototype.has(key)
      // 23.2.3.7 Set.prototype.has(value)
      has: function has(key) {
        return !!getEntry(validate(this, NAME), key);
      }
    });
    if (DESCRIPTORS) dP(C.prototype, 'size', {
      get: function () {
        return validate(this, NAME)[SIZE];
      }
    });
    return C;
  },
  def: function (that, key, value) {
    var entry = getEntry(that, key);
    var prev, index;
    // change existing entry
    if (entry) {
      entry.v = value;
    // create new entry
    } else {
      that._l = entry = {
        i: index = fastKey(key, true), // <- index
        k: key,                        // <- key
        v: value,                      // <- value
        p: prev = that._l,             // <- previous entry
        n: undefined,                  // <- next entry
        r: false                       // <- removed
      };
      if (!that._f) that._f = entry;
      if (prev) prev.n = entry;
      that[SIZE]++;
      // add to index
      if (index !== 'F') that._i[index] = entry;
    } return that;
  },
  getEntry: getEntry,
  setStrong: function (C, NAME, IS_MAP) {
    // add .keys, .values, .entries, [@@iterator]
    // 23.1.3.4, 23.1.3.8, 23.1.3.11, 23.1.3.12, 23.2.3.5, 23.2.3.8, 23.2.3.10, 23.2.3.11
    $iterDefine(C, NAME, function (iterated, kind) {
      this._t = validate(iterated, NAME); // target
      this._k = kind;                     // kind
      this._l = undefined;                // previous
    }, function () {
      var that = this;
      var kind = that._k;
      var entry = that._l;
      // revert to the last existing entry
      while (entry && entry.r) entry = entry.p;
      // get next entry
      if (!that._t || !(that._l = entry = entry ? entry.n : that._t._f)) {
        // or finish the iteration
        that._t = undefined;
        return step(1);
      }
      // return step by kind
      if (kind == 'keys') return step(0, entry.k);
      if (kind == 'values') return step(0, entry.v);
      return step(0, [entry.k, entry.v]);
    }, IS_MAP ? 'entries' : 'values', !IS_MAP, true);

    // add [@@species], 23.1.2.2, 23.2.2.2
    setSpecies(NAME);
  }
};

},{"100":100,"125":125,"25":25,"29":29,"39":39,"55":55,"57":57,"6":6,"66":66,"71":71,"72":72,"93":93}],20:[function(_dereq_,module,exports){
// https://github.com/DavidBruant/Map-Set.prototype.toJSON
var classof = _dereq_(17);
var from = _dereq_(10);
module.exports = function (NAME) {
  return function toJSON() {
    if (classof(this) != NAME) throw TypeError(NAME + "#toJSON isn't generic");
    return from(this);
  };
};

},{"10":10,"17":17}],21:[function(_dereq_,module,exports){
var redefineAll = _dereq_(93);
var getWeak = _dereq_(66).getWeak;
var anObject = _dereq_(7);
var isObject = _dereq_(51);
var anInstance = _dereq_(6);
var forOf = _dereq_(39);
var createArrayMethod = _dereq_(12);
var $has = _dereq_(41);
var validate = _dereq_(125);
var arrayFind = createArrayMethod(5);
var arrayFindIndex = createArrayMethod(6);
var id = 0;

// fallback for uncaught frozen keys
var uncaughtFrozenStore = function (that) {
  return that._l || (that._l = new UncaughtFrozenStore());
};
var UncaughtFrozenStore = function () {
  this.a = [];
};
var findUncaughtFrozen = function (store, key) {
  return arrayFind(store.a, function (it) {
    return it[0] === key;
  });
};
UncaughtFrozenStore.prototype = {
  get: function (key) {
    var entry = findUncaughtFrozen(this, key);
    if (entry) return entry[1];
  },
  has: function (key) {
    return !!findUncaughtFrozen(this, key);
  },
  set: function (key, value) {
    var entry = findUncaughtFrozen(this, key);
    if (entry) entry[1] = value;
    else this.a.push([key, value]);
  },
  'delete': function (key) {
    var index = arrayFindIndex(this.a, function (it) {
      return it[0] === key;
    });
    if (~index) this.a.splice(index, 1);
    return !!~index;
  }
};

module.exports = {
  getConstructor: function (wrapper, NAME, IS_MAP, ADDER) {
    var C = wrapper(function (that, iterable) {
      anInstance(that, C, NAME, '_i');
      that._t = NAME;      // collection type
      that._i = id++;      // collection id
      that._l = undefined; // leak store for uncaught frozen objects
      if (iterable != undefined) forOf(iterable, IS_MAP, that[ADDER], that);
    });
    redefineAll(C.prototype, {
      // 23.3.3.2 WeakMap.prototype.delete(key)
      // 23.4.3.3 WeakSet.prototype.delete(value)
      'delete': function (key) {
        if (!isObject(key)) return false;
        var data = getWeak(key);
        if (data === true) return uncaughtFrozenStore(validate(this, NAME))['delete'](key);
        return data && $has(data, this._i) && delete data[this._i];
      },
      // 23.3.3.4 WeakMap.prototype.has(key)
      // 23.4.3.4 WeakSet.prototype.has(value)
      has: function has(key) {
        if (!isObject(key)) return false;
        var data = getWeak(key);
        if (data === true) return uncaughtFrozenStore(validate(this, NAME)).has(key);
        return data && $has(data, this._i);
      }
    });
    return C;
  },
  def: function (that, key, value) {
    var data = getWeak(anObject(key), true);
    if (data === true) uncaughtFrozenStore(that).set(key, value);
    else data[that._i] = value;
    return that;
  },
  ufstore: uncaughtFrozenStore
};

},{"12":12,"125":125,"39":39,"41":41,"51":51,"6":6,"66":66,"7":7,"93":93}],22:[function(_dereq_,module,exports){
var global = _dereq_(40);
var $export = _dereq_(33);
var redefine = _dereq_(94);
var redefineAll = _dereq_(93);
var meta = _dereq_(66);
var forOf = _dereq_(39);
var anInstance = _dereq_(6);
var isObject = _dereq_(51);
var fails = _dereq_(35);
var $iterDetect = _dereq_(56);
var setToStringTag = _dereq_(101);
var inheritIfRequired = _dereq_(45);

module.exports = function (NAME, wrapper, methods, common, IS_MAP, IS_WEAK) {
  var Base = global[NAME];
  var C = Base;
  var ADDER = IS_MAP ? 'set' : 'add';
  var proto = C && C.prototype;
  var O = {};
  var fixMethod = function (KEY) {
    var fn = proto[KEY];
    redefine(proto, KEY,
      KEY == 'delete' ? function (a) {
        return IS_WEAK && !isObject(a) ? false : fn.call(this, a === 0 ? 0 : a);
      } : KEY == 'has' ? function has(a) {
        return IS_WEAK && !isObject(a) ? false : fn.call(this, a === 0 ? 0 : a);
      } : KEY == 'get' ? function get(a) {
        return IS_WEAK && !isObject(a) ? undefined : fn.call(this, a === 0 ? 0 : a);
      } : KEY == 'add' ? function add(a) { fn.call(this, a === 0 ? 0 : a); return this; }
        : function set(a, b) { fn.call(this, a === 0 ? 0 : a, b); return this; }
    );
  };
  if (typeof C != 'function' || !(IS_WEAK || proto.forEach && !fails(function () {
    new C().entries().next();
  }))) {
    // create collection constructor
    C = common.getConstructor(wrapper, NAME, IS_MAP, ADDER);
    redefineAll(C.prototype, methods);
    meta.NEED = true;
  } else {
    var instance = new C();
    // early implementations not supports chaining
    var HASNT_CHAINING = instance[ADDER](IS_WEAK ? {} : -0, 1) != instance;
    // V8 ~  Chromium 40- weak-collections throws on primitives, but should return false
    var THROWS_ON_PRIMITIVES = fails(function () { instance.has(1); });
    // most early implementations doesn't supports iterables, most modern - not close it correctly
    var ACCEPT_ITERABLES = $iterDetect(function (iter) { new C(iter); }); // eslint-disable-line no-new
    // for early implementations -0 and +0 not the same
    var BUGGY_ZERO = !IS_WEAK && fails(function () {
      // V8 ~ Chromium 42- fails only with 5+ elements
      var $instance = new C();
      var index = 5;
      while (index--) $instance[ADDER](index, index);
      return !$instance.has(-0);
    });
    if (!ACCEPT_ITERABLES) {
      C = wrapper(function (target, iterable) {
        anInstance(target, C, NAME);
        var that = inheritIfRequired(new Base(), target, C);
        if (iterable != undefined) forOf(iterable, IS_MAP, that[ADDER], that);
        return that;
      });
      C.prototype = proto;
      proto.constructor = C;
    }
    if (THROWS_ON_PRIMITIVES || BUGGY_ZERO) {
      fixMethod('delete');
      fixMethod('has');
      IS_MAP && fixMethod('get');
    }
    if (BUGGY_ZERO || HASNT_CHAINING) fixMethod(ADDER);
    // weak collections should not contains .clear method
    if (IS_WEAK && proto.clear) delete proto.clear;
  }

  setToStringTag(C, NAME);

  O[NAME] = C;
  $export($export.G + $export.W + $export.F * (C != Base), O);

  if (!IS_WEAK) common.setStrong(C, NAME, IS_MAP);

  return C;
};

},{"101":101,"33":33,"35":35,"39":39,"40":40,"45":45,"51":51,"56":56,"6":6,"66":66,"93":93,"94":94}],23:[function(_dereq_,module,exports){
var core = module.exports = { version: '2.5.0' };
if (typeof __e == 'number') __e = core; // eslint-disable-line no-undef

},{}],24:[function(_dereq_,module,exports){
var $defineProperty = _dereq_(72);
var createDesc = _dereq_(92);

module.exports = function (object, index, value) {
  if (index in object) $defineProperty.f(object, index, createDesc(0, value));
  else object[index] = value;
};

},{"72":72,"92":92}],25:[function(_dereq_,module,exports){
// optional / simple context binding
var aFunction = _dereq_(3);
module.exports = function (fn, that, length) {
  aFunction(fn);
  if (that === undefined) return fn;
  switch (length) {
    case 1: return function (a) {
      return fn.call(that, a);
    };
    case 2: return function (a, b) {
      return fn.call(that, a, b);
    };
    case 3: return function (a, b, c) {
      return fn.call(that, a, b, c);
    };
  }
  return function (/* ...args */) {
    return fn.apply(that, arguments);
  };
};

},{"3":3}],26:[function(_dereq_,module,exports){
// 20.3.4.36 / 15.9.5.43 Date.prototype.toISOString()
var fails = _dereq_(35);
var getTime = Date.prototype.getTime;
var $toISOString = Date.prototype.toISOString;

var lz = function (num) {
  return num > 9 ? num : '0' + num;
};

// PhantomJS / old WebKit has a broken implementations
module.exports = (fails(function () {
  return $toISOString.call(new Date(-5e13 - 1)) != '0385-07-25T07:06:39.999Z';
}) || !fails(function () {
  $toISOString.call(new Date(NaN));
})) ? function toISOString() {
  if (!isFinite(getTime.call(this))) throw RangeError('Invalid time value');
  var d = this;
  var y = d.getUTCFullYear();
  var m = d.getUTCMilliseconds();
  var s = y < 0 ? '-' : y > 9999 ? '+' : '';
  return s + ('00000' + Math.abs(y)).slice(s ? -6 : -4) +
    '-' + lz(d.getUTCMonth() + 1) + '-' + lz(d.getUTCDate()) +
    'T' + lz(d.getUTCHours()) + ':' + lz(d.getUTCMinutes()) +
    ':' + lz(d.getUTCSeconds()) + '.' + (m > 99 ? m : '0' + lz(m)) + 'Z';
} : $toISOString;

},{"35":35}],27:[function(_dereq_,module,exports){
var anObject = _dereq_(7);
var toPrimitive = _dereq_(120);
var NUMBER = 'number';

module.exports = function (hint) {
  if (hint !== 'string' && hint !== NUMBER && hint !== 'default') throw TypeError('Incorrect hint');
  return toPrimitive(anObject(this), hint != NUMBER);
};

},{"120":120,"7":7}],28:[function(_dereq_,module,exports){
// 7.2.1 RequireObjectCoercible(argument)
module.exports = function (it) {
  if (it == undefined) throw TypeError("Can't call method on  " + it);
  return it;
};

},{}],29:[function(_dereq_,module,exports){
// Thank's IE8 for his funny defineProperty
module.exports = !_dereq_(35)(function () {
  return Object.defineProperty({}, 'a', { get: function () { return 7; } }).a != 7;
});

},{"35":35}],30:[function(_dereq_,module,exports){
var isObject = _dereq_(51);
var document = _dereq_(40).document;
// typeof document.createElement is 'object' in old IE
var is = isObject(document) && isObject(document.createElement);
module.exports = function (it) {
  return is ? document.createElement(it) : {};
};

},{"40":40,"51":51}],31:[function(_dereq_,module,exports){
// IE 8- don't enum bug keys
module.exports = (
  'constructor,hasOwnProperty,isPrototypeOf,propertyIsEnumerable,toLocaleString,toString,valueOf'
).split(',');

},{}],32:[function(_dereq_,module,exports){
// all enumerable object keys, includes symbols
var getKeys = _dereq_(81);
var gOPS = _dereq_(78);
var pIE = _dereq_(82);
module.exports = function (it) {
  var result = getKeys(it);
  var getSymbols = gOPS.f;
  if (getSymbols) {
    var symbols = getSymbols(it);
    var isEnum = pIE.f;
    var i = 0;
    var key;
    while (symbols.length > i) if (isEnum.call(it, key = symbols[i++])) result.push(key);
  } return result;
};

},{"78":78,"81":81,"82":82}],33:[function(_dereq_,module,exports){
var global = _dereq_(40);
var core = _dereq_(23);
var hide = _dereq_(42);
var redefine = _dereq_(94);
var ctx = _dereq_(25);
var PROTOTYPE = 'prototype';

var $export = function (type, name, source) {
  var IS_FORCED = type & $export.F;
  var IS_GLOBAL = type & $export.G;
  var IS_STATIC = type & $export.S;
  var IS_PROTO = type & $export.P;
  var IS_BIND = type & $export.B;
  var target = IS_GLOBAL ? global : IS_STATIC ? global[name] || (global[name] = {}) : (global[name] || {})[PROTOTYPE];
  var exports = IS_GLOBAL ? core : core[name] || (core[name] = {});
  var expProto = exports[PROTOTYPE] || (exports[PROTOTYPE] = {});
  var key, own, out, exp;
  if (IS_GLOBAL) source = name;
  for (key in source) {
    // contains in native
    own = !IS_FORCED && target && target[key] !== undefined;
    // export native or passed
    out = (own ? target : source)[key];
    // bind timers to global for call from export context
    exp = IS_BIND && own ? ctx(out, global) : IS_PROTO && typeof out == 'function' ? ctx(Function.call, out) : out;
    // extend global
    if (target) redefine(target, key, out, type & $export.U);
    // export
    if (exports[key] != out) hide(exports, key, exp);
    if (IS_PROTO && expProto[key] != out) expProto[key] = out;
  }
};
global.core = core;
// type bitmap
$export.F = 1;   // forced
$export.G = 2;   // global
$export.S = 4;   // static
$export.P = 8;   // proto
$export.B = 16;  // bind
$export.W = 32;  // wrap
$export.U = 64;  // safe
$export.R = 128; // real proto method for `library`
module.exports = $export;

},{"23":23,"25":25,"40":40,"42":42,"94":94}],34:[function(_dereq_,module,exports){
var MATCH = _dereq_(128)('match');
module.exports = function (KEY) {
  var re = /./;
  try {
    '/./'[KEY](re);
  } catch (e) {
    try {
      re[MATCH] = false;
      return !'/./'[KEY](re);
    } catch (f) { /* empty */ }
  } return true;
};

},{"128":128}],35:[function(_dereq_,module,exports){
module.exports = function (exec) {
  try {
    return !!exec();
  } catch (e) {
    return true;
  }
};

},{}],36:[function(_dereq_,module,exports){
var hide = _dereq_(42);
var redefine = _dereq_(94);
var fails = _dereq_(35);
var defined = _dereq_(28);
var wks = _dereq_(128);

module.exports = function (KEY, length, exec) {
  var SYMBOL = wks(KEY);
  var fns = exec(defined, SYMBOL, ''[KEY]);
  var strfn = fns[0];
  var rxfn = fns[1];
  if (fails(function () {
    var O = {};
    O[SYMBOL] = function () { return 7; };
    return ''[KEY](O) != 7;
  })) {
    redefine(String.prototype, KEY, strfn);
    hide(RegExp.prototype, SYMBOL, length == 2
      // 21.2.5.8 RegExp.prototype[@@replace](string, replaceValue)
      // 21.2.5.11 RegExp.prototype[@@split](string, limit)
      ? function (string, arg) { return rxfn.call(string, this, arg); }
      // 21.2.5.6 RegExp.prototype[@@match](string)
      // 21.2.5.9 RegExp.prototype[@@search](string)
      : function (string) { return rxfn.call(string, this); }
    );
  }
};

},{"128":128,"28":28,"35":35,"42":42,"94":94}],37:[function(_dereq_,module,exports){
// 21.2.5.3 get RegExp.prototype.flags
var anObject = _dereq_(7);
module.exports = function () {
  var that = anObject(this);
  var result = '';
  if (that.global) result += 'g';
  if (that.ignoreCase) result += 'i';
  if (that.multiline) result += 'm';
  if (that.unicode) result += 'u';
  if (that.sticky) result += 'y';
  return result;
};

},{"7":7}],38:[function(_dereq_,module,exports){
// https://tc39.github.io/proposal-flatMap/#sec-FlattenIntoArray
var isArray = _dereq_(49);
var isObject = _dereq_(51);
var toLength = _dereq_(118);
var ctx = _dereq_(25);
var IS_CONCAT_SPREADABLE = _dereq_(128)('isConcatSpreadable');

function flattenIntoArray(target, original, source, sourceLen, start, depth, mapper, thisArg) {
  var targetIndex = start;
  var sourceIndex = 0;
  var mapFn = mapper ? ctx(mapper, thisArg, 3) : false;
  var element, spreadable;

  while (sourceIndex < sourceLen) {
    if (sourceIndex in source) {
      element = mapFn ? mapFn(source[sourceIndex], sourceIndex, original) : source[sourceIndex];

      spreadable = false;
      if (isObject(element)) {
        spreadable = element[IS_CONCAT_SPREADABLE];
        spreadable = spreadable !== undefined ? !!spreadable : isArray(element);
      }

      if (spreadable && depth > 0) {
        targetIndex = flattenIntoArray(target, original, element, toLength(element.length), targetIndex, depth - 1) - 1;
      } else {
        if (targetIndex >= 0x1fffffffffffff) throw TypeError();
        target[targetIndex] = element;
      }

      targetIndex++;
    }
    sourceIndex++;
  }
  return targetIndex;
}

module.exports = flattenIntoArray;

},{"118":118,"128":128,"25":25,"49":49,"51":51}],39:[function(_dereq_,module,exports){
var ctx = _dereq_(25);
var call = _dereq_(53);
var isArrayIter = _dereq_(48);
var anObject = _dereq_(7);
var toLength = _dereq_(118);
var getIterFn = _dereq_(129);
var BREAK = {};
var RETURN = {};
var exports = module.exports = function (iterable, entries, fn, that, ITERATOR) {
  var iterFn = ITERATOR ? function () { return iterable; } : getIterFn(iterable);
  var f = ctx(fn, that, entries ? 2 : 1);
  var index = 0;
  var length, step, iterator, result;
  if (typeof iterFn != 'function') throw TypeError(iterable + ' is not iterable!');
  // fast case for arrays with default iterator
  if (isArrayIter(iterFn)) for (length = toLength(iterable.length); length > index; index++) {
    result = entries ? f(anObject(step = iterable[index])[0], step[1]) : f(iterable[index]);
    if (result === BREAK || result === RETURN) return result;
  } else for (iterator = iterFn.call(iterable); !(step = iterator.next()).done;) {
    result = call(iterator, f, step.value, entries);
    if (result === BREAK || result === RETURN) return result;
  }
};
exports.BREAK = BREAK;
exports.RETURN = RETURN;

},{"118":118,"129":129,"25":25,"48":48,"53":53,"7":7}],40:[function(_dereq_,module,exports){
// https://github.com/zloirock/core-js/issues/86#issuecomment-115759028
var global = module.exports = typeof window != 'undefined' && window.Math == Math
  ? window : typeof self != 'undefined' && self.Math == Math ? self
  // eslint-disable-next-line no-new-func
  : Function('return this')();
if (typeof __g == 'number') __g = global; // eslint-disable-line no-undef

},{}],41:[function(_dereq_,module,exports){
var hasOwnProperty = {}.hasOwnProperty;
module.exports = function (it, key) {
  return hasOwnProperty.call(it, key);
};

},{}],42:[function(_dereq_,module,exports){
var dP = _dereq_(72);
var createDesc = _dereq_(92);
module.exports = _dereq_(29) ? function (object, key, value) {
  return dP.f(object, key, createDesc(1, value));
} : function (object, key, value) {
  object[key] = value;
  return object;
};

},{"29":29,"72":72,"92":92}],43:[function(_dereq_,module,exports){
var document = _dereq_(40).document;
module.exports = document && document.documentElement;

},{"40":40}],44:[function(_dereq_,module,exports){
module.exports = !_dereq_(29) && !_dereq_(35)(function () {
  return Object.defineProperty(_dereq_(30)('div'), 'a', { get: function () { return 7; } }).a != 7;
});

},{"29":29,"30":30,"35":35}],45:[function(_dereq_,module,exports){
var isObject = _dereq_(51);
var setPrototypeOf = _dereq_(99).set;
module.exports = function (that, target, C) {
  var S = target.constructor;
  var P;
  if (S !== C && typeof S == 'function' && (P = S.prototype) !== C.prototype && isObject(P) && setPrototypeOf) {
    setPrototypeOf(that, P);
  } return that;
};

},{"51":51,"99":99}],46:[function(_dereq_,module,exports){
// fast apply, http://jsperf.lnkit.com/fast-apply/5
module.exports = function (fn, args, that) {
  var un = that === undefined;
  switch (args.length) {
    case 0: return un ? fn()
                      : fn.call(that);
    case 1: return un ? fn(args[0])
                      : fn.call(that, args[0]);
    case 2: return un ? fn(args[0], args[1])
                      : fn.call(that, args[0], args[1]);
    case 3: return un ? fn(args[0], args[1], args[2])
                      : fn.call(that, args[0], args[1], args[2]);
    case 4: return un ? fn(args[0], args[1], args[2], args[3])
                      : fn.call(that, args[0], args[1], args[2], args[3]);
  } return fn.apply(that, args);
};

},{}],47:[function(_dereq_,module,exports){
// fallback for non-array-like ES3 and non-enumerable old V8 strings
var cof = _dereq_(18);
// eslint-disable-next-line no-prototype-builtins
module.exports = Object('z').propertyIsEnumerable(0) ? Object : function (it) {
  return cof(it) == 'String' ? it.split('') : Object(it);
};

},{"18":18}],48:[function(_dereq_,module,exports){
// check on default Array iterator
var Iterators = _dereq_(58);
var ITERATOR = _dereq_(128)('iterator');
var ArrayProto = Array.prototype;

module.exports = function (it) {
  return it !== undefined && (Iterators.Array === it || ArrayProto[ITERATOR] === it);
};

},{"128":128,"58":58}],49:[function(_dereq_,module,exports){
// 7.2.2 IsArray(argument)
var cof = _dereq_(18);
module.exports = Array.isArray || function isArray(arg) {
  return cof(arg) == 'Array';
};

},{"18":18}],50:[function(_dereq_,module,exports){
// 20.1.2.3 Number.isInteger(number)
var isObject = _dereq_(51);
var floor = Math.floor;
module.exports = function isInteger(it) {
  return !isObject(it) && isFinite(it) && floor(it) === it;
};

},{"51":51}],51:[function(_dereq_,module,exports){
module.exports = function (it) {
  return typeof it === 'object' ? it !== null : typeof it === 'function';
};

},{}],52:[function(_dereq_,module,exports){
// 7.2.8 IsRegExp(argument)
var isObject = _dereq_(51);
var cof = _dereq_(18);
var MATCH = _dereq_(128)('match');
module.exports = function (it) {
  var isRegExp;
  return isObject(it) && ((isRegExp = it[MATCH]) !== undefined ? !!isRegExp : cof(it) == 'RegExp');
};

},{"128":128,"18":18,"51":51}],53:[function(_dereq_,module,exports){
// call something on iterator step with safe closing on error
var anObject = _dereq_(7);
module.exports = function (iterator, fn, value, entries) {
  try {
    return entries ? fn(anObject(value)[0], value[1]) : fn(value);
  // 7.4.6 IteratorClose(iterator, completion)
  } catch (e) {
    var ret = iterator['return'];
    if (ret !== undefined) anObject(ret.call(iterator));
    throw e;
  }
};

},{"7":7}],54:[function(_dereq_,module,exports){
var create = _dereq_(71);
var descriptor = _dereq_(92);
var setToStringTag = _dereq_(101);
var IteratorPrototype = {};

// 25.1.2.1.1 %IteratorPrototype%[@@iterator]()
_dereq_(42)(IteratorPrototype, _dereq_(128)('iterator'), function () { return this; });

module.exports = function (Constructor, NAME, next) {
  Constructor.prototype = create(IteratorPrototype, { next: descriptor(1, next) });
  setToStringTag(Constructor, NAME + ' Iterator');
};

},{"101":101,"128":128,"42":42,"71":71,"92":92}],55:[function(_dereq_,module,exports){
var LIBRARY = _dereq_(60);
var $export = _dereq_(33);
var redefine = _dereq_(94);
var hide = _dereq_(42);
var has = _dereq_(41);
var Iterators = _dereq_(58);
var $iterCreate = _dereq_(54);
var setToStringTag = _dereq_(101);
var getPrototypeOf = _dereq_(79);
var ITERATOR = _dereq_(128)('iterator');
var BUGGY = !([].keys && 'next' in [].keys()); // Safari has buggy iterators w/o `next`
var FF_ITERATOR = '@@iterator';
var KEYS = 'keys';
var VALUES = 'values';

var returnThis = function () { return this; };

module.exports = function (Base, NAME, Constructor, next, DEFAULT, IS_SET, FORCED) {
  $iterCreate(Constructor, NAME, next);
  var getMethod = function (kind) {
    if (!BUGGY && kind in proto) return proto[kind];
    switch (kind) {
      case KEYS: return function keys() { return new Constructor(this, kind); };
      case VALUES: return function values() { return new Constructor(this, kind); };
    } return function entries() { return new Constructor(this, kind); };
  };
  var TAG = NAME + ' Iterator';
  var DEF_VALUES = DEFAULT == VALUES;
  var VALUES_BUG = false;
  var proto = Base.prototype;
  var $native = proto[ITERATOR] || proto[FF_ITERATOR] || DEFAULT && proto[DEFAULT];
  var $default = $native || getMethod(DEFAULT);
  var $entries = DEFAULT ? !DEF_VALUES ? $default : getMethod('entries') : undefined;
  var $anyNative = NAME == 'Array' ? proto.entries || $native : $native;
  var methods, key, IteratorPrototype;
  // Fix native
  if ($anyNative) {
    IteratorPrototype = getPrototypeOf($anyNative.call(new Base()));
    if (IteratorPrototype !== Object.prototype && IteratorPrototype.next) {
      // Set @@toStringTag to native iterators
      setToStringTag(IteratorPrototype, TAG, true);
      // fix for some old engines
      if (!LIBRARY && !has(IteratorPrototype, ITERATOR)) hide(IteratorPrototype, ITERATOR, returnThis);
    }
  }
  // fix Array#{values, @@iterator}.name in V8 / FF
  if (DEF_VALUES && $native && $native.name !== VALUES) {
    VALUES_BUG = true;
    $default = function values() { return $native.call(this); };
  }
  // Define iterator
  if ((!LIBRARY || FORCED) && (BUGGY || VALUES_BUG || !proto[ITERATOR])) {
    hide(proto, ITERATOR, $default);
  }
  // Plug for library
  Iterators[NAME] = $default;
  Iterators[TAG] = returnThis;
  if (DEFAULT) {
    methods = {
      values: DEF_VALUES ? $default : getMethod(VALUES),
      keys: IS_SET ? $default : getMethod(KEYS),
      entries: $entries
    };
    if (FORCED) for (key in methods) {
      if (!(key in proto)) redefine(proto, key, methods[key]);
    } else $export($export.P + $export.F * (BUGGY || VALUES_BUG), NAME, methods);
  }
  return methods;
};

},{"101":101,"128":128,"33":33,"41":41,"42":42,"54":54,"58":58,"60":60,"79":79,"94":94}],56:[function(_dereq_,module,exports){
var ITERATOR = _dereq_(128)('iterator');
var SAFE_CLOSING = false;

try {
  var riter = [7][ITERATOR]();
  riter['return'] = function () { SAFE_CLOSING = true; };
  // eslint-disable-next-line no-throw-literal
  Array.from(riter, function () { throw 2; });
} catch (e) { /* empty */ }

module.exports = function (exec, skipClosing) {
  if (!skipClosing && !SAFE_CLOSING) return false;
  var safe = false;
  try {
    var arr = [7];
    var iter = arr[ITERATOR]();
    iter.next = function () { return { done: safe = true }; };
    arr[ITERATOR] = function () { return iter; };
    exec(arr);
  } catch (e) { /* empty */ }
  return safe;
};

},{"128":128}],57:[function(_dereq_,module,exports){
module.exports = function (done, value) {
  return { value: value, done: !!done };
};

},{}],58:[function(_dereq_,module,exports){
module.exports = {};

},{}],59:[function(_dereq_,module,exports){
var getKeys = _dereq_(81);
var toIObject = _dereq_(117);
module.exports = function (object, el) {
  var O = toIObject(object);
  var keys = getKeys(O);
  var length = keys.length;
  var index = 0;
  var key;
  while (length > index) if (O[key = keys[index++]] === el) return key;
};

},{"117":117,"81":81}],60:[function(_dereq_,module,exports){
module.exports = false;

},{}],61:[function(_dereq_,module,exports){
// 20.2.2.14 Math.expm1(x)
var $expm1 = Math.expm1;
module.exports = (!$expm1
  // Old FF bug
  || $expm1(10) > 22025.465794806719 || $expm1(10) < 22025.4657948067165168
  // Tor Browser bug
  || $expm1(-2e-17) != -2e-17
) ? function expm1(x) {
  return (x = +x) == 0 ? x : x > -1e-6 && x < 1e-6 ? x + x * x / 2 : Math.exp(x) - 1;
} : $expm1;

},{}],62:[function(_dereq_,module,exports){
// 20.2.2.16 Math.fround(x)
var sign = _dereq_(65);
var pow = Math.pow;
var EPSILON = pow(2, -52);
var EPSILON32 = pow(2, -23);
var MAX32 = pow(2, 127) * (2 - EPSILON32);
var MIN32 = pow(2, -126);

var roundTiesToEven = function (n) {
  return n + 1 / EPSILON - 1 / EPSILON;
};

module.exports = Math.fround || function fround(x) {
  var $abs = Math.abs(x);
  var $sign = sign(x);
  var a, result;
  if ($abs < MIN32) return $sign * roundTiesToEven($abs / MIN32 / EPSILON32) * MIN32 * EPSILON32;
  a = (1 + EPSILON32 / EPSILON) * $abs;
  result = a - (a - $abs);
  // eslint-disable-next-line no-self-compare
  if (result > MAX32 || result != result) return $sign * Infinity;
  return $sign * result;
};

},{"65":65}],63:[function(_dereq_,module,exports){
// 20.2.2.20 Math.log1p(x)
module.exports = Math.log1p || function log1p(x) {
  return (x = +x) > -1e-8 && x < 1e-8 ? x - x * x / 2 : Math.log(1 + x);
};

},{}],64:[function(_dereq_,module,exports){
// https://rwaldron.github.io/proposal-math-extensions/
module.exports = Math.scale || function scale(x, inLow, inHigh, outLow, outHigh) {
  if (
    arguments.length === 0
      // eslint-disable-next-line no-self-compare
      || x != x
      // eslint-disable-next-line no-self-compare
      || inLow != inLow
      // eslint-disable-next-line no-self-compare
      || inHigh != inHigh
      // eslint-disable-next-line no-self-compare
      || outLow != outLow
      // eslint-disable-next-line no-self-compare
      || outHigh != outHigh
  ) return NaN;
  if (x === Infinity || x === -Infinity) return x;
  return (x - inLow) * (outHigh - outLow) / (inHigh - inLow) + outLow;
};

},{}],65:[function(_dereq_,module,exports){
// 20.2.2.28 Math.sign(x)
module.exports = Math.sign || function sign(x) {
  // eslint-disable-next-line no-self-compare
  return (x = +x) == 0 || x != x ? x : x < 0 ? -1 : 1;
};

},{}],66:[function(_dereq_,module,exports){
var META = _dereq_(124)('meta');
var isObject = _dereq_(51);
var has = _dereq_(41);
var setDesc = _dereq_(72).f;
var id = 0;
var isExtensible = Object.isExtensible || function () {
  return true;
};
var FREEZE = !_dereq_(35)(function () {
  return isExtensible(Object.preventExtensions({}));
});
var setMeta = function (it) {
  setDesc(it, META, { value: {
    i: 'O' + ++id, // object ID
    w: {}          // weak collections IDs
  } });
};
var fastKey = function (it, create) {
  // return primitive with prefix
  if (!isObject(it)) return typeof it == 'symbol' ? it : (typeof it == 'string' ? 'S' : 'P') + it;
  if (!has(it, META)) {
    // can't set metadata to uncaught frozen object
    if (!isExtensible(it)) return 'F';
    // not necessary to add metadata
    if (!create) return 'E';
    // add missing metadata
    setMeta(it);
  // return object ID
  } return it[META].i;
};
var getWeak = function (it, create) {
  if (!has(it, META)) {
    // can't set metadata to uncaught frozen object
    if (!isExtensible(it)) return true;
    // not necessary to add metadata
    if (!create) return false;
    // add missing metadata
    setMeta(it);
  // return hash weak collections IDs
  } return it[META].w;
};
// add metadata on freeze-family methods calling
var onFreeze = function (it) {
  if (FREEZE && meta.NEED && isExtensible(it) && !has(it, META)) setMeta(it);
  return it;
};
var meta = module.exports = {
  KEY: META,
  NEED: false,
  fastKey: fastKey,
  getWeak: getWeak,
  onFreeze: onFreeze
};

},{"124":124,"35":35,"41":41,"51":51,"72":72}],67:[function(_dereq_,module,exports){
var Map = _dereq_(160);
var $export = _dereq_(33);
var shared = _dereq_(103)('metadata');
var store = shared.store || (shared.store = new (_dereq_(266))());

var getOrCreateMetadataMap = function (target, targetKey, create) {
  var targetMetadata = store.get(target);
  if (!targetMetadata) {
    if (!create) return undefined;
    store.set(target, targetMetadata = new Map());
  }
  var keyMetadata = targetMetadata.get(targetKey);
  if (!keyMetadata) {
    if (!create) return undefined;
    targetMetadata.set(targetKey, keyMetadata = new Map());
  } return keyMetadata;
};
var ordinaryHasOwnMetadata = function (MetadataKey, O, P) {
  var metadataMap = getOrCreateMetadataMap(O, P, false);
  return metadataMap === undefined ? false : metadataMap.has(MetadataKey);
};
var ordinaryGetOwnMetadata = function (MetadataKey, O, P) {
  var metadataMap = getOrCreateMetadataMap(O, P, false);
  return metadataMap === undefined ? undefined : metadataMap.get(MetadataKey);
};
var ordinaryDefineOwnMetadata = function (MetadataKey, MetadataValue, O, P) {
  getOrCreateMetadataMap(O, P, true).set(MetadataKey, MetadataValue);
};
var ordinaryOwnMetadataKeys = function (target, targetKey) {
  var metadataMap = getOrCreateMetadataMap(target, targetKey, false);
  var keys = [];
  if (metadataMap) metadataMap.forEach(function (_, key) { keys.push(key); });
  return keys;
};
var toMetaKey = function (it) {
  return it === undefined || typeof it == 'symbol' ? it : String(it);
};
var exp = function (O) {
  $export($export.S, 'Reflect', O);
};

module.exports = {
  store: store,
  map: getOrCreateMetadataMap,
  has: ordinaryHasOwnMetadata,
  get: ordinaryGetOwnMetadata,
  set: ordinaryDefineOwnMetadata,
  keys: ordinaryOwnMetadataKeys,
  key: toMetaKey,
  exp: exp
};

},{"103":103,"160":160,"266":266,"33":33}],68:[function(_dereq_,module,exports){
var global = _dereq_(40);
var macrotask = _dereq_(113).set;
var Observer = global.MutationObserver || global.WebKitMutationObserver;
var process = global.process;
var Promise = global.Promise;
var isNode = _dereq_(18)(process) == 'process';

module.exports = function () {
  var head, last, notify;

  var flush = function () {
    var parent, fn;
    if (isNode && (parent = process.domain)) parent.exit();
    while (head) {
      fn = head.fn;
      head = head.next;
      try {
        fn();
      } catch (e) {
        if (head) notify();
        else last = undefined;
        throw e;
      }
    } last = undefined;
    if (parent) parent.enter();
  };

  // Node.js
  if (isNode) {
    notify = function () {
      process.nextTick(flush);
    };
  // browsers with MutationObserver
  } else if (Observer) {
    var toggle = true;
    var node = document.createTextNode('');
    new Observer(flush).observe(node, { characterData: true }); // eslint-disable-line no-new
    notify = function () {
      node.data = toggle = !toggle;
    };
  // environments with maybe non-completely correct, but existent Promise
  } else if (Promise && Promise.resolve) {
    var promise = Promise.resolve();
    notify = function () {
      promise.then(flush);
    };
  // for other environments - macrotask based on:
  // - setImmediate
  // - MessageChannel
  // - window.postMessag
  // - onreadystatechange
  // - setTimeout
  } else {
    notify = function () {
      // strange IE + webpack dev server bug - use .call(global)
      macrotask.call(global, flush);
    };
  }

  return function (fn) {
    var task = { fn: fn, next: undefined };
    if (last) last.next = task;
    if (!head) {
      head = task;
      notify();
    } last = task;
  };
};

},{"113":113,"18":18,"40":40}],69:[function(_dereq_,module,exports){
// 25.4.1.5 NewPromiseCapability(C)
var aFunction = _dereq_(3);

function PromiseCapability(C) {
  var resolve, reject;
  this.promise = new C(function ($$resolve, $$reject) {
    if (resolve !== undefined || reject !== undefined) throw TypeError('Bad Promise constructor');
    resolve = $$resolve;
    reject = $$reject;
  });
  this.resolve = aFunction(resolve);
  this.reject = aFunction(reject);
}

module.exports.f = function (C) {
  return new PromiseCapability(C);
};

},{"3":3}],70:[function(_dereq_,module,exports){
// 19.1.2.1 Object.assign(target, source, ...)
var getKeys = _dereq_(81);
var gOPS = _dereq_(78);
var pIE = _dereq_(82);
var toObject = _dereq_(119);
var IObject = _dereq_(47);
var $assign = Object.assign;

// should work with symbols and should have deterministic property order (V8 bug)
module.exports = !$assign || _dereq_(35)(function () {
  var A = {};
  var B = {};
  // eslint-disable-next-line no-undef
  var S = Symbol();
  var K = 'abcdefghijklmnopqrst';
  A[S] = 7;
  K.split('').forEach(function (k) { B[k] = k; });
  return $assign({}, A)[S] != 7 || Object.keys($assign({}, B)).join('') != K;
}) ? function assign(target, source) { // eslint-disable-line no-unused-vars
  var T = toObject(target);
  var aLen = arguments.length;
  var index = 1;
  var getSymbols = gOPS.f;
  var isEnum = pIE.f;
  while (aLen > index) {
    var S = IObject(arguments[index++]);
    var keys = getSymbols ? getKeys(S).concat(getSymbols(S)) : getKeys(S);
    var length = keys.length;
    var j = 0;
    var key;
    while (length > j) if (isEnum.call(S, key = keys[j++])) T[key] = S[key];
  } return T;
} : $assign;

},{"119":119,"35":35,"47":47,"78":78,"81":81,"82":82}],71:[function(_dereq_,module,exports){
// 19.1.2.2 / 15.2.3.5 Object.create(O [, Properties])
var anObject = _dereq_(7);
var dPs = _dereq_(73);
var enumBugKeys = _dereq_(31);
var IE_PROTO = _dereq_(102)('IE_PROTO');
var Empty = function () { /* empty */ };
var PROTOTYPE = 'prototype';

// Create object with fake `null` prototype: use iframe Object with cleared prototype
var createDict = function () {
  // Thrash, waste and sodomy: IE GC bug
  var iframe = _dereq_(30)('iframe');
  var i = enumBugKeys.length;
  var lt = '<';
  var gt = '>';
  var iframeDocument;
  iframe.style.display = 'none';
  _dereq_(43).appendChild(iframe);
  iframe.src = 'javascript:'; // eslint-disable-line no-script-url
  // createDict = iframe.contentWindow.Object;
  // html.removeChild(iframe);
  iframeDocument = iframe.contentWindow.document;
  iframeDocument.open();
  iframeDocument.write(lt + 'script' + gt + 'document.F=Object' + lt + '/script' + gt);
  iframeDocument.close();
  createDict = iframeDocument.F;
  while (i--) delete createDict[PROTOTYPE][enumBugKeys[i]];
  return createDict();
};

module.exports = Object.create || function create(O, Properties) {
  var result;
  if (O !== null) {
    Empty[PROTOTYPE] = anObject(O);
    result = new Empty();
    Empty[PROTOTYPE] = null;
    // add "__proto__" for Object.getPrototypeOf polyfill
    result[IE_PROTO] = O;
  } else result = createDict();
  return Properties === undefined ? result : dPs(result, Properties);
};

},{"102":102,"30":30,"31":31,"43":43,"7":7,"73":73}],72:[function(_dereq_,module,exports){
var anObject = _dereq_(7);
var IE8_DOM_DEFINE = _dereq_(44);
var toPrimitive = _dereq_(120);
var dP = Object.defineProperty;

exports.f = _dereq_(29) ? Object.defineProperty : function defineProperty(O, P, Attributes) {
  anObject(O);
  P = toPrimitive(P, true);
  anObject(Attributes);
  if (IE8_DOM_DEFINE) try {
    return dP(O, P, Attributes);
  } catch (e) { /* empty */ }
  if ('get' in Attributes || 'set' in Attributes) throw TypeError('Accessors not supported!');
  if ('value' in Attributes) O[P] = Attributes.value;
  return O;
};

},{"120":120,"29":29,"44":44,"7":7}],73:[function(_dereq_,module,exports){
var dP = _dereq_(72);
var anObject = _dereq_(7);
var getKeys = _dereq_(81);

module.exports = _dereq_(29) ? Object.defineProperties : function defineProperties(O, Properties) {
  anObject(O);
  var keys = getKeys(Properties);
  var length = keys.length;
  var i = 0;
  var P;
  while (length > i) dP.f(O, P = keys[i++], Properties[P]);
  return O;
};

},{"29":29,"7":7,"72":72,"81":81}],74:[function(_dereq_,module,exports){
// Forced replacement prototype accessors methods
module.exports = _dereq_(60) || !_dereq_(35)(function () {
  var K = Math.random();
  // In FF throws only define methods
  // eslint-disable-next-line no-undef, no-useless-call
  __defineSetter__.call(null, K, function () { /* empty */ });
  delete _dereq_(40)[K];
});

},{"35":35,"40":40,"60":60}],75:[function(_dereq_,module,exports){
var pIE = _dereq_(82);
var createDesc = _dereq_(92);
var toIObject = _dereq_(117);
var toPrimitive = _dereq_(120);
var has = _dereq_(41);
var IE8_DOM_DEFINE = _dereq_(44);
var gOPD = Object.getOwnPropertyDescriptor;

exports.f = _dereq_(29) ? gOPD : function getOwnPropertyDescriptor(O, P) {
  O = toIObject(O);
  P = toPrimitive(P, true);
  if (IE8_DOM_DEFINE) try {
    return gOPD(O, P);
  } catch (e) { /* empty */ }
  if (has(O, P)) return createDesc(!pIE.f.call(O, P), O[P]);
};

},{"117":117,"120":120,"29":29,"41":41,"44":44,"82":82,"92":92}],76:[function(_dereq_,module,exports){
// fallback for IE11 buggy Object.getOwnPropertyNames with iframe and window
var toIObject = _dereq_(117);
var gOPN = _dereq_(77).f;
var toString = {}.toString;

var windowNames = typeof window == 'object' && window && Object.getOwnPropertyNames
  ? Object.getOwnPropertyNames(window) : [];

var getWindowNames = function (it) {
  try {
    return gOPN(it);
  } catch (e) {
    return windowNames.slice();
  }
};

module.exports.f = function getOwnPropertyNames(it) {
  return windowNames && toString.call(it) == '[object Window]' ? getWindowNames(it) : gOPN(toIObject(it));
};

},{"117":117,"77":77}],77:[function(_dereq_,module,exports){
// 19.1.2.7 / 15.2.3.4 Object.getOwnPropertyNames(O)
var $keys = _dereq_(80);
var hiddenKeys = _dereq_(31).concat('length', 'prototype');

exports.f = Object.getOwnPropertyNames || function getOwnPropertyNames(O) {
  return $keys(O, hiddenKeys);
};

},{"31":31,"80":80}],78:[function(_dereq_,module,exports){
exports.f = Object.getOwnPropertySymbols;

},{}],79:[function(_dereq_,module,exports){
// 19.1.2.9 / 15.2.3.2 Object.getPrototypeOf(O)
var has = _dereq_(41);
var toObject = _dereq_(119);
var IE_PROTO = _dereq_(102)('IE_PROTO');
var ObjectProto = Object.prototype;

module.exports = Object.getPrototypeOf || function (O) {
  O = toObject(O);
  if (has(O, IE_PROTO)) return O[IE_PROTO];
  if (typeof O.constructor == 'function' && O instanceof O.constructor) {
    return O.constructor.prototype;
  } return O instanceof Object ? ObjectProto : null;
};

},{"102":102,"119":119,"41":41}],80:[function(_dereq_,module,exports){
var has = _dereq_(41);
var toIObject = _dereq_(117);
var arrayIndexOf = _dereq_(11)(false);
var IE_PROTO = _dereq_(102)('IE_PROTO');

module.exports = function (object, names) {
  var O = toIObject(object);
  var i = 0;
  var result = [];
  var key;
  for (key in O) if (key != IE_PROTO) has(O, key) && result.push(key);
  // Don't enum bug & hidden keys
  while (names.length > i) if (has(O, key = names[i++])) {
    ~arrayIndexOf(result, key) || result.push(key);
  }
  return result;
};

},{"102":102,"11":11,"117":117,"41":41}],81:[function(_dereq_,module,exports){
// 19.1.2.14 / 15.2.3.14 Object.keys(O)
var $keys = _dereq_(80);
var enumBugKeys = _dereq_(31);

module.exports = Object.keys || function keys(O) {
  return $keys(O, enumBugKeys);
};

},{"31":31,"80":80}],82:[function(_dereq_,module,exports){
exports.f = {}.propertyIsEnumerable;

},{}],83:[function(_dereq_,module,exports){
// most Object methods by ES6 should accept primitives
var $export = _dereq_(33);
var core = _dereq_(23);
var fails = _dereq_(35);
module.exports = function (KEY, exec) {
  var fn = (core.Object || {})[KEY] || Object[KEY];
  var exp = {};
  exp[KEY] = exec(fn);
  $export($export.S + $export.F * fails(function () { fn(1); }), 'Object', exp);
};

},{"23":23,"33":33,"35":35}],84:[function(_dereq_,module,exports){
var getKeys = _dereq_(81);
var toIObject = _dereq_(117);
var isEnum = _dereq_(82).f;
module.exports = function (isEntries) {
  return function (it) {
    var O = toIObject(it);
    var keys = getKeys(O);
    var length = keys.length;
    var i = 0;
    var result = [];
    var key;
    while (length > i) if (isEnum.call(O, key = keys[i++])) {
      result.push(isEntries ? [key, O[key]] : O[key]);
    } return result;
  };
};

},{"117":117,"81":81,"82":82}],85:[function(_dereq_,module,exports){
// all object keys, includes non-enumerable and symbols
var gOPN = _dereq_(77);
var gOPS = _dereq_(78);
var anObject = _dereq_(7);
var Reflect = _dereq_(40).Reflect;
module.exports = Reflect && Reflect.ownKeys || function ownKeys(it) {
  var keys = gOPN.f(anObject(it));
  var getSymbols = gOPS.f;
  return getSymbols ? keys.concat(getSymbols(it)) : keys;
};

},{"40":40,"7":7,"77":77,"78":78}],86:[function(_dereq_,module,exports){
var $parseFloat = _dereq_(40).parseFloat;
var $trim = _dereq_(111).trim;

module.exports = 1 / $parseFloat(_dereq_(112) + '-0') !== -Infinity ? function parseFloat(str) {
  var string = $trim(String(str), 3);
  var result = $parseFloat(string);
  return result === 0 && string.charAt(0) == '-' ? -0 : result;
} : $parseFloat;

},{"111":111,"112":112,"40":40}],87:[function(_dereq_,module,exports){
var $parseInt = _dereq_(40).parseInt;
var $trim = _dereq_(111).trim;
var ws = _dereq_(112);
var hex = /^[-+]?0[xX]/;

module.exports = $parseInt(ws + '08') !== 8 || $parseInt(ws + '0x16') !== 22 ? function parseInt(str, radix) {
  var string = $trim(String(str), 3);
  return $parseInt(string, (radix >>> 0) || (hex.test(string) ? 16 : 10));
} : $parseInt;

},{"111":111,"112":112,"40":40}],88:[function(_dereq_,module,exports){
var path = _dereq_(89);
var invoke = _dereq_(46);
var aFunction = _dereq_(3);
module.exports = function (/* ...pargs */) {
  var fn = aFunction(this);
  var length = arguments.length;
  var pargs = Array(length);
  var i = 0;
  var _ = path._;
  var holder = false;
  while (length > i) if ((pargs[i] = arguments[i++]) === _) holder = true;
  return function (/* ...args */) {
    var that = this;
    var aLen = arguments.length;
    var j = 0;
    var k = 0;
    var args;
    if (!holder && !aLen) return invoke(fn, pargs, that);
    args = pargs.slice();
    if (holder) for (;length > j; j++) if (args[j] === _) args[j] = arguments[k++];
    while (aLen > k) args.push(arguments[k++]);
    return invoke(fn, args, that);
  };
};

},{"3":3,"46":46,"89":89}],89:[function(_dereq_,module,exports){
module.exports = _dereq_(40);

},{"40":40}],90:[function(_dereq_,module,exports){
module.exports = function (exec) {
  try {
    return { e: false, v: exec() };
  } catch (e) {
    return { e: true, v: e };
  }
};

},{}],91:[function(_dereq_,module,exports){
var newPromiseCapability = _dereq_(69);

module.exports = function (C, x) {
  var promiseCapability = newPromiseCapability.f(C);
  var resolve = promiseCapability.resolve;
  resolve(x);
  return promiseCapability.promise;
};

},{"69":69}],92:[function(_dereq_,module,exports){
module.exports = function (bitmap, value) {
  return {
    enumerable: !(bitmap & 1),
    configurable: !(bitmap & 2),
    writable: !(bitmap & 4),
    value: value
  };
};

},{}],93:[function(_dereq_,module,exports){
var redefine = _dereq_(94);
module.exports = function (target, src, safe) {
  for (var key in src) redefine(target, key, src[key], safe);
  return target;
};

},{"94":94}],94:[function(_dereq_,module,exports){
var global = _dereq_(40);
var hide = _dereq_(42);
var has = _dereq_(41);
var SRC = _dereq_(124)('src');
var TO_STRING = 'toString';
var $toString = Function[TO_STRING];
var TPL = ('' + $toString).split(TO_STRING);

_dereq_(23).inspectSource = function (it) {
  return $toString.call(it);
};

(module.exports = function (O, key, val, safe) {
  var isFunction = typeof val == 'function';
  if (isFunction) has(val, 'name') || hide(val, 'name', key);
  if (O[key] === val) return;
  if (isFunction) has(val, SRC) || hide(val, SRC, O[key] ? '' + O[key] : TPL.join(String(key)));
  if (O === global) {
    O[key] = val;
  } else if (!safe) {
    delete O[key];
    hide(O, key, val);
  } else if (O[key]) {
    O[key] = val;
  } else {
    hide(O, key, val);
  }
// add fake Function#toString for correct work wrapped methods / constructors with methods like LoDash isNative
})(Function.prototype, TO_STRING, function toString() {
  return typeof this == 'function' && this[SRC] || $toString.call(this);
});

},{"124":124,"23":23,"40":40,"41":41,"42":42}],95:[function(_dereq_,module,exports){
module.exports = function (regExp, replace) {
  var replacer = replace === Object(replace) ? function (part) {
    return replace[part];
  } : replace;
  return function (it) {
    return String(it).replace(regExp, replacer);
  };
};

},{}],96:[function(_dereq_,module,exports){
// 7.2.9 SameValue(x, y)
module.exports = Object.is || function is(x, y) {
  // eslint-disable-next-line no-self-compare
  return x === y ? x !== 0 || 1 / x === 1 / y : x != x && y != y;
};

},{}],97:[function(_dereq_,module,exports){
// https://tc39.github.io/proposal-setmap-offrom/
var $export = _dereq_(33);
var aFunction = _dereq_(3);
var ctx = _dereq_(25);
var forOf = _dereq_(39);

module.exports = function (COLLECTION) {
  $export($export.S, COLLECTION, { from: function from(source /* , mapFn, thisArg */) {
    var mapFn = arguments[1];
    var mapping, A, n, cb;
    aFunction(this);
    mapping = mapFn !== undefined;
    if (mapping) aFunction(mapFn);
    if (source == undefined) return new this();
    A = [];
    if (mapping) {
      n = 0;
      cb = ctx(mapFn, arguments[2], 2);
      forOf(source, false, function (nextItem) {
        A.push(cb(nextItem, n++));
      });
    } else {
      forOf(source, false, A.push, A);
    }
    return new this(A);
  } });
};

},{"25":25,"3":3,"33":33,"39":39}],98:[function(_dereq_,module,exports){
// https://tc39.github.io/proposal-setmap-offrom/
var $export = _dereq_(33);

module.exports = function (COLLECTION) {
  $export($export.S, COLLECTION, { of: function of() {
    var length = arguments.length;
    var A = Array(length);
    while (length--) A[length] = arguments[length];
    return new this(A);
  } });
};

},{"33":33}],99:[function(_dereq_,module,exports){
// Works with __proto__ only. Old v8 can't work with null proto objects.
/* eslint-disable no-proto */
var isObject = _dereq_(51);
var anObject = _dereq_(7);
var check = function (O, proto) {
  anObject(O);
  if (!isObject(proto) && proto !== null) throw TypeError(proto + ": can't set as prototype!");
};
module.exports = {
  set: Object.setPrototypeOf || ('__proto__' in {} ? // eslint-disable-line
    function (test, buggy, set) {
      try {
        set = _dereq_(25)(Function.call, _dereq_(75).f(Object.prototype, '__proto__').set, 2);
        set(test, []);
        buggy = !(test instanceof Array);
      } catch (e) { buggy = true; }
      return function setPrototypeOf(O, proto) {
        check(O, proto);
        if (buggy) O.__proto__ = proto;
        else set(O, proto);
        return O;
      };
    }({}, false) : undefined),
  check: check
};

},{"25":25,"51":51,"7":7,"75":75}],100:[function(_dereq_,module,exports){
var global = _dereq_(40);
var dP = _dereq_(72);
var DESCRIPTORS = _dereq_(29);
var SPECIES = _dereq_(128)('species');

module.exports = function (KEY) {
  var C = global[KEY];
  if (DESCRIPTORS && C && !C[SPECIES]) dP.f(C, SPECIES, {
    configurable: true,
    get: function () { return this; }
  });
};

},{"128":128,"29":29,"40":40,"72":72}],101:[function(_dereq_,module,exports){
var def = _dereq_(72).f;
var has = _dereq_(41);
var TAG = _dereq_(128)('toStringTag');

module.exports = function (it, tag, stat) {
  if (it && !has(it = stat ? it : it.prototype, TAG)) def(it, TAG, { configurable: true, value: tag });
};

},{"128":128,"41":41,"72":72}],102:[function(_dereq_,module,exports){
var shared = _dereq_(103)('keys');
var uid = _dereq_(124);
module.exports = function (key) {
  return shared[key] || (shared[key] = uid(key));
};

},{"103":103,"124":124}],103:[function(_dereq_,module,exports){
var global = _dereq_(40);
var SHARED = '__core-js_shared__';
var store = global[SHARED] || (global[SHARED] = {});
module.exports = function (key) {
  return store[key] || (store[key] = {});
};

},{"40":40}],104:[function(_dereq_,module,exports){
// 7.3.20 SpeciesConstructor(O, defaultConstructor)
var anObject = _dereq_(7);
var aFunction = _dereq_(3);
var SPECIES = _dereq_(128)('species');
module.exports = function (O, D) {
  var C = anObject(O).constructor;
  var S;
  return C === undefined || (S = anObject(C)[SPECIES]) == undefined ? D : aFunction(S);
};

},{"128":128,"3":3,"7":7}],105:[function(_dereq_,module,exports){
var fails = _dereq_(35);

module.exports = function (method, arg) {
  return !!method && fails(function () {
    // eslint-disable-next-line no-useless-call
    arg ? method.call(null, function () { /* empty */ }, 1) : method.call(null);
  });
};

},{"35":35}],106:[function(_dereq_,module,exports){
var toInteger = _dereq_(116);
var defined = _dereq_(28);
// true  -> String#at
// false -> String#codePointAt
module.exports = function (TO_STRING) {
  return function (that, pos) {
    var s = String(defined(that));
    var i = toInteger(pos);
    var l = s.length;
    var a, b;
    if (i < 0 || i >= l) return TO_STRING ? '' : undefined;
    a = s.charCodeAt(i);
    return a < 0xd800 || a > 0xdbff || i + 1 === l || (b = s.charCodeAt(i + 1)) < 0xdc00 || b > 0xdfff
      ? TO_STRING ? s.charAt(i) : a
      : TO_STRING ? s.slice(i, i + 2) : (a - 0xd800 << 10) + (b - 0xdc00) + 0x10000;
  };
};

},{"116":116,"28":28}],107:[function(_dereq_,module,exports){
// helper for String#{startsWith, endsWith, includes}
var isRegExp = _dereq_(52);
var defined = _dereq_(28);

module.exports = function (that, searchString, NAME) {
  if (isRegExp(searchString)) throw TypeError('String#' + NAME + " doesn't accept regex!");
  return String(defined(that));
};

},{"28":28,"52":52}],108:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var fails = _dereq_(35);
var defined = _dereq_(28);
var quot = /"/g;
// B.2.3.2.1 CreateHTML(string, tag, attribute, value)
var createHTML = function (string, tag, attribute, value) {
  var S = String(defined(string));
  var p1 = '<' + tag;
  if (attribute !== '') p1 += ' ' + attribute + '="' + String(value).replace(quot, '&quot;') + '"';
  return p1 + '>' + S + '</' + tag + '>';
};
module.exports = function (NAME, exec) {
  var O = {};
  O[NAME] = exec(createHTML);
  $export($export.P + $export.F * fails(function () {
    var test = ''[NAME]('"');
    return test !== test.toLowerCase() || test.split('"').length > 3;
  }), 'String', O);
};

},{"28":28,"33":33,"35":35}],109:[function(_dereq_,module,exports){
// https://github.com/tc39/proposal-string-pad-start-end
var toLength = _dereq_(118);
var repeat = _dereq_(110);
var defined = _dereq_(28);

module.exports = function (that, maxLength, fillString, left) {
  var S = String(defined(that));
  var stringLength = S.length;
  var fillStr = fillString === undefined ? ' ' : String(fillString);
  var intMaxLength = toLength(maxLength);
  if (intMaxLength <= stringLength || fillStr == '') return S;
  var fillLen = intMaxLength - stringLength;
  var stringFiller = repeat.call(fillStr, Math.ceil(fillLen / fillStr.length));
  if (stringFiller.length > fillLen) stringFiller = stringFiller.slice(0, fillLen);
  return left ? stringFiller + S : S + stringFiller;
};

},{"110":110,"118":118,"28":28}],110:[function(_dereq_,module,exports){
var toInteger = _dereq_(116);
var defined = _dereq_(28);

module.exports = function repeat(count) {
  var str = String(defined(this));
  var res = '';
  var n = toInteger(count);
  if (n < 0 || n == Infinity) throw RangeError("Count can't be negative");
  for (;n > 0; (n >>>= 1) && (str += str)) if (n & 1) res += str;
  return res;
};

},{"116":116,"28":28}],111:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var defined = _dereq_(28);
var fails = _dereq_(35);
var spaces = _dereq_(112);
var space = '[' + spaces + ']';
var non = '\u200b\u0085';
var ltrim = RegExp('^' + space + space + '*');
var rtrim = RegExp(space + space + '*$');

var exporter = function (KEY, exec, ALIAS) {
  var exp = {};
  var FORCE = fails(function () {
    return !!spaces[KEY]() || non[KEY]() != non;
  });
  var fn = exp[KEY] = FORCE ? exec(trim) : spaces[KEY];
  if (ALIAS) exp[ALIAS] = fn;
  $export($export.P + $export.F * FORCE, 'String', exp);
};

// 1 -> String#trimLeft
// 2 -> String#trimRight
// 3 -> String#trim
var trim = exporter.trim = function (string, TYPE) {
  string = String(defined(string));
  if (TYPE & 1) string = string.replace(ltrim, '');
  if (TYPE & 2) string = string.replace(rtrim, '');
  return string;
};

module.exports = exporter;

},{"112":112,"28":28,"33":33,"35":35}],112:[function(_dereq_,module,exports){
module.exports = '\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003' +
  '\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028\u2029\uFEFF';

},{}],113:[function(_dereq_,module,exports){
var ctx = _dereq_(25);
var invoke = _dereq_(46);
var html = _dereq_(43);
var cel = _dereq_(30);
var global = _dereq_(40);
var process = global.process;
var setTask = global.setImmediate;
var clearTask = global.clearImmediate;
var MessageChannel = global.MessageChannel;
var Dispatch = global.Dispatch;
var counter = 0;
var queue = {};
var ONREADYSTATECHANGE = 'onreadystatechange';
var defer, channel, port;
var run = function () {
  var id = +this;
  // eslint-disable-next-line no-prototype-builtins
  if (queue.hasOwnProperty(id)) {
    var fn = queue[id];
    delete queue[id];
    fn();
  }
};
var listener = function (event) {
  run.call(event.data);
};
// Node.js 0.9+ & IE10+ has setImmediate, otherwise:
if (!setTask || !clearTask) {
  setTask = function setImmediate(fn) {
    var args = [];
    var i = 1;
    while (arguments.length > i) args.push(arguments[i++]);
    queue[++counter] = function () {
      // eslint-disable-next-line no-new-func
      invoke(typeof fn == 'function' ? fn : Function(fn), args);
    };
    defer(counter);
    return counter;
  };
  clearTask = function clearImmediate(id) {
    delete queue[id];
  };
  // Node.js 0.8-
  if (_dereq_(18)(process) == 'process') {
    defer = function (id) {
      process.nextTick(ctx(run, id, 1));
    };
  // Sphere (JS game engine) Dispatch API
  } else if (Dispatch && Dispatch.now) {
    defer = function (id) {
      Dispatch.now(ctx(run, id, 1));
    };
  // Browsers with MessageChannel, includes WebWorkers
  } else if (MessageChannel) {
    channel = new MessageChannel();
    port = channel.port2;
    channel.port1.onmessage = listener;
    defer = ctx(port.postMessage, port, 1);
  // Browsers with postMessage, skip WebWorkers
  // IE8 has postMessage, but it's sync & typeof its postMessage is 'object'
  } else if (global.addEventListener && typeof postMessage == 'function' && !global.importScripts) {
    defer = function (id) {
      global.postMessage(id + '', '*');
    };
    global.addEventListener('message', listener, false);
  // IE8-
  } else if (ONREADYSTATECHANGE in cel('script')) {
    defer = function (id) {
      html.appendChild(cel('script'))[ONREADYSTATECHANGE] = function () {
        html.removeChild(this);
        run.call(id);
      };
    };
  // Rest old browsers
  } else {
    defer = function (id) {
      setTimeout(ctx(run, id, 1), 0);
    };
  }
}
module.exports = {
  set: setTask,
  clear: clearTask
};

},{"18":18,"25":25,"30":30,"40":40,"43":43,"46":46}],114:[function(_dereq_,module,exports){
var toInteger = _dereq_(116);
var max = Math.max;
var min = Math.min;
module.exports = function (index, length) {
  index = toInteger(index);
  return index < 0 ? max(index + length, 0) : min(index, length);
};

},{"116":116}],115:[function(_dereq_,module,exports){
// https://tc39.github.io/ecma262/#sec-toindex
var toInteger = _dereq_(116);
var toLength = _dereq_(118);
module.exports = function (it) {
  if (it === undefined) return 0;
  var number = toInteger(it);
  var length = toLength(number);
  if (number !== length) throw RangeError('Wrong length!');
  return length;
};

},{"116":116,"118":118}],116:[function(_dereq_,module,exports){
// 7.1.4 ToInteger
var ceil = Math.ceil;
var floor = Math.floor;
module.exports = function (it) {
  return isNaN(it = +it) ? 0 : (it > 0 ? floor : ceil)(it);
};

},{}],117:[function(_dereq_,module,exports){
// to indexed object, toObject with fallback for non-array-like ES3 strings
var IObject = _dereq_(47);
var defined = _dereq_(28);
module.exports = function (it) {
  return IObject(defined(it));
};

},{"28":28,"47":47}],118:[function(_dereq_,module,exports){
// 7.1.15 ToLength
var toInteger = _dereq_(116);
var min = Math.min;
module.exports = function (it) {
  return it > 0 ? min(toInteger(it), 0x1fffffffffffff) : 0; // pow(2, 53) - 1 == 9007199254740991
};

},{"116":116}],119:[function(_dereq_,module,exports){
// 7.1.13 ToObject(argument)
var defined = _dereq_(28);
module.exports = function (it) {
  return Object(defined(it));
};

},{"28":28}],120:[function(_dereq_,module,exports){
// 7.1.1 ToPrimitive(input [, PreferredType])
var isObject = _dereq_(51);
// instead of the ES6 spec version, we didn't implement @@toPrimitive case
// and the second argument - flag - preferred type is a string
module.exports = function (it, S) {
  if (!isObject(it)) return it;
  var fn, val;
  if (S && typeof (fn = it.toString) == 'function' && !isObject(val = fn.call(it))) return val;
  if (typeof (fn = it.valueOf) == 'function' && !isObject(val = fn.call(it))) return val;
  if (!S && typeof (fn = it.toString) == 'function' && !isObject(val = fn.call(it))) return val;
  throw TypeError("Can't convert object to primitive value");
};

},{"51":51}],121:[function(_dereq_,module,exports){
if (_dereq_(29)) {
  var LIBRARY = _dereq_(60);
  var global = _dereq_(40);
  var fails = _dereq_(35);
  var $export = _dereq_(33);
  var $typed = _dereq_(123);
  var $buffer = _dereq_(122);
  var ctx = _dereq_(25);
  var anInstance = _dereq_(6);
  var propertyDesc = _dereq_(92);
  var hide = _dereq_(42);
  var redefineAll = _dereq_(93);
  var toInteger = _dereq_(116);
  var toLength = _dereq_(118);
  var toIndex = _dereq_(115);
  var toAbsoluteIndex = _dereq_(114);
  var toPrimitive = _dereq_(120);
  var has = _dereq_(41);
  var classof = _dereq_(17);
  var isObject = _dereq_(51);
  var toObject = _dereq_(119);
  var isArrayIter = _dereq_(48);
  var create = _dereq_(71);
  var getPrototypeOf = _dereq_(79);
  var gOPN = _dereq_(77).f;
  var getIterFn = _dereq_(129);
  var uid = _dereq_(124);
  var wks = _dereq_(128);
  var createArrayMethod = _dereq_(12);
  var createArrayIncludes = _dereq_(11);
  var speciesConstructor = _dereq_(104);
  var ArrayIterators = _dereq_(141);
  var Iterators = _dereq_(58);
  var $iterDetect = _dereq_(56);
  var setSpecies = _dereq_(100);
  var arrayFill = _dereq_(9);
  var arrayCopyWithin = _dereq_(8);
  var $DP = _dereq_(72);
  var $GOPD = _dereq_(75);
  var dP = $DP.f;
  var gOPD = $GOPD.f;
  var RangeError = global.RangeError;
  var TypeError = global.TypeError;
  var Uint8Array = global.Uint8Array;
  var ARRAY_BUFFER = 'ArrayBuffer';
  var SHARED_BUFFER = 'Shared' + ARRAY_BUFFER;
  var BYTES_PER_ELEMENT = 'BYTES_PER_ELEMENT';
  var PROTOTYPE = 'prototype';
  var ArrayProto = Array[PROTOTYPE];
  var $ArrayBuffer = $buffer.ArrayBuffer;
  var $DataView = $buffer.DataView;
  var arrayForEach = createArrayMethod(0);
  var arrayFilter = createArrayMethod(2);
  var arraySome = createArrayMethod(3);
  var arrayEvery = createArrayMethod(4);
  var arrayFind = createArrayMethod(5);
  var arrayFindIndex = createArrayMethod(6);
  var arrayIncludes = createArrayIncludes(true);
  var arrayIndexOf = createArrayIncludes(false);
  var arrayValues = ArrayIterators.values;
  var arrayKeys = ArrayIterators.keys;
  var arrayEntries = ArrayIterators.entries;
  var arrayLastIndexOf = ArrayProto.lastIndexOf;
  var arrayReduce = ArrayProto.reduce;
  var arrayReduceRight = ArrayProto.reduceRight;
  var arrayJoin = ArrayProto.join;
  var arraySort = ArrayProto.sort;
  var arraySlice = ArrayProto.slice;
  var arrayToString = ArrayProto.toString;
  var arrayToLocaleString = ArrayProto.toLocaleString;
  var ITERATOR = wks('iterator');
  var TAG = wks('toStringTag');
  var TYPED_CONSTRUCTOR = uid('typed_constructor');
  var DEF_CONSTRUCTOR = uid('def_constructor');
  var ALL_CONSTRUCTORS = $typed.CONSTR;
  var TYPED_ARRAY = $typed.TYPED;
  var VIEW = $typed.VIEW;
  var WRONG_LENGTH = 'Wrong length!';

  var $map = createArrayMethod(1, function (O, length) {
    return allocate(speciesConstructor(O, O[DEF_CONSTRUCTOR]), length);
  });

  var LITTLE_ENDIAN = fails(function () {
    // eslint-disable-next-line no-undef
    return new Uint8Array(new Uint16Array([1]).buffer)[0] === 1;
  });

  var FORCED_SET = !!Uint8Array && !!Uint8Array[PROTOTYPE].set && fails(function () {
    new Uint8Array(1).set({});
  });

  var toOffset = function (it, BYTES) {
    var offset = toInteger(it);
    if (offset < 0 || offset % BYTES) throw RangeError('Wrong offset!');
    return offset;
  };

  var validate = function (it) {
    if (isObject(it) && TYPED_ARRAY in it) return it;
    throw TypeError(it + ' is not a typed array!');
  };

  var allocate = function (C, length) {
    if (!(isObject(C) && TYPED_CONSTRUCTOR in C)) {
      throw TypeError('It is not a typed array constructor!');
    } return new C(length);
  };

  var speciesFromList = function (O, list) {
    return fromList(speciesConstructor(O, O[DEF_CONSTRUCTOR]), list);
  };

  var fromList = function (C, list) {
    var index = 0;
    var length = list.length;
    var result = allocate(C, length);
    while (length > index) result[index] = list[index++];
    return result;
  };

  var addGetter = function (it, key, internal) {
    dP(it, key, { get: function () { return this._d[internal]; } });
  };

  var $from = function from(source /* , mapfn, thisArg */) {
    var O = toObject(source);
    var aLen = arguments.length;
    var mapfn = aLen > 1 ? arguments[1] : undefined;
    var mapping = mapfn !== undefined;
    var iterFn = getIterFn(O);
    var i, length, values, result, step, iterator;
    if (iterFn != undefined && !isArrayIter(iterFn)) {
      for (iterator = iterFn.call(O), values = [], i = 0; !(step = iterator.next()).done; i++) {
        values.push(step.value);
      } O = values;
    }
    if (mapping && aLen > 2) mapfn = ctx(mapfn, arguments[2], 2);
    for (i = 0, length = toLength(O.length), result = allocate(this, length); length > i; i++) {
      result[i] = mapping ? mapfn(O[i], i) : O[i];
    }
    return result;
  };

  var $of = function of(/* ...items */) {
    var index = 0;
    var length = arguments.length;
    var result = allocate(this, length);
    while (length > index) result[index] = arguments[index++];
    return result;
  };

  // iOS Safari 6.x fails here
  var TO_LOCALE_BUG = !!Uint8Array && fails(function () { arrayToLocaleString.call(new Uint8Array(1)); });

  var $toLocaleString = function toLocaleString() {
    return arrayToLocaleString.apply(TO_LOCALE_BUG ? arraySlice.call(validate(this)) : validate(this), arguments);
  };

  var proto = {
    copyWithin: function copyWithin(target, start /* , end */) {
      return arrayCopyWithin.call(validate(this), target, start, arguments.length > 2 ? arguments[2] : undefined);
    },
    every: function every(callbackfn /* , thisArg */) {
      return arrayEvery(validate(this), callbackfn, arguments.length > 1 ? arguments[1] : undefined);
    },
    fill: function fill(value /* , start, end */) { // eslint-disable-line no-unused-vars
      return arrayFill.apply(validate(this), arguments);
    },
    filter: function filter(callbackfn /* , thisArg */) {
      return speciesFromList(this, arrayFilter(validate(this), callbackfn,
        arguments.length > 1 ? arguments[1] : undefined));
    },
    find: function find(predicate /* , thisArg */) {
      return arrayFind(validate(this), predicate, arguments.length > 1 ? arguments[1] : undefined);
    },
    findIndex: function findIndex(predicate /* , thisArg */) {
      return arrayFindIndex(validate(this), predicate, arguments.length > 1 ? arguments[1] : undefined);
    },
    forEach: function forEach(callbackfn /* , thisArg */) {
      arrayForEach(validate(this), callbackfn, arguments.length > 1 ? arguments[1] : undefined);
    },
    indexOf: function indexOf(searchElement /* , fromIndex */) {
      return arrayIndexOf(validate(this), searchElement, arguments.length > 1 ? arguments[1] : undefined);
    },
    includes: function includes(searchElement /* , fromIndex */) {
      return arrayIncludes(validate(this), searchElement, arguments.length > 1 ? arguments[1] : undefined);
    },
    join: function join(separator) { // eslint-disable-line no-unused-vars
      return arrayJoin.apply(validate(this), arguments);
    },
    lastIndexOf: function lastIndexOf(searchElement /* , fromIndex */) { // eslint-disable-line no-unused-vars
      return arrayLastIndexOf.apply(validate(this), arguments);
    },
    map: function map(mapfn /* , thisArg */) {
      return $map(validate(this), mapfn, arguments.length > 1 ? arguments[1] : undefined);
    },
    reduce: function reduce(callbackfn /* , initialValue */) { // eslint-disable-line no-unused-vars
      return arrayReduce.apply(validate(this), arguments);
    },
    reduceRight: function reduceRight(callbackfn /* , initialValue */) { // eslint-disable-line no-unused-vars
      return arrayReduceRight.apply(validate(this), arguments);
    },
    reverse: function reverse() {
      var that = this;
      var length = validate(that).length;
      var middle = Math.floor(length / 2);
      var index = 0;
      var value;
      while (index < middle) {
        value = that[index];
        that[index++] = that[--length];
        that[length] = value;
      } return that;
    },
    some: function some(callbackfn /* , thisArg */) {
      return arraySome(validate(this), callbackfn, arguments.length > 1 ? arguments[1] : undefined);
    },
    sort: function sort(comparefn) {
      return arraySort.call(validate(this), comparefn);
    },
    subarray: function subarray(begin, end) {
      var O = validate(this);
      var length = O.length;
      var $begin = toAbsoluteIndex(begin, length);
      return new (speciesConstructor(O, O[DEF_CONSTRUCTOR]))(
        O.buffer,
        O.byteOffset + $begin * O.BYTES_PER_ELEMENT,
        toLength((end === undefined ? length : toAbsoluteIndex(end, length)) - $begin)
      );
    }
  };

  var $slice = function slice(start, end) {
    return speciesFromList(this, arraySlice.call(validate(this), start, end));
  };

  var $set = function set(arrayLike /* , offset */) {
    validate(this);
    var offset = toOffset(arguments[1], 1);
    var length = this.length;
    var src = toObject(arrayLike);
    var len = toLength(src.length);
    var index = 0;
    if (len + offset > length) throw RangeError(WRONG_LENGTH);
    while (index < len) this[offset + index] = src[index++];
  };

  var $iterators = {
    entries: function entries() {
      return arrayEntries.call(validate(this));
    },
    keys: function keys() {
      return arrayKeys.call(validate(this));
    },
    values: function values() {
      return arrayValues.call(validate(this));
    }
  };

  var isTAIndex = function (target, key) {
    return isObject(target)
      && target[TYPED_ARRAY]
      && typeof key != 'symbol'
      && key in target
      && String(+key) == String(key);
  };
  var $getDesc = function getOwnPropertyDescriptor(target, key) {
    return isTAIndex(target, key = toPrimitive(key, true))
      ? propertyDesc(2, target[key])
      : gOPD(target, key);
  };
  var $setDesc = function defineProperty(target, key, desc) {
    if (isTAIndex(target, key = toPrimitive(key, true))
      && isObject(desc)
      && has(desc, 'value')
      && !has(desc, 'get')
      && !has(desc, 'set')
      // TODO: add validation descriptor w/o calling accessors
      && !desc.configurable
      && (!has(desc, 'writable') || desc.writable)
      && (!has(desc, 'enumerable') || desc.enumerable)
    ) {
      target[key] = desc.value;
      return target;
    } return dP(target, key, desc);
  };

  if (!ALL_CONSTRUCTORS) {
    $GOPD.f = $getDesc;
    $DP.f = $setDesc;
  }

  $export($export.S + $export.F * !ALL_CONSTRUCTORS, 'Object', {
    getOwnPropertyDescriptor: $getDesc,
    defineProperty: $setDesc
  });

  if (fails(function () { arrayToString.call({}); })) {
    arrayToString = arrayToLocaleString = function toString() {
      return arrayJoin.call(this);
    };
  }

  var $TypedArrayPrototype$ = redefineAll({}, proto);
  redefineAll($TypedArrayPrototype$, $iterators);
  hide($TypedArrayPrototype$, ITERATOR, $iterators.values);
  redefineAll($TypedArrayPrototype$, {
    slice: $slice,
    set: $set,
    constructor: function () { /* noop */ },
    toString: arrayToString,
    toLocaleString: $toLocaleString
  });
  addGetter($TypedArrayPrototype$, 'buffer', 'b');
  addGetter($TypedArrayPrototype$, 'byteOffset', 'o');
  addGetter($TypedArrayPrototype$, 'byteLength', 'l');
  addGetter($TypedArrayPrototype$, 'length', 'e');
  dP($TypedArrayPrototype$, TAG, {
    get: function () { return this[TYPED_ARRAY]; }
  });

  // eslint-disable-next-line max-statements
  module.exports = function (KEY, BYTES, wrapper, CLAMPED) {
    CLAMPED = !!CLAMPED;
    var NAME = KEY + (CLAMPED ? 'Clamped' : '') + 'Array';
    var GETTER = 'get' + KEY;
    var SETTER = 'set' + KEY;
    var TypedArray = global[NAME];
    var Base = TypedArray || {};
    var TAC = TypedArray && getPrototypeOf(TypedArray);
    var FORCED = !TypedArray || !$typed.ABV;
    var O = {};
    var TypedArrayPrototype = TypedArray && TypedArray[PROTOTYPE];
    var getter = function (that, index) {
      var data = that._d;
      return data.v[GETTER](index * BYTES + data.o, LITTLE_ENDIAN);
    };
    var setter = function (that, index, value) {
      var data = that._d;
      if (CLAMPED) value = (value = Math.round(value)) < 0 ? 0 : value > 0xff ? 0xff : value & 0xff;
      data.v[SETTER](index * BYTES + data.o, value, LITTLE_ENDIAN);
    };
    var addElement = function (that, index) {
      dP(that, index, {
        get: function () {
          return getter(this, index);
        },
        set: function (value) {
          return setter(this, index, value);
        },
        enumerable: true
      });
    };
    if (FORCED) {
      TypedArray = wrapper(function (that, data, $offset, $length) {
        anInstance(that, TypedArray, NAME, '_d');
        var index = 0;
        var offset = 0;
        var buffer, byteLength, length, klass;
        if (!isObject(data)) {
          length = toIndex(data);
          byteLength = length * BYTES;
          buffer = new $ArrayBuffer(byteLength);
        } else if (data instanceof $ArrayBuffer || (klass = classof(data)) == ARRAY_BUFFER || klass == SHARED_BUFFER) {
          buffer = data;
          offset = toOffset($offset, BYTES);
          var $len = data.byteLength;
          if ($length === undefined) {
            if ($len % BYTES) throw RangeError(WRONG_LENGTH);
            byteLength = $len - offset;
            if (byteLength < 0) throw RangeError(WRONG_LENGTH);
          } else {
            byteLength = toLength($length) * BYTES;
            if (byteLength + offset > $len) throw RangeError(WRONG_LENGTH);
          }
          length = byteLength / BYTES;
        } else if (TYPED_ARRAY in data) {
          return fromList(TypedArray, data);
        } else {
          return $from.call(TypedArray, data);
        }
        hide(that, '_d', {
          b: buffer,
          o: offset,
          l: byteLength,
          e: length,
          v: new $DataView(buffer)
        });
        while (index < length) addElement(that, index++);
      });
      TypedArrayPrototype = TypedArray[PROTOTYPE] = create($TypedArrayPrototype$);
      hide(TypedArrayPrototype, 'constructor', TypedArray);
    } else if (!fails(function () {
      TypedArray(1);
    }) || !fails(function () {
      new TypedArray(-1); // eslint-disable-line no-new
    }) || !$iterDetect(function (iter) {
      new TypedArray(); // eslint-disable-line no-new
      new TypedArray(null); // eslint-disable-line no-new
      new TypedArray(1.5); // eslint-disable-line no-new
      new TypedArray(iter); // eslint-disable-line no-new
    }, true)) {
      TypedArray = wrapper(function (that, data, $offset, $length) {
        anInstance(that, TypedArray, NAME);
        var klass;
        // `ws` module bug, temporarily remove validation length for Uint8Array
        // https://github.com/websockets/ws/pull/645
        if (!isObject(data)) return new Base(toIndex(data));
        if (data instanceof $ArrayBuffer || (klass = classof(data)) == ARRAY_BUFFER || klass == SHARED_BUFFER) {
          return $length !== undefined
            ? new Base(data, toOffset($offset, BYTES), $length)
            : $offset !== undefined
              ? new Base(data, toOffset($offset, BYTES))
              : new Base(data);
        }
        if (TYPED_ARRAY in data) return fromList(TypedArray, data);
        return $from.call(TypedArray, data);
      });
      arrayForEach(TAC !== Function.prototype ? gOPN(Base).concat(gOPN(TAC)) : gOPN(Base), function (key) {
        if (!(key in TypedArray)) hide(TypedArray, key, Base[key]);
      });
      TypedArray[PROTOTYPE] = TypedArrayPrototype;
      if (!LIBRARY) TypedArrayPrototype.constructor = TypedArray;
    }
    var $nativeIterator = TypedArrayPrototype[ITERATOR];
    var CORRECT_ITER_NAME = !!$nativeIterator
      && ($nativeIterator.name == 'values' || $nativeIterator.name == undefined);
    var $iterator = $iterators.values;
    hide(TypedArray, TYPED_CONSTRUCTOR, true);
    hide(TypedArrayPrototype, TYPED_ARRAY, NAME);
    hide(TypedArrayPrototype, VIEW, true);
    hide(TypedArrayPrototype, DEF_CONSTRUCTOR, TypedArray);

    if (CLAMPED ? new TypedArray(1)[TAG] != NAME : !(TAG in TypedArrayPrototype)) {
      dP(TypedArrayPrototype, TAG, {
        get: function () { return NAME; }
      });
    }

    O[NAME] = TypedArray;

    $export($export.G + $export.W + $export.F * (TypedArray != Base), O);

    $export($export.S, NAME, {
      BYTES_PER_ELEMENT: BYTES
    });

    $export($export.S + $export.F * fails(function () { Base.of.call(TypedArray, 1); }), NAME, {
      from: $from,
      of: $of
    });

    if (!(BYTES_PER_ELEMENT in TypedArrayPrototype)) hide(TypedArrayPrototype, BYTES_PER_ELEMENT, BYTES);

    $export($export.P, NAME, proto);

    setSpecies(NAME);

    $export($export.P + $export.F * FORCED_SET, NAME, { set: $set });

    $export($export.P + $export.F * !CORRECT_ITER_NAME, NAME, $iterators);

    if (!LIBRARY && TypedArrayPrototype.toString != arrayToString) TypedArrayPrototype.toString = arrayToString;

    $export($export.P + $export.F * fails(function () {
      new TypedArray(1).slice();
    }), NAME, { slice: $slice });

    $export($export.P + $export.F * (fails(function () {
      return [1, 2].toLocaleString() != new TypedArray([1, 2]).toLocaleString();
    }) || !fails(function () {
      TypedArrayPrototype.toLocaleString.call([1, 2]);
    })), NAME, { toLocaleString: $toLocaleString });

    Iterators[NAME] = CORRECT_ITER_NAME ? $nativeIterator : $iterator;
    if (!LIBRARY && !CORRECT_ITER_NAME) hide(TypedArrayPrototype, ITERATOR, $iterator);
  };
} else module.exports = function () { /* empty */ };

},{"100":100,"104":104,"11":11,"114":114,"115":115,"116":116,"118":118,"119":119,"12":12,"120":120,"122":122,"123":123,"124":124,"128":128,"129":129,"141":141,"17":17,"25":25,"29":29,"33":33,"35":35,"40":40,"41":41,"42":42,"48":48,"51":51,"56":56,"58":58,"6":6,"60":60,"71":71,"72":72,"75":75,"77":77,"79":79,"8":8,"9":9,"92":92,"93":93}],122:[function(_dereq_,module,exports){
var global = _dereq_(40);
var DESCRIPTORS = _dereq_(29);
var LIBRARY = _dereq_(60);
var $typed = _dereq_(123);
var hide = _dereq_(42);
var redefineAll = _dereq_(93);
var fails = _dereq_(35);
var anInstance = _dereq_(6);
var toInteger = _dereq_(116);
var toLength = _dereq_(118);
var toIndex = _dereq_(115);
var gOPN = _dereq_(77).f;
var dP = _dereq_(72).f;
var arrayFill = _dereq_(9);
var setToStringTag = _dereq_(101);
var ARRAY_BUFFER = 'ArrayBuffer';
var DATA_VIEW = 'DataView';
var PROTOTYPE = 'prototype';
var WRONG_LENGTH = 'Wrong length!';
var WRONG_INDEX = 'Wrong index!';
var $ArrayBuffer = global[ARRAY_BUFFER];
var $DataView = global[DATA_VIEW];
var Math = global.Math;
var RangeError = global.RangeError;
// eslint-disable-next-line no-shadow-restricted-names
var Infinity = global.Infinity;
var BaseBuffer = $ArrayBuffer;
var abs = Math.abs;
var pow = Math.pow;
var floor = Math.floor;
var log = Math.log;
var LN2 = Math.LN2;
var BUFFER = 'buffer';
var BYTE_LENGTH = 'byteLength';
var BYTE_OFFSET = 'byteOffset';
var $BUFFER = DESCRIPTORS ? '_b' : BUFFER;
var $LENGTH = DESCRIPTORS ? '_l' : BYTE_LENGTH;
var $OFFSET = DESCRIPTORS ? '_o' : BYTE_OFFSET;

// IEEE754 conversions based on https://github.com/feross/ieee754
function packIEEE754(value, mLen, nBytes) {
  var buffer = Array(nBytes);
  var eLen = nBytes * 8 - mLen - 1;
  var eMax = (1 << eLen) - 1;
  var eBias = eMax >> 1;
  var rt = mLen === 23 ? pow(2, -24) - pow(2, -77) : 0;
  var i = 0;
  var s = value < 0 || value === 0 && 1 / value < 0 ? 1 : 0;
  var e, m, c;
  value = abs(value);
  // eslint-disable-next-line no-self-compare
  if (value != value || value === Infinity) {
    // eslint-disable-next-line no-self-compare
    m = value != value ? 1 : 0;
    e = eMax;
  } else {
    e = floor(log(value) / LN2);
    if (value * (c = pow(2, -e)) < 1) {
      e--;
      c *= 2;
    }
    if (e + eBias >= 1) {
      value += rt / c;
    } else {
      value += rt * pow(2, 1 - eBias);
    }
    if (value * c >= 2) {
      e++;
      c /= 2;
    }
    if (e + eBias >= eMax) {
      m = 0;
      e = eMax;
    } else if (e + eBias >= 1) {
      m = (value * c - 1) * pow(2, mLen);
      e = e + eBias;
    } else {
      m = value * pow(2, eBias - 1) * pow(2, mLen);
      e = 0;
    }
  }
  for (; mLen >= 8; buffer[i++] = m & 255, m /= 256, mLen -= 8);
  e = e << mLen | m;
  eLen += mLen;
  for (; eLen > 0; buffer[i++] = e & 255, e /= 256, eLen -= 8);
  buffer[--i] |= s * 128;
  return buffer;
}
function unpackIEEE754(buffer, mLen, nBytes) {
  var eLen = nBytes * 8 - mLen - 1;
  var eMax = (1 << eLen) - 1;
  var eBias = eMax >> 1;
  var nBits = eLen - 7;
  var i = nBytes - 1;
  var s = buffer[i--];
  var e = s & 127;
  var m;
  s >>= 7;
  for (; nBits > 0; e = e * 256 + buffer[i], i--, nBits -= 8);
  m = e & (1 << -nBits) - 1;
  e >>= -nBits;
  nBits += mLen;
  for (; nBits > 0; m = m * 256 + buffer[i], i--, nBits -= 8);
  if (e === 0) {
    e = 1 - eBias;
  } else if (e === eMax) {
    return m ? NaN : s ? -Infinity : Infinity;
  } else {
    m = m + pow(2, mLen);
    e = e - eBias;
  } return (s ? -1 : 1) * m * pow(2, e - mLen);
}

function unpackI32(bytes) {
  return bytes[3] << 24 | bytes[2] << 16 | bytes[1] << 8 | bytes[0];
}
function packI8(it) {
  return [it & 0xff];
}
function packI16(it) {
  return [it & 0xff, it >> 8 & 0xff];
}
function packI32(it) {
  return [it & 0xff, it >> 8 & 0xff, it >> 16 & 0xff, it >> 24 & 0xff];
}
function packF64(it) {
  return packIEEE754(it, 52, 8);
}
function packF32(it) {
  return packIEEE754(it, 23, 4);
}

function addGetter(C, key, internal) {
  dP(C[PROTOTYPE], key, { get: function () { return this[internal]; } });
}

function get(view, bytes, index, isLittleEndian) {
  var numIndex = +index;
  var intIndex = toIndex(numIndex);
  if (intIndex + bytes > view[$LENGTH]) throw RangeError(WRONG_INDEX);
  var store = view[$BUFFER]._b;
  var start = intIndex + view[$OFFSET];
  var pack = store.slice(start, start + bytes);
  return isLittleEndian ? pack : pack.reverse();
}
function set(view, bytes, index, conversion, value, isLittleEndian) {
  var numIndex = +index;
  var intIndex = toIndex(numIndex);
  if (intIndex + bytes > view[$LENGTH]) throw RangeError(WRONG_INDEX);
  var store = view[$BUFFER]._b;
  var start = intIndex + view[$OFFSET];
  var pack = conversion(+value);
  for (var i = 0; i < bytes; i++) store[start + i] = pack[isLittleEndian ? i : bytes - i - 1];
}

if (!$typed.ABV) {
  $ArrayBuffer = function ArrayBuffer(length) {
    anInstance(this, $ArrayBuffer, ARRAY_BUFFER);
    var byteLength = toIndex(length);
    this._b = arrayFill.call(Array(byteLength), 0);
    this[$LENGTH] = byteLength;
  };

  $DataView = function DataView(buffer, byteOffset, byteLength) {
    anInstance(this, $DataView, DATA_VIEW);
    anInstance(buffer, $ArrayBuffer, DATA_VIEW);
    var bufferLength = buffer[$LENGTH];
    var offset = toInteger(byteOffset);
    if (offset < 0 || offset > bufferLength) throw RangeError('Wrong offset!');
    byteLength = byteLength === undefined ? bufferLength - offset : toLength(byteLength);
    if (offset + byteLength > bufferLength) throw RangeError(WRONG_LENGTH);
    this[$BUFFER] = buffer;
    this[$OFFSET] = offset;
    this[$LENGTH] = byteLength;
  };

  if (DESCRIPTORS) {
    addGetter($ArrayBuffer, BYTE_LENGTH, '_l');
    addGetter($DataView, BUFFER, '_b');
    addGetter($DataView, BYTE_LENGTH, '_l');
    addGetter($DataView, BYTE_OFFSET, '_o');
  }

  redefineAll($DataView[PROTOTYPE], {
    getInt8: function getInt8(byteOffset) {
      return get(this, 1, byteOffset)[0] << 24 >> 24;
    },
    getUint8: function getUint8(byteOffset) {
      return get(this, 1, byteOffset)[0];
    },
    getInt16: function getInt16(byteOffset /* , littleEndian */) {
      var bytes = get(this, 2, byteOffset, arguments[1]);
      return (bytes[1] << 8 | bytes[0]) << 16 >> 16;
    },
    getUint16: function getUint16(byteOffset /* , littleEndian */) {
      var bytes = get(this, 2, byteOffset, arguments[1]);
      return bytes[1] << 8 | bytes[0];
    },
    getInt32: function getInt32(byteOffset /* , littleEndian */) {
      return unpackI32(get(this, 4, byteOffset, arguments[1]));
    },
    getUint32: function getUint32(byteOffset /* , littleEndian */) {
      return unpackI32(get(this, 4, byteOffset, arguments[1])) >>> 0;
    },
    getFloat32: function getFloat32(byteOffset /* , littleEndian */) {
      return unpackIEEE754(get(this, 4, byteOffset, arguments[1]), 23, 4);
    },
    getFloat64: function getFloat64(byteOffset /* , littleEndian */) {
      return unpackIEEE754(get(this, 8, byteOffset, arguments[1]), 52, 8);
    },
    setInt8: function setInt8(byteOffset, value) {
      set(this, 1, byteOffset, packI8, value);
    },
    setUint8: function setUint8(byteOffset, value) {
      set(this, 1, byteOffset, packI8, value);
    },
    setInt16: function setInt16(byteOffset, value /* , littleEndian */) {
      set(this, 2, byteOffset, packI16, value, arguments[2]);
    },
    setUint16: function setUint16(byteOffset, value /* , littleEndian */) {
      set(this, 2, byteOffset, packI16, value, arguments[2]);
    },
    setInt32: function setInt32(byteOffset, value /* , littleEndian */) {
      set(this, 4, byteOffset, packI32, value, arguments[2]);
    },
    setUint32: function setUint32(byteOffset, value /* , littleEndian */) {
      set(this, 4, byteOffset, packI32, value, arguments[2]);
    },
    setFloat32: function setFloat32(byteOffset, value /* , littleEndian */) {
      set(this, 4, byteOffset, packF32, value, arguments[2]);
    },
    setFloat64: function setFloat64(byteOffset, value /* , littleEndian */) {
      set(this, 8, byteOffset, packF64, value, arguments[2]);
    }
  });
} else {
  if (!fails(function () {
    $ArrayBuffer(1);
  }) || !fails(function () {
    new $ArrayBuffer(-1); // eslint-disable-line no-new
  }) || fails(function () {
    new $ArrayBuffer(); // eslint-disable-line no-new
    new $ArrayBuffer(1.5); // eslint-disable-line no-new
    new $ArrayBuffer(NaN); // eslint-disable-line no-new
    return $ArrayBuffer.name != ARRAY_BUFFER;
  })) {
    $ArrayBuffer = function ArrayBuffer(length) {
      anInstance(this, $ArrayBuffer);
      return new BaseBuffer(toIndex(length));
    };
    var ArrayBufferProto = $ArrayBuffer[PROTOTYPE] = BaseBuffer[PROTOTYPE];
    for (var keys = gOPN(BaseBuffer), j = 0, key; keys.length > j;) {
      if (!((key = keys[j++]) in $ArrayBuffer)) hide($ArrayBuffer, key, BaseBuffer[key]);
    }
    if (!LIBRARY) ArrayBufferProto.constructor = $ArrayBuffer;
  }
  // iOS Safari 7.x bug
  var view = new $DataView(new $ArrayBuffer(2));
  var $setInt8 = $DataView[PROTOTYPE].setInt8;
  view.setInt8(0, 2147483648);
  view.setInt8(1, 2147483649);
  if (view.getInt8(0) || !view.getInt8(1)) redefineAll($DataView[PROTOTYPE], {
    setInt8: function setInt8(byteOffset, value) {
      $setInt8.call(this, byteOffset, value << 24 >> 24);
    },
    setUint8: function setUint8(byteOffset, value) {
      $setInt8.call(this, byteOffset, value << 24 >> 24);
    }
  }, true);
}
setToStringTag($ArrayBuffer, ARRAY_BUFFER);
setToStringTag($DataView, DATA_VIEW);
hide($DataView[PROTOTYPE], $typed.VIEW, true);
exports[ARRAY_BUFFER] = $ArrayBuffer;
exports[DATA_VIEW] = $DataView;

},{"101":101,"115":115,"116":116,"118":118,"123":123,"29":29,"35":35,"40":40,"42":42,"6":6,"60":60,"72":72,"77":77,"9":9,"93":93}],123:[function(_dereq_,module,exports){
var global = _dereq_(40);
var hide = _dereq_(42);
var uid = _dereq_(124);
var TYPED = uid('typed_array');
var VIEW = uid('view');
var ABV = !!(global.ArrayBuffer && global.DataView);
var CONSTR = ABV;
var i = 0;
var l = 9;
var Typed;

var TypedArrayConstructors = (
  'Int8Array,Uint8Array,Uint8ClampedArray,Int16Array,Uint16Array,Int32Array,Uint32Array,Float32Array,Float64Array'
).split(',');

while (i < l) {
  if (Typed = global[TypedArrayConstructors[i++]]) {
    hide(Typed.prototype, TYPED, true);
    hide(Typed.prototype, VIEW, true);
  } else CONSTR = false;
}

module.exports = {
  ABV: ABV,
  CONSTR: CONSTR,
  TYPED: TYPED,
  VIEW: VIEW
};

},{"124":124,"40":40,"42":42}],124:[function(_dereq_,module,exports){
var id = 0;
var px = Math.random();
module.exports = function (key) {
  return 'Symbol('.concat(key === undefined ? '' : key, ')_', (++id + px).toString(36));
};

},{}],125:[function(_dereq_,module,exports){
var isObject = _dereq_(51);
module.exports = function (it, TYPE) {
  if (!isObject(it) || it._t !== TYPE) throw TypeError('Incompatible receiver, ' + TYPE + ' required!');
  return it;
};

},{"51":51}],126:[function(_dereq_,module,exports){
var global = _dereq_(40);
var core = _dereq_(23);
var LIBRARY = _dereq_(60);
var wksExt = _dereq_(127);
var defineProperty = _dereq_(72).f;
module.exports = function (name) {
  var $Symbol = core.Symbol || (core.Symbol = LIBRARY ? {} : global.Symbol || {});
  if (name.charAt(0) != '_' && !(name in $Symbol)) defineProperty($Symbol, name, { value: wksExt.f(name) });
};

},{"127":127,"23":23,"40":40,"60":60,"72":72}],127:[function(_dereq_,module,exports){
exports.f = _dereq_(128);

},{"128":128}],128:[function(_dereq_,module,exports){
var store = _dereq_(103)('wks');
var uid = _dereq_(124);
var Symbol = _dereq_(40).Symbol;
var USE_SYMBOL = typeof Symbol == 'function';

var $exports = module.exports = function (name) {
  return store[name] || (store[name] =
    USE_SYMBOL && Symbol[name] || (USE_SYMBOL ? Symbol : uid)('Symbol.' + name));
};

$exports.store = store;

},{"103":103,"124":124,"40":40}],129:[function(_dereq_,module,exports){
var classof = _dereq_(17);
var ITERATOR = _dereq_(128)('iterator');
var Iterators = _dereq_(58);
module.exports = _dereq_(23).getIteratorMethod = function (it) {
  if (it != undefined) return it[ITERATOR]
    || it['@@iterator']
    || Iterators[classof(it)];
};

},{"128":128,"17":17,"23":23,"58":58}],130:[function(_dereq_,module,exports){
// https://github.com/benjamingr/RexExp.escape
var $export = _dereq_(33);
var $re = _dereq_(95)(/[\\^$*+?.()|[\]{}]/g, '\\$&');

$export($export.S, 'RegExp', { escape: function escape(it) { return $re(it); } });

},{"33":33,"95":95}],131:[function(_dereq_,module,exports){
// 22.1.3.3 Array.prototype.copyWithin(target, start, end = this.length)
var $export = _dereq_(33);

$export($export.P, 'Array', { copyWithin: _dereq_(8) });

_dereq_(5)('copyWithin');

},{"33":33,"5":5,"8":8}],132:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $every = _dereq_(12)(4);

$export($export.P + $export.F * !_dereq_(105)([].every, true), 'Array', {
  // 22.1.3.5 / 15.4.4.16 Array.prototype.every(callbackfn [, thisArg])
  every: function every(callbackfn /* , thisArg */) {
    return $every(this, callbackfn, arguments[1]);
  }
});

},{"105":105,"12":12,"33":33}],133:[function(_dereq_,module,exports){
// 22.1.3.6 Array.prototype.fill(value, start = 0, end = this.length)
var $export = _dereq_(33);

$export($export.P, 'Array', { fill: _dereq_(9) });

_dereq_(5)('fill');

},{"33":33,"5":5,"9":9}],134:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $filter = _dereq_(12)(2);

$export($export.P + $export.F * !_dereq_(105)([].filter, true), 'Array', {
  // 22.1.3.7 / 15.4.4.20 Array.prototype.filter(callbackfn [, thisArg])
  filter: function filter(callbackfn /* , thisArg */) {
    return $filter(this, callbackfn, arguments[1]);
  }
});

},{"105":105,"12":12,"33":33}],135:[function(_dereq_,module,exports){
// 22.1.3.9 Array.prototype.findIndex(predicate, thisArg = undefined)
var $export = _dereq_(33);
var $find = _dereq_(12)(6);
var KEY = 'findIndex';
var forced = true;
// Shouldn't skip holes
if (KEY in []) Array(1)[KEY](function () { forced = false; });
$export($export.P + $export.F * forced, 'Array', {
  findIndex: function findIndex(callbackfn /* , that = undefined */) {
    return $find(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
  }
});
_dereq_(5)(KEY);

},{"12":12,"33":33,"5":5}],136:[function(_dereq_,module,exports){
// 22.1.3.8 Array.prototype.find(predicate, thisArg = undefined)
var $export = _dereq_(33);
var $find = _dereq_(12)(5);
var KEY = 'find';
var forced = true;
// Shouldn't skip holes
if (KEY in []) Array(1)[KEY](function () { forced = false; });
$export($export.P + $export.F * forced, 'Array', {
  find: function find(callbackfn /* , that = undefined */) {
    return $find(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
  }
});
_dereq_(5)(KEY);

},{"12":12,"33":33,"5":5}],137:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $forEach = _dereq_(12)(0);
var STRICT = _dereq_(105)([].forEach, true);

$export($export.P + $export.F * !STRICT, 'Array', {
  // 22.1.3.10 / 15.4.4.18 Array.prototype.forEach(callbackfn [, thisArg])
  forEach: function forEach(callbackfn /* , thisArg */) {
    return $forEach(this, callbackfn, arguments[1]);
  }
});

},{"105":105,"12":12,"33":33}],138:[function(_dereq_,module,exports){
var ctx = _dereq_(25);
var $export = _dereq_(33);
var toObject = _dereq_(119);
var call = _dereq_(53);
var isArrayIter = _dereq_(48);
var toLength = _dereq_(118);
var createProperty = _dereq_(24);
var getIterFn = _dereq_(129);

$export($export.S + $export.F * !_dereq_(56)(function (iter) { Array.from(iter); }), 'Array', {
  // 22.1.2.1 Array.from(arrayLike, mapfn = undefined, thisArg = undefined)
  from: function from(arrayLike /* , mapfn = undefined, thisArg = undefined */) {
    var O = toObject(arrayLike);
    var C = typeof this == 'function' ? this : Array;
    var aLen = arguments.length;
    var mapfn = aLen > 1 ? arguments[1] : undefined;
    var mapping = mapfn !== undefined;
    var index = 0;
    var iterFn = getIterFn(O);
    var length, result, step, iterator;
    if (mapping) mapfn = ctx(mapfn, aLen > 2 ? arguments[2] : undefined, 2);
    // if object isn't iterable or it's array with default iterator - use simple case
    if (iterFn != undefined && !(C == Array && isArrayIter(iterFn))) {
      for (iterator = iterFn.call(O), result = new C(); !(step = iterator.next()).done; index++) {
        createProperty(result, index, mapping ? call(iterator, mapfn, [step.value, index], true) : step.value);
      }
    } else {
      length = toLength(O.length);
      for (result = new C(length); length > index; index++) {
        createProperty(result, index, mapping ? mapfn(O[index], index) : O[index]);
      }
    }
    result.length = index;
    return result;
  }
});

},{"118":118,"119":119,"129":129,"24":24,"25":25,"33":33,"48":48,"53":53,"56":56}],139:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $indexOf = _dereq_(11)(false);
var $native = [].indexOf;
var NEGATIVE_ZERO = !!$native && 1 / [1].indexOf(1, -0) < 0;

$export($export.P + $export.F * (NEGATIVE_ZERO || !_dereq_(105)($native)), 'Array', {
  // 22.1.3.11 / 15.4.4.14 Array.prototype.indexOf(searchElement [, fromIndex])
  indexOf: function indexOf(searchElement /* , fromIndex = 0 */) {
    return NEGATIVE_ZERO
      // convert -0 to +0
      ? $native.apply(this, arguments) || 0
      : $indexOf(this, searchElement, arguments[1]);
  }
});

},{"105":105,"11":11,"33":33}],140:[function(_dereq_,module,exports){
// 22.1.2.2 / 15.4.3.2 Array.isArray(arg)
var $export = _dereq_(33);

$export($export.S, 'Array', { isArray: _dereq_(49) });

},{"33":33,"49":49}],141:[function(_dereq_,module,exports){
var addToUnscopables = _dereq_(5);
var step = _dereq_(57);
var Iterators = _dereq_(58);
var toIObject = _dereq_(117);

// 22.1.3.4 Array.prototype.entries()
// 22.1.3.13 Array.prototype.keys()
// 22.1.3.29 Array.prototype.values()
// 22.1.3.30 Array.prototype[@@iterator]()
module.exports = _dereq_(55)(Array, 'Array', function (iterated, kind) {
  this._t = toIObject(iterated); // target
  this._i = 0;                   // next index
  this._k = kind;                // kind
// 22.1.5.2.1 %ArrayIteratorPrototype%.next()
}, function () {
  var O = this._t;
  var kind = this._k;
  var index = this._i++;
  if (!O || index >= O.length) {
    this._t = undefined;
    return step(1);
  }
  if (kind == 'keys') return step(0, index);
  if (kind == 'values') return step(0, O[index]);
  return step(0, [index, O[index]]);
}, 'values');

// argumentsList[@@iterator] is %ArrayProto_values% (9.4.4.6, 9.4.4.7)
Iterators.Arguments = Iterators.Array;

addToUnscopables('keys');
addToUnscopables('values');
addToUnscopables('entries');

},{"117":117,"5":5,"55":55,"57":57,"58":58}],142:[function(_dereq_,module,exports){
// 22.1.3.13 Array.prototype.join(separator)
var $export = _dereq_(33);
var toIObject = _dereq_(117);
var arrayJoin = [].join;

// fallback for not array-like strings
$export($export.P + $export.F * (_dereq_(47) != Object || !_dereq_(105)(arrayJoin)), 'Array', {
  join: function join(separator) {
    return arrayJoin.call(toIObject(this), separator === undefined ? ',' : separator);
  }
});

},{"105":105,"117":117,"33":33,"47":47}],143:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var toIObject = _dereq_(117);
var toInteger = _dereq_(116);
var toLength = _dereq_(118);
var $native = [].lastIndexOf;
var NEGATIVE_ZERO = !!$native && 1 / [1].lastIndexOf(1, -0) < 0;

$export($export.P + $export.F * (NEGATIVE_ZERO || !_dereq_(105)($native)), 'Array', {
  // 22.1.3.14 / 15.4.4.15 Array.prototype.lastIndexOf(searchElement [, fromIndex])
  lastIndexOf: function lastIndexOf(searchElement /* , fromIndex = @[*-1] */) {
    // convert -0 to +0
    if (NEGATIVE_ZERO) return $native.apply(this, arguments) || 0;
    var O = toIObject(this);
    var length = toLength(O.length);
    var index = length - 1;
    if (arguments.length > 1) index = Math.min(index, toInteger(arguments[1]));
    if (index < 0) index = length + index;
    for (;index >= 0; index--) if (index in O) if (O[index] === searchElement) return index || 0;
    return -1;
  }
});

},{"105":105,"116":116,"117":117,"118":118,"33":33}],144:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $map = _dereq_(12)(1);

$export($export.P + $export.F * !_dereq_(105)([].map, true), 'Array', {
  // 22.1.3.15 / 15.4.4.19 Array.prototype.map(callbackfn [, thisArg])
  map: function map(callbackfn /* , thisArg */) {
    return $map(this, callbackfn, arguments[1]);
  }
});

},{"105":105,"12":12,"33":33}],145:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var createProperty = _dereq_(24);

// WebKit Array.of isn't generic
$export($export.S + $export.F * _dereq_(35)(function () {
  function F() { /* empty */ }
  return !(Array.of.call(F) instanceof F);
}), 'Array', {
  // 22.1.2.3 Array.of( ...items)
  of: function of(/* ...args */) {
    var index = 0;
    var aLen = arguments.length;
    var result = new (typeof this == 'function' ? this : Array)(aLen);
    while (aLen > index) createProperty(result, index, arguments[index++]);
    result.length = aLen;
    return result;
  }
});

},{"24":24,"33":33,"35":35}],146:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $reduce = _dereq_(13);

$export($export.P + $export.F * !_dereq_(105)([].reduceRight, true), 'Array', {
  // 22.1.3.19 / 15.4.4.22 Array.prototype.reduceRight(callbackfn [, initialValue])
  reduceRight: function reduceRight(callbackfn /* , initialValue */) {
    return $reduce(this, callbackfn, arguments.length, arguments[1], true);
  }
});

},{"105":105,"13":13,"33":33}],147:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $reduce = _dereq_(13);

$export($export.P + $export.F * !_dereq_(105)([].reduce, true), 'Array', {
  // 22.1.3.18 / 15.4.4.21 Array.prototype.reduce(callbackfn [, initialValue])
  reduce: function reduce(callbackfn /* , initialValue */) {
    return $reduce(this, callbackfn, arguments.length, arguments[1], false);
  }
});

},{"105":105,"13":13,"33":33}],148:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var html = _dereq_(43);
var cof = _dereq_(18);
var toAbsoluteIndex = _dereq_(114);
var toLength = _dereq_(118);
var arraySlice = [].slice;

// fallback for not array-like ES3 strings and DOM objects
$export($export.P + $export.F * _dereq_(35)(function () {
  if (html) arraySlice.call(html);
}), 'Array', {
  slice: function slice(begin, end) {
    var len = toLength(this.length);
    var klass = cof(this);
    end = end === undefined ? len : end;
    if (klass == 'Array') return arraySlice.call(this, begin, end);
    var start = toAbsoluteIndex(begin, len);
    var upTo = toAbsoluteIndex(end, len);
    var size = toLength(upTo - start);
    var cloned = Array(size);
    var i = 0;
    for (; i < size; i++) cloned[i] = klass == 'String'
      ? this.charAt(start + i)
      : this[start + i];
    return cloned;
  }
});

},{"114":114,"118":118,"18":18,"33":33,"35":35,"43":43}],149:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $some = _dereq_(12)(3);

$export($export.P + $export.F * !_dereq_(105)([].some, true), 'Array', {
  // 22.1.3.23 / 15.4.4.17 Array.prototype.some(callbackfn [, thisArg])
  some: function some(callbackfn /* , thisArg */) {
    return $some(this, callbackfn, arguments[1]);
  }
});

},{"105":105,"12":12,"33":33}],150:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var aFunction = _dereq_(3);
var toObject = _dereq_(119);
var fails = _dereq_(35);
var $sort = [].sort;
var test = [1, 2, 3];

$export($export.P + $export.F * (fails(function () {
  // IE8-
  test.sort(undefined);
}) || !fails(function () {
  // V8 bug
  test.sort(null);
  // Old WebKit
}) || !_dereq_(105)($sort)), 'Array', {
  // 22.1.3.25 Array.prototype.sort(comparefn)
  sort: function sort(comparefn) {
    return comparefn === undefined
      ? $sort.call(toObject(this))
      : $sort.call(toObject(this), aFunction(comparefn));
  }
});

},{"105":105,"119":119,"3":3,"33":33,"35":35}],151:[function(_dereq_,module,exports){
_dereq_(100)('Array');

},{"100":100}],152:[function(_dereq_,module,exports){
// 20.3.3.1 / 15.9.4.4 Date.now()
var $export = _dereq_(33);

$export($export.S, 'Date', { now: function () { return new Date().getTime(); } });

},{"33":33}],153:[function(_dereq_,module,exports){
// 20.3.4.36 / 15.9.5.43 Date.prototype.toISOString()
var $export = _dereq_(33);
var toISOString = _dereq_(26);

// PhantomJS / old WebKit has a broken implementations
$export($export.P + $export.F * (Date.prototype.toISOString !== toISOString), 'Date', {
  toISOString: toISOString
});

},{"26":26,"33":33}],154:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var toObject = _dereq_(119);
var toPrimitive = _dereq_(120);

$export($export.P + $export.F * _dereq_(35)(function () {
  return new Date(NaN).toJSON() !== null
    || Date.prototype.toJSON.call({ toISOString: function () { return 1; } }) !== 1;
}), 'Date', {
  // eslint-disable-next-line no-unused-vars
  toJSON: function toJSON(key) {
    var O = toObject(this);
    var pv = toPrimitive(O);
    return typeof pv == 'number' && !isFinite(pv) ? null : O.toISOString();
  }
});

},{"119":119,"120":120,"33":33,"35":35}],155:[function(_dereq_,module,exports){
var TO_PRIMITIVE = _dereq_(128)('toPrimitive');
var proto = Date.prototype;

if (!(TO_PRIMITIVE in proto)) _dereq_(42)(proto, TO_PRIMITIVE, _dereq_(27));

},{"128":128,"27":27,"42":42}],156:[function(_dereq_,module,exports){
var DateProto = Date.prototype;
var INVALID_DATE = 'Invalid Date';
var TO_STRING = 'toString';
var $toString = DateProto[TO_STRING];
var getTime = DateProto.getTime;
if (new Date(NaN) + '' != INVALID_DATE) {
  _dereq_(94)(DateProto, TO_STRING, function toString() {
    var value = getTime.call(this);
    // eslint-disable-next-line no-self-compare
    return value === value ? $toString.call(this) : INVALID_DATE;
  });
}

},{"94":94}],157:[function(_dereq_,module,exports){
// 19.2.3.2 / 15.3.4.5 Function.prototype.bind(thisArg, args...)
var $export = _dereq_(33);

$export($export.P, 'Function', { bind: _dereq_(16) });

},{"16":16,"33":33}],158:[function(_dereq_,module,exports){
var isObject = _dereq_(51);
var getPrototypeOf = _dereq_(79);
var HAS_INSTANCE = _dereq_(128)('hasInstance');
var FunctionProto = Function.prototype;
// 19.2.3.6 Function.prototype[@@hasInstance](V)
if (!(HAS_INSTANCE in FunctionProto)) _dereq_(72).f(FunctionProto, HAS_INSTANCE, { value: function (O) {
  if (typeof this != 'function' || !isObject(O)) return false;
  if (!isObject(this.prototype)) return O instanceof this;
  // for environment w/o native `@@hasInstance` logic enough `instanceof`, but add this:
  while (O = getPrototypeOf(O)) if (this.prototype === O) return true;
  return false;
} });

},{"128":128,"51":51,"72":72,"79":79}],159:[function(_dereq_,module,exports){
var dP = _dereq_(72).f;
var FProto = Function.prototype;
var nameRE = /^\s*function ([^ (]*)/;
var NAME = 'name';

// 19.2.4.2 name
NAME in FProto || _dereq_(29) && dP(FProto, NAME, {
  configurable: true,
  get: function () {
    try {
      return ('' + this).match(nameRE)[1];
    } catch (e) {
      return '';
    }
  }
});

},{"29":29,"72":72}],160:[function(_dereq_,module,exports){
var strong = _dereq_(19);
var validate = _dereq_(125);
var MAP = 'Map';

// 23.1 Map Objects
module.exports = _dereq_(22)(MAP, function (get) {
  return function Map() { return get(this, arguments.length > 0 ? arguments[0] : undefined); };
}, {
  // 23.1.3.6 Map.prototype.get(key)
  get: function get(key) {
    var entry = strong.getEntry(validate(this, MAP), key);
    return entry && entry.v;
  },
  // 23.1.3.9 Map.prototype.set(key, value)
  set: function set(key, value) {
    return strong.def(validate(this, MAP), key === 0 ? 0 : key, value);
  }
}, strong, true);

},{"125":125,"19":19,"22":22}],161:[function(_dereq_,module,exports){
// 20.2.2.3 Math.acosh(x)
var $export = _dereq_(33);
var log1p = _dereq_(63);
var sqrt = Math.sqrt;
var $acosh = Math.acosh;

$export($export.S + $export.F * !($acosh
  // V8 bug: https://code.google.com/p/v8/issues/detail?id=3509
  && Math.floor($acosh(Number.MAX_VALUE)) == 710
  // Tor Browser bug: Math.acosh(Infinity) -> NaN
  && $acosh(Infinity) == Infinity
), 'Math', {
  acosh: function acosh(x) {
    return (x = +x) < 1 ? NaN : x > 94906265.62425156
      ? Math.log(x) + Math.LN2
      : log1p(x - 1 + sqrt(x - 1) * sqrt(x + 1));
  }
});

},{"33":33,"63":63}],162:[function(_dereq_,module,exports){
// 20.2.2.5 Math.asinh(x)
var $export = _dereq_(33);
var $asinh = Math.asinh;

function asinh(x) {
  return !isFinite(x = +x) || x == 0 ? x : x < 0 ? -asinh(-x) : Math.log(x + Math.sqrt(x * x + 1));
}

// Tor Browser bug: Math.asinh(0) -> -0
$export($export.S + $export.F * !($asinh && 1 / $asinh(0) > 0), 'Math', { asinh: asinh });

},{"33":33}],163:[function(_dereq_,module,exports){
// 20.2.2.7 Math.atanh(x)
var $export = _dereq_(33);
var $atanh = Math.atanh;

// Tor Browser bug: Math.atanh(-0) -> 0
$export($export.S + $export.F * !($atanh && 1 / $atanh(-0) < 0), 'Math', {
  atanh: function atanh(x) {
    return (x = +x) == 0 ? x : Math.log((1 + x) / (1 - x)) / 2;
  }
});

},{"33":33}],164:[function(_dereq_,module,exports){
// 20.2.2.9 Math.cbrt(x)
var $export = _dereq_(33);
var sign = _dereq_(65);

$export($export.S, 'Math', {
  cbrt: function cbrt(x) {
    return sign(x = +x) * Math.pow(Math.abs(x), 1 / 3);
  }
});

},{"33":33,"65":65}],165:[function(_dereq_,module,exports){
// 20.2.2.11 Math.clz32(x)
var $export = _dereq_(33);

$export($export.S, 'Math', {
  clz32: function clz32(x) {
    return (x >>>= 0) ? 31 - Math.floor(Math.log(x + 0.5) * Math.LOG2E) : 32;
  }
});

},{"33":33}],166:[function(_dereq_,module,exports){
// 20.2.2.12 Math.cosh(x)
var $export = _dereq_(33);
var exp = Math.exp;

$export($export.S, 'Math', {
  cosh: function cosh(x) {
    return (exp(x = +x) + exp(-x)) / 2;
  }
});

},{"33":33}],167:[function(_dereq_,module,exports){
// 20.2.2.14 Math.expm1(x)
var $export = _dereq_(33);
var $expm1 = _dereq_(61);

$export($export.S + $export.F * ($expm1 != Math.expm1), 'Math', { expm1: $expm1 });

},{"33":33,"61":61}],168:[function(_dereq_,module,exports){
// 20.2.2.16 Math.fround(x)
var $export = _dereq_(33);

$export($export.S, 'Math', { fround: _dereq_(62) });

},{"33":33,"62":62}],169:[function(_dereq_,module,exports){
// 20.2.2.17 Math.hypot([value1[, value2[, … ]]])
var $export = _dereq_(33);
var abs = Math.abs;

$export($export.S, 'Math', {
  hypot: function hypot(value1, value2) { // eslint-disable-line no-unused-vars
    var sum = 0;
    var i = 0;
    var aLen = arguments.length;
    var larg = 0;
    var arg, div;
    while (i < aLen) {
      arg = abs(arguments[i++]);
      if (larg < arg) {
        div = larg / arg;
        sum = sum * div * div + 1;
        larg = arg;
      } else if (arg > 0) {
        div = arg / larg;
        sum += div * div;
      } else sum += arg;
    }
    return larg === Infinity ? Infinity : larg * Math.sqrt(sum);
  }
});

},{"33":33}],170:[function(_dereq_,module,exports){
// 20.2.2.18 Math.imul(x, y)
var $export = _dereq_(33);
var $imul = Math.imul;

// some WebKit versions fails with big numbers, some has wrong arity
$export($export.S + $export.F * _dereq_(35)(function () {
  return $imul(0xffffffff, 5) != -5 || $imul.length != 2;
}), 'Math', {
  imul: function imul(x, y) {
    var UINT16 = 0xffff;
    var xn = +x;
    var yn = +y;
    var xl = UINT16 & xn;
    var yl = UINT16 & yn;
    return 0 | xl * yl + ((UINT16 & xn >>> 16) * yl + xl * (UINT16 & yn >>> 16) << 16 >>> 0);
  }
});

},{"33":33,"35":35}],171:[function(_dereq_,module,exports){
// 20.2.2.21 Math.log10(x)
var $export = _dereq_(33);

$export($export.S, 'Math', {
  log10: function log10(x) {
    return Math.log(x) * Math.LOG10E;
  }
});

},{"33":33}],172:[function(_dereq_,module,exports){
// 20.2.2.20 Math.log1p(x)
var $export = _dereq_(33);

$export($export.S, 'Math', { log1p: _dereq_(63) });

},{"33":33,"63":63}],173:[function(_dereq_,module,exports){
// 20.2.2.22 Math.log2(x)
var $export = _dereq_(33);

$export($export.S, 'Math', {
  log2: function log2(x) {
    return Math.log(x) / Math.LN2;
  }
});

},{"33":33}],174:[function(_dereq_,module,exports){
// 20.2.2.28 Math.sign(x)
var $export = _dereq_(33);

$export($export.S, 'Math', { sign: _dereq_(65) });

},{"33":33,"65":65}],175:[function(_dereq_,module,exports){
// 20.2.2.30 Math.sinh(x)
var $export = _dereq_(33);
var expm1 = _dereq_(61);
var exp = Math.exp;

// V8 near Chromium 38 has a problem with very small numbers
$export($export.S + $export.F * _dereq_(35)(function () {
  return !Math.sinh(-2e-17) != -2e-17;
}), 'Math', {
  sinh: function sinh(x) {
    return Math.abs(x = +x) < 1
      ? (expm1(x) - expm1(-x)) / 2
      : (exp(x - 1) - exp(-x - 1)) * (Math.E / 2);
  }
});

},{"33":33,"35":35,"61":61}],176:[function(_dereq_,module,exports){
// 20.2.2.33 Math.tanh(x)
var $export = _dereq_(33);
var expm1 = _dereq_(61);
var exp = Math.exp;

$export($export.S, 'Math', {
  tanh: function tanh(x) {
    var a = expm1(x = +x);
    var b = expm1(-x);
    return a == Infinity ? 1 : b == Infinity ? -1 : (a - b) / (exp(x) + exp(-x));
  }
});

},{"33":33,"61":61}],177:[function(_dereq_,module,exports){
// 20.2.2.34 Math.trunc(x)
var $export = _dereq_(33);

$export($export.S, 'Math', {
  trunc: function trunc(it) {
    return (it > 0 ? Math.floor : Math.ceil)(it);
  }
});

},{"33":33}],178:[function(_dereq_,module,exports){
var global = _dereq_(40);
var has = _dereq_(41);
var cof = _dereq_(18);
var inheritIfRequired = _dereq_(45);
var toPrimitive = _dereq_(120);
var fails = _dereq_(35);
var gOPN = _dereq_(77).f;
var gOPD = _dereq_(75).f;
var dP = _dereq_(72).f;
var $trim = _dereq_(111).trim;
var NUMBER = 'Number';
var $Number = global[NUMBER];
var Base = $Number;
var proto = $Number.prototype;
// Opera ~12 has broken Object#toString
var BROKEN_COF = cof(_dereq_(71)(proto)) == NUMBER;
var TRIM = 'trim' in String.prototype;

// 7.1.3 ToNumber(argument)
var toNumber = function (argument) {
  var it = toPrimitive(argument, false);
  if (typeof it == 'string' && it.length > 2) {
    it = TRIM ? it.trim() : $trim(it, 3);
    var first = it.charCodeAt(0);
    var third, radix, maxCode;
    if (first === 43 || first === 45) {
      third = it.charCodeAt(2);
      if (third === 88 || third === 120) return NaN; // Number('+0x1') should be NaN, old V8 fix
    } else if (first === 48) {
      switch (it.charCodeAt(1)) {
        case 66: case 98: radix = 2; maxCode = 49; break; // fast equal /^0b[01]+$/i
        case 79: case 111: radix = 8; maxCode = 55; break; // fast equal /^0o[0-7]+$/i
        default: return +it;
      }
      for (var digits = it.slice(2), i = 0, l = digits.length, code; i < l; i++) {
        code = digits.charCodeAt(i);
        // parseInt parses a string to a first unavailable symbol
        // but ToNumber should return NaN if a string contains unavailable symbols
        if (code < 48 || code > maxCode) return NaN;
      } return parseInt(digits, radix);
    }
  } return +it;
};

if (!$Number(' 0o1') || !$Number('0b1') || $Number('+0x1')) {
  $Number = function Number(value) {
    var it = arguments.length < 1 ? 0 : value;
    var that = this;
    return that instanceof $Number
      // check on 1..constructor(foo) case
      && (BROKEN_COF ? fails(function () { proto.valueOf.call(that); }) : cof(that) != NUMBER)
        ? inheritIfRequired(new Base(toNumber(it)), that, $Number) : toNumber(it);
  };
  for (var keys = _dereq_(29) ? gOPN(Base) : (
    // ES3:
    'MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,' +
    // ES6 (in case, if modules with ES6 Number statics required before):
    'EPSILON,isFinite,isInteger,isNaN,isSafeInteger,MAX_SAFE_INTEGER,' +
    'MIN_SAFE_INTEGER,parseFloat,parseInt,isInteger'
  ).split(','), j = 0, key; keys.length > j; j++) {
    if (has(Base, key = keys[j]) && !has($Number, key)) {
      dP($Number, key, gOPD(Base, key));
    }
  }
  $Number.prototype = proto;
  proto.constructor = $Number;
  _dereq_(94)(global, NUMBER, $Number);
}

},{"111":111,"120":120,"18":18,"29":29,"35":35,"40":40,"41":41,"45":45,"71":71,"72":72,"75":75,"77":77,"94":94}],179:[function(_dereq_,module,exports){
// 20.1.2.1 Number.EPSILON
var $export = _dereq_(33);

$export($export.S, 'Number', { EPSILON: Math.pow(2, -52) });

},{"33":33}],180:[function(_dereq_,module,exports){
// 20.1.2.2 Number.isFinite(number)
var $export = _dereq_(33);
var _isFinite = _dereq_(40).isFinite;

$export($export.S, 'Number', {
  isFinite: function isFinite(it) {
    return typeof it == 'number' && _isFinite(it);
  }
});

},{"33":33,"40":40}],181:[function(_dereq_,module,exports){
// 20.1.2.3 Number.isInteger(number)
var $export = _dereq_(33);

$export($export.S, 'Number', { isInteger: _dereq_(50) });

},{"33":33,"50":50}],182:[function(_dereq_,module,exports){
// 20.1.2.4 Number.isNaN(number)
var $export = _dereq_(33);

$export($export.S, 'Number', {
  isNaN: function isNaN(number) {
    // eslint-disable-next-line no-self-compare
    return number != number;
  }
});

},{"33":33}],183:[function(_dereq_,module,exports){
// 20.1.2.5 Number.isSafeInteger(number)
var $export = _dereq_(33);
var isInteger = _dereq_(50);
var abs = Math.abs;

$export($export.S, 'Number', {
  isSafeInteger: function isSafeInteger(number) {
    return isInteger(number) && abs(number) <= 0x1fffffffffffff;
  }
});

},{"33":33,"50":50}],184:[function(_dereq_,module,exports){
// 20.1.2.6 Number.MAX_SAFE_INTEGER
var $export = _dereq_(33);

$export($export.S, 'Number', { MAX_SAFE_INTEGER: 0x1fffffffffffff });

},{"33":33}],185:[function(_dereq_,module,exports){
// 20.1.2.10 Number.MIN_SAFE_INTEGER
var $export = _dereq_(33);

$export($export.S, 'Number', { MIN_SAFE_INTEGER: -0x1fffffffffffff });

},{"33":33}],186:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $parseFloat = _dereq_(86);
// 20.1.2.12 Number.parseFloat(string)
$export($export.S + $export.F * (Number.parseFloat != $parseFloat), 'Number', { parseFloat: $parseFloat });

},{"33":33,"86":86}],187:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $parseInt = _dereq_(87);
// 20.1.2.13 Number.parseInt(string, radix)
$export($export.S + $export.F * (Number.parseInt != $parseInt), 'Number', { parseInt: $parseInt });

},{"33":33,"87":87}],188:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var toInteger = _dereq_(116);
var aNumberValue = _dereq_(4);
var repeat = _dereq_(110);
var $toFixed = 1.0.toFixed;
var floor = Math.floor;
var data = [0, 0, 0, 0, 0, 0];
var ERROR = 'Number.toFixed: incorrect invocation!';
var ZERO = '0';

var multiply = function (n, c) {
  var i = -1;
  var c2 = c;
  while (++i < 6) {
    c2 += n * data[i];
    data[i] = c2 % 1e7;
    c2 = floor(c2 / 1e7);
  }
};
var divide = function (n) {
  var i = 6;
  var c = 0;
  while (--i >= 0) {
    c += data[i];
    data[i] = floor(c / n);
    c = (c % n) * 1e7;
  }
};
var numToString = function () {
  var i = 6;
  var s = '';
  while (--i >= 0) {
    if (s !== '' || i === 0 || data[i] !== 0) {
      var t = String(data[i]);
      s = s === '' ? t : s + repeat.call(ZERO, 7 - t.length) + t;
    }
  } return s;
};
var pow = function (x, n, acc) {
  return n === 0 ? acc : n % 2 === 1 ? pow(x, n - 1, acc * x) : pow(x * x, n / 2, acc);
};
var log = function (x) {
  var n = 0;
  var x2 = x;
  while (x2 >= 4096) {
    n += 12;
    x2 /= 4096;
  }
  while (x2 >= 2) {
    n += 1;
    x2 /= 2;
  } return n;
};

$export($export.P + $export.F * (!!$toFixed && (
  0.00008.toFixed(3) !== '0.000' ||
  0.9.toFixed(0) !== '1' ||
  1.255.toFixed(2) !== '1.25' ||
  1000000000000000128.0.toFixed(0) !== '1000000000000000128'
) || !_dereq_(35)(function () {
  // V8 ~ Android 4.3-
  $toFixed.call({});
})), 'Number', {
  toFixed: function toFixed(fractionDigits) {
    var x = aNumberValue(this, ERROR);
    var f = toInteger(fractionDigits);
    var s = '';
    var m = ZERO;
    var e, z, j, k;
    if (f < 0 || f > 20) throw RangeError(ERROR);
    // eslint-disable-next-line no-self-compare
    if (x != x) return 'NaN';
    if (x <= -1e21 || x >= 1e21) return String(x);
    if (x < 0) {
      s = '-';
      x = -x;
    }
    if (x > 1e-21) {
      e = log(x * pow(2, 69, 1)) - 69;
      z = e < 0 ? x * pow(2, -e, 1) : x / pow(2, e, 1);
      z *= 0x10000000000000;
      e = 52 - e;
      if (e > 0) {
        multiply(0, z);
        j = f;
        while (j >= 7) {
          multiply(1e7, 0);
          j -= 7;
        }
        multiply(pow(10, j, 1), 0);
        j = e - 1;
        while (j >= 23) {
          divide(1 << 23);
          j -= 23;
        }
        divide(1 << j);
        multiply(1, 1);
        divide(2);
        m = numToString();
      } else {
        multiply(0, z);
        multiply(1 << -e, 0);
        m = numToString() + repeat.call(ZERO, f);
      }
    }
    if (f > 0) {
      k = m.length;
      m = s + (k <= f ? '0.' + repeat.call(ZERO, f - k) + m : m.slice(0, k - f) + '.' + m.slice(k - f));
    } else {
      m = s + m;
    } return m;
  }
});

},{"110":110,"116":116,"33":33,"35":35,"4":4}],189:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $fails = _dereq_(35);
var aNumberValue = _dereq_(4);
var $toPrecision = 1.0.toPrecision;

$export($export.P + $export.F * ($fails(function () {
  // IE7-
  return $toPrecision.call(1, undefined) !== '1';
}) || !$fails(function () {
  // V8 ~ Android 4.3-
  $toPrecision.call({});
})), 'Number', {
  toPrecision: function toPrecision(precision) {
    var that = aNumberValue(this, 'Number#toPrecision: incorrect invocation!');
    return precision === undefined ? $toPrecision.call(that) : $toPrecision.call(that, precision);
  }
});

},{"33":33,"35":35,"4":4}],190:[function(_dereq_,module,exports){
// 19.1.3.1 Object.assign(target, source)
var $export = _dereq_(33);

$export($export.S + $export.F, 'Object', { assign: _dereq_(70) });

},{"33":33,"70":70}],191:[function(_dereq_,module,exports){
var $export = _dereq_(33);
// 19.1.2.2 / 15.2.3.5 Object.create(O [, Properties])
$export($export.S, 'Object', { create: _dereq_(71) });

},{"33":33,"71":71}],192:[function(_dereq_,module,exports){
var $export = _dereq_(33);
// 19.1.2.3 / 15.2.3.7 Object.defineProperties(O, Properties)
$export($export.S + $export.F * !_dereq_(29), 'Object', { defineProperties: _dereq_(73) });

},{"29":29,"33":33,"73":73}],193:[function(_dereq_,module,exports){
var $export = _dereq_(33);
// 19.1.2.4 / 15.2.3.6 Object.defineProperty(O, P, Attributes)
$export($export.S + $export.F * !_dereq_(29), 'Object', { defineProperty: _dereq_(72).f });

},{"29":29,"33":33,"72":72}],194:[function(_dereq_,module,exports){
// 19.1.2.5 Object.freeze(O)
var isObject = _dereq_(51);
var meta = _dereq_(66).onFreeze;

_dereq_(83)('freeze', function ($freeze) {
  return function freeze(it) {
    return $freeze && isObject(it) ? $freeze(meta(it)) : it;
  };
});

},{"51":51,"66":66,"83":83}],195:[function(_dereq_,module,exports){
// 19.1.2.6 Object.getOwnPropertyDescriptor(O, P)
var toIObject = _dereq_(117);
var $getOwnPropertyDescriptor = _dereq_(75).f;

_dereq_(83)('getOwnPropertyDescriptor', function () {
  return function getOwnPropertyDescriptor(it, key) {
    return $getOwnPropertyDescriptor(toIObject(it), key);
  };
});

},{"117":117,"75":75,"83":83}],196:[function(_dereq_,module,exports){
// 19.1.2.7 Object.getOwnPropertyNames(O)
_dereq_(83)('getOwnPropertyNames', function () {
  return _dereq_(76).f;
});

},{"76":76,"83":83}],197:[function(_dereq_,module,exports){
// 19.1.2.9 Object.getPrototypeOf(O)
var toObject = _dereq_(119);
var $getPrototypeOf = _dereq_(79);

_dereq_(83)('getPrototypeOf', function () {
  return function getPrototypeOf(it) {
    return $getPrototypeOf(toObject(it));
  };
});

},{"119":119,"79":79,"83":83}],198:[function(_dereq_,module,exports){
// 19.1.2.11 Object.isExtensible(O)
var isObject = _dereq_(51);

_dereq_(83)('isExtensible', function ($isExtensible) {
  return function isExtensible(it) {
    return isObject(it) ? $isExtensible ? $isExtensible(it) : true : false;
  };
});

},{"51":51,"83":83}],199:[function(_dereq_,module,exports){
// 19.1.2.12 Object.isFrozen(O)
var isObject = _dereq_(51);

_dereq_(83)('isFrozen', function ($isFrozen) {
  return function isFrozen(it) {
    return isObject(it) ? $isFrozen ? $isFrozen(it) : false : true;
  };
});

},{"51":51,"83":83}],200:[function(_dereq_,module,exports){
// 19.1.2.13 Object.isSealed(O)
var isObject = _dereq_(51);

_dereq_(83)('isSealed', function ($isSealed) {
  return function isSealed(it) {
    return isObject(it) ? $isSealed ? $isSealed(it) : false : true;
  };
});

},{"51":51,"83":83}],201:[function(_dereq_,module,exports){
// 19.1.3.10 Object.is(value1, value2)
var $export = _dereq_(33);
$export($export.S, 'Object', { is: _dereq_(96) });

},{"33":33,"96":96}],202:[function(_dereq_,module,exports){
// 19.1.2.14 Object.keys(O)
var toObject = _dereq_(119);
var $keys = _dereq_(81);

_dereq_(83)('keys', function () {
  return function keys(it) {
    return $keys(toObject(it));
  };
});

},{"119":119,"81":81,"83":83}],203:[function(_dereq_,module,exports){
// 19.1.2.15 Object.preventExtensions(O)
var isObject = _dereq_(51);
var meta = _dereq_(66).onFreeze;

_dereq_(83)('preventExtensions', function ($preventExtensions) {
  return function preventExtensions(it) {
    return $preventExtensions && isObject(it) ? $preventExtensions(meta(it)) : it;
  };
});

},{"51":51,"66":66,"83":83}],204:[function(_dereq_,module,exports){
// 19.1.2.17 Object.seal(O)
var isObject = _dereq_(51);
var meta = _dereq_(66).onFreeze;

_dereq_(83)('seal', function ($seal) {
  return function seal(it) {
    return $seal && isObject(it) ? $seal(meta(it)) : it;
  };
});

},{"51":51,"66":66,"83":83}],205:[function(_dereq_,module,exports){
// 19.1.3.19 Object.setPrototypeOf(O, proto)
var $export = _dereq_(33);
$export($export.S, 'Object', { setPrototypeOf: _dereq_(99).set });

},{"33":33,"99":99}],206:[function(_dereq_,module,exports){
// 19.1.3.6 Object.prototype.toString()
var classof = _dereq_(17);
var test = {};
test[_dereq_(128)('toStringTag')] = 'z';
if (test + '' != '[object z]') {
  _dereq_(94)(Object.prototype, 'toString', function toString() {
    return '[object ' + classof(this) + ']';
  }, true);
}

},{"128":128,"17":17,"94":94}],207:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $parseFloat = _dereq_(86);
// 18.2.4 parseFloat(string)
$export($export.G + $export.F * (parseFloat != $parseFloat), { parseFloat: $parseFloat });

},{"33":33,"86":86}],208:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $parseInt = _dereq_(87);
// 18.2.5 parseInt(string, radix)
$export($export.G + $export.F * (parseInt != $parseInt), { parseInt: $parseInt });

},{"33":33,"87":87}],209:[function(_dereq_,module,exports){
var LIBRARY = _dereq_(60);
var global = _dereq_(40);
var ctx = _dereq_(25);
var classof = _dereq_(17);
var $export = _dereq_(33);
var isObject = _dereq_(51);
var aFunction = _dereq_(3);
var anInstance = _dereq_(6);
var forOf = _dereq_(39);
var speciesConstructor = _dereq_(104);
var task = _dereq_(113).set;
var microtask = _dereq_(68)();
var newPromiseCapabilityModule = _dereq_(69);
var perform = _dereq_(90);
var promiseResolve = _dereq_(91);
var PROMISE = 'Promise';
var TypeError = global.TypeError;
var process = global.process;
var $Promise = global[PROMISE];
var isNode = classof(process) == 'process';
var empty = function () { /* empty */ };
var Internal, newGenericPromiseCapability, OwnPromiseCapability, Wrapper;
var newPromiseCapability = newGenericPromiseCapability = newPromiseCapabilityModule.f;

var USE_NATIVE = !!function () {
  try {
    // correct subclassing with @@species support
    var promise = $Promise.resolve(1);
    var FakePromise = (promise.constructor = {})[_dereq_(128)('species')] = function (exec) {
      exec(empty, empty);
    };
    // unhandled rejections tracking support, NodeJS Promise without it fails @@species test
    return (isNode || typeof PromiseRejectionEvent == 'function') && promise.then(empty) instanceof FakePromise;
  } catch (e) { /* empty */ }
}();

// helpers
var sameConstructor = LIBRARY ? function (a, b) {
  // with library wrapper special case
  return a === b || a === $Promise && b === Wrapper;
} : function (a, b) {
  return a === b;
};
var isThenable = function (it) {
  var then;
  return isObject(it) && typeof (then = it.then) == 'function' ? then : false;
};
var notify = function (promise, isReject) {
  if (promise._n) return;
  promise._n = true;
  var chain = promise._c;
  microtask(function () {
    var value = promise._v;
    var ok = promise._s == 1;
    var i = 0;
    var run = function (reaction) {
      var handler = ok ? reaction.ok : reaction.fail;
      var resolve = reaction.resolve;
      var reject = reaction.reject;
      var domain = reaction.domain;
      var result, then;
      try {
        if (handler) {
          if (!ok) {
            if (promise._h == 2) onHandleUnhandled(promise);
            promise._h = 1;
          }
          if (handler === true) result = value;
          else {
            if (domain) domain.enter();
            result = handler(value);
            if (domain) domain.exit();
          }
          if (result === reaction.promise) {
            reject(TypeError('Promise-chain cycle'));
          } else if (then = isThenable(result)) {
            then.call(result, resolve, reject);
          } else resolve(result);
        } else reject(value);
      } catch (e) {
        reject(e);
      }
    };
    while (chain.length > i) run(chain[i++]); // variable length - can't use forEach
    promise._c = [];
    promise._n = false;
    if (isReject && !promise._h) onUnhandled(promise);
  });
};
var onUnhandled = function (promise) {
  task.call(global, function () {
    var value = promise._v;
    var unhandled = isUnhandled(promise);
    var result, handler, console;
    if (unhandled) {
      result = perform(function () {
        if (isNode) {
          process.emit('unhandledRejection', value, promise);
        } else if (handler = global.onunhandledrejection) {
          handler({ promise: promise, reason: value });
        } else if ((console = global.console) && console.error) {
          console.error('Unhandled promise rejection', value);
        }
      });
      // Browsers should not trigger `rejectionHandled` event if it was handled here, NodeJS - should
      promise._h = isNode || isUnhandled(promise) ? 2 : 1;
    } promise._a = undefined;
    if (unhandled && result.e) throw result.v;
  });
};
var isUnhandled = function (promise) {
  if (promise._h == 1) return false;
  var chain = promise._a || promise._c;
  var i = 0;
  var reaction;
  while (chain.length > i) {
    reaction = chain[i++];
    if (reaction.fail || !isUnhandled(reaction.promise)) return false;
  } return true;
};
var onHandleUnhandled = function (promise) {
  task.call(global, function () {
    var handler;
    if (isNode) {
      process.emit('rejectionHandled', promise);
    } else if (handler = global.onrejectionhandled) {
      handler({ promise: promise, reason: promise._v });
    }
  });
};
var $reject = function (value) {
  var promise = this;
  if (promise._d) return;
  promise._d = true;
  promise = promise._w || promise; // unwrap
  promise._v = value;
  promise._s = 2;
  if (!promise._a) promise._a = promise._c.slice();
  notify(promise, true);
};
var $resolve = function (value) {
  var promise = this;
  var then;
  if (promise._d) return;
  promise._d = true;
  promise = promise._w || promise; // unwrap
  try {
    if (promise === value) throw TypeError("Promise can't be resolved itself");
    if (then = isThenable(value)) {
      microtask(function () {
        var wrapper = { _w: promise, _d: false }; // wrap
        try {
          then.call(value, ctx($resolve, wrapper, 1), ctx($reject, wrapper, 1));
        } catch (e) {
          $reject.call(wrapper, e);
        }
      });
    } else {
      promise._v = value;
      promise._s = 1;
      notify(promise, false);
    }
  } catch (e) {
    $reject.call({ _w: promise, _d: false }, e); // wrap
  }
};

// constructor polyfill
if (!USE_NATIVE) {
  // 25.4.3.1 Promise(executor)
  $Promise = function Promise(executor) {
    anInstance(this, $Promise, PROMISE, '_h');
    aFunction(executor);
    Internal.call(this);
    try {
      executor(ctx($resolve, this, 1), ctx($reject, this, 1));
    } catch (err) {
      $reject.call(this, err);
    }
  };
  // eslint-disable-next-line no-unused-vars
  Internal = function Promise(executor) {
    this._c = [];             // <- awaiting reactions
    this._a = undefined;      // <- checked in isUnhandled reactions
    this._s = 0;              // <- state
    this._d = false;          // <- done
    this._v = undefined;      // <- value
    this._h = 0;              // <- rejection state, 0 - default, 1 - handled, 2 - unhandled
    this._n = false;          // <- notify
  };
  Internal.prototype = _dereq_(93)($Promise.prototype, {
    // 25.4.5.3 Promise.prototype.then(onFulfilled, onRejected)
    then: function then(onFulfilled, onRejected) {
      var reaction = newPromiseCapability(speciesConstructor(this, $Promise));
      reaction.ok = typeof onFulfilled == 'function' ? onFulfilled : true;
      reaction.fail = typeof onRejected == 'function' && onRejected;
      reaction.domain = isNode ? process.domain : undefined;
      this._c.push(reaction);
      if (this._a) this._a.push(reaction);
      if (this._s) notify(this, false);
      return reaction.promise;
    },
    // 25.4.5.1 Promise.prototype.catch(onRejected)
    'catch': function (onRejected) {
      return this.then(undefined, onRejected);
    }
  });
  OwnPromiseCapability = function () {
    var promise = new Internal();
    this.promise = promise;
    this.resolve = ctx($resolve, promise, 1);
    this.reject = ctx($reject, promise, 1);
  };
  newPromiseCapabilityModule.f = newPromiseCapability = function (C) {
    return sameConstructor($Promise, C)
      ? new OwnPromiseCapability(C)
      : newGenericPromiseCapability(C);
  };
}

$export($export.G + $export.W + $export.F * !USE_NATIVE, { Promise: $Promise });
_dereq_(101)($Promise, PROMISE);
_dereq_(100)(PROMISE);
Wrapper = _dereq_(23)[PROMISE];

// statics
$export($export.S + $export.F * !USE_NATIVE, PROMISE, {
  // 25.4.4.5 Promise.reject(r)
  reject: function reject(r) {
    var capability = newPromiseCapability(this);
    var $$reject = capability.reject;
    $$reject(r);
    return capability.promise;
  }
});
$export($export.S + $export.F * (LIBRARY || !USE_NATIVE), PROMISE, {
  // 25.4.4.6 Promise.resolve(x)
  resolve: function resolve(x) {
    // instanceof instead of internal slot check because we should fix it without replacement native Promise core
    if (x instanceof $Promise && sameConstructor(x.constructor, this)) return x;
    return promiseResolve(this, x);
  }
});
$export($export.S + $export.F * !(USE_NATIVE && _dereq_(56)(function (iter) {
  $Promise.all(iter)['catch'](empty);
})), PROMISE, {
  // 25.4.4.1 Promise.all(iterable)
  all: function all(iterable) {
    var C = this;
    var capability = newPromiseCapability(C);
    var resolve = capability.resolve;
    var reject = capability.reject;
    var result = perform(function () {
      var values = [];
      var index = 0;
      var remaining = 1;
      forOf(iterable, false, function (promise) {
        var $index = index++;
        var alreadyCalled = false;
        values.push(undefined);
        remaining++;
        C.resolve(promise).then(function (value) {
          if (alreadyCalled) return;
          alreadyCalled = true;
          values[$index] = value;
          --remaining || resolve(values);
        }, reject);
      });
      --remaining || resolve(values);
    });
    if (result.e) reject(result.v);
    return capability.promise;
  },
  // 25.4.4.4 Promise.race(iterable)
  race: function race(iterable) {
    var C = this;
    var capability = newPromiseCapability(C);
    var reject = capability.reject;
    var result = perform(function () {
      forOf(iterable, false, function (promise) {
        C.resolve(promise).then(capability.resolve, reject);
      });
    });
    if (result.e) reject(result.v);
    return capability.promise;
  }
});

},{"100":100,"101":101,"104":104,"113":113,"128":128,"17":17,"23":23,"25":25,"3":3,"33":33,"39":39,"40":40,"51":51,"56":56,"6":6,"60":60,"68":68,"69":69,"90":90,"91":91,"93":93}],210:[function(_dereq_,module,exports){
// 26.1.1 Reflect.apply(target, thisArgument, argumentsList)
var $export = _dereq_(33);
var aFunction = _dereq_(3);
var anObject = _dereq_(7);
var rApply = (_dereq_(40).Reflect || {}).apply;
var fApply = Function.apply;
// MS Edge argumentsList argument is optional
$export($export.S + $export.F * !_dereq_(35)(function () {
  rApply(function () { /* empty */ });
}), 'Reflect', {
  apply: function apply(target, thisArgument, argumentsList) {
    var T = aFunction(target);
    var L = anObject(argumentsList);
    return rApply ? rApply(T, thisArgument, L) : fApply.call(T, thisArgument, L);
  }
});

},{"3":3,"33":33,"35":35,"40":40,"7":7}],211:[function(_dereq_,module,exports){
// 26.1.2 Reflect.construct(target, argumentsList [, newTarget])
var $export = _dereq_(33);
var create = _dereq_(71);
var aFunction = _dereq_(3);
var anObject = _dereq_(7);
var isObject = _dereq_(51);
var fails = _dereq_(35);
var bind = _dereq_(16);
var rConstruct = (_dereq_(40).Reflect || {}).construct;

// MS Edge supports only 2 arguments and argumentsList argument is optional
// FF Nightly sets third argument as `new.target`, but does not create `this` from it
var NEW_TARGET_BUG = fails(function () {
  function F() { /* empty */ }
  return !(rConstruct(function () { /* empty */ }, [], F) instanceof F);
});
var ARGS_BUG = !fails(function () {
  rConstruct(function () { /* empty */ });
});

$export($export.S + $export.F * (NEW_TARGET_BUG || ARGS_BUG), 'Reflect', {
  construct: function construct(Target, args /* , newTarget */) {
    aFunction(Target);
    anObject(args);
    var newTarget = arguments.length < 3 ? Target : aFunction(arguments[2]);
    if (ARGS_BUG && !NEW_TARGET_BUG) return rConstruct(Target, args, newTarget);
    if (Target == newTarget) {
      // w/o altered newTarget, optimization for 0-4 arguments
      switch (args.length) {
        case 0: return new Target();
        case 1: return new Target(args[0]);
        case 2: return new Target(args[0], args[1]);
        case 3: return new Target(args[0], args[1], args[2]);
        case 4: return new Target(args[0], args[1], args[2], args[3]);
      }
      // w/o altered newTarget, lot of arguments case
      var $args = [null];
      $args.push.apply($args, args);
      return new (bind.apply(Target, $args))();
    }
    // with altered newTarget, not support built-in constructors
    var proto = newTarget.prototype;
    var instance = create(isObject(proto) ? proto : Object.prototype);
    var result = Function.apply.call(Target, instance, args);
    return isObject(result) ? result : instance;
  }
});

},{"16":16,"3":3,"33":33,"35":35,"40":40,"51":51,"7":7,"71":71}],212:[function(_dereq_,module,exports){
// 26.1.3 Reflect.defineProperty(target, propertyKey, attributes)
var dP = _dereq_(72);
var $export = _dereq_(33);
var anObject = _dereq_(7);
var toPrimitive = _dereq_(120);

// MS Edge has broken Reflect.defineProperty - throwing instead of returning false
$export($export.S + $export.F * _dereq_(35)(function () {
  // eslint-disable-next-line no-undef
  Reflect.defineProperty(dP.f({}, 1, { value: 1 }), 1, { value: 2 });
}), 'Reflect', {
  defineProperty: function defineProperty(target, propertyKey, attributes) {
    anObject(target);
    propertyKey = toPrimitive(propertyKey, true);
    anObject(attributes);
    try {
      dP.f(target, propertyKey, attributes);
      return true;
    } catch (e) {
      return false;
    }
  }
});

},{"120":120,"33":33,"35":35,"7":7,"72":72}],213:[function(_dereq_,module,exports){
// 26.1.4 Reflect.deleteProperty(target, propertyKey)
var $export = _dereq_(33);
var gOPD = _dereq_(75).f;
var anObject = _dereq_(7);

$export($export.S, 'Reflect', {
  deleteProperty: function deleteProperty(target, propertyKey) {
    var desc = gOPD(anObject(target), propertyKey);
    return desc && !desc.configurable ? false : delete target[propertyKey];
  }
});

},{"33":33,"7":7,"75":75}],214:[function(_dereq_,module,exports){
// 26.1.5 Reflect.enumerate(target)
var $export = _dereq_(33);
var anObject = _dereq_(7);
var Enumerate = function (iterated) {
  this._t = anObject(iterated); // target
  this._i = 0;                  // next index
  var keys = this._k = [];      // keys
  var key;
  for (key in iterated) keys.push(key);
};
_dereq_(54)(Enumerate, 'Object', function () {
  var that = this;
  var keys = that._k;
  var key;
  do {
    if (that._i >= keys.length) return { value: undefined, done: true };
  } while (!((key = keys[that._i++]) in that._t));
  return { value: key, done: false };
});

$export($export.S, 'Reflect', {
  enumerate: function enumerate(target) {
    return new Enumerate(target);
  }
});

},{"33":33,"54":54,"7":7}],215:[function(_dereq_,module,exports){
// 26.1.7 Reflect.getOwnPropertyDescriptor(target, propertyKey)
var gOPD = _dereq_(75);
var $export = _dereq_(33);
var anObject = _dereq_(7);

$export($export.S, 'Reflect', {
  getOwnPropertyDescriptor: function getOwnPropertyDescriptor(target, propertyKey) {
    return gOPD.f(anObject(target), propertyKey);
  }
});

},{"33":33,"7":7,"75":75}],216:[function(_dereq_,module,exports){
// 26.1.8 Reflect.getPrototypeOf(target)
var $export = _dereq_(33);
var getProto = _dereq_(79);
var anObject = _dereq_(7);

$export($export.S, 'Reflect', {
  getPrototypeOf: function getPrototypeOf(target) {
    return getProto(anObject(target));
  }
});

},{"33":33,"7":7,"79":79}],217:[function(_dereq_,module,exports){
// 26.1.6 Reflect.get(target, propertyKey [, receiver])
var gOPD = _dereq_(75);
var getPrototypeOf = _dereq_(79);
var has = _dereq_(41);
var $export = _dereq_(33);
var isObject = _dereq_(51);
var anObject = _dereq_(7);

function get(target, propertyKey /* , receiver */) {
  var receiver = arguments.length < 3 ? target : arguments[2];
  var desc, proto;
  if (anObject(target) === receiver) return target[propertyKey];
  if (desc = gOPD.f(target, propertyKey)) return has(desc, 'value')
    ? desc.value
    : desc.get !== undefined
      ? desc.get.call(receiver)
      : undefined;
  if (isObject(proto = getPrototypeOf(target))) return get(proto, propertyKey, receiver);
}

$export($export.S, 'Reflect', { get: get });

},{"33":33,"41":41,"51":51,"7":7,"75":75,"79":79}],218:[function(_dereq_,module,exports){
// 26.1.9 Reflect.has(target, propertyKey)
var $export = _dereq_(33);

$export($export.S, 'Reflect', {
  has: function has(target, propertyKey) {
    return propertyKey in target;
  }
});

},{"33":33}],219:[function(_dereq_,module,exports){
// 26.1.10 Reflect.isExtensible(target)
var $export = _dereq_(33);
var anObject = _dereq_(7);
var $isExtensible = Object.isExtensible;

$export($export.S, 'Reflect', {
  isExtensible: function isExtensible(target) {
    anObject(target);
    return $isExtensible ? $isExtensible(target) : true;
  }
});

},{"33":33,"7":7}],220:[function(_dereq_,module,exports){
// 26.1.11 Reflect.ownKeys(target)
var $export = _dereq_(33);

$export($export.S, 'Reflect', { ownKeys: _dereq_(85) });

},{"33":33,"85":85}],221:[function(_dereq_,module,exports){
// 26.1.12 Reflect.preventExtensions(target)
var $export = _dereq_(33);
var anObject = _dereq_(7);
var $preventExtensions = Object.preventExtensions;

$export($export.S, 'Reflect', {
  preventExtensions: function preventExtensions(target) {
    anObject(target);
    try {
      if ($preventExtensions) $preventExtensions(target);
      return true;
    } catch (e) {
      return false;
    }
  }
});

},{"33":33,"7":7}],222:[function(_dereq_,module,exports){
// 26.1.14 Reflect.setPrototypeOf(target, proto)
var $export = _dereq_(33);
var setProto = _dereq_(99);

if (setProto) $export($export.S, 'Reflect', {
  setPrototypeOf: function setPrototypeOf(target, proto) {
    setProto.check(target, proto);
    try {
      setProto.set(target, proto);
      return true;
    } catch (e) {
      return false;
    }
  }
});

},{"33":33,"99":99}],223:[function(_dereq_,module,exports){
// 26.1.13 Reflect.set(target, propertyKey, V [, receiver])
var dP = _dereq_(72);
var gOPD = _dereq_(75);
var getPrototypeOf = _dereq_(79);
var has = _dereq_(41);
var $export = _dereq_(33);
var createDesc = _dereq_(92);
var anObject = _dereq_(7);
var isObject = _dereq_(51);

function set(target, propertyKey, V /* , receiver */) {
  var receiver = arguments.length < 4 ? target : arguments[3];
  var ownDesc = gOPD.f(anObject(target), propertyKey);
  var existingDescriptor, proto;
  if (!ownDesc) {
    if (isObject(proto = getPrototypeOf(target))) {
      return set(proto, propertyKey, V, receiver);
    }
    ownDesc = createDesc(0);
  }
  if (has(ownDesc, 'value')) {
    if (ownDesc.writable === false || !isObject(receiver)) return false;
    existingDescriptor = gOPD.f(receiver, propertyKey) || createDesc(0);
    existingDescriptor.value = V;
    dP.f(receiver, propertyKey, existingDescriptor);
    return true;
  }
  return ownDesc.set === undefined ? false : (ownDesc.set.call(receiver, V), true);
}

$export($export.S, 'Reflect', { set: set });

},{"33":33,"41":41,"51":51,"7":7,"72":72,"75":75,"79":79,"92":92}],224:[function(_dereq_,module,exports){
var global = _dereq_(40);
var inheritIfRequired = _dereq_(45);
var dP = _dereq_(72).f;
var gOPN = _dereq_(77).f;
var isRegExp = _dereq_(52);
var $flags = _dereq_(37);
var $RegExp = global.RegExp;
var Base = $RegExp;
var proto = $RegExp.prototype;
var re1 = /a/g;
var re2 = /a/g;
// "new" creates a new object, old webkit buggy here
var CORRECT_NEW = new $RegExp(re1) !== re1;

if (_dereq_(29) && (!CORRECT_NEW || _dereq_(35)(function () {
  re2[_dereq_(128)('match')] = false;
  // RegExp constructor can alter flags and IsRegExp works correct with @@match
  return $RegExp(re1) != re1 || $RegExp(re2) == re2 || $RegExp(re1, 'i') != '/a/i';
}))) {
  $RegExp = function RegExp(p, f) {
    var tiRE = this instanceof $RegExp;
    var piRE = isRegExp(p);
    var fiU = f === undefined;
    return !tiRE && piRE && p.constructor === $RegExp && fiU ? p
      : inheritIfRequired(CORRECT_NEW
        ? new Base(piRE && !fiU ? p.source : p, f)
        : Base((piRE = p instanceof $RegExp) ? p.source : p, piRE && fiU ? $flags.call(p) : f)
      , tiRE ? this : proto, $RegExp);
  };
  var proxy = function (key) {
    key in $RegExp || dP($RegExp, key, {
      configurable: true,
      get: function () { return Base[key]; },
      set: function (it) { Base[key] = it; }
    });
  };
  for (var keys = gOPN(Base), i = 0; keys.length > i;) proxy(keys[i++]);
  proto.constructor = $RegExp;
  $RegExp.prototype = proto;
  _dereq_(94)(global, 'RegExp', $RegExp);
}

_dereq_(100)('RegExp');

},{"100":100,"128":128,"29":29,"35":35,"37":37,"40":40,"45":45,"52":52,"72":72,"77":77,"94":94}],225:[function(_dereq_,module,exports){
// 21.2.5.3 get RegExp.prototype.flags()
if (_dereq_(29) && /./g.flags != 'g') _dereq_(72).f(RegExp.prototype, 'flags', {
  configurable: true,
  get: _dereq_(37)
});

},{"29":29,"37":37,"72":72}],226:[function(_dereq_,module,exports){
// @@match logic
_dereq_(36)('match', 1, function (defined, MATCH, $match) {
  // 21.1.3.11 String.prototype.match(regexp)
  return [function match(regexp) {
var O = defined(this);
    var fn = regexp == undefined ? undefined : regexp[MATCH];
    return fn !== undefined ? fn.call(regexp, O) : new RegExp(regexp)[MATCH](String(O));
  }, $match];
});

},{"36":36}],227:[function(_dereq_,module,exports){
// @@replace logic
_dereq_(36)('replace', 2, function (defined, REPLACE, $replace) {
  // 21.1.3.14 String.prototype.replace(searchValue, replaceValue)
  return [function replace(searchValue, replaceValue) {
var O = defined(this);
    var fn = searchValue == undefined ? undefined : searchValue[REPLACE];
    return fn !== undefined
      ? fn.call(searchValue, O, replaceValue)
      : $replace.call(String(O), searchValue, replaceValue);
  }, $replace];
});

},{"36":36}],228:[function(_dereq_,module,exports){
// @@search logic
_dereq_(36)('search', 1, function (defined, SEARCH, $search) {
  // 21.1.3.15 String.prototype.search(regexp)
  return [function search(regexp) {
var O = defined(this);
    var fn = regexp == undefined ? undefined : regexp[SEARCH];
    return fn !== undefined ? fn.call(regexp, O) : new RegExp(regexp)[SEARCH](String(O));
  }, $search];
});

},{"36":36}],229:[function(_dereq_,module,exports){
// @@split logic
_dereq_(36)('split', 2, function (defined, SPLIT, $split) {
var isRegExp = _dereq_(52);
  var _split = $split;
  var $push = [].push;
  var $SPLIT = 'split';
  var LENGTH = 'length';
  var LAST_INDEX = 'lastIndex';
  if (
    'abbc'[$SPLIT](/(b)*/)[1] == 'c' ||
    'test'[$SPLIT](/(?:)/, -1)[LENGTH] != 4 ||
    'ab'[$SPLIT](/(?:ab)*/)[LENGTH] != 2 ||
    '.'[$SPLIT](/(.?)(.?)/)[LENGTH] != 4 ||
    '.'[$SPLIT](/()()/)[LENGTH] > 1 ||
    ''[$SPLIT](/.?/)[LENGTH]
  ) {
    var NPCG = /()??/.exec('')[1] === undefined; // nonparticipating capturing group
    // based on es5-shim implementation, need to rework it
    $split = function (separator, limit) {
      var string = String(this);
      if (separator === undefined && limit === 0) return [];
      // If `separator` is not a regex, use native split
      if (!isRegExp(separator)) return _split.call(string, separator, limit);
      var output = [];
      var flags = (separator.ignoreCase ? 'i' : '') +
                  (separator.multiline ? 'm' : '') +
                  (separator.unicode ? 'u' : '') +
                  (separator.sticky ? 'y' : '');
      var lastLastIndex = 0;
      var splitLimit = limit === undefined ? 4294967295 : limit >>> 0;
      // Make `global` and avoid `lastIndex` issues by working with a copy
      var separatorCopy = new RegExp(separator.source, flags + 'g');
      var separator2, match, lastIndex, lastLength, i;
      // Doesn't need flags gy, but they don't hurt
      if (!NPCG) separator2 = new RegExp('^' + separatorCopy.source + '$(?!\\s)', flags);
      while (match = separatorCopy.exec(string)) {
        // `separatorCopy.lastIndex` is not reliable cross-browser
        lastIndex = match.index + match[0][LENGTH];
        if (lastIndex > lastLastIndex) {
          output.push(string.slice(lastLastIndex, match.index));
          // Fix browsers whose `exec` methods don't consistently return `undefined` for NPCG
          // eslint-disable-next-line no-loop-func
          if (!NPCG && match[LENGTH] > 1) match[0].replace(separator2, function () {
            for (i = 1; i < arguments[LENGTH] - 2; i++) if (arguments[i] === undefined) match[i] = undefined;
          });
          if (match[LENGTH] > 1 && match.index < string[LENGTH]) $push.apply(output, match.slice(1));
          lastLength = match[0][LENGTH];
          lastLastIndex = lastIndex;
          if (output[LENGTH] >= splitLimit) break;
        }
        if (separatorCopy[LAST_INDEX] === match.index) separatorCopy[LAST_INDEX]++; // Avoid an infinite loop
      }
      if (lastLastIndex === string[LENGTH]) {
        if (lastLength || !separatorCopy.test('')) output.push('');
      } else output.push(string.slice(lastLastIndex));
      return output[LENGTH] > splitLimit ? output.slice(0, splitLimit) : output;
    };
  // Chakra, V8
  } else if ('0'[$SPLIT](undefined, 0)[LENGTH]) {
    $split = function (separator, limit) {
      return separator === undefined && limit === 0 ? [] : _split.call(this, separator, limit);
    };
  }
  // 21.1.3.17 String.prototype.split(separator, limit)
  return [function split(separator, limit) {
    var O = defined(this);
    var fn = separator == undefined ? undefined : separator[SPLIT];
    return fn !== undefined ? fn.call(separator, O, limit) : $split.call(String(O), separator, limit);
  }, $split];
});

},{"36":36,"52":52}],230:[function(_dereq_,module,exports){
_dereq_(225);
var anObject = _dereq_(7);
var $flags = _dereq_(37);
var DESCRIPTORS = _dereq_(29);
var TO_STRING = 'toString';
var $toString = /./[TO_STRING];

var define = function (fn) {
  _dereq_(94)(RegExp.prototype, TO_STRING, fn, true);
};

// 21.2.5.14 RegExp.prototype.toString()
if (_dereq_(35)(function () { return $toString.call({ source: 'a', flags: 'b' }) != '/a/b'; })) {
  define(function toString() {
    var R = anObject(this);
    return '/'.concat(R.source, '/',
      'flags' in R ? R.flags : !DESCRIPTORS && R instanceof RegExp ? $flags.call(R) : undefined);
  });
// FF44- RegExp#toString has a wrong name
} else if ($toString.name != TO_STRING) {
  define(function toString() {
    return $toString.call(this);
  });
}

},{"225":225,"29":29,"35":35,"37":37,"7":7,"94":94}],231:[function(_dereq_,module,exports){
var strong = _dereq_(19);
var validate = _dereq_(125);
var SET = 'Set';

// 23.2 Set Objects
module.exports = _dereq_(22)(SET, function (get) {
  return function Set() { return get(this, arguments.length > 0 ? arguments[0] : undefined); };
}, {
  // 23.2.3.1 Set.prototype.add(value)
  add: function add(value) {
    return strong.def(validate(this, SET), value = value === 0 ? 0 : value, value);
  }
}, strong);

},{"125":125,"19":19,"22":22}],232:[function(_dereq_,module,exports){
// B.2.3.2 String.prototype.anchor(name)
_dereq_(108)('anchor', function (createHTML) {
  return function anchor(name) {
    return createHTML(this, 'a', 'name', name);
  };
});

},{"108":108}],233:[function(_dereq_,module,exports){
// B.2.3.3 String.prototype.big()
_dereq_(108)('big', function (createHTML) {
  return function big() {
    return createHTML(this, 'big', '', '');
  };
});

},{"108":108}],234:[function(_dereq_,module,exports){
// B.2.3.4 String.prototype.blink()
_dereq_(108)('blink', function (createHTML) {
  return function blink() {
    return createHTML(this, 'blink', '', '');
  };
});

},{"108":108}],235:[function(_dereq_,module,exports){
// B.2.3.5 String.prototype.bold()
_dereq_(108)('bold', function (createHTML) {
  return function bold() {
    return createHTML(this, 'b', '', '');
  };
});

},{"108":108}],236:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $at = _dereq_(106)(false);
$export($export.P, 'String', {
  // 21.1.3.3 String.prototype.codePointAt(pos)
  codePointAt: function codePointAt(pos) {
    return $at(this, pos);
  }
});

},{"106":106,"33":33}],237:[function(_dereq_,module,exports){
// 21.1.3.6 String.prototype.endsWith(searchString [, endPosition])
var $export = _dereq_(33);
var toLength = _dereq_(118);
var context = _dereq_(107);
var ENDS_WITH = 'endsWith';
var $endsWith = ''[ENDS_WITH];

$export($export.P + $export.F * _dereq_(34)(ENDS_WITH), 'String', {
  endsWith: function endsWith(searchString /* , endPosition = @length */) {
    var that = context(this, searchString, ENDS_WITH);
    var endPosition = arguments.length > 1 ? arguments[1] : undefined;
    var len = toLength(that.length);
    var end = endPosition === undefined ? len : Math.min(toLength(endPosition), len);
    var search = String(searchString);
    return $endsWith
      ? $endsWith.call(that, search, end)
      : that.slice(end - search.length, end) === search;
  }
});

},{"107":107,"118":118,"33":33,"34":34}],238:[function(_dereq_,module,exports){
// B.2.3.6 String.prototype.fixed()
_dereq_(108)('fixed', function (createHTML) {
  return function fixed() {
    return createHTML(this, 'tt', '', '');
  };
});

},{"108":108}],239:[function(_dereq_,module,exports){
// B.2.3.7 String.prototype.fontcolor(color)
_dereq_(108)('fontcolor', function (createHTML) {
  return function fontcolor(color) {
    return createHTML(this, 'font', 'color', color);
  };
});

},{"108":108}],240:[function(_dereq_,module,exports){
// B.2.3.8 String.prototype.fontsize(size)
_dereq_(108)('fontsize', function (createHTML) {
  return function fontsize(size) {
    return createHTML(this, 'font', 'size', size);
  };
});

},{"108":108}],241:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var toAbsoluteIndex = _dereq_(114);
var fromCharCode = String.fromCharCode;
var $fromCodePoint = String.fromCodePoint;

// length should be 1, old FF problem
$export($export.S + $export.F * (!!$fromCodePoint && $fromCodePoint.length != 1), 'String', {
  // 21.1.2.2 String.fromCodePoint(...codePoints)
  fromCodePoint: function fromCodePoint(x) { // eslint-disable-line no-unused-vars
    var res = [];
    var aLen = arguments.length;
    var i = 0;
    var code;
    while (aLen > i) {
      code = +arguments[i++];
      if (toAbsoluteIndex(code, 0x10ffff) !== code) throw RangeError(code + ' is not a valid code point');
      res.push(code < 0x10000
        ? fromCharCode(code)
        : fromCharCode(((code -= 0x10000) >> 10) + 0xd800, code % 0x400 + 0xdc00)
      );
    } return res.join('');
  }
});

},{"114":114,"33":33}],242:[function(_dereq_,module,exports){
// 21.1.3.7 String.prototype.includes(searchString, position = 0)
var $export = _dereq_(33);
var context = _dereq_(107);
var INCLUDES = 'includes';

$export($export.P + $export.F * _dereq_(34)(INCLUDES), 'String', {
  includes: function includes(searchString /* , position = 0 */) {
    return !!~context(this, searchString, INCLUDES)
      .indexOf(searchString, arguments.length > 1 ? arguments[1] : undefined);
  }
});

},{"107":107,"33":33,"34":34}],243:[function(_dereq_,module,exports){
// B.2.3.9 String.prototype.italics()
_dereq_(108)('italics', function (createHTML) {
  return function italics() {
    return createHTML(this, 'i', '', '');
  };
});

},{"108":108}],244:[function(_dereq_,module,exports){
var $at = _dereq_(106)(true);

// 21.1.3.27 String.prototype[@@iterator]()
_dereq_(55)(String, 'String', function (iterated) {
  this._t = String(iterated); // target
  this._i = 0;                // next index
// 21.1.5.2.1 %StringIteratorPrototype%.next()
}, function () {
  var O = this._t;
  var index = this._i;
  var point;
  if (index >= O.length) return { value: undefined, done: true };
  point = $at(O, index);
  this._i += point.length;
  return { value: point, done: false };
});

},{"106":106,"55":55}],245:[function(_dereq_,module,exports){
// B.2.3.10 String.prototype.link(url)
_dereq_(108)('link', function (createHTML) {
  return function link(url) {
    return createHTML(this, 'a', 'href', url);
  };
});

},{"108":108}],246:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var toIObject = _dereq_(117);
var toLength = _dereq_(118);

$export($export.S, 'String', {
  // 21.1.2.4 String.raw(callSite, ...substitutions)
  raw: function raw(callSite) {
    var tpl = toIObject(callSite.raw);
    var len = toLength(tpl.length);
    var aLen = arguments.length;
    var res = [];
    var i = 0;
    while (len > i) {
      res.push(String(tpl[i++]));
      if (i < aLen) res.push(String(arguments[i]));
    } return res.join('');
  }
});

},{"117":117,"118":118,"33":33}],247:[function(_dereq_,module,exports){
var $export = _dereq_(33);

$export($export.P, 'String', {
  // 21.1.3.13 String.prototype.repeat(count)
  repeat: _dereq_(110)
});

},{"110":110,"33":33}],248:[function(_dereq_,module,exports){
// B.2.3.11 String.prototype.small()
_dereq_(108)('small', function (createHTML) {
  return function small() {
    return createHTML(this, 'small', '', '');
  };
});

},{"108":108}],249:[function(_dereq_,module,exports){
// 21.1.3.18 String.prototype.startsWith(searchString [, position ])
var $export = _dereq_(33);
var toLength = _dereq_(118);
var context = _dereq_(107);
var STARTS_WITH = 'startsWith';
var $startsWith = ''[STARTS_WITH];

$export($export.P + $export.F * _dereq_(34)(STARTS_WITH), 'String', {
  startsWith: function startsWith(searchString /* , position = 0 */) {
    var that = context(this, searchString, STARTS_WITH);
    var index = toLength(Math.min(arguments.length > 1 ? arguments[1] : undefined, that.length));
    var search = String(searchString);
    return $startsWith
      ? $startsWith.call(that, search, index)
      : that.slice(index, index + search.length) === search;
  }
});

},{"107":107,"118":118,"33":33,"34":34}],250:[function(_dereq_,module,exports){
// B.2.3.12 String.prototype.strike()
_dereq_(108)('strike', function (createHTML) {
  return function strike() {
    return createHTML(this, 'strike', '', '');
  };
});

},{"108":108}],251:[function(_dereq_,module,exports){
// B.2.3.13 String.prototype.sub()
_dereq_(108)('sub', function (createHTML) {
  return function sub() {
    return createHTML(this, 'sub', '', '');
  };
});

},{"108":108}],252:[function(_dereq_,module,exports){
// B.2.3.14 String.prototype.sup()
_dereq_(108)('sup', function (createHTML) {
  return function sup() {
    return createHTML(this, 'sup', '', '');
  };
});

},{"108":108}],253:[function(_dereq_,module,exports){
// 21.1.3.25 String.prototype.trim()
_dereq_(111)('trim', function ($trim) {
  return function trim() {
    return $trim(this, 3);
  };
});

},{"111":111}],254:[function(_dereq_,module,exports){
// ECMAScript 6 symbols shim
var global = _dereq_(40);
var has = _dereq_(41);
var DESCRIPTORS = _dereq_(29);
var $export = _dereq_(33);
var redefine = _dereq_(94);
var META = _dereq_(66).KEY;
var $fails = _dereq_(35);
var shared = _dereq_(103);
var setToStringTag = _dereq_(101);
var uid = _dereq_(124);
var wks = _dereq_(128);
var wksExt = _dereq_(127);
var wksDefine = _dereq_(126);
var keyOf = _dereq_(59);
var enumKeys = _dereq_(32);
var isArray = _dereq_(49);
var anObject = _dereq_(7);
var toIObject = _dereq_(117);
var toPrimitive = _dereq_(120);
var createDesc = _dereq_(92);
var _create = _dereq_(71);
var gOPNExt = _dereq_(76);
var $GOPD = _dereq_(75);
var $DP = _dereq_(72);
var $keys = _dereq_(81);
var gOPD = $GOPD.f;
var dP = $DP.f;
var gOPN = gOPNExt.f;
var $Symbol = global.Symbol;
var $JSON = global.JSON;
var _stringify = $JSON && $JSON.stringify;
var PROTOTYPE = 'prototype';
var HIDDEN = wks('_hidden');
var TO_PRIMITIVE = wks('toPrimitive');
var isEnum = {}.propertyIsEnumerable;
var SymbolRegistry = shared('symbol-registry');
var AllSymbols = shared('symbols');
var OPSymbols = shared('op-symbols');
var ObjectProto = Object[PROTOTYPE];
var USE_NATIVE = typeof $Symbol == 'function';
var QObject = global.QObject;
// Don't use setters in Qt Script, https://github.com/zloirock/core-js/issues/173
var setter = !QObject || !QObject[PROTOTYPE] || !QObject[PROTOTYPE].findChild;

// fallback for old Android, https://code.google.com/p/v8/issues/detail?id=687
var setSymbolDesc = DESCRIPTORS && $fails(function () {
  return _create(dP({}, 'a', {
    get: function () { return dP(this, 'a', { value: 7 }).a; }
  })).a != 7;
}) ? function (it, key, D) {
  var protoDesc = gOPD(ObjectProto, key);
  if (protoDesc) delete ObjectProto[key];
  dP(it, key, D);
  if (protoDesc && it !== ObjectProto) dP(ObjectProto, key, protoDesc);
} : dP;

var wrap = function (tag) {
  var sym = AllSymbols[tag] = _create($Symbol[PROTOTYPE]);
  sym._k = tag;
  return sym;
};

var isSymbol = USE_NATIVE && typeof $Symbol.iterator == 'symbol' ? function (it) {
  return typeof it == 'symbol';
} : function (it) {
  return it instanceof $Symbol;
};

var $defineProperty = function defineProperty(it, key, D) {
  if (it === ObjectProto) $defineProperty(OPSymbols, key, D);
  anObject(it);
  key = toPrimitive(key, true);
  anObject(D);
  if (has(AllSymbols, key)) {
    if (!D.enumerable) {
      if (!has(it, HIDDEN)) dP(it, HIDDEN, createDesc(1, {}));
      it[HIDDEN][key] = true;
    } else {
      if (has(it, HIDDEN) && it[HIDDEN][key]) it[HIDDEN][key] = false;
      D = _create(D, { enumerable: createDesc(0, false) });
    } return setSymbolDesc(it, key, D);
  } return dP(it, key, D);
};
var $defineProperties = function defineProperties(it, P) {
  anObject(it);
  var keys = enumKeys(P = toIObject(P));
  var i = 0;
  var l = keys.length;
  var key;
  while (l > i) $defineProperty(it, key = keys[i++], P[key]);
  return it;
};
var $create = function create(it, P) {
  return P === undefined ? _create(it) : $defineProperties(_create(it), P);
};
var $propertyIsEnumerable = function propertyIsEnumerable(key) {
  var E = isEnum.call(this, key = toPrimitive(key, true));
  if (this === ObjectProto && has(AllSymbols, key) && !has(OPSymbols, key)) return false;
  return E || !has(this, key) || !has(AllSymbols, key) || has(this, HIDDEN) && this[HIDDEN][key] ? E : true;
};
var $getOwnPropertyDescriptor = function getOwnPropertyDescriptor(it, key) {
  it = toIObject(it);
  key = toPrimitive(key, true);
  if (it === ObjectProto && has(AllSymbols, key) && !has(OPSymbols, key)) return;
  var D = gOPD(it, key);
  if (D && has(AllSymbols, key) && !(has(it, HIDDEN) && it[HIDDEN][key])) D.enumerable = true;
  return D;
};
var $getOwnPropertyNames = function getOwnPropertyNames(it) {
  var names = gOPN(toIObject(it));
  var result = [];
  var i = 0;
  var key;
  while (names.length > i) {
    if (!has(AllSymbols, key = names[i++]) && key != HIDDEN && key != META) result.push(key);
  } return result;
};
var $getOwnPropertySymbols = function getOwnPropertySymbols(it) {
  var IS_OP = it === ObjectProto;
  var names = gOPN(IS_OP ? OPSymbols : toIObject(it));
  var result = [];
  var i = 0;
  var key;
  while (names.length > i) {
    if (has(AllSymbols, key = names[i++]) && (IS_OP ? has(ObjectProto, key) : true)) result.push(AllSymbols[key]);
  } return result;
};

// 19.4.1.1 Symbol([description])
if (!USE_NATIVE) {
  $Symbol = function Symbol() {
    if (this instanceof $Symbol) throw TypeError('Symbol is not a constructor!');
    var tag = uid(arguments.length > 0 ? arguments[0] : undefined);
    var $set = function (value) {
      if (this === ObjectProto) $set.call(OPSymbols, value);
      if (has(this, HIDDEN) && has(this[HIDDEN], tag)) this[HIDDEN][tag] = false;
      setSymbolDesc(this, tag, createDesc(1, value));
    };
    if (DESCRIPTORS && setter) setSymbolDesc(ObjectProto, tag, { configurable: true, set: $set });
    return wrap(tag);
  };
  redefine($Symbol[PROTOTYPE], 'toString', function toString() {
    return this._k;
  });

  $GOPD.f = $getOwnPropertyDescriptor;
  $DP.f = $defineProperty;
  _dereq_(77).f = gOPNExt.f = $getOwnPropertyNames;
  _dereq_(82).f = $propertyIsEnumerable;
  _dereq_(78).f = $getOwnPropertySymbols;

  if (DESCRIPTORS && !_dereq_(60)) {
    redefine(ObjectProto, 'propertyIsEnumerable', $propertyIsEnumerable, true);
  }

  wksExt.f = function (name) {
    return wrap(wks(name));
  };
}

$export($export.G + $export.W + $export.F * !USE_NATIVE, { Symbol: $Symbol });

for (var es6Symbols = (
  // 19.4.2.2, 19.4.2.3, 19.4.2.4, 19.4.2.6, 19.4.2.8, 19.4.2.9, 19.4.2.10, 19.4.2.11, 19.4.2.12, 19.4.2.13, 19.4.2.14
  'hasInstance,isConcatSpreadable,iterator,match,replace,search,species,split,toPrimitive,toStringTag,unscopables'
).split(','), j = 0; es6Symbols.length > j;)wks(es6Symbols[j++]);

for (var wellKnownSymbols = $keys(wks.store), k = 0; wellKnownSymbols.length > k;) wksDefine(wellKnownSymbols[k++]);

$export($export.S + $export.F * !USE_NATIVE, 'Symbol', {
  // 19.4.2.1 Symbol.for(key)
  'for': function (key) {
    return has(SymbolRegistry, key += '')
      ? SymbolRegistry[key]
      : SymbolRegistry[key] = $Symbol(key);
  },
  // 19.4.2.5 Symbol.keyFor(sym)
  keyFor: function keyFor(key) {
    if (isSymbol(key)) return keyOf(SymbolRegistry, key);
    throw TypeError(key + ' is not a symbol!');
  },
  useSetter: function () { setter = true; },
  useSimple: function () { setter = false; }
});

$export($export.S + $export.F * !USE_NATIVE, 'Object', {
  // 19.1.2.2 Object.create(O [, Properties])
  create: $create,
  // 19.1.2.4 Object.defineProperty(O, P, Attributes)
  defineProperty: $defineProperty,
  // 19.1.2.3 Object.defineProperties(O, Properties)
  defineProperties: $defineProperties,
  // 19.1.2.6 Object.getOwnPropertyDescriptor(O, P)
  getOwnPropertyDescriptor: $getOwnPropertyDescriptor,
  // 19.1.2.7 Object.getOwnPropertyNames(O)
  getOwnPropertyNames: $getOwnPropertyNames,
  // 19.1.2.8 Object.getOwnPropertySymbols(O)
  getOwnPropertySymbols: $getOwnPropertySymbols
});

// 24.3.2 JSON.stringify(value [, replacer [, space]])
$JSON && $export($export.S + $export.F * (!USE_NATIVE || $fails(function () {
  var S = $Symbol();
  // MS Edge converts symbol values to JSON as {}
  // WebKit converts symbol values to JSON as null
  // V8 throws on boxed symbols
  return _stringify([S]) != '[null]' || _stringify({ a: S }) != '{}' || _stringify(Object(S)) != '{}';
})), 'JSON', {
  stringify: function stringify(it) {
    if (it === undefined || isSymbol(it)) return; // IE8 returns string on undefined
    var args = [it];
    var i = 1;
    var replacer, $replacer;
    while (arguments.length > i) args.push(arguments[i++]);
    replacer = args[1];
    if (typeof replacer == 'function') $replacer = replacer;
    if ($replacer || !isArray(replacer)) replacer = function (key, value) {
      if ($replacer) value = $replacer.call(this, key, value);
      if (!isSymbol(value)) return value;
    };
    args[1] = replacer;
    return _stringify.apply($JSON, args);
  }
});

// 19.4.3.4 Symbol.prototype[@@toPrimitive](hint)
$Symbol[PROTOTYPE][TO_PRIMITIVE] || _dereq_(42)($Symbol[PROTOTYPE], TO_PRIMITIVE, $Symbol[PROTOTYPE].valueOf);
// 19.4.3.5 Symbol.prototype[@@toStringTag]
setToStringTag($Symbol, 'Symbol');
// 20.2.1.9 Math[@@toStringTag]
setToStringTag(Math, 'Math', true);
// 24.3.3 JSON[@@toStringTag]
setToStringTag(global.JSON, 'JSON', true);

},{"101":101,"103":103,"117":117,"120":120,"124":124,"126":126,"127":127,"128":128,"29":29,"32":32,"33":33,"35":35,"40":40,"41":41,"42":42,"49":49,"59":59,"60":60,"66":66,"7":7,"71":71,"72":72,"75":75,"76":76,"77":77,"78":78,"81":81,"82":82,"92":92,"94":94}],255:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $typed = _dereq_(123);
var buffer = _dereq_(122);
var anObject = _dereq_(7);
var toAbsoluteIndex = _dereq_(114);
var toLength = _dereq_(118);
var isObject = _dereq_(51);
var ArrayBuffer = _dereq_(40).ArrayBuffer;
var speciesConstructor = _dereq_(104);
var $ArrayBuffer = buffer.ArrayBuffer;
var $DataView = buffer.DataView;
var $isView = $typed.ABV && ArrayBuffer.isView;
var $slice = $ArrayBuffer.prototype.slice;
var VIEW = $typed.VIEW;
var ARRAY_BUFFER = 'ArrayBuffer';

$export($export.G + $export.W + $export.F * (ArrayBuffer !== $ArrayBuffer), { ArrayBuffer: $ArrayBuffer });

$export($export.S + $export.F * !$typed.CONSTR, ARRAY_BUFFER, {
  // 24.1.3.1 ArrayBuffer.isView(arg)
  isView: function isView(it) {
    return $isView && $isView(it) || isObject(it) && VIEW in it;
  }
});

$export($export.P + $export.U + $export.F * _dereq_(35)(function () {
  return !new $ArrayBuffer(2).slice(1, undefined).byteLength;
}), ARRAY_BUFFER, {
  // 24.1.4.3 ArrayBuffer.prototype.slice(start, end)
  slice: function slice(start, end) {
    if ($slice !== undefined && end === undefined) return $slice.call(anObject(this), start); // FF fix
    var len = anObject(this).byteLength;
    var first = toAbsoluteIndex(start, len);
    var final = toAbsoluteIndex(end === undefined ? len : end, len);
    var result = new (speciesConstructor(this, $ArrayBuffer))(toLength(final - first));
    var viewS = new $DataView(this);
    var viewT = new $DataView(result);
    var index = 0;
    while (first < final) {
      viewT.setUint8(index++, viewS.getUint8(first++));
    } return result;
  }
});

_dereq_(100)(ARRAY_BUFFER);

},{"100":100,"104":104,"114":114,"118":118,"122":122,"123":123,"33":33,"35":35,"40":40,"51":51,"7":7}],256:[function(_dereq_,module,exports){
var $export = _dereq_(33);
$export($export.G + $export.W + $export.F * !_dereq_(123).ABV, {
  DataView: _dereq_(122).DataView
});

},{"122":122,"123":123,"33":33}],257:[function(_dereq_,module,exports){
_dereq_(121)('Float32', 4, function (init) {
  return function Float32Array(data, byteOffset, length) {
    return init(this, data, byteOffset, length);
  };
});

},{"121":121}],258:[function(_dereq_,module,exports){
_dereq_(121)('Float64', 8, function (init) {
  return function Float64Array(data, byteOffset, length) {
    return init(this, data, byteOffset, length);
  };
});

},{"121":121}],259:[function(_dereq_,module,exports){
_dereq_(121)('Int16', 2, function (init) {
  return function Int16Array(data, byteOffset, length) {
    return init(this, data, byteOffset, length);
  };
});

},{"121":121}],260:[function(_dereq_,module,exports){
_dereq_(121)('Int32', 4, function (init) {
  return function Int32Array(data, byteOffset, length) {
    return init(this, data, byteOffset, length);
  };
});

},{"121":121}],261:[function(_dereq_,module,exports){
_dereq_(121)('Int8', 1, function (init) {
  return function Int8Array(data, byteOffset, length) {
    return init(this, data, byteOffset, length);
  };
});

},{"121":121}],262:[function(_dereq_,module,exports){
_dereq_(121)('Uint16', 2, function (init) {
  return function Uint16Array(data, byteOffset, length) {
    return init(this, data, byteOffset, length);
  };
});

},{"121":121}],263:[function(_dereq_,module,exports){
_dereq_(121)('Uint32', 4, function (init) {
  return function Uint32Array(data, byteOffset, length) {
    return init(this, data, byteOffset, length);
  };
});

},{"121":121}],264:[function(_dereq_,module,exports){
_dereq_(121)('Uint8', 1, function (init) {
  return function Uint8Array(data, byteOffset, length) {
    return init(this, data, byteOffset, length);
  };
});

},{"121":121}],265:[function(_dereq_,module,exports){
_dereq_(121)('Uint8', 1, function (init) {
  return function Uint8ClampedArray(data, byteOffset, length) {
    return init(this, data, byteOffset, length);
  };
}, true);

},{"121":121}],266:[function(_dereq_,module,exports){
var each = _dereq_(12)(0);
var redefine = _dereq_(94);
var meta = _dereq_(66);
var assign = _dereq_(70);
var weak = _dereq_(21);
var isObject = _dereq_(51);
var fails = _dereq_(35);
var validate = _dereq_(125);
var WEAK_MAP = 'WeakMap';
var getWeak = meta.getWeak;
var isExtensible = Object.isExtensible;
var uncaughtFrozenStore = weak.ufstore;
var tmp = {};
var InternalMap;

var wrapper = function (get) {
  return function WeakMap() {
    return get(this, arguments.length > 0 ? arguments[0] : undefined);
  };
};

var methods = {
  // 23.3.3.3 WeakMap.prototype.get(key)
  get: function get(key) {
    if (isObject(key)) {
      var data = getWeak(key);
      if (data === true) return uncaughtFrozenStore(validate(this, WEAK_MAP)).get(key);
      return data ? data[this._i] : undefined;
    }
  },
  // 23.3.3.5 WeakMap.prototype.set(key, value)
  set: function set(key, value) {
    return weak.def(validate(this, WEAK_MAP), key, value);
  }
};

// 23.3 WeakMap Objects
var $WeakMap = module.exports = _dereq_(22)(WEAK_MAP, wrapper, methods, weak, true, true);

// IE11 WeakMap frozen keys fix
if (fails(function () { return new $WeakMap().set((Object.freeze || Object)(tmp), 7).get(tmp) != 7; })) {
  InternalMap = weak.getConstructor(wrapper, WEAK_MAP);
  assign(InternalMap.prototype, methods);
  meta.NEED = true;
  each(['delete', 'has', 'get', 'set'], function (key) {
    var proto = $WeakMap.prototype;
    var method = proto[key];
    redefine(proto, key, function (a, b) {
      // store frozen objects on internal weakmap shim
      if (isObject(a) && !isExtensible(a)) {
        if (!this._f) this._f = new InternalMap();
        var result = this._f[key](a, b);
        return key == 'set' ? this : result;
      // store all the rest on native weakmap
      } return method.call(this, a, b);
    });
  });
}

},{"12":12,"125":125,"21":21,"22":22,"35":35,"51":51,"66":66,"70":70,"94":94}],267:[function(_dereq_,module,exports){
var weak = _dereq_(21);
var validate = _dereq_(125);
var WEAK_SET = 'WeakSet';

// 23.4 WeakSet Objects
_dereq_(22)(WEAK_SET, function (get) {
  return function WeakSet() { return get(this, arguments.length > 0 ? arguments[0] : undefined); };
}, {
  // 23.4.3.1 WeakSet.prototype.add(value)
  add: function add(value) {
    return weak.def(validate(this, WEAK_SET), value, true);
  }
}, weak, false, true);

},{"125":125,"21":21,"22":22}],268:[function(_dereq_,module,exports){
// https://tc39.github.io/proposal-flatMap/#sec-Array.prototype.flatMap
var $export = _dereq_(33);
var flattenIntoArray = _dereq_(38);
var toObject = _dereq_(119);
var toLength = _dereq_(118);
var aFunction = _dereq_(3);
var arraySpeciesCreate = _dereq_(15);

$export($export.P, 'Array', {
  flatMap: function flatMap(callbackfn /* , thisArg */) {
    var O = toObject(this);
    var sourceLen, A;
    aFunction(callbackfn);
    sourceLen = toLength(O.length);
    A = arraySpeciesCreate(O, 0);
    flattenIntoArray(A, O, O, sourceLen, 0, 1, callbackfn, arguments[1]);
    return A;
  }
});

_dereq_(5)('flatMap');

},{"118":118,"119":119,"15":15,"3":3,"33":33,"38":38,"5":5}],269:[function(_dereq_,module,exports){
// https://tc39.github.io/proposal-flatMap/#sec-Array.prototype.flatten
var $export = _dereq_(33);
var flattenIntoArray = _dereq_(38);
var toObject = _dereq_(119);
var toLength = _dereq_(118);
var toInteger = _dereq_(116);
var arraySpeciesCreate = _dereq_(15);

$export($export.P, 'Array', {
  flatten: function flatten(/* depthArg = 1 */) {
    var depthArg = arguments[0];
    var O = toObject(this);
    var sourceLen = toLength(O.length);
    var A = arraySpeciesCreate(O, 0);
    flattenIntoArray(A, O, O, sourceLen, 0, depthArg === undefined ? 1 : toInteger(depthArg));
    return A;
  }
});

_dereq_(5)('flatten');

},{"116":116,"118":118,"119":119,"15":15,"33":33,"38":38,"5":5}],270:[function(_dereq_,module,exports){
// https://github.com/tc39/Array.prototype.includes
var $export = _dereq_(33);
var $includes = _dereq_(11)(true);

$export($export.P, 'Array', {
  includes: function includes(el /* , fromIndex = 0 */) {
    return $includes(this, el, arguments.length > 1 ? arguments[1] : undefined);
  }
});

_dereq_(5)('includes');

},{"11":11,"33":33,"5":5}],271:[function(_dereq_,module,exports){
// https://github.com/rwaldron/tc39-notes/blob/master/es6/2014-09/sept-25.md#510-globalasap-for-enqueuing-a-microtask
var $export = _dereq_(33);
var microtask = _dereq_(68)();
var process = _dereq_(40).process;
var isNode = _dereq_(18)(process) == 'process';

$export($export.G, {
  asap: function asap(fn) {
    var domain = isNode && process.domain;
    microtask(domain ? domain.bind(fn) : fn);
  }
});

},{"18":18,"33":33,"40":40,"68":68}],272:[function(_dereq_,module,exports){
// https://github.com/ljharb/proposal-is-error
var $export = _dereq_(33);
var cof = _dereq_(18);

$export($export.S, 'Error', {
  isError: function isError(it) {
    return cof(it) === 'Error';
  }
});

},{"18":18,"33":33}],273:[function(_dereq_,module,exports){
// https://github.com/tc39/proposal-global
var $export = _dereq_(33);

$export($export.G, { global: _dereq_(40) });

},{"33":33,"40":40}],274:[function(_dereq_,module,exports){
// https://tc39.github.io/proposal-setmap-offrom/#sec-map.from
_dereq_(97)('Map');

},{"97":97}],275:[function(_dereq_,module,exports){
// https://tc39.github.io/proposal-setmap-offrom/#sec-map.of
_dereq_(98)('Map');

},{"98":98}],276:[function(_dereq_,module,exports){
// https://github.com/DavidBruant/Map-Set.prototype.toJSON
var $export = _dereq_(33);

$export($export.P + $export.R, 'Map', { toJSON: _dereq_(20)('Map') });

},{"20":20,"33":33}],277:[function(_dereq_,module,exports){
// https://rwaldron.github.io/proposal-math-extensions/
var $export = _dereq_(33);

$export($export.S, 'Math', {
  clamp: function clamp(x, lower, upper) {
    return Math.min(upper, Math.max(lower, x));
  }
});

},{"33":33}],278:[function(_dereq_,module,exports){
// https://rwaldron.github.io/proposal-math-extensions/
var $export = _dereq_(33);

$export($export.S, 'Math', { DEG_PER_RAD: Math.PI / 180 });

},{"33":33}],279:[function(_dereq_,module,exports){
// https://rwaldron.github.io/proposal-math-extensions/
var $export = _dereq_(33);
var RAD_PER_DEG = 180 / Math.PI;

$export($export.S, 'Math', {
  degrees: function degrees(radians) {
    return radians * RAD_PER_DEG;
  }
});

},{"33":33}],280:[function(_dereq_,module,exports){
// https://rwaldron.github.io/proposal-math-extensions/
var $export = _dereq_(33);
var scale = _dereq_(64);
var fround = _dereq_(62);

$export($export.S, 'Math', {
  fscale: function fscale(x, inLow, inHigh, outLow, outHigh) {
    return fround(scale(x, inLow, inHigh, outLow, outHigh));
  }
});

},{"33":33,"62":62,"64":64}],281:[function(_dereq_,module,exports){
// https://gist.github.com/BrendanEich/4294d5c212a6d2254703
var $export = _dereq_(33);

$export($export.S, 'Math', {
  iaddh: function iaddh(x0, x1, y0, y1) {
    var $x0 = x0 >>> 0;
    var $x1 = x1 >>> 0;
    var $y0 = y0 >>> 0;
    return $x1 + (y1 >>> 0) + (($x0 & $y0 | ($x0 | $y0) & ~($x0 + $y0 >>> 0)) >>> 31) | 0;
  }
});

},{"33":33}],282:[function(_dereq_,module,exports){
// https://gist.github.com/BrendanEich/4294d5c212a6d2254703
var $export = _dereq_(33);

$export($export.S, 'Math', {
  imulh: function imulh(u, v) {
    var UINT16 = 0xffff;
    var $u = +u;
    var $v = +v;
    var u0 = $u & UINT16;
    var v0 = $v & UINT16;
    var u1 = $u >> 16;
    var v1 = $v >> 16;
    var t = (u1 * v0 >>> 0) + (u0 * v0 >>> 16);
    return u1 * v1 + (t >> 16) + ((u0 * v1 >>> 0) + (t & UINT16) >> 16);
  }
});

},{"33":33}],283:[function(_dereq_,module,exports){
// https://gist.github.com/BrendanEich/4294d5c212a6d2254703
var $export = _dereq_(33);

$export($export.S, 'Math', {
  isubh: function isubh(x0, x1, y0, y1) {
    var $x0 = x0 >>> 0;
    var $x1 = x1 >>> 0;
    var $y0 = y0 >>> 0;
    return $x1 - (y1 >>> 0) - ((~$x0 & $y0 | ~($x0 ^ $y0) & $x0 - $y0 >>> 0) >>> 31) | 0;
  }
});

},{"33":33}],284:[function(_dereq_,module,exports){
// https://rwaldron.github.io/proposal-math-extensions/
var $export = _dereq_(33);

$export($export.S, 'Math', { RAD_PER_DEG: 180 / Math.PI });

},{"33":33}],285:[function(_dereq_,module,exports){
// https://rwaldron.github.io/proposal-math-extensions/
var $export = _dereq_(33);
var DEG_PER_RAD = Math.PI / 180;

$export($export.S, 'Math', {
  radians: function radians(degrees) {
    return degrees * DEG_PER_RAD;
  }
});

},{"33":33}],286:[function(_dereq_,module,exports){
// https://rwaldron.github.io/proposal-math-extensions/
var $export = _dereq_(33);

$export($export.S, 'Math', { scale: _dereq_(64) });

},{"33":33,"64":64}],287:[function(_dereq_,module,exports){
// http://jfbastien.github.io/papers/Math.signbit.html
var $export = _dereq_(33);

$export($export.S, 'Math', { signbit: function signbit(x) {
  // eslint-disable-next-line no-self-compare
  return (x = +x) != x ? x : x == 0 ? 1 / x == Infinity : x > 0;
} });

},{"33":33}],288:[function(_dereq_,module,exports){
// https://gist.github.com/BrendanEich/4294d5c212a6d2254703
var $export = _dereq_(33);

$export($export.S, 'Math', {
  umulh: function umulh(u, v) {
    var UINT16 = 0xffff;
    var $u = +u;
    var $v = +v;
    var u0 = $u & UINT16;
    var v0 = $v & UINT16;
    var u1 = $u >>> 16;
    var v1 = $v >>> 16;
    var t = (u1 * v0 >>> 0) + (u0 * v0 >>> 16);
    return u1 * v1 + (t >>> 16) + ((u0 * v1 >>> 0) + (t & UINT16) >>> 16);
  }
});

},{"33":33}],289:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var toObject = _dereq_(119);
var aFunction = _dereq_(3);
var $defineProperty = _dereq_(72);

// B.2.2.2 Object.prototype.__defineGetter__(P, getter)
_dereq_(29) && $export($export.P + _dereq_(74), 'Object', {
  __defineGetter__: function __defineGetter__(P, getter) {
    $defineProperty.f(toObject(this), P, { get: aFunction(getter), enumerable: true, configurable: true });
  }
});

},{"119":119,"29":29,"3":3,"33":33,"72":72,"74":74}],290:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var toObject = _dereq_(119);
var aFunction = _dereq_(3);
var $defineProperty = _dereq_(72);

// B.2.2.3 Object.prototype.__defineSetter__(P, setter)
_dereq_(29) && $export($export.P + _dereq_(74), 'Object', {
  __defineSetter__: function __defineSetter__(P, setter) {
    $defineProperty.f(toObject(this), P, { set: aFunction(setter), enumerable: true, configurable: true });
  }
});

},{"119":119,"29":29,"3":3,"33":33,"72":72,"74":74}],291:[function(_dereq_,module,exports){
// https://github.com/tc39/proposal-object-values-entries
var $export = _dereq_(33);
var $entries = _dereq_(84)(true);

$export($export.S, 'Object', {
  entries: function entries(it) {
    return $entries(it);
  }
});

},{"33":33,"84":84}],292:[function(_dereq_,module,exports){
// https://github.com/tc39/proposal-object-getownpropertydescriptors
var $export = _dereq_(33);
var ownKeys = _dereq_(85);
var toIObject = _dereq_(117);
var gOPD = _dereq_(75);
var createProperty = _dereq_(24);

$export($export.S, 'Object', {
  getOwnPropertyDescriptors: function getOwnPropertyDescriptors(object) {
    var O = toIObject(object);
    var getDesc = gOPD.f;
    var keys = ownKeys(O);
    var result = {};
    var i = 0;
    var key, desc;
    while (keys.length > i) {
      desc = getDesc(O, key = keys[i++]);
      if (desc !== undefined) createProperty(result, key, desc);
    }
    return result;
  }
});

},{"117":117,"24":24,"33":33,"75":75,"85":85}],293:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var toObject = _dereq_(119);
var toPrimitive = _dereq_(120);
var getPrototypeOf = _dereq_(79);
var getOwnPropertyDescriptor = _dereq_(75).f;

// B.2.2.4 Object.prototype.__lookupGetter__(P)
_dereq_(29) && $export($export.P + _dereq_(74), 'Object', {
  __lookupGetter__: function __lookupGetter__(P) {
    var O = toObject(this);
    var K = toPrimitive(P, true);
    var D;
    do {
      if (D = getOwnPropertyDescriptor(O, K)) return D.get;
    } while (O = getPrototypeOf(O));
  }
});

},{"119":119,"120":120,"29":29,"33":33,"74":74,"75":75,"79":79}],294:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var toObject = _dereq_(119);
var toPrimitive = _dereq_(120);
var getPrototypeOf = _dereq_(79);
var getOwnPropertyDescriptor = _dereq_(75).f;

// B.2.2.5 Object.prototype.__lookupSetter__(P)
_dereq_(29) && $export($export.P + _dereq_(74), 'Object', {
  __lookupSetter__: function __lookupSetter__(P) {
    var O = toObject(this);
    var K = toPrimitive(P, true);
    var D;
    do {
      if (D = getOwnPropertyDescriptor(O, K)) return D.set;
    } while (O = getPrototypeOf(O));
  }
});

},{"119":119,"120":120,"29":29,"33":33,"74":74,"75":75,"79":79}],295:[function(_dereq_,module,exports){
// https://github.com/tc39/proposal-object-values-entries
var $export = _dereq_(33);
var $values = _dereq_(84)(false);

$export($export.S, 'Object', {
  values: function values(it) {
    return $values(it);
  }
});

},{"33":33,"84":84}],296:[function(_dereq_,module,exports){
// https://github.com/zenparsing/es-observable
var $export = _dereq_(33);
var global = _dereq_(40);
var core = _dereq_(23);
var microtask = _dereq_(68)();
var OBSERVABLE = _dereq_(128)('observable');
var aFunction = _dereq_(3);
var anObject = _dereq_(7);
var anInstance = _dereq_(6);
var redefineAll = _dereq_(93);
var hide = _dereq_(42);
var forOf = _dereq_(39);
var RETURN = forOf.RETURN;

var getMethod = function (fn) {
  return fn == null ? undefined : aFunction(fn);
};

var cleanupSubscription = function (subscription) {
  var cleanup = subscription._c;
  if (cleanup) {
    subscription._c = undefined;
    cleanup();
  }
};

var subscriptionClosed = function (subscription) {
  return subscription._o === undefined;
};

var closeSubscription = function (subscription) {
  if (!subscriptionClosed(subscription)) {
    subscription._o = undefined;
    cleanupSubscription(subscription);
  }
};

var Subscription = function (observer, subscriber) {
  anObject(observer);
  this._c = undefined;
  this._o = observer;
  observer = new SubscriptionObserver(this);
  try {
    var cleanup = subscriber(observer);
    var subscription = cleanup;
    if (cleanup != null) {
      if (typeof cleanup.unsubscribe === 'function') cleanup = function () { subscription.unsubscribe(); };
      else aFunction(cleanup);
      this._c = cleanup;
    }
  } catch (e) {
    observer.error(e);
    return;
  } if (subscriptionClosed(this)) cleanupSubscription(this);
};

Subscription.prototype = redefineAll({}, {
  unsubscribe: function unsubscribe() { closeSubscription(this); }
});

var SubscriptionObserver = function (subscription) {
  this._s = subscription;
};

SubscriptionObserver.prototype = redefineAll({}, {
  next: function next(value) {
    var subscription = this._s;
    if (!subscriptionClosed(subscription)) {
      var observer = subscription._o;
      try {
        var m = getMethod(observer.next);
        if (m) return m.call(observer, value);
      } catch (e) {
        try {
          closeSubscription(subscription);
        } finally {
          throw e;
        }
      }
    }
  },
  error: function error(value) {
    var subscription = this._s;
    if (subscriptionClosed(subscription)) throw value;
    var observer = subscription._o;
    subscription._o = undefined;
    try {
      var m = getMethod(observer.error);
      if (!m) throw value;
      value = m.call(observer, value);
    } catch (e) {
      try {
        cleanupSubscription(subscription);
      } finally {
        throw e;
      }
    } cleanupSubscription(subscription);
    return value;
  },
  complete: function complete(value) {
    var subscription = this._s;
    if (!subscriptionClosed(subscription)) {
      var observer = subscription._o;
      subscription._o = undefined;
      try {
        var m = getMethod(observer.complete);
        value = m ? m.call(observer, value) : undefined;
      } catch (e) {
        try {
          cleanupSubscription(subscription);
        } finally {
          throw e;
        }
      } cleanupSubscription(subscription);
      return value;
    }
  }
});

var $Observable = function Observable(subscriber) {
  anInstance(this, $Observable, 'Observable', '_f')._f = aFunction(subscriber);
};

redefineAll($Observable.prototype, {
  subscribe: function subscribe(observer) {
    return new Subscription(observer, this._f);
  },
  forEach: function forEach(fn) {
    var that = this;
    return new (core.Promise || global.Promise)(function (resolve, reject) {
      aFunction(fn);
      var subscription = that.subscribe({
        next: function (value) {
          try {
            return fn(value);
          } catch (e) {
            reject(e);
            subscription.unsubscribe();
          }
        },
        error: reject,
        complete: resolve
      });
    });
  }
});

redefineAll($Observable, {
  from: function from(x) {
    var C = typeof this === 'function' ? this : $Observable;
    var method = getMethod(anObject(x)[OBSERVABLE]);
    if (method) {
      var observable = anObject(method.call(x));
      return observable.constructor === C ? observable : new C(function (observer) {
        return observable.subscribe(observer);
      });
    }
    return new C(function (observer) {
      var done = false;
      microtask(function () {
        if (!done) {
          try {
            if (forOf(x, false, function (it) {
              observer.next(it);
              if (done) return RETURN;
            }) === RETURN) return;
          } catch (e) {
            if (done) throw e;
            observer.error(e);
            return;
          } observer.complete();
        }
      });
      return function () { done = true; };
    });
  },
  of: function of() {
    for (var i = 0, l = arguments.length, items = Array(l); i < l;) items[i] = arguments[i++];
    return new (typeof this === 'function' ? this : $Observable)(function (observer) {
      var done = false;
      microtask(function () {
        if (!done) {
          for (var j = 0; j < items.length; ++j) {
            observer.next(items[j]);
            if (done) return;
          } observer.complete();
        }
      });
      return function () { done = true; };
    });
  }
});

hide($Observable.prototype, OBSERVABLE, function () { return this; });

$export($export.G, { Observable: $Observable });

_dereq_(100)('Observable');

},{"100":100,"128":128,"23":23,"3":3,"33":33,"39":39,"40":40,"42":42,"6":6,"68":68,"7":7,"93":93}],297:[function(_dereq_,module,exports){
// https://github.com/tc39/proposal-promise-finally
var $export = _dereq_(33);
var core = _dereq_(23);
var global = _dereq_(40);
var speciesConstructor = _dereq_(104);
var promiseResolve = _dereq_(91);

$export($export.P + $export.R, 'Promise', { 'finally': function (onFinally) {
  var C = speciesConstructor(this, core.Promise || global.Promise);
  var isFunction = typeof onFinally == 'function';
  return this.then(
    isFunction ? function (x) {
      return promiseResolve(C, onFinally()).then(function () { return x; });
    } : onFinally,
    isFunction ? function (e) {
      return promiseResolve(C, onFinally()).then(function () { throw e; });
    } : onFinally
  );
} });

},{"104":104,"23":23,"33":33,"40":40,"91":91}],298:[function(_dereq_,module,exports){
// https://github.com/tc39/proposal-promise-try
var $export = _dereq_(33);
var newPromiseCapability = _dereq_(69);
var perform = _dereq_(90);

$export($export.S, 'Promise', { 'try': function (callbackfn) {
  var promiseCapability = newPromiseCapability.f(this);
  var result = perform(callbackfn);
  (result.e ? promiseCapability.reject : promiseCapability.resolve)(result.v);
  return promiseCapability.promise;
} });

},{"33":33,"69":69,"90":90}],299:[function(_dereq_,module,exports){
var metadata = _dereq_(67);
var anObject = _dereq_(7);
var toMetaKey = metadata.key;
var ordinaryDefineOwnMetadata = metadata.set;

metadata.exp({ defineMetadata: function defineMetadata(metadataKey, metadataValue, target, targetKey) {
  ordinaryDefineOwnMetadata(metadataKey, metadataValue, anObject(target), toMetaKey(targetKey));
} });

},{"67":67,"7":7}],300:[function(_dereq_,module,exports){
var metadata = _dereq_(67);
var anObject = _dereq_(7);
var toMetaKey = metadata.key;
var getOrCreateMetadataMap = metadata.map;
var store = metadata.store;

metadata.exp({ deleteMetadata: function deleteMetadata(metadataKey, target /* , targetKey */) {
  var targetKey = arguments.length < 3 ? undefined : toMetaKey(arguments[2]);
  var metadataMap = getOrCreateMetadataMap(anObject(target), targetKey, false);
  if (metadataMap === undefined || !metadataMap['delete'](metadataKey)) return false;
  if (metadataMap.size) return true;
  var targetMetadata = store.get(target);
  targetMetadata['delete'](targetKey);
  return !!targetMetadata.size || store['delete'](target);
} });

},{"67":67,"7":7}],301:[function(_dereq_,module,exports){
var Set = _dereq_(231);
var from = _dereq_(10);
var metadata = _dereq_(67);
var anObject = _dereq_(7);
var getPrototypeOf = _dereq_(79);
var ordinaryOwnMetadataKeys = metadata.keys;
var toMetaKey = metadata.key;

var ordinaryMetadataKeys = function (O, P) {
  var oKeys = ordinaryOwnMetadataKeys(O, P);
  var parent = getPrototypeOf(O);
  if (parent === null) return oKeys;
  var pKeys = ordinaryMetadataKeys(parent, P);
  return pKeys.length ? oKeys.length ? from(new Set(oKeys.concat(pKeys))) : pKeys : oKeys;
};

metadata.exp({ getMetadataKeys: function getMetadataKeys(target /* , targetKey */) {
  return ordinaryMetadataKeys(anObject(target), arguments.length < 2 ? undefined : toMetaKey(arguments[1]));
} });

},{"10":10,"231":231,"67":67,"7":7,"79":79}],302:[function(_dereq_,module,exports){
var metadata = _dereq_(67);
var anObject = _dereq_(7);
var getPrototypeOf = _dereq_(79);
var ordinaryHasOwnMetadata = metadata.has;
var ordinaryGetOwnMetadata = metadata.get;
var toMetaKey = metadata.key;

var ordinaryGetMetadata = function (MetadataKey, O, P) {
  var hasOwn = ordinaryHasOwnMetadata(MetadataKey, O, P);
  if (hasOwn) return ordinaryGetOwnMetadata(MetadataKey, O, P);
  var parent = getPrototypeOf(O);
  return parent !== null ? ordinaryGetMetadata(MetadataKey, parent, P) : undefined;
};

metadata.exp({ getMetadata: function getMetadata(metadataKey, target /* , targetKey */) {
  return ordinaryGetMetadata(metadataKey, anObject(target), arguments.length < 3 ? undefined : toMetaKey(arguments[2]));
} });

},{"67":67,"7":7,"79":79}],303:[function(_dereq_,module,exports){
var metadata = _dereq_(67);
var anObject = _dereq_(7);
var ordinaryOwnMetadataKeys = metadata.keys;
var toMetaKey = metadata.key;

metadata.exp({ getOwnMetadataKeys: function getOwnMetadataKeys(target /* , targetKey */) {
  return ordinaryOwnMetadataKeys(anObject(target), arguments.length < 2 ? undefined : toMetaKey(arguments[1]));
} });

},{"67":67,"7":7}],304:[function(_dereq_,module,exports){
var metadata = _dereq_(67);
var anObject = _dereq_(7);
var ordinaryGetOwnMetadata = metadata.get;
var toMetaKey = metadata.key;

metadata.exp({ getOwnMetadata: function getOwnMetadata(metadataKey, target /* , targetKey */) {
  return ordinaryGetOwnMetadata(metadataKey, anObject(target)
    , arguments.length < 3 ? undefined : toMetaKey(arguments[2]));
} });

},{"67":67,"7":7}],305:[function(_dereq_,module,exports){
var metadata = _dereq_(67);
var anObject = _dereq_(7);
var getPrototypeOf = _dereq_(79);
var ordinaryHasOwnMetadata = metadata.has;
var toMetaKey = metadata.key;

var ordinaryHasMetadata = function (MetadataKey, O, P) {
  var hasOwn = ordinaryHasOwnMetadata(MetadataKey, O, P);
  if (hasOwn) return true;
  var parent = getPrototypeOf(O);
  return parent !== null ? ordinaryHasMetadata(MetadataKey, parent, P) : false;
};

metadata.exp({ hasMetadata: function hasMetadata(metadataKey, target /* , targetKey */) {
  return ordinaryHasMetadata(metadataKey, anObject(target), arguments.length < 3 ? undefined : toMetaKey(arguments[2]));
} });

},{"67":67,"7":7,"79":79}],306:[function(_dereq_,module,exports){
var metadata = _dereq_(67);
var anObject = _dereq_(7);
var ordinaryHasOwnMetadata = metadata.has;
var toMetaKey = metadata.key;

metadata.exp({ hasOwnMetadata: function hasOwnMetadata(metadataKey, target /* , targetKey */) {
  return ordinaryHasOwnMetadata(metadataKey, anObject(target)
    , arguments.length < 3 ? undefined : toMetaKey(arguments[2]));
} });

},{"67":67,"7":7}],307:[function(_dereq_,module,exports){
var $metadata = _dereq_(67);
var anObject = _dereq_(7);
var aFunction = _dereq_(3);
var toMetaKey = $metadata.key;
var ordinaryDefineOwnMetadata = $metadata.set;

$metadata.exp({ metadata: function metadata(metadataKey, metadataValue) {
  return function decorator(target, targetKey) {
    ordinaryDefineOwnMetadata(
      metadataKey, metadataValue,
      (targetKey !== undefined ? anObject : aFunction)(target),
      toMetaKey(targetKey)
    );
  };
} });

},{"3":3,"67":67,"7":7}],308:[function(_dereq_,module,exports){
// https://tc39.github.io/proposal-setmap-offrom/#sec-set.from
_dereq_(97)('Set');

},{"97":97}],309:[function(_dereq_,module,exports){
// https://tc39.github.io/proposal-setmap-offrom/#sec-set.of
_dereq_(98)('Set');

},{"98":98}],310:[function(_dereq_,module,exports){
// https://github.com/DavidBruant/Map-Set.prototype.toJSON
var $export = _dereq_(33);

$export($export.P + $export.R, 'Set', { toJSON: _dereq_(20)('Set') });

},{"20":20,"33":33}],311:[function(_dereq_,module,exports){
// https://github.com/mathiasbynens/String.prototype.at
var $export = _dereq_(33);
var $at = _dereq_(106)(true);

$export($export.P, 'String', {
  at: function at(pos) {
    return $at(this, pos);
  }
});

},{"106":106,"33":33}],312:[function(_dereq_,module,exports){
// https://tc39.github.io/String.prototype.matchAll/
var $export = _dereq_(33);
var defined = _dereq_(28);
var toLength = _dereq_(118);
var isRegExp = _dereq_(52);
var getFlags = _dereq_(37);
var RegExpProto = RegExp.prototype;

var $RegExpStringIterator = function (regexp, string) {
  this._r = regexp;
  this._s = string;
};

_dereq_(54)($RegExpStringIterator, 'RegExp String', function next() {
  var match = this._r.exec(this._s);
  return { value: match, done: match === null };
});

$export($export.P, 'String', {
  matchAll: function matchAll(regexp) {
    defined(this);
    if (!isRegExp(regexp)) throw TypeError(regexp + ' is not a regexp!');
    var S = String(this);
    var flags = 'flags' in RegExpProto ? String(regexp.flags) : getFlags.call(regexp);
    var rx = new RegExp(regexp.source, ~flags.indexOf('g') ? flags : 'g' + flags);
    rx.lastIndex = toLength(regexp.lastIndex);
    return new $RegExpStringIterator(rx, S);
  }
});

},{"118":118,"28":28,"33":33,"37":37,"52":52,"54":54}],313:[function(_dereq_,module,exports){
// https://github.com/tc39/proposal-string-pad-start-end
var $export = _dereq_(33);
var $pad = _dereq_(109);

$export($export.P, 'String', {
  padEnd: function padEnd(maxLength /* , fillString = ' ' */) {
    return $pad(this, maxLength, arguments.length > 1 ? arguments[1] : undefined, false);
  }
});

},{"109":109,"33":33}],314:[function(_dereq_,module,exports){
// https://github.com/tc39/proposal-string-pad-start-end
var $export = _dereq_(33);
var $pad = _dereq_(109);

$export($export.P, 'String', {
  padStart: function padStart(maxLength /* , fillString = ' ' */) {
    return $pad(this, maxLength, arguments.length > 1 ? arguments[1] : undefined, true);
  }
});

},{"109":109,"33":33}],315:[function(_dereq_,module,exports){
// https://github.com/sebmarkbage/ecmascript-string-left-right-trim
_dereq_(111)('trimLeft', function ($trim) {
  return function trimLeft() {
    return $trim(this, 1);
  };
}, 'trimStart');

},{"111":111}],316:[function(_dereq_,module,exports){
// https://github.com/sebmarkbage/ecmascript-string-left-right-trim
_dereq_(111)('trimRight', function ($trim) {
  return function trimRight() {
    return $trim(this, 2);
  };
}, 'trimEnd');

},{"111":111}],317:[function(_dereq_,module,exports){
_dereq_(126)('asyncIterator');

},{"126":126}],318:[function(_dereq_,module,exports){
_dereq_(126)('observable');

},{"126":126}],319:[function(_dereq_,module,exports){
// https://github.com/tc39/proposal-global
var $export = _dereq_(33);

$export($export.S, 'System', { global: _dereq_(40) });

},{"33":33,"40":40}],320:[function(_dereq_,module,exports){
// https://tc39.github.io/proposal-setmap-offrom/#sec-weakmap.from
_dereq_(97)('WeakMap');

},{"97":97}],321:[function(_dereq_,module,exports){
// https://tc39.github.io/proposal-setmap-offrom/#sec-weakmap.of
_dereq_(98)('WeakMap');

},{"98":98}],322:[function(_dereq_,module,exports){
// https://tc39.github.io/proposal-setmap-offrom/#sec-weakset.from
_dereq_(97)('WeakSet');

},{"97":97}],323:[function(_dereq_,module,exports){
// https://tc39.github.io/proposal-setmap-offrom/#sec-weakset.of
_dereq_(98)('WeakSet');

},{"98":98}],324:[function(_dereq_,module,exports){
var $iterators = _dereq_(141);
var getKeys = _dereq_(81);
var redefine = _dereq_(94);
var global = _dereq_(40);
var hide = _dereq_(42);
var Iterators = _dereq_(58);
var wks = _dereq_(128);
var ITERATOR = wks('iterator');
var TO_STRING_TAG = wks('toStringTag');
var ArrayValues = Iterators.Array;

var DOMIterables = {
  CSSRuleList: true, // TODO: Not spec compliant, should be false.
  CSSStyleDeclaration: false,
  CSSValueList: false,
  ClientRectList: false,
  DOMRectList: false,
  DOMStringList: false,
  DOMTokenList: true,
  DataTransferItemList: false,
  FileList: false,
  HTMLAllCollection: false,
  HTMLCollection: false,
  HTMLFormElement: false,
  HTMLSelectElement: false,
  MediaList: true, // TODO: Not spec compliant, should be false.
  MimeTypeArray: false,
  NamedNodeMap: false,
  NodeList: true,
  PaintRequestList: false,
  Plugin: false,
  PluginArray: false,
  SVGLengthList: false,
  SVGNumberList: false,
  SVGPathSegList: false,
  SVGPointList: false,
  SVGStringList: false,
  SVGTransformList: false,
  SourceBufferList: false,
  StyleSheetList: true, // TODO: Not spec compliant, should be false.
  TextTrackCueList: false,
  TextTrackList: false,
  TouchList: false
};

for (var collections = getKeys(DOMIterables), i = 0; i < collections.length; i++) {
  var NAME = collections[i];
  var explicit = DOMIterables[NAME];
  var Collection = global[NAME];
  var proto = Collection && Collection.prototype;
  var key;
  if (proto) {
    if (!proto[ITERATOR]) hide(proto, ITERATOR, ArrayValues);
    if (!proto[TO_STRING_TAG]) hide(proto, TO_STRING_TAG, NAME);
    Iterators[NAME] = ArrayValues;
    if (explicit) for (key in $iterators) if (!proto[key]) redefine(proto, key, $iterators[key], true);
  }
}

},{"128":128,"141":141,"40":40,"42":42,"58":58,"81":81,"94":94}],325:[function(_dereq_,module,exports){
var $export = _dereq_(33);
var $task = _dereq_(113);
$export($export.G + $export.B, {
  setImmediate: $task.set,
  clearImmediate: $task.clear
});

},{"113":113,"33":33}],326:[function(_dereq_,module,exports){
// ie9- setTimeout & setInterval additional parameters fix
var global = _dereq_(40);
var $export = _dereq_(33);
var invoke = _dereq_(46);
var partial = _dereq_(88);
var navigator = global.navigator;
var MSIE = !!navigator && /MSIE .\./.test(navigator.userAgent); // <- dirty ie9- check
var wrap = function (set) {
  return MSIE ? function (fn, time /* , ...args */) {
    return set(invoke(
      partial,
      [].slice.call(arguments, 2),
      // eslint-disable-next-line no-new-func
      typeof fn == 'function' ? fn : Function(fn)
    ), time);
  } : set;
};
$export($export.G + $export.B + $export.F * MSIE, {
  setTimeout: wrap(global.setTimeout),
  setInterval: wrap(global.setInterval)
});

},{"33":33,"40":40,"46":46,"88":88}],327:[function(_dereq_,module,exports){
_dereq_(254);
_dereq_(191);
_dereq_(193);
_dereq_(192);
_dereq_(195);
_dereq_(197);
_dereq_(202);
_dereq_(196);
_dereq_(194);
_dereq_(204);
_dereq_(203);
_dereq_(199);
_dereq_(200);
_dereq_(198);
_dereq_(190);
_dereq_(201);
_dereq_(205);
_dereq_(206);
_dereq_(157);
_dereq_(159);
_dereq_(158);
_dereq_(208);
_dereq_(207);
_dereq_(178);
_dereq_(188);
_dereq_(189);
_dereq_(179);
_dereq_(180);
_dereq_(181);
_dereq_(182);
_dereq_(183);
_dereq_(184);
_dereq_(185);
_dereq_(186);
_dereq_(187);
_dereq_(161);
_dereq_(162);
_dereq_(163);
_dereq_(164);
_dereq_(165);
_dereq_(166);
_dereq_(167);
_dereq_(168);
_dereq_(169);
_dereq_(170);
_dereq_(171);
_dereq_(172);
_dereq_(173);
_dereq_(174);
_dereq_(175);
_dereq_(176);
_dereq_(177);
_dereq_(241);
_dereq_(246);
_dereq_(253);
_dereq_(244);
_dereq_(236);
_dereq_(237);
_dereq_(242);
_dereq_(247);
_dereq_(249);
_dereq_(232);
_dereq_(233);
_dereq_(234);
_dereq_(235);
_dereq_(238);
_dereq_(239);
_dereq_(240);
_dereq_(243);
_dereq_(245);
_dereq_(248);
_dereq_(250);
_dereq_(251);
_dereq_(252);
_dereq_(152);
_dereq_(154);
_dereq_(153);
_dereq_(156);
_dereq_(155);
_dereq_(140);
_dereq_(138);
_dereq_(145);
_dereq_(142);
_dereq_(148);
_dereq_(150);
_dereq_(137);
_dereq_(144);
_dereq_(134);
_dereq_(149);
_dereq_(132);
_dereq_(147);
_dereq_(146);
_dereq_(139);
_dereq_(143);
_dereq_(131);
_dereq_(133);
_dereq_(136);
_dereq_(135);
_dereq_(151);
_dereq_(141);
_dereq_(224);
_dereq_(230);
_dereq_(225);
_dereq_(226);
_dereq_(227);
_dereq_(228);
_dereq_(229);
_dereq_(209);
_dereq_(160);
_dereq_(231);
_dereq_(266);
_dereq_(267);
_dereq_(255);
_dereq_(256);
_dereq_(261);
_dereq_(264);
_dereq_(265);
_dereq_(259);
_dereq_(262);
_dereq_(260);
_dereq_(263);
_dereq_(257);
_dereq_(258);
_dereq_(210);
_dereq_(211);
_dereq_(212);
_dereq_(213);
_dereq_(214);
_dereq_(217);
_dereq_(215);
_dereq_(216);
_dereq_(218);
_dereq_(219);
_dereq_(220);
_dereq_(221);
_dereq_(223);
_dereq_(222);
_dereq_(270);
_dereq_(268);
_dereq_(269);
_dereq_(311);
_dereq_(314);
_dereq_(313);
_dereq_(315);
_dereq_(316);
_dereq_(312);
_dereq_(317);
_dereq_(318);
_dereq_(292);
_dereq_(295);
_dereq_(291);
_dereq_(289);
_dereq_(290);
_dereq_(293);
_dereq_(294);
_dereq_(276);
_dereq_(310);
_dereq_(275);
_dereq_(309);
_dereq_(321);
_dereq_(323);
_dereq_(274);
_dereq_(308);
_dereq_(320);
_dereq_(322);
_dereq_(273);
_dereq_(319);
_dereq_(272);
_dereq_(277);
_dereq_(278);
_dereq_(279);
_dereq_(280);
_dereq_(281);
_dereq_(283);
_dereq_(282);
_dereq_(284);
_dereq_(285);
_dereq_(286);
_dereq_(288);
_dereq_(287);
_dereq_(297);
_dereq_(298);
_dereq_(299);
_dereq_(300);
_dereq_(302);
_dereq_(301);
_dereq_(304);
_dereq_(303);
_dereq_(305);
_dereq_(306);
_dereq_(307);
_dereq_(271);
_dereq_(296);
_dereq_(326);
_dereq_(325);
_dereq_(324);
module.exports = _dereq_(23);

},{"131":131,"132":132,"133":133,"134":134,"135":135,"136":136,"137":137,"138":138,"139":139,"140":140,"141":141,"142":142,"143":143,"144":144,"145":145,"146":146,"147":147,"148":148,"149":149,"150":150,"151":151,"152":152,"153":153,"154":154,"155":155,"156":156,"157":157,"158":158,"159":159,"160":160,"161":161,"162":162,"163":163,"164":164,"165":165,"166":166,"167":167,"168":168,"169":169,"170":170,"171":171,"172":172,"173":173,"174":174,"175":175,"176":176,"177":177,"178":178,"179":179,"180":180,"181":181,"182":182,"183":183,"184":184,"185":185,"186":186,"187":187,"188":188,"189":189,"190":190,"191":191,"192":192,"193":193,"194":194,"195":195,"196":196,"197":197,"198":198,"199":199,"200":200,"201":201,"202":202,"203":203,"204":204,"205":205,"206":206,"207":207,"208":208,"209":209,"210":210,"211":211,"212":212,"213":213,"214":214,"215":215,"216":216,"217":217,"218":218,"219":219,"220":220,"221":221,"222":222,"223":223,"224":224,"225":225,"226":226,"227":227,"228":228,"229":229,"23":23,"230":230,"231":231,"232":232,"233":233,"234":234,"235":235,"236":236,"237":237,"238":238,"239":239,"240":240,"241":241,"242":242,"243":243,"244":244,"245":245,"246":246,"247":247,"248":248,"249":249,"250":250,"251":251,"252":252,"253":253,"254":254,"255":255,"256":256,"257":257,"258":258,"259":259,"260":260,"261":261,"262":262,"263":263,"264":264,"265":265,"266":266,"267":267,"268":268,"269":269,"270":270,"271":271,"272":272,"273":273,"274":274,"275":275,"276":276,"277":277,"278":278,"279":279,"280":280,"281":281,"282":282,"283":283,"284":284,"285":285,"286":286,"287":287,"288":288,"289":289,"290":290,"291":291,"292":292,"293":293,"294":294,"295":295,"296":296,"297":297,"298":298,"299":299,"300":300,"301":301,"302":302,"303":303,"304":304,"305":305,"306":306,"307":307,"308":308,"309":309,"310":310,"311":311,"312":312,"313":313,"314":314,"315":315,"316":316,"317":317,"318":318,"319":319,"320":320,"321":321,"322":322,"323":323,"324":324,"325":325,"326":326}],328:[function(_dereq_,module,exports){
(function (global){
/**
 * Copyright (c) 2014, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * https://raw.github.com/facebook/regenerator/master/LICENSE file. An
 * additional grant of patent rights can be found in the PATENTS file in
 * the same directory.
 */

!(function(global) {
var Op = Object.prototype;
  var hasOwn = Op.hasOwnProperty;
  var undefined; // More compressible than void 0.
  var $Symbol = typeof Symbol === "function" ? Symbol : {};
  var iteratorSymbol = $Symbol.iterator || "@@iterator";
  var asyncIteratorSymbol = $Symbol.asyncIterator || "@@asyncIterator";
  var toStringTagSymbol = $Symbol.toStringTag || "@@toStringTag";

  var inModule = typeof module === "object";
  var runtime = global.regeneratorRuntime;
  if (runtime) {
    if (inModule) {
      // If regeneratorRuntime is defined globally and we're in a module,
      // make the exports object identical to regeneratorRuntime.
      module.exports = runtime;
    }
    // Don't bother evaluating the rest of this file if the runtime was
    // already defined globally.
    return;
  }

  // Define the runtime globally (as expected by generated code) as either
  // module.exports (if we're in a module) or a new, empty object.
  runtime = global.regeneratorRuntime = inModule ? module.exports : {};

  function wrap(innerFn, outerFn, self, tryLocsList) {
    // If outerFn provided and outerFn.prototype is a Generator, then outerFn.prototype instanceof Generator.
    var protoGenerator = outerFn && outerFn.prototype instanceof Generator ? outerFn : Generator;
    var generator = Object.create(protoGenerator.prototype);
    var context = new Context(tryLocsList || []);

    // The ._invoke method unifies the implementations of the .next,
    // .throw, and .return methods.
    generator._invoke = makeInvokeMethod(innerFn, self, context);

    return generator;
  }
  runtime.wrap = wrap;

  // Try/catch helper to minimize deoptimizations. Returns a completion
  // record like context.tryEntries[i].completion. This interface could
  // have been (and was previously) designed to take a closure to be
  // invoked without arguments, but in all the cases we care about we
  // already have an existing method we want to call, so there's no need
  // to create a new function object. We can even get away with assuming
  // the method takes exactly one argument, since that happens to be true
  // in every case, so we don't have to touch the arguments object. The
  // only additional allocation required is the completion record, which
  // has a stable shape and so hopefully should be cheap to allocate.
  function tryCatch(fn, obj, arg) {
    try {
      return { type: "normal", arg: fn.call(obj, arg) };
    } catch (err) {
      return { type: "throw", arg: err };
    }
  }

  var GenStateSuspendedStart = "suspendedStart";
  var GenStateSuspendedYield = "suspendedYield";
  var GenStateExecuting = "executing";
  var GenStateCompleted = "completed";

  // Returning this object from the innerFn has the same effect as
  // breaking out of the dispatch switch statement.
  var ContinueSentinel = {};

  // Dummy constructor functions that we use as the .constructor and
  // .constructor.prototype properties for functions that return Generator
  // objects. For full spec compliance, you may wish to configure your
  // minifier not to mangle the names of these two functions.
  function Generator() {}
  function GeneratorFunction() {}
  function GeneratorFunctionPrototype() {}

  // This is a polyfill for %IteratorPrototype% for environments that
  // don't natively support it.
  var IteratorPrototype = {};
  IteratorPrototype[iteratorSymbol] = function () {
    return this;
  };

  var getProto = Object.getPrototypeOf;
  var NativeIteratorPrototype = getProto && getProto(getProto(values([])));
  if (NativeIteratorPrototype &&
      NativeIteratorPrototype !== Op &&
      hasOwn.call(NativeIteratorPrototype, iteratorSymbol)) {
    // This environment has a native %IteratorPrototype%; use it instead
    // of the polyfill.
    IteratorPrototype = NativeIteratorPrototype;
  }

  var Gp = GeneratorFunctionPrototype.prototype =
    Generator.prototype = Object.create(IteratorPrototype);
  GeneratorFunction.prototype = Gp.constructor = GeneratorFunctionPrototype;
  GeneratorFunctionPrototype.constructor = GeneratorFunction;
  GeneratorFunctionPrototype[toStringTagSymbol] =
    GeneratorFunction.displayName = "GeneratorFunction";

  // Helper for defining the .next, .throw, and .return methods of the
  // Iterator interface in terms of a single ._invoke method.
  function defineIteratorMethods(prototype) {
    ["next", "throw", "return"].forEach(function(method) {
      prototype[method] = function(arg) {
        return this._invoke(method, arg);
      };
    });
  }

  runtime.isGeneratorFunction = function(genFun) {
    var ctor = typeof genFun === "function" && genFun.constructor;
    return ctor
      ? ctor === GeneratorFunction ||
        // For the native GeneratorFunction constructor, the best we can
        // do is to check its .name property.
        (ctor.displayName || ctor.name) === "GeneratorFunction"
      : false;
  };

  runtime.mark = function(genFun) {
    if (Object.setPrototypeOf) {
      Object.setPrototypeOf(genFun, GeneratorFunctionPrototype);
    } else {
      genFun.__proto__ = GeneratorFunctionPrototype;
      if (!(toStringTagSymbol in genFun)) {
        genFun[toStringTagSymbol] = "GeneratorFunction";
      }
    }
    genFun.prototype = Object.create(Gp);
    return genFun;
  };

  // Within the body of any async function, `await x` is transformed to
  // `yield regeneratorRuntime.awrap(x)`, so that the runtime can test
  // `hasOwn.call(value, "__await")` to determine if the yielded value is
  // meant to be awaited.
  runtime.awrap = function(arg) {
    return { __await: arg };
  };

  function AsyncIterator(generator) {
    function invoke(method, arg, resolve, reject) {
      var record = tryCatch(generator[method], generator, arg);
      if (record.type === "throw") {
        reject(record.arg);
      } else {
        var result = record.arg;
        var value = result.value;
        if (value &&
            typeof value === "object" &&
            hasOwn.call(value, "__await")) {
          return Promise.resolve(value.__await).then(function(value) {
            invoke("next", value, resolve, reject);
          }, function(err) {
            invoke("throw", err, resolve, reject);
          });
        }

        return Promise.resolve(value).then(function(unwrapped) {
          // When a yielded Promise is resolved, its final value becomes
          // the .value of the Promise<{value,done}> result for the
          // current iteration. If the Promise is rejected, however, the
          // result for this iteration will be rejected with the same
          // reason. Note that rejections of yielded Promises are not
          // thrown back into the generator function, as is the case
          // when an awaited Promise is rejected. This difference in
          // behavior between yield and await is important, because it
          // allows the consumer to decide what to do with the yielded
          // rejection (swallow it and continue, manually .throw it back
          // into the generator, abandon iteration, whatever). With
          // await, by contrast, there is no opportunity to examine the
          // rejection reason outside the generator function, so the
          // only option is to throw it from the await expression, and
          // let the generator function handle the exception.
          result.value = unwrapped;
          resolve(result);
        }, reject);
      }
    }

    if (typeof global.process === "object" && global.process.domain) {
      invoke = global.process.domain.bind(invoke);
    }

    var previousPromise;

    function enqueue(method, arg) {
      function callInvokeWithMethodAndArg() {
        return new Promise(function(resolve, reject) {
          invoke(method, arg, resolve, reject);
        });
      }

      return previousPromise =
        // If enqueue has been called before, then we want to wait until
        // all previous Promises have been resolved before calling invoke,
        // so that results are always delivered in the correct order. If
        // enqueue has not been called before, then it is important to
        // call invoke immediately, without waiting on a callback to fire,
        // so that the async generator function has the opportunity to do
        // any necessary setup in a predictable way. This predictability
        // is why the Promise constructor synchronously invokes its
        // executor callback, and why async functions synchronously
        // execute code before the first await. Since we implement simple
        // async functions in terms of async generators, it is especially
        // important to get this right, even though it requires care.
        previousPromise ? previousPromise.then(
          callInvokeWithMethodAndArg,
          // Avoid propagating failures to Promises returned by later
          // invocations of the iterator.
          callInvokeWithMethodAndArg
        ) : callInvokeWithMethodAndArg();
    }

    // Define the unified helper method that is used to implement .next,
    // .throw, and .return (see defineIteratorMethods).
    this._invoke = enqueue;
  }

  defineIteratorMethods(AsyncIterator.prototype);
  AsyncIterator.prototype[asyncIteratorSymbol] = function () {
    return this;
  };
  runtime.AsyncIterator = AsyncIterator;

  // Note that simple async functions are implemented on top of
  // AsyncIterator objects; they just return a Promise for the value of
  // the final result produced by the iterator.
  runtime.async = function(innerFn, outerFn, self, tryLocsList) {
    var iter = new AsyncIterator(
      wrap(innerFn, outerFn, self, tryLocsList)
    );

    return runtime.isGeneratorFunction(outerFn)
      ? iter // If outerFn is a generator, return the full iterator.
      : iter.next().then(function(result) {
          return result.done ? result.value : iter.next();
        });
  };

  function makeInvokeMethod(innerFn, self, context) {
    var state = GenStateSuspendedStart;

    return function invoke(method, arg) {
      if (state === GenStateExecuting) {
        throw new Error("Generator is already running");
      }

      if (state === GenStateCompleted) {
        if (method === "throw") {
          throw arg;
        }

        // Be forgiving, per 25.3.3.3.3 of the spec:
        // https://people.mozilla.org/~jorendorff/es6-draft.html#sec-generatorresume
        return doneResult();
      }

      context.method = method;
      context.arg = arg;

      while (true) {
        var delegate = context.delegate;
        if (delegate) {
          var delegateResult = maybeInvokeDelegate(delegate, context);
          if (delegateResult) {
            if (delegateResult === ContinueSentinel) continue;
            return delegateResult;
          }
        }

        if (context.method === "next") {
          // Setting context._sent for legacy support of Babel's
          // function.sent implementation.
          context.sent = context._sent = context.arg;

        } else if (context.method === "throw") {
          if (state === GenStateSuspendedStart) {
            state = GenStateCompleted;
            throw context.arg;
          }

          context.dispatchException(context.arg);

        } else if (context.method === "return") {
          context.abrupt("return", context.arg);
        }

        state = GenStateExecuting;

        var record = tryCatch(innerFn, self, context);
        if (record.type === "normal") {
          // If an exception is thrown from innerFn, we leave state ===
          // GenStateExecuting and loop back for another invocation.
          state = context.done
            ? GenStateCompleted
            : GenStateSuspendedYield;

          if (record.arg === ContinueSentinel) {
            continue;
          }

          return {
            value: record.arg,
            done: context.done
          };

        } else if (record.type === "throw") {
          state = GenStateCompleted;
          // Dispatch the exception by looping back around to the
          // context.dispatchException(context.arg) call above.
          context.method = "throw";
          context.arg = record.arg;
        }
      }
    };
  }

  // Call delegate.iterator[context.method](context.arg) and handle the
  // result, either by returning a { value, done } result from the
  // delegate iterator, or by modifying context.method and context.arg,
  // setting context.delegate to null, and returning the ContinueSentinel.
  function maybeInvokeDelegate(delegate, context) {
    var method = delegate.iterator[context.method];
    if (method === undefined) {
      // A .throw or .return when the delegate iterator has no .throw
      // method always terminates the yield* loop.
      context.delegate = null;

      if (context.method === "throw") {
        if (delegate.iterator.return) {
          // If the delegate iterator has a return method, give it a
          // chance to clean up.
          context.method = "return";
          context.arg = undefined;
          maybeInvokeDelegate(delegate, context);

          if (context.method === "throw") {
            // If maybeInvokeDelegate(context) changed context.method from
            // "return" to "throw", let that override the TypeError below.
            return ContinueSentinel;
          }
        }

        context.method = "throw";
        context.arg = new TypeError(
          "The iterator does not provide a 'throw' method");
      }

      return ContinueSentinel;
    }

    var record = tryCatch(method, delegate.iterator, context.arg);

    if (record.type === "throw") {
      context.method = "throw";
      context.arg = record.arg;
      context.delegate = null;
      return ContinueSentinel;
    }

    var info = record.arg;

    if (! info) {
      context.method = "throw";
      context.arg = new TypeError("iterator result is not an object");
      context.delegate = null;
      return ContinueSentinel;
    }

    if (info.done) {
      // Assign the result of the finished delegate to the temporary
      // variable specified by delegate.resultName (see delegateYield).
      context[delegate.resultName] = info.value;

      // Resume execution at the desired location (see delegateYield).
      context.next = delegate.nextLoc;

      // If context.method was "throw" but the delegate handled the
      // exception, let the outer generator proceed normally. If
      // context.method was "next", forget context.arg since it has been
      // "consumed" by the delegate iterator. If context.method was
      // "return", allow the original .return call to continue in the
      // outer generator.
      if (context.method !== "return") {
        context.method = "next";
        context.arg = undefined;
      }

    } else {
      // Re-yield the result returned by the delegate method.
      return info;
    }

    // The delegate iterator is finished, so forget it and continue with
    // the outer generator.
    context.delegate = null;
    return ContinueSentinel;
  }

  // Define Generator.prototype.{next,throw,return} in terms of the
  // unified ._invoke helper method.
  defineIteratorMethods(Gp);

  Gp[toStringTagSymbol] = "Generator";

  // A Generator should always return itself as the iterator object when the
  // @@iterator function is called on it. Some browsers' implementations of the
  // iterator prototype chain incorrectly implement this, causing the Generator
  // object to not be returned from this call. This ensures that doesn't happen.
  // See https://github.com/facebook/regenerator/issues/274 for more details.
  Gp[iteratorSymbol] = function() {
    return this;
  };

  Gp.toString = function() {
    return "[object Generator]";
  };

  function pushTryEntry(locs) {
    var entry = { tryLoc: locs[0] };

    if (1 in locs) {
      entry.catchLoc = locs[1];
    }

    if (2 in locs) {
      entry.finallyLoc = locs[2];
      entry.afterLoc = locs[3];
    }

    this.tryEntries.push(entry);
  }

  function resetTryEntry(entry) {
    var record = entry.completion || {};
    record.type = "normal";
    delete record.arg;
    entry.completion = record;
  }

  function Context(tryLocsList) {
    // The root entry object (effectively a try statement without a catch
    // or a finally block) gives us a place to store values thrown from
    // locations where there is no enclosing try statement.
    this.tryEntries = [{ tryLoc: "root" }];
    tryLocsList.forEach(pushTryEntry, this);
    this.reset(true);
  }

  runtime.keys = function(object) {
    var keys = [];
    for (var key in object) {
      keys.push(key);
    }
    keys.reverse();

    // Rather than returning an object with a next method, we keep
    // things simple and return the next function itself.
    return function next() {
      while (keys.length) {
        var key = keys.pop();
        if (key in object) {
          next.value = key;
          next.done = false;
          return next;
        }
      }

      // To avoid creating an additional object, we just hang the .value
      // and .done properties off the next function object itself. This
      // also ensures that the minifier will not anonymize the function.
      next.done = true;
      return next;
    };
  };

  function values(iterable) {
    if (iterable) {
      var iteratorMethod = iterable[iteratorSymbol];
      if (iteratorMethod) {
        return iteratorMethod.call(iterable);
      }

      if (typeof iterable.next === "function") {
        return iterable;
      }

      if (!isNaN(iterable.length)) {
        var i = -1, next = function next() {
          while (++i < iterable.length) {
            if (hasOwn.call(iterable, i)) {
              next.value = iterable[i];
              next.done = false;
              return next;
            }
          }

          next.value = undefined;
          next.done = true;

          return next;
        };

        return next.next = next;
      }
    }

    // Return an iterator with no values.
    return { next: doneResult };
  }
  runtime.values = values;

  function doneResult() {
    return { value: undefined, done: true };
  }

  Context.prototype = {
    constructor: Context,

    reset: function(skipTempReset) {
      this.prev = 0;
      this.next = 0;
      // Resetting context._sent for legacy support of Babel's
      // function.sent implementation.
      this.sent = this._sent = undefined;
      this.done = false;
      this.delegate = null;

      this.method = "next";
      this.arg = undefined;

      this.tryEntries.forEach(resetTryEntry);

      if (!skipTempReset) {
        for (var name in this) {
          // Not sure about the optimal order of these conditions:
          if (name.charAt(0) === "t" &&
              hasOwn.call(this, name) &&
              !isNaN(+name.slice(1))) {
            this[name] = undefined;
          }
        }
      }
    },

    stop: function() {
      this.done = true;

      var rootEntry = this.tryEntries[0];
      var rootRecord = rootEntry.completion;
      if (rootRecord.type === "throw") {
        throw rootRecord.arg;
      }

      return this.rval;
    },

    dispatchException: function(exception) {
      if (this.done) {
        throw exception;
      }

      var context = this;
      function handle(loc, caught) {
        record.type = "throw";
        record.arg = exception;
        context.next = loc;

        if (caught) {
          // If the dispatched exception was caught by a catch block,
          // then let that catch block handle the exception normally.
          context.method = "next";
          context.arg = undefined;
        }

        return !! caught;
      }

      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        var record = entry.completion;

        if (entry.tryLoc === "root") {
          // Exception thrown outside of any try block that could handle
          // it, so set the completion value of the entire function to
          // throw the exception.
          return handle("end");
        }

        if (entry.tryLoc <= this.prev) {
          var hasCatch = hasOwn.call(entry, "catchLoc");
          var hasFinally = hasOwn.call(entry, "finallyLoc");

          if (hasCatch && hasFinally) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            } else if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else if (hasCatch) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            }

          } else if (hasFinally) {
            if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else {
            throw new Error("try statement without catch or finally");
          }
        }
      }
    },

    abrupt: function(type, arg) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc <= this.prev &&
            hasOwn.call(entry, "finallyLoc") &&
            this.prev < entry.finallyLoc) {
          var finallyEntry = entry;
          break;
        }
      }

      if (finallyEntry &&
          (type === "break" ||
           type === "continue") &&
          finallyEntry.tryLoc <= arg &&
          arg <= finallyEntry.finallyLoc) {
        // Ignore the finally entry if control is not jumping to a
        // location outside the try/catch block.
        finallyEntry = null;
      }

      var record = finallyEntry ? finallyEntry.completion : {};
      record.type = type;
      record.arg = arg;

      if (finallyEntry) {
        this.method = "next";
        this.next = finallyEntry.finallyLoc;
        return ContinueSentinel;
      }

      return this.complete(record);
    },

    complete: function(record, afterLoc) {
      if (record.type === "throw") {
        throw record.arg;
      }

      if (record.type === "break" ||
          record.type === "continue") {
        this.next = record.arg;
      } else if (record.type === "return") {
        this.rval = this.arg = record.arg;
        this.method = "return";
        this.next = "end";
      } else if (record.type === "normal" && afterLoc) {
        this.next = afterLoc;
      }

      return ContinueSentinel;
    },

    finish: function(finallyLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.finallyLoc === finallyLoc) {
          this.complete(entry.completion, entry.afterLoc);
          resetTryEntry(entry);
          return ContinueSentinel;
        }
      }
    },

    "catch": function(tryLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc === tryLoc) {
          var record = entry.completion;
          if (record.type === "throw") {
            var thrown = record.arg;
            resetTryEntry(entry);
          }
          return thrown;
        }
      }

      // The context.catch method must only be called with a location
      // argument that corresponds to a known catch block.
      throw new Error("illegal catch attempt");
    },

    delegateYield: function(iterable, resultName, nextLoc) {
      this.delegate = {
        iterator: values(iterable),
        resultName: resultName,
        nextLoc: nextLoc
      };

      if (this.method === "next") {
        // Deliberately forget the last sent value so that we don't
        // accidentally pass it on to the delegate.
        this.arg = undefined;
      }

      return ContinueSentinel;
    }
  };
})(
  // Among the various tricks for obtaining a reference to the global
  // object, this seems to be the most reliable technique that does not
  // use indirect eval (which violates Content Security Policy).
  typeof global === "object" ? global :
  typeof window === "object" ? window :
  typeof self === "object" ? self : this
);

}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})
},{}]},{},[1]);

// Source: dist/npm/@salaxy/core/salaxy-core-all.js
require=(function(){function r(e,n,t){function o(i,f){if(!n[i]){if(!e[i]){var c="function"==typeof require&&require;if(!f&&c)return c(i,!0);if(u)return u(i,!0);var a=new Error("Cannot find module '"+i+"'");throw a.code="MODULE_NOT_FOUND",a}var p=n[i]={exports:{}};e[i][0].call(p.exports,function(r){var n=e[i][1][r];return o(n||r)},p,p.exports,r,e,n,t)}return n[i].exports}for(var u="function"==typeof require&&require,i=0;i<t.length;i++)o(t[i]);return o}return r})()({"@salaxy/core":[function(require,module,exports){
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
__export(require("./api"));
__export(require("./codegen"));
__export(require("./i18n"));
__export(require("./logic"));
__export(require("./util"));
__export(require("./model"));

},{"./api":33,"./codegen":39,"./i18n":44,"./logic":66,"./model":73,"./util":90}],1:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Provides CRUD access for Absences of a Worker
 */
var Absences = /** @class */ (function (_super) {
    __extends(Absences, _super);
    function Absences(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/v03-rc/api/absences";
        return _this;
    }
    /** Client-side (synchronous) method for getting a new blank item as bases for UI binding. */
    Absences.prototype.getBlank = function (workerId) {
        return {
            employmentId: null,
            workerId: workerId,
            periods: [],
        };
    };
    /**
     * Gets the Absences for a specific employment relation.
     * @param employmentId Identifier for the Employment relation.
     * @return A Promise with Absences.
     */
    Absences.prototype.getForEmployment = function (employmentId) {
        return this.ajax.getJSON(this.baseUrl + "/employment/" + employmentId);
    };
    /**
     * Gets the Absences for the given employment relations.
     * @param employmentIds Identifiers for the Employment relations.
     * @return A Promise with result data array.
     */
    Absences.prototype.getForEmployments = function (employmentIds) {
        if (employmentIds == null || employmentIds.length === 0) {
            return Promise.resolve([]);
        }
        var method = this.baseUrl + "/employment/set?";
        employmentIds.forEach(function (x) { method += "employmentIds=" + encodeURIComponent("" + x) + "&"; });
        method = method.replace(/[?&]$/, "");
        return this.ajax.getJSON(method);
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Absences.$inject = ["AjaxNg1"];
    return Absences;
}(CrudApiBase_1.CrudApiBase));
exports.Absences = Absences;

},{"./CrudApiBase":13}],2:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Methods for updating account information
 */
var Accounts = /** @class */ (function () {
    function Accounts(ajax) {
        this.ajax = ajax;
    }
    /**
     * Gets the current company account if the current account is a company.
     * NOTE: Typically the account data is fetched in Session check => You do not need to fetch it separately.
     *
     * @return A Promise with result data (Company account or null).
     */
    Accounts.prototype.getCompany = function () {
        return this.ajax.getJSON("/accounts/company");
    };
    /**
     * Gets the current Person account:
     * Either the current account or the Primary contact person account if the current account is a company.
     * NOTE: Typically the current account data is fetched in Session check => You do not need to fetch it separately.
     * => Only use this to fetch the Primary contact person account if the current account is a company.
     *
     * @return A Promise with result data (Personal account).
     */
    Accounts.prototype.getPerson = function () {
        return this.ajax.getJSON("/accounts/person");
    };
    /**
     * Gets the current set of products for this account
     *
     * @return A Promise with result data (AccountProducts).
     */
    Accounts.prototype.getProducts = function () {
        return this.ajax.getJSON("/accounts/products/available");
    };
    /**
     * Updates the current set of products for this account
     *
     * @param products - The products object with modified products. You may leave unmodified products as null - they will not be set as null.
     *
     * @return A Promise with result data (updated products).
     */
    Accounts.prototype.updateProducts = function (products) {
        return this.ajax.postJSON("/accounts/products", products);
    };
    /**
     * Switches the current web site usage role.
     *
     * @param role - household or worker. You cannot change to company at the moment using this method.
     *
     * @return A Promise with result data (new role).
     */
    Accounts.prototype.switchRole = function (role) {
        return this.ajax.postJSON("/accounts/switchRole?role=" + role, {});
    };
    /**
     * Sends a verification.
     *
     * @param type - Verification type.
     * @param address - Verification address.
     *
     * @return A Promise with result data (true if succeeded).
     */
    Accounts.prototype.sendVerification = function (type, address) {
        return this.ajax.postJSON("/accounts/verification/" + type, JSON.stringify(address));
    };
    /**
     * Confirms a verification.
     *
     * @param type - Verification type.
     * @param pin - Verification pin code.
     *
     * @return A Promise with result data (true/false).
     */
    Accounts.prototype.confirmVerification = function (type, pin) {
        return this.ajax.postJSON("/accounts/verification/" + type + "/confirm", JSON.stringify(pin));
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Accounts.$inject = ["AjaxNg1"];
    return Accounts;
}());
exports.Accounts = Accounts;

},{}],3:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var Cookies_1 = require("../util/Cookies");
/**
 * Provides wrapper methods for communicating with the Palkkaus.fi API.
 * The raw Ajax-access to the server methods: GET, POST and DELETE
 * with different return types and authentication / error events.
 * This is the JQuery based ajax implementation.
 */
var AjaxJQuery = /** @class */ (function () {
    /**
     * Creates a new instance of AjaxJQuery
     */
    function AjaxJQuery() {
        /**
         * By default (true) the token is set to salaxy-token -cookie.
         * Disable cookies with this flag.
         */
        this.useCookie = true;
        /**
         * By default credentials are not used in http-calls.
         * Enable credentials with this flag.
         */
        this.useCredentials = false;
        /**
         * The server address - root of the server. This is settable field.
         * Will probably be changed to a configuration object in the final version.
         */
        this.serverAddress = "https://test-api.salaxy.com";
        // apiServer
        if (salaxy && salaxy.config && salaxy.config.apiServer) {
            this.serverAddress = salaxy.config.apiServer;
        }
        // useCredentials
        if (salaxy && salaxy.config && salaxy.config.useCredentials != null) {
            this.useCredentials = salaxy.config.useCredentials;
        }
        // useCookie
        if (salaxy && salaxy.config && salaxy.config.useCookie != null) {
            this.useCookie = salaxy.config.useCookie;
        }
    }
    /** Gets the API address with version information. E.g. 'https://test-api.salaxy.com/v02/api' */
    AjaxJQuery.prototype.getApiAddress = function () {
        return this.serverAddress + "/v02/api";
    };
    /** Gets the Server address that is used as bases to the HTML queries. E.g. 'https://test-api.salaxy.com' */
    AjaxJQuery.prototype.getServerAddress = function () {
        return this.serverAddress;
    };
    /**
     * Gets a JSON-message from server using the API
     *
     * @param method - The API method is the url path after the api version segments (e.g. '/v02/api')
     *        and starts with a forward slash, e.g. '/calculator/new', or a full URL address.
     *
     * @return A Promise with result data. Standard Promise rejection to be used for error handling.
     */
    AjaxJQuery.prototype.getJSON = function (method) {
        var token = this.getCurrentToken();
        return this.getJQuery().ajax({
            dataType: "json",
            url: this.getUrl(method),
            xhrFields: {
                withCredentials: (token) ? false : this.useCredentials,
            },
            beforeSend: function (request) {
                if (token) {
                    request.setRequestHeader("Authorization", "Bearer " + token);
                }
            },
        });
    };
    /**
     * Gets a HTML-message from server using the API
     *
     * @param method - The API method is the url path after the api version segments (e.g. '/v02/api')
     *        and starts with a forward slash, e.g. '/calculator/new', or a full URL address.
     *
     * @return A Promise with result html. Standard Promise rejection to be used for error handling.
     */
    AjaxJQuery.prototype.getHTML = function (method) {
        var token = this.getCurrentToken();
        return this.getJQuery().ajax({
            dataType: "html",
            url: this.getUrl(method),
            xhrFields: {
                withCredentials: (token) ? false : this.useCredentials,
            },
            beforeSend: function (request) {
                if (token) {
                    request.setRequestHeader("Authorization", "Bearer " + token);
                }
            },
        });
    };
    /**
     * POSTS data to server and receives back a JSON-message.
     *
     * @param method - The API method is the url path after the api version segments (e.g. '/v02/api')
     *        and starts with a forward slash, e.g. '/calculator/new', or a full URL address.
     * @param data - The data that is posted to the server.
     *
     * @return A Promise with result data. Standard Promise rejection to be used for error handling.
     */
    AjaxJQuery.prototype.postJSON = function (method, data) {
        var token = this.getCurrentToken();
        return this.getJQuery().ajax({
            type: "POST",
            url: this.getUrl(method),
            data: data,
            dataType: "json",
            xhrFields: {
                withCredentials: (token) ? false : this.useCredentials,
            },
            beforeSend: function (request) {
                if (token) {
                    request.setRequestHeader("Authorization", "Bearer " + token);
                }
            },
        });
    };
    /**
     * POSTS data to server and receives back HTML.
     *
     * @param method - The API method is the url starting from api version, e.g. '/v02/api'. E.g. '/calculator/new'
     * @param data - The data that is posted to the server.
     *
     * @return A Promise with result data. Standard Promise rejection to be used for error handling.
     */
    AjaxJQuery.prototype.postHTML = function (method, data) {
        var token = this.getCurrentToken();
        return this.getJQuery().ajax({
            type: "POST",
            url: this.getUrl(method),
            data: data,
            dataType: "html",
            xhrFields: {
                withCredentials: (token) ? false : this.useCredentials,
            },
            beforeSend: function (request) {
                if (token) {
                    request.setRequestHeader("Authorization", "Bearer " + token);
                }
            },
        });
    };
    /**
     * Sends a DELETE-message to server using the API
     *
     * @param method - The API method is the url path after the api version segments (e.g. '/v02/api')
     *        and starts with a forward slash, e.g. '/calculator/new', or a full URL address.
     *
     * @return A Promise with result data. Standard Promise rejection to be used for error handling.
     */
    AjaxJQuery.prototype.remove = function (method) {
        var token = this.getCurrentToken();
        return this.getJQuery().ajax({
            type: "DELETE",
            url: this.getUrl(method),
            xhrFields: {
                withCredentials: (token) ? false : this.useCredentials,
            },
            beforeSend: function (request) {
                if (token) {
                    request.setRequestHeader("Authorization", "Bearer " + token);
                }
            },
        });
    };
    /**
     * Gets the current token.
     * Will check the salaxy-token cookie if the token is persisted there
     */
    AjaxJQuery.prototype.getCurrentToken = function () {
        if (!this.token && this.useCookie) {
            this.token = new Cookies_1.Cookies().get("salaxy-token") || "";
        }
        return this.token;
    };
    /**
     * Sets the current token. The token is set to cookie called "salaxy-token" or
     * if the HTML page is running from local computer, it is set to local storage.
     *
     * @param token - the authentication token to store.
     */
    AjaxJQuery.prototype.setCurrentToken = function (token) {
        if (this.useCookie) {
            new Cookies_1.Cookies().setCookie("salaxy-token", token || "");
        }
        this.token = token;
    };
    /**
     * Implements the OAuth2 "Resource Owner Password Credentials Grant" flow (RFC6749 4.3).
     * This method is not typically used in production web sites - use Implicit Grant instead for client side JavScript (SPAs).
     * However, it is very useful in development, testing, trusted helpers and server-side scenarios.
     */
    AjaxJQuery.prototype.resourceOwnerLogin = function (username, password) {
        var _this = this;
        return this.getJQuery().ajax({
            type: "POST",
            url: this.getServerAddress() + "/oauth2/token",
            data: {
                grant_type: "password",
                username: username,
                password: password,
            },
            success: function (data, textStatus, request) {
                _this.setCurrentToken(data.access_token);
            },
            dataType: "json",
        });
    };
    AjaxJQuery.prototype.getJQuery = function () {
        var jQuery = window.jQuery;
        if (jQuery) {
            return jQuery;
        }
        else {
            throw new Error("ERROR: No jQuery. AjaxJQuery requires jQuery to be referenced.");
        }
    };
    /** If missing, append the API server address to the given url method string */
    AjaxJQuery.prototype.getUrl = function (method) {
        if (!method || method.trim() === "") {
            return null;
        }
        if (method.toLowerCase().startsWith("http")) {
            return method;
        }
        if (method.toLowerCase().startsWith("/v")) {
            return this.getServerAddress() + method;
        }
        return this.getApiAddress() + method;
    };
    return AjaxJQuery;
}());
exports.AjaxJQuery = AjaxJQuery;

},{"../util/Cookies":80}],4:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var Cookies_1 = require("../util/Cookies");
/**
 * Provides wrapper methods for communicating with the Palkkaus.fi API.
 * The raw Ajax-access to the server methods: GET, POST and DELETE
 * with different return types and authentication / error events.
 * This is the XMLHttpRequest based Ajax implementation.
 */
var AjaxXHR = /** @class */ (function () {
    /**
     * Creates a new instance of AjaxXHR
     */
    function AjaxXHR() {
        /**
         * By default (true) the token is set to salaxy-token -cookie.
         * Disable cookies with this flag.
         */
        this.useCookie = true;
        /**
         * The server address - root of the server. This is settable field.
         * Will probably be changed to a configuration object in the final version.
         */
        this.serverAddress = "https://test-api.salaxy.com";
        // apiServer
        if (salaxy && salaxy.config && salaxy.config.apiServer) {
            this.serverAddress = salaxy.config.apiServer;
        }
        // useCredentials
        if (salaxy && salaxy.config && salaxy.config.useCredentials != null) {
            this.useCredentials = salaxy.config.useCredentials;
        }
        // useCookie
        if (salaxy && salaxy.config && salaxy.config.useCookie != null) {
            this.useCookie = salaxy.config.useCookie;
        }
    }
    /** Gets the API address with version information. E.g. 'https://test-api.salaxy.com/v02/api' */
    AjaxXHR.prototype.getApiAddress = function () {
        return this.serverAddress + "/v02/api";
    };
    /** Gets the Server address that is used as bases to the HTML queries. E.g. 'https://test-api.salaxy.com' */
    AjaxXHR.prototype.getServerAddress = function () {
        return this.serverAddress;
    };
    /**
     * Gets a JSON-message from server using the API
     *
     * @param method - The API method is the url path after the api version segments (e.g. '/v02/api')
     *        and starts with a forward slash, e.g. '/calculator/new', or a full URL address.
     *
     * @return A Promise with result data. Standard Promise rejection to be used for error handling.
     */
    AjaxXHR.prototype.getJSON = function (method) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var xhr = _this.createCORSRequest("GET", _this.getUrl(method));
            if (!xhr) {
                return reject(new Error("CORS not supported!"));
            }
            xhr.setRequestHeader("Content-Type", "application/json; charset=UTF-8");
            xhr.setRequestHeader("Accept", "application/json; charset=UTF-8");
            // xhr.setRequestHeader("Cache-Control", "max-age=0");
            var token = _this.getCurrentToken();
            if (token) {
                xhr.setRequestHeader("Authorization", "Bearer " + token);
            }
            xhr.withCredentials = (token) ? false : _this.useCredentials;
            xhr.onreadystatechange = function () {
                if (xhr.readyState === XMLHttpRequest.DONE) {
                    if (xhr.status === 200) {
                        try {
                            var response = JSON.parse(xhr.responseText);
                            return resolve(response);
                        }
                        catch (error) {
                            return reject(error);
                        }
                    }
                    else {
                        return reject(new Error("There was a problem with the request."));
                    }
                }
            };
            xhr.onerror = function () {
                return reject(new Error("There was a problem with the request."));
            };
            xhr.send();
        });
    };
    /**
     * Gets a HTML-message from server using the API
     *
     * @param method - The API method is the url path after the api version segments (e.g. '/v02/api')
     *        and starts with a forward slash, e.g. '/calculator/new', or a full URL address.
     *
     * @return A Promise with result html. Standard Promise rejection to be used for error handling.
     */
    AjaxXHR.prototype.getHTML = function (method) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var xhr = _this.createCORSRequest("GET", _this.getUrl(method));
            if (!xhr) {
                return reject(new Error("CORS not supported!"));
            }
            xhr.setRequestHeader("Content-Type", "application/json; charset=UTF-8");
            xhr.setRequestHeader("Accept", "application/json; charset=UTF-8");
            // xhr.setRequestHeader("Cache-Control", "max-age=0");
            var token = _this.getCurrentToken();
            if (token) {
                xhr.setRequestHeader("Authorization", "Bearer " + token);
            }
            xhr.withCredentials = (token) ? false : _this.useCredentials;
            xhr.onreadystatechange = function () {
                if (xhr.readyState === XMLHttpRequest.DONE) {
                    if (xhr.status === 200) {
                        return resolve(xhr.responseText);
                    }
                    else {
                        return reject(new Error("There was a problem with the request."));
                    }
                }
            };
            xhr.onerror = function () {
                return reject(new Error("There was a problem with the request."));
            };
            xhr.send();
        });
    };
    /**
     * POSTS data to server and receives back a JSON-message.
     *
     * @param method - The API method is the url path after the api version segments (e.g. '/v02/api')
     *        and starts with a forward slash, e.g. '/calculator/new', or a full URL address.
     * @param data - The data that is posted to the server.
     *
     * @return A Promise with result. Standard Promise rejection to be used for error handling.
     */
    AjaxXHR.prototype.postJSON = function (method, data) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var xhr = _this.createCORSRequest("POST", _this.getUrl(method));
            if (!xhr) {
                return reject(new Error("CORS not supported!"));
            }
            xhr.setRequestHeader("Content-Type", "application/json; charset=UTF-8");
            xhr.setRequestHeader("Accept", "application/json; charset=UTF-8");
            // xhr.setRequestHeader("Cache-Control", "max-age=0");
            var token = _this.getCurrentToken();
            if (token) {
                xhr.setRequestHeader("Authorization", "Bearer " + token);
            }
            xhr.withCredentials = (token) ? false : _this.useCredentials;
            xhr.onreadystatechange = function () {
                if (xhr.readyState === XMLHttpRequest.DONE) {
                    if (xhr.status === 200) {
                        try {
                            var response = JSON.parse(xhr.responseText);
                            return resolve(response);
                        }
                        catch (error) {
                            return reject(error);
                        }
                    }
                    else {
                        return reject(new Error("There was a problem with the request."));
                    }
                }
            };
            xhr.onerror = function () {
                return reject(new Error("There was a problem with the request."));
            };
            var params = typeof data === "string" ? data : Object.keys(data).map(function (k) { return encodeURIComponent(k) + "=" + encodeURIComponent(data[k]); }).join("&");
            xhr.send(params);
        });
    };
    /**
     * POSTS data to server and receives back HTML.
     *
     * @param method - The API method is the url path after the api version segments (e.g. '/v02/api')
     *        and starts with a forward slash, e.g. '/calculator/new', or a full URL address.
     * @param data - The data that is posted to the server.
     *
     * @return A Promise with result. Standard Promise rejection to be used for error handling.
     */
    AjaxXHR.prototype.postHTML = function (method, data) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var xhr = _this.createCORSRequest("POST", _this.getUrl(method));
            if (!xhr) {
                return reject(new Error("CORS not supported!"));
            }
            xhr.setRequestHeader("Content-Type", "application/json; charset=UTF-8");
            xhr.setRequestHeader("Accept", "application/json; charset=UTF-8");
            // xhr.setRequestHeader("Cache-Control", "max-age=0");
            var token = _this.getCurrentToken();
            if (token) {
                xhr.setRequestHeader("Authorization", "Bearer " + token);
            }
            xhr.withCredentials = (token) ? false : _this.useCredentials;
            xhr.onreadystatechange = function () {
                if (xhr.readyState === XMLHttpRequest.DONE) {
                    if (xhr.status === 200) {
                        return resolve(xhr.responseText);
                    }
                    else {
                        return reject(new Error("There was a problem with the request."));
                    }
                }
            };
            xhr.onerror = function () {
                return reject(new Error("There was a problem with the request."));
            };
            var params = typeof data === "string" ? data : Object.keys(data).map(function (k) { return encodeURIComponent(k) + "=" + encodeURIComponent(data[k]); }).join("&");
            xhr.send(params);
        });
    };
    /**
     * Sends a DELETE-message to server using the API
     *
     * @param method - The API method is the url path after the api version segments (e.g. '/v02/api')
     *        and starts with a forward slash, e.g. '/calculator/new', or a full URL address.
     *
     * @return A Promise with result. Standard Promise rejection to be used for error handling.
     */
    AjaxXHR.prototype.remove = function (method) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var xhr = _this.createCORSRequest("DELETE", _this.getUrl(method));
            if (!xhr) {
                return reject(new Error("CORS not supported!"));
            }
            xhr.setRequestHeader("Content-Type", "application/json; charset=UTF-8");
            xhr.setRequestHeader("Accept", "application/json; charset=UTF-8");
            // xhr.setRequestHeader("Cache-Control", "max-age=0");
            var token = _this.getCurrentToken();
            if (token) {
                xhr.setRequestHeader("Authorization", "Bearer " + token);
            }
            xhr.withCredentials = (token) ? false : _this.useCredentials;
            xhr.onreadystatechange = function () {
                if (xhr.readyState === XMLHttpRequest.DONE) {
                    if (xhr.status === 200) {
                        try {
                            var response = JSON.parse(xhr.responseText);
                            return resolve(response);
                        }
                        catch (error) {
                            return reject(error);
                        }
                    }
                    else {
                        return reject(new Error("There was a problem with the request."));
                    }
                }
            };
            xhr.onerror = function () {
                return reject(new Error("There was a problem with the request."));
            };
            xhr.send();
        });
    };
    /**
     * Gets the current token.
     * Will check the salaxy-token cookie if the token is persisted there
     */
    AjaxXHR.prototype.getCurrentToken = function () {
        if (!this.token && this.useCookie) {
            this.token = new Cookies_1.Cookies().get("salaxy-token") || "";
        }
        return this.token;
    };
    /**
     * Sets the current token. The token is set to cookie called "salaxy-token" or
     * if the HTML page is running from local computer, it is set to local storage.
     *
     * @param token - the authentication token to store.
     */
    AjaxXHR.prototype.setCurrentToken = function (token) {
        if (this.useCookie) {
            new Cookies_1.Cookies().setCookie("salaxy-token", token || "");
        }
        this.token = token;
    };
    /** If missing, append the API server address to the given url method string */
    AjaxXHR.prototype.getUrl = function (method) {
        if (!method || method.trim() === "") {
            return null;
        }
        if (method.toLowerCase().startsWith("http")) {
            return method;
        }
        if (method.toLowerCase().startsWith("/v")) {
            return this.getServerAddress() + method;
        }
        return this.getApiAddress() + method;
    };
    AjaxXHR.prototype.createCORSRequest = function (method, url) {
        var xhr = new XMLHttpRequest();
        if ("withCredentials" in xhr) {
            // XHR for Chrome/Firefox/Opera/Safari.
            xhr.open(method, url, true);
        }
        else if (typeof XDomainRequest !== "undefined") {
            // XDomainRequest for IE8/9.
            xhr = new XDomainRequest();
            xhr.open(method, url);
        }
        else {
            // CORS not supported.
            xhr = null;
        }
        return xhr;
    };
    return AjaxXHR;
}());
exports.AjaxXHR = AjaxXHR;

},{"../util/Cookies":80}],5:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Provides CRUD access for CMS Articles and other documentation
 */
var Articles = /** @class */ (function (_super) {
    __extends(Articles, _super);
    function Articles(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/cms/articles";
        return _this;
    }
    /** Client-side (synchronous) method for getting a new blank item as bases for UI binding. */
    Articles.prototype.getBlank = function () {
        return {
        //
        };
    };
    /**
     * Gets the article based on its ID.
     * TODO: getSingle or getArticle ?
     *
     * @param articleId Identifier for the article
     * @param articleLinkPattern Optional pattern for CMS links from one article to another.
     *        The default is "/Cms/Article/{0}" where parameter '{0}' is replaced with article id.
     *        The caller can change this to direct internal links to appropriate page template.
     *
     * @return A Promise with article data.
     */
    Articles.prototype.getArticle = function (articleId, articleLinkPattern) {
        if (articleLinkPattern === void 0) { articleLinkPattern = null; }
        var method = this.baseUrl + "/" + articleId;
        if (articleLinkPattern) {
            method += "?articleLinkPattern=" + encodeURIComponent(articleLinkPattern);
        }
        return this.ajax.getJSON(method);
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Articles.$inject = ["AjaxNg1"];
    return Articles;
}(CrudApiBase_1.CrudApiBase));
exports.Articles = Articles;

},{"./CrudApiBase":13}],6:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Provides CRUD access for authenticated user to access a his/her own authorized accounts
 */
var AuthorizedAccounts = /** @class */ (function (_super) {
    __extends(AuthorizedAccounts, _super);
    function AuthorizedAccounts(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/accounts/authorizedAccount";
        return _this;
    }
    /**
     * Returns an empty avatar without any values.
     */
    AuthorizedAccounts.prototype.getBlank = function () {
        return {};
    };
    /**
     * Lists all accounts on behalf of which this account has been authorized to act.
     *
     * @return A Promise with result data (list of account objects).
     */
    // tslint:disable-next-line
    AuthorizedAccounts.prototype.getAuthorizingAccounts = function () {
        var method = "/accounts/authorizingAccount";
        return this.ajax.getJSON(method);
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    AuthorizedAccounts.$inject = ["AjaxNg1"];
    return AuthorizedAccounts;
}(CrudApiBase_1.CrudApiBase));
exports.AuthorizedAccounts = AuthorizedAccounts;

},{"./CrudApiBase":13}],7:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var logic_1 = require("../logic");
var Calculator_1 = require("./Calculator");
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Provides CRUD access for authenticated user to access a his/her own calculations
 */
var Calculations = /** @class */ (function (_super) {
    __extends(Calculations, _super);
    function Calculations(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/calculations";
        _this.calculator = new Calculator_1.Calculator(ajax);
        return _this;
    }
    /** Client-side (synchronous) method for getting a new blank item as bases for UI binding. */
    Calculations.prototype.getBlank = function () {
        return logic_1.CalculatorLogic.getBlank();
    };
    /**
     * Takes in a calculation - typically with modified parameters - and recalculates it.
     * @param calc The salary calculation that should be recalculated
     * @return A Promise with the recalculated Calculation.
     */
    Calculations.prototype.recalculate = function (calc) {
        return this.calculator.recalculate(calc);
    };
    /**
     * Recalculates a calculation taking into account holiday year and absences from the worktime property.
     * This is an anonymous method that can be used for unit testing: Does not read / write from database.
     * @param calc The salary calculation that should be recalculated.
     * Worktime property should contian the bases for the recalculation.
     *
     * @returns A Promise with the recalculated Calculation.
     */
    Calculations.prototype.recalculateWorktime = function (calc) {
        return this.calculator.recalculateWorktime(calc);
    };
    /**
     * Gets the worktime data for Period recalculation based on given calculation
     * but fetching absences and holidays from the database.
     *
     * @param calc The salary calculation that should be recalculated.
     * It may potentially have changes to compared to the one in database or the calc may not have even been saved.
     * The calculation MUST have emloymentId and period set for calculation to work properly.
     * @returns A Promise with Worktime data.
     */
    Calculations.prototype.getWorktimeData = function (calc) {
        return this.ajax.postJSON(this.baseUrl + "/worktime", calc);
    };
    /**
     * Gets the Calculation objects for the given ids.
     * @param ids Identifiers for the Calculation objects.
     * @return A Promise with result data array.
     */
    Calculations.prototype.getMulti = function (ids) {
        if (ids == null || ids.length === 0) {
            return Promise.resolve([]);
        }
        var method = this.baseUrl + "/set?";
        ids.forEach(function (x) { method += "ids=" + encodeURIComponent("" + x) + "&"; });
        method = method.replace(/[?&]$/, "");
        return this.ajax.getJSON(method);
    };
    /**
     * Gets the Calculations for a specific employment relation.
     * @param employmentId Identifier for the Employment relation.
     * @return A Promise with Calculations.
     */
    Calculations.prototype.getForEmployment = function (employmentId) {
        return this.ajax.getJSON(this.baseUrl + "/employment/" + employmentId);
    };
    /**
     * Gets the Calculations for the given employment relations.
     * @param employmentIds Identifiers for the Employment relations.
     * @return A Promise with Calculations.
     */
    Calculations.prototype.getForEmployments = function (employmentIds) {
        if (employmentIds == null || employmentIds.length === 0) {
            return Promise.resolve([]);
        }
        var method = this.baseUrl + "/employment/set?";
        employmentIds.forEach(function (x) { method += "employmentIds=" + encodeURIComponent("" + x) + "&"; });
        method = method.replace(/[?&]$/, "");
        return this.ajax.getJSON(method);
    };
    /**
     * Updates a calculation from employment relation by deleting all the rows and re-setting the employment.
     * @param calc Calculation to update.
     * @param save If true, saves the calculation. If false, only recalculates. Returns the result in any case.
     * @param updateRows If true, updates also the default salary rows from employment data to calculation.
     * False updates only other employment data IBAN, phone, E-mail, pension insurance code message etc.
     * @return The updated and saved or recalculated calculation
     */
    Calculations.prototype.updateFromEmployment = function (calc, save, updateRows) {
        return this.ajax.postJSON(this.baseUrl + "/update-from-employment?save=" + save + "&updateRows=" + updateRows, calc);
    };
    /**
     * Updates (saves) the employment related information from Calculation to Employment relation.
     * Currently only updates rows, OccupationCode and WorkDescription.
     * @param calc Calculation to update.
     * @return The updated and saves employment relation
     */
    Calculations.prototype.updateToEmployment = function (calc) {
        return this.ajax.postJSON(this.baseUrl + "/update-to-employment", calc);
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Calculations.$inject = ["AjaxNg1"];
    return Calculations;
}(CrudApiBase_1.CrudApiBase));
exports.Calculations = Calculations;

},{"../logic":66,"./Calculator":8,"./CrudApiBase":13}],8:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var model_1 = require("../model");
var util_1 = require("../util");
/**
 * Calculator is the main module for creating and modifying salary calculations.
 * The module can be used completely anonymously without any authentication.
 */
var Calculator = /** @class */ (function () {
    function Calculator(ajax) {
        this.ajax = ajax;
    }
    /**
     * OBSOLETE: use CalculatorLogic.getBlank() instead.
     * @deprecated Factory method to create a new calculation on server-side.
     * Typically, you do not need to call server-side factory methods in JavaScript.
     * Instead, you can use client-side factory methods under logic. This saves you one round-trip to server.
     * @hidden
     */
    Calculator.prototype.createNew = function () {
        return this.ajax.getJSON("/calculator/new");
    };
    /**
     * Creates a new calucation with simple salary
     *
     * @param kind The type of the salary.
     * @param [amount=1] The amount of typically hours (could be months etc.). Defaults to 1 if left as null.
     * @param price The price of one unit of amount.
     * @param message Message text for end user - used in salary calculation
     * @param calc The calculation object that should be updated. This is optional - often null, but can be set if you are updating an existing calculation.
     *
     * @return A Promise with the recalculated Calculation.
     */
    Calculator.prototype.calculateSalary = function (kind, amount, price, message, calc) {
        if (calc === void 0) { calc = null; }
        var method = "/calculator/salary?kind=" + kind
            + "&amount=" + util_1.Numeric.parseNumber(amount)
            + "&price=" + util_1.Numeric.parseNumber(price)
            + "&message=" + message;
        return this.ajax.postJSON(method, calc);
    };
    /**
     * Creates a new calculation with the Worker as a specified Person
     *
     * @param calc The calculation object that should be updated.
     * @param profileId The identifier of the Profile that should be set as Worker.
     *
     * @return A Promise with the recalculated Calculation.
     */
    Calculator.prototype.workerSet = function (calc, profileId) {
        return this.ajax.postJSON("/calculator/workerset?profileId=" + profileId, calc);
    };
    /**
     * Sets a household deduction to a calculation
     *
     * @param calc The calculation object to which household deduction is added
     * @param setHouseHoldDeductionTo Boolean to which household
     *
     * @return A Promise with the recalculated Calculation.
     */
    Calculator.prototype.setTaxDeduction = function (calc, setHouseHoldDeductionTo) {
        var method = "/calculator/taxdeduction?setHouseHoldDeduction=" + setHouseHoldDeductionTo;
        return this.ajax.postJSON(method, calc);
    };
    /**
     * Takes in a calculation - typically with modified parameters - and recalculates it.
     *
     * @param calc The salary calculation that should be recalculated
     *
     * @return A Promise with the recalculated Calculation.
     */
    Calculator.prototype.recalculate = function (calc) {
        return this.ajax.postJSON("/calculator/recalculate", calc);
    };
    /**
     * Recalculates a calculation taking into account holiday year and absences from the worktime property.
     * This is an anonymous method that can be used for unit testing: Does not read / write from database.
     * @param calc The salary calculation that should be recalculated.
     * Worktime property should contian the bases for the recalculation.
     *
     * @returns A Promise with the recalculated Calculation.
     */
    Calculator.prototype.recalculateWorktime = function (calc) {
        return this.ajax.postJSON("/calculator/recalculate-worktime", calc);
    };
    /**
     * Gets the worktime data for Period recalculation from raw calc, holidays andabsences data.
     * This is an anonymous method that can be used for unit testing: Does not read / write from database.
     *
     * @param calc The salary calculation that should be recalculated.
     * @param holidayYear Holiday year with holidays that should be added as salary rows. If not provided, holidays are not calculated.
     * @param absences Absences that should be deducted from monthly salary. If not provided, absences are not calculated.
     *
     * @returns A Promise with Worktime data.
     */
    Calculator.prototype.getWorktimeData = function (calc, holidayYear, absences) {
        return this.ajax.postJSON("/calculator/worktime", {
            calc: calc,
            holidayYear: holidayYear,
            absences: absences,
        });
    };
    /**
     * Sets a unionPayment to a calculation
     *
     * @param calc The calculation object to which union payment is added
     * @param paymentType Type of union payment, options are 'notSelected', 'raksaNormal', 'raksaUnemploymentOnly' and 'other'
     * @param unionPaymentPercent How many percents the union payment is from the salary
     *
     * @return A Promise with the recalculated Calculation.
     */
    Calculator.prototype.setUnionPayment = function (calc, paymentType, unionPaymentPercent) {
        var method = "/calculator/setunionpayment?paymentType=" + paymentType
            + "&unionPaymentPercent=" + util_1.Numeric.parseNumber(unionPaymentPercent);
        return this.ajax.postJSON(method, calc);
    };
    /**
     * Adds a calculation row: An expenses, benefits or other such row and returns the recalculated calculation with full data.
     *
     * @param calc The salary calculation that should be modified.
     * @param rowType Type of the calculation row that should be added.
     * @param message Message text for end user - used in salary calculation
     * @param price Price for the row (e.g. €/h, €/km, €/month. Default is 0.
     * @param count Count of the items - default is 1.
     *
     * @return A Promise with the recalculated Calculation.
     */
    Calculator.prototype.addRow = function (calc, rowType, message, price, count) {
        var method = "/calculator/addrow?rowType=" + rowType
            + "&message=" + message
            + "&price=" + util_1.Numeric.parseNumber(price)
            + "&count=" + util_1.Numeric.parseNumber(count);
        return this.ajax.postJSON(method, calc);
    };
    /**
     * Deletes a calculation row: Expenses, benefits etc. item and returns the recalculated calculation with full data.
     *
     * @param calc The salary calculation that should be modified.
     * @param rowIndex Zero based row index of the row that should be deleted.
     *
     * @return A Promise with the recalculated Calculation.
     */
    Calculator.prototype.deleteRow = function (calc, rowIndex) {
        return this.ajax.postJSON("/calculator/deleterow?rowIndex=" + rowIndex, calc);
    };
    /**
     * Gets salary calculation parameters that are changing yearly.
     * The method is designed for the end-of-year and as such it only supports 2 years:
     * the current / previous year (from Jan to Nov) OR current / next year (in approx. December).
     *
     * @param forDate Date for which the numbers are fetched.
     *
     * @return The yearly changing numbers if year supported. Error if year not supported.
     */
    Calculator.prototype.getYearlyChangingNumbers = function (forYear) {
        return util_1.Years.getYearlyChangingNumbers(forYear);
    };
    /**
     * Returns a new Finvoice object for the given calculations.
     * @param calculations Calculations for the Finvoice.
     * @param tableType Accounting table type for the generated Finvoice.
     * @hidden experimental
     */
    Calculator.prototype.getFinvoice = function (calculations, tableType) {
        if (tableType === void 0) { tableType = model_1.AccountingReportTableType.Classic; }
        var method = "/calculator/finvoice/new?";
        method += "tableType=" + encodeURIComponent("" + tableType);
        return this.ajax.postJSON(method, calculations);
    };
    /**
     * Returns a new  earnings payment report content for the given calculation.
     * @param calculation Calculation for the earnings payment report generation.
     * @hidden experimental
     */
    Calculator.prototype.getEarningsPayment = function (calculation) {
        var method = "/calculator/earningsPayment/new";
        return this.ajax.postJSON(method, calculation);
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Calculator.$inject = ["AjaxNg1"];
    return Calculator;
}());
exports.Calculator = Calculator;

},{"../model":73,"../util":90}],9:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Provides CRUD access for authenticated user to access a his/her own Certificates
 */
var Certificates = /** @class */ (function (_super) {
    __extends(Certificates, _super);
    function Certificates(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/accounts/certificate";
        return _this;
    }
    /**
     * Returns an empty certificate without any values.
     */
    Certificates.prototype.getBlank = function () {
        return {};
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Certificates.$inject = ["AjaxNg1"];
    return Certificates;
}(CrudApiBase_1.CrudApiBase));
exports.Certificates = Certificates;

},{"./CrudApiBase":13}],10:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var Accounts_1 = require("./Accounts");
var Calculations_1 = require("./Calculations");
var Calculator_1 = require("./Calculator");
var Cms_1 = require("./Cms");
var Files_1 = require("./Files");
var OAuth2_1 = require("./OAuth2");
var Onboardings_1 = require("./Onboardings");
var Payments_1 = require("./Payments");
var Profiles_1 = require("./Profiles");
var Reports_1 = require("./Reports");
var Session_1 = require("./Session");
var Taxcards_1 = require("./Taxcards");
var Test_1 = require("./Test");
var Workers_1 = require("./Workers");
/**
 * Client to Salaxy API.
 * Abstracts the raw REST api to async methods that are easier to call from TypeScript / JavaScript.
 * Differnet platforms (NG1, NG, jQuery etc.) create derived Clients typically at least by injecting their own Ajax implementation,
 * potentially also by overriding other methods.
 */
var Client = /** @class */ (function () {
    function Client(ajaxImpl) {
        this._ajax = ajaxImpl;
    }
    Object.defineProperty(Client.prototype, "ajax", {
        /** The platform (NG1, NG, jQuery etc.) dependent class that performs the actual Ajax calls */
        get: function () {
            return this._ajax;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Client.prototype, "accountsApi", {
        /** Gets the Accounts API: Access to current account, its products and workers */
        get: function () {
            if (!this._accountsApi) {
                this._accountsApi = new Accounts_1.Accounts(this._ajax);
            }
            return this._accountsApi;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Client.prototype, "calculationsApi", {
        /** Gets the Calculations API: CRUD operations on calculations */
        get: function () {
            if (!this._calculationsApi) {
                this._calculationsApi = new Calculations_1.Calculations(this._ajax);
            }
            return this._calculationsApi;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Client.prototype, "calculatorApi", {
        /** Gets the Calculator API: Anonymous salary calculation methods */
        get: function () {
            if (!this._calculatorApi) {
                this._calculatorApi = new Calculator_1.Calculator(this._ajax);
            }
            return this._calculatorApi;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Client.prototype, "reportsApi", {
        /** Gets the Reports API: Viewing and generating reports in different formats */
        get: function () {
            if (!this._reportsApi) {
                this._reportsApi = new Reports_1.Reports(this._ajax);
            }
            return this._reportsApi;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Client.prototype, "filesApi", {
        /** Gets the Files API: Files stored by the user, thumbnails of pictures etc. */
        get: function () {
            if (!this._filesApi) {
                this._filesApi = new Files_1.Files(this._ajax);
            }
            return this._filesApi;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Client.prototype, "sessionApi", {
        /** Gets the Session API: Access to current session, user and roles */
        get: function () {
            if (!this._sessionApi) {
                this._sessionApi = new Session_1.Session(this._ajax);
            }
            return this._sessionApi;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Client.prototype, "cmsApi", {
        /** Gets the Content Management API: Articles about salary payment and employment in general. */
        get: function () {
            if (!this._cmsApi) {
                this._cmsApi = new Cms_1.Cms(this._ajax);
            }
            return this._cmsApi;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Client.prototype, "profilesApi", {
        /** Gets the Profiles API: Worker profile (Osaajaprofiili) */
        get: function () {
            if (!this._profilesApi) {
                this._profilesApi = new Profiles_1.Profiles(this._ajax);
            }
            return this._profilesApi;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Client.prototype, "paymentsApi", {
        /** Gets the Payments API for paying salaries using different methods */
        get: function () {
            if (!this._paymentsApi) {
                this._paymentsApi = new Payments_1.Payments(this._ajax);
            }
            return this._paymentsApi;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Client.prototype, "oAuth2Api", {
        /** Gets the OAuth2 API: Authentication methods */
        get: function () {
            if (!this._oAuth2Api) {
                this._oAuth2Api = new OAuth2_1.OAuth2(this._ajax);
            }
            return this._oAuth2Api;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Client.prototype, "testApi", {
        /** Gets the Test API: Testing different functionalities of the API and system in general. */
        get: function () {
            if (!this._testApi) {
                this._testApi = new Test_1.Test(this._ajax);
            }
            return this._testApi;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Client.prototype, "taxcardsApi", {
        /** Gets the Tax cards API */
        get: function () {
            if (!this._taxcardsApi) {
                this._taxcardsApi = new Taxcards_1.Taxcards(this._ajax);
            }
            return this._taxcardsApi;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Client.prototype, "workersApi", {
        /** Gets the Workers API */
        get: function () {
            if (!this._workersApi) {
                this._workersApi = new Workers_1.Workers(this._ajax);
            }
            return this._workersApi;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Client.prototype, "onboardingsApi", {
        /** Gets the Onboarding API for creating a new user */
        get: function () {
            if (!this._onboardingsApi) {
                this._onboardingsApi = new Onboardings_1.Onboardings(this._ajax);
            }
            return this._onboardingsApi;
        },
        enumerable: true,
        configurable: true
    });
    return Client;
}());
exports.Client = Client;

},{"./Accounts":2,"./Calculations":7,"./Calculator":8,"./Cms":11,"./Files":16,"./OAuth2":19,"./Onboardings":20,"./Payments":22,"./Profiles":24,"./Reports":25,"./Session":26,"./Taxcards":29,"./Test":30,"./Workers":31}],11:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Read-only access to CMS Articles and other documentation
 */
var Cms = /** @class */ (function () {
    function Cms(ajax) {
        this.ajax = ajax;
    }
    /**
     * Gets articles from the server
     *
     * @param filter is one of the ABC-section categories. Use null to list all the articles.
     *
     * @return A Promise with result data (Article[]).
     */
    Cms.prototype.getArticles = function (filter) {
        var method = "/cms/articles";
        if (filter) {
            method += "?filter=" + filter;
        }
        return this.ajax.getJSON(method);
    };
    /**
     * Gets an article from the server
     *
     * @param id Identifier for the article
     * @param articleLinkPattern Optional pattern for CMS links from one article to another.
     *        The default is "/Cms/Article/{0}" where parameter '{0}' is replaced with article id.
     *        The caller can change this to direct internal links to appropriate page template.
     *
     * @return A Promise with result data (Article).
     */
    Cms.prototype.getArticle = function (id, articleLinkPattern) {
        if (articleLinkPattern === void 0) { articleLinkPattern = null; }
        var method = "/cms/articles/" + id;
        if (articleLinkPattern) {
            method += "?articleLinkPattern=" + encodeURIComponent(articleLinkPattern);
        }
        return this.ajax.getJSON(method);
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Cms.$inject = ["AjaxNg1"];
    return Cms;
}());
exports.Cms = Cms;

},{}],12:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Provides CRUD access for authenticated user to access all credentials which can access this account.
 */
var Credentials = /** @class */ (function (_super) {
    __extends(Credentials, _super);
    function Credentials(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/accounts/credential";
        return _this;
    }
    /**
     * Returns an empty credential without any values.
     */
    Credentials.prototype.getBlank = function () {
        return {};
    };
    /**
     * Returns the url where to post the avatar file
     */
    Credentials.prototype.getAvatarUploadUrl = function (credentialId) {
        return this.ajax.getApiAddress()
            + this.baseUrl
            + (credentialId ? "/" + credentialId : "")
            + "/avatar";
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Credentials.$inject = ["AjaxNg1"];
    return Credentials;
}(CrudApiBase_1.CrudApiBase));
exports.Credentials = Credentials;

},{"./CrudApiBase":13}],13:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var util_1 = require("../util");
/** Base class for CRUD services. */
var CrudApiBase = /** @class */ (function () {
    /** Constructor creates a new CRUD api with given Ajax-implementation */
    function CrudApiBase(ajax) {
        this.ajax = ajax;
    }
    /**
     * Makes an OData query to the service's main OData method.
     * @param query The options for the query: Filter, search sort etc.
     * This is either a strongly typed object or query string that is added directly.
     */
    CrudApiBase.prototype.getOData = function (query) {
        // TODO: Make result strongly typed: A second Generic parameter of the class.
        var baseUrl = this.getODataUrl();
        var fullPath;
        if (typeof query === "string") {
            query = query.trim();
            if (query.length > 0 && query.substr(0, 1) === "?") {
                query = query.substr(1);
            }
            fullPath = (query.length === 0) ? baseUrl : (baseUrl + "?" + query);
        }
        else {
            query = query || {};
            if (util_1.Token.validate(this.ajax.getCurrentToken()) !== "ok" && !query.anon) {
                throw new Error("OData call without token and anon option not set to true.");
            }
            fullPath = util_1.OData.getUrl(baseUrl, query);
        }
        return this.ajax.getJSON(fullPath).then(function (data) {
            return util_1.OData.getODataResult(data);
        });
    };
    /**
     * Gets all the items of a given type.
     * @return A Promise with result data array.
     */
    CrudApiBase.prototype.getAll = function () {
        return this.ajax.getJSON(this.baseUrl);
    };
    /**
     * Gets a single item based on identier
     * @param id - Unique identifier for the object
     * @return A Promise with result data.
     */
    CrudApiBase.prototype.getSingle = function (id) {
        return this.ajax.getJSON(this.baseUrl + "/" + id);
    };
    /**
     * Deletes an single item from the sotrage
     * @param id - Unique identifier for the object
     * @return A Promise with result data "Object deleted".
     */
    CrudApiBase.prototype.delete = function (id) {
        return this.ajax.remove(this.baseUrl + "/" + id);
    };
    /**
     * Saves an item to the storage.
     * If id is null, this is add/insert. If id exists, this is update.
     * @param itemToSave - The item that is updated/inserted.
     * @return A Promise with result data as saved to the storage (contains id, createAt, owner etc.).
     */
    CrudApiBase.prototype.save = function (itemToSave) {
        return this.ajax.postJSON(this.baseUrl + "/", itemToSave);
    };
    /** Gets the OData URL for v03 compatible services */
    CrudApiBase.prototype.getODataUrl = function () {
        if (this.baseUrl.startsWith("/v03")) {
            // e.g. "/v03-rc/api/messages"
            return this.baseUrl;
        }
        // Backporting the OData features to v02 version API's
        switch (this.baseUrl) {
            case "/cms/articles":
                return "/v03-rc/api/cms/articles";
            case "/accounts/workers":
                // This API now really returns employment relations, not workers. Will probably not change this in v03 scope
                return "/v03-rc/api/accounts/workers";
            case "/calculations":
                return "/v03-rc/api/calculations/all";
            case "/taxcards/owned":
                return "/v03-rc/api/taxcards";
            // TODO: Should be implemented ASAP
            case "/nir/earningsPayment":
            case "/esalary":
            case "/payments":
            // TODO: Account based - probably implement
            case "/accounts/certificate":
            case "/accounts/credential":
            case "/accounts/authorizedAccount":
                throw new Error("getODataUrl() not implemented for: " + this.baseUrl);
            case "/absences":
            case "/holidays/all":
                throw new Error("getODataUrl() is only implemented in Version 03 for: " + this.baseUrl);
            case "/yearEnd/feedback":
                throw new Error("Year end is depricated and OData querying does not make sense for YearEnd in any case (because there is only on per year).");
        }
        throw new Error("Service " + this.baseUrl + " does not support OData interface.");
    };
    /** Returns the base url for this api. */
    CrudApiBase.prototype.getBaseUrl = function () {
        return this.baseUrl;
    };
    /**
     * Adds/updates the workflow event for the item.
     *
     * @param item - Item for which to set the workflow event.
     * @param wfEvent - Event to add or update.
     * @return Workflow data for the item.
     */
    CrudApiBase.prototype.saveWorkflowEvent = function (item, wfEvent) {
        return this.ajax.postJSON(this.baseUrl + "/" + item.id + "/workflows", wfEvent);
    };
    /**
     * Deletes the worklflow item or items from the item.
     * @param item - Item for which to delete workflow events.
     * @param wfIdOrType - Event id or type.
     * @return A Promise with result data "Object deleted".
     */
    CrudApiBase.prototype.deleteWorkflowEvent = function (item, wfIdOrType) {
        return this.ajax.remove(this.baseUrl + "/" + item.id + "/workflows/" + wfIdOrType);
    };
    return CrudApiBase;
}());
exports.CrudApiBase = CrudApiBase;

},{"../util":90}],14:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Provides CRUD access for authenticated user to access a his/her own E-salary payments
 */
var ESalaryPayments = /** @class */ (function (_super) {
    __extends(ESalaryPayments, _super);
    function ESalaryPayments(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/esalary";
        return _this;
    }
    /** Client-side (synchronous) method for getting a new blank item as bases for UI binding. */
    ESalaryPayments.prototype.getBlank = function () {
        return {
            calc: {},
            household: {},
            request: {},
        };
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    ESalaryPayments.$inject = ["AjaxNg1"];
    return ESalaryPayments;
}(CrudApiBase_1.CrudApiBase));
exports.ESalaryPayments = ESalaryPayments;

},{"./CrudApiBase":13}],15:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Provides CRUD access for authenticated user to access a his/her own Earnings Payments objects
 */
var EarningsPayments = /** @class */ (function (_super) {
    __extends(EarningsPayments, _super);
    function EarningsPayments(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = null;
        _this.baseUrl = ajax.getServerAddress() + "/nir/earningsPayment";
        return _this;
    }
    /** Client-side (synchronous) method for getting a new blank item as bases for UI binding. */
    EarningsPayments.prototype.getBlank = function () {
        return {
            deliveryData: {},
            info: {},
            validation: {},
        };
    };
    /**
     * Validates an Earnings Payment object for delivery.
     * @param earningsPaymentToValidate Earnings payment that should be validated.
     * @returns The Earnings Payment object with validation.
     */
    EarningsPayments.prototype.validate = function (earningsPaymentToValidate) {
        return this.ajax.postJSON(this.baseUrl + "/validate", earningsPaymentToValidate);
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    EarningsPayments.$inject = ["AjaxNg1"];
    return EarningsPayments;
}(CrudApiBase_1.CrudApiBase));
exports.EarningsPayments = EarningsPayments;

},{"./CrudApiBase":13}],16:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Provides access to user files (of the authenticated user).
 */
var Files = /** @class */ (function (_super) {
    __extends(Files, _super);
    function Files(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/v03-rc/api/files";
        return _this;
    }
    /**
     * Gets a list of files - filtered by a type
     *
     * @param type: Logical file type.
     *
     * @return A Promise with result data (list of files).
     */
    Files.prototype.filesOfType = function (type) {
        return this.ajax.getJSON(this.baseUrl + "/type/" + type);
    };
    /**
     * Returns the content url for the file id.
     * The returned url is not escaped and does not contain access token.
     * @param fileUri - Identifier of the file.
     */
    Files.prototype.getContentUrl = function (id) {
        return this.ajax.getApiAddress() + "/" + this.baseUrl + "/" + id + "/stream";
    };
    /**
     * Returns the preview image url for the file id.
     * The returned url is not escaped and does not contain access token.
     * @param id - Identifier of the file.
     */
    Files.prototype.getPreviewUrl = function (id) {
        return this.ajax.getApiAddress() + "/" + this.baseUrl + "/" + id + "/preview";
    };
    /**
     * Downloads the content as bytes.
     * @param id - The identifier of the file.
     */
    Files.prototype.download = function (id) {
        return this.ajax.getJSON(this.baseUrl + "/" + id + "/content");
    };
    /**
     * Client-side (synchronous) method for getting a new blank CRUD item as bases for UI binding.
     * The basic idea is that all the child object properties should be non-null to avoid null reference exceptions.
     * In special cases, when null is significant it may be used: e.g. Calculation.result is null untill the recalculation has been done.
     * Strings, dates and booleans may be null (false if bool), but typically just undefined.
     */
    Files.prototype.getBlank = function () {
        throw new Error("Not supported.");
    };
    /**
     * Gets all the items of a given type.
     * @return A Promise with result data array.
     */
    Files.prototype.getAll = function () {
        throw new Error("Not supported.");
    };
    /**
     * Deletes an single item from the sotrage
     * @param id - Unique identifier for the object
     * @return A Promise with result data "Object deleted".
     */
    Files.prototype.delete = function (id) {
        throw new Error("Not supported.");
    };
    /**
     * Saves an item to the storage.
     * If id is null, this is add/insert. If id exists, this is update.
     * @param itemToSave - The item that is updated/inserted.
     * @return A Promise with result data as saved to the storage (contains id, createAt, owner etc.).
     */
    Files.prototype.save = function (itemToSave) {
        throw new Error("Not supported.");
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Files.$inject = ["AjaxNg1"];
    return Files;
}(CrudApiBase_1.CrudApiBase));
exports.Files = Files;

},{"./CrudApiBase":13}],17:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var logic_1 = require("../logic");
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Provides CRUD access for Holiday Years as a raw list and
 * more typically as holiday years relate to an employment relation.
 */
var HolidayYears = /** @class */ (function (_super) {
    __extends(HolidayYears, _super);
    function HolidayYears(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/v03-rc/api/holidays";
        return _this;
    }
    /** Client-side (synchronous) method for getting a new blank item as bases for UI binding. */
    HolidayYears.prototype.getBlank = function () {
        return logic_1.HolidaysLogic.getBlank();
    };
    /**
     * Gets a default holiday specification based on employment relation information.
     * This is presented to the user before calling initForEmployment().
     * @param employmentId The employment relation ID from which the defaults are fetched.
     * @returns Holiday specification that can be used for inititalization.
     */
    HolidayYears.prototype.getDefaultSpecForEmployment = function (employmentId) {
        var url = this.baseUrl + "/employment/" + employmentId + "/default-spec";
        return this.ajax.getJSON(url);
    };
    /**
     * Initializes (or re-creates) the holiday years for an employment relation.
     * @param employmentId Identifier of the Employment relation that stores the holiday specification.
     * @param holidaySpec The holiday specification tht should be used for inititalization. The spec is also stored to the Employment relation.
     * @returns Holiday years for this employment relation - as initialized.
     */
    HolidayYears.prototype.initForEmployment = function (employmentId, holidaySpec) {
        var url = this.baseUrl + "/employment/" + employmentId;
        return this.ajax.postJSON(url, holidaySpec);
    };
    /**
     * Gets the Holiday Years for a specific employment relation.
     * @param employmentId Identifier for the Employment relation.
     * @return A Promise with Holiday Years.
     */
    HolidayYears.prototype.getForEmployment = function (employmentId) {
        return this.ajax.getJSON(this.baseUrl + "/employment/" + employmentId);
    };
    /**
     * Gets the Holiday Years for the given employment relations.
     * @param employmentIds Identifiers for the Employment relations.
     * @return A Promise with Holiday Years.
     */
    HolidayYears.prototype.getForEmployments = function (employmentIds) {
        if (employmentIds == null || employmentIds.length === 0) {
            return Promise.resolve([]);
        }
        var method = "${this.baseUrl}/employment/set?";
        employmentIds.forEach(function (x) { method += "employmentIds=" + encodeURIComponent("" + x) + "&"; });
        method = method.replace(/[?&]$/, "");
        return this.ajax.getJSON(method);
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    HolidayYears.$inject = ["AjaxNg1"];
    return HolidayYears;
}(CrudApiBase_1.CrudApiBase));
exports.HolidayYears = HolidayYears;

},{"../logic":66,"./CrudApiBase":13}],18:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Provides CRUD access for Message threads.
 */
var MessageThreads = /** @class */ (function (_super) {
    __extends(MessageThreads, _super);
    function MessageThreads(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/v03-rc/api/messages";
        return _this;
    }
    /** Gets a new blank message thread. */
    MessageThreads.prototype.getBlank = function () {
        return {
            messages: [],
        };
    };
    /**
     * Adds a new message with text.
     * @param id Identifier of the messages thread.
     * @param message The message to add.
     */
    MessageThreads.prototype.addMessage = function (id, message) {
        var method = this.baseUrl + "/" + id + "/messages";
        return this.ajax.postJSON(method, message);
    };
    /**
     * Gets the upload URL for attachment files of a message thread.
     * This URL is compatible with the HTML forms standard multipart/form-data upload.
     * @param id Identifier of the messages thread.
     * @returns The URL for multipart/form-data upload
     */
    MessageThreads.prototype.getUploadUrl = function (id) {
        return "" + this.ajax.getServerAddress() + this.baseUrl + "/" + id + "/files";
    };
    /**
     * Marks all messages as read by a given party
     * @param id Identifier of the thread
     * @param readBy The party for which the messages are marked as read.
     * @returns The entire thread with the messages marked as read.
     */
    MessageThreads.prototype.markAsRead = function (id, readBy) {
        var method = this.baseUrl + "/" + id + "/read-by/" + readBy;
        return this.ajax.postJSON(method, null);
    };
    /**
     * Sends an email notification to the owner of the message thread.
     * @param id Identifier of the thread
     * @param subject Subject of the notification.
     * @param body Body of the notification.
     * @returns A boolean indicating if the email was sent successfully.
     */
    MessageThreads.prototype.sendNotification = function (id, subject, body) {
        var method = this.baseUrl + "/" + id + "/notifications?subject=" + encodeURIComponent(subject);
        return this.ajax.postJSON(method, JSON.stringify(body));
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    MessageThreads.$inject = ["AjaxNg1"];
    return MessageThreads;
}(CrudApiBase_1.CrudApiBase));
exports.MessageThreads = MessageThreads;

},{"./CrudApiBase":13}],19:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Methods for oauth2 communication.
 */
var OAuth2 = /** @class */ (function () {
    function OAuth2(ajax) {
        this.ajax = ajax;
    }
    /**
     * Token endpoint.
     *
     * @param msg - OAuth 2.0 authorization request.
     *
     * @return A Promise with OAuthMessage.
     */
    OAuth2.prototype.token = function (msg) {
        return this.ajax.postJSON(this.ajax.getServerAddress() + "/oauth2/token", msg);
    };
    /**
     * Gets a federation message for the currently signed-in account as OpenID Connect UserInfo Response
     * (http://openid.net/specs/openid-connect-core-1_0.html#UserInfo).
     * This message can be used by trusted authentication providers (mainly Banks) to federate authentication and authorization information to Salaxy.
     * In such a flow this service end-point provides an example that could be used in testing.
     *
     * @return A Promise with federation message {OpenIdUserInfoSupportedClaims}.
     */
    OAuth2.prototype.getFederationMessage = function () {
        return this.ajax.getJSON(this.ajax.getServerAddress() + "/oauth2/federationMessage");
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    OAuth2.$inject = ["AjaxNg1"];
    return OAuth2;
}());
exports.OAuth2 = OAuth2;

},{}],20:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Provides functionality for Onboarding:
 * The process where the user becomes a user of Salaxy service and an account is created for him / her / the company.
 */
var Onboardings = /** @class */ (function () {
    function Onboardings(ajax) {
        this.ajax = ajax;
    }
    /**
     * Gets a single Onboarding object based on identier
     *
     * @param id - Unique identifier for the object
     *
     * @return A Promise with result data (Onboarding).
     */
    Onboardings.prototype.getOnboarding = function (id) {
        return this.ajax.getJSON("/onboarding/" + encodeURIComponent("" + id));
    };
    /**
     * Gets a single Onboarding object for authorizing account
     *
     * @param accountId - Account id of the authorizing account.
     *
     * @return A Promise with result data (Onboarding).
     */
    Onboardings.prototype.getOnboardingForAccount = function (accountId) {
        return this.ajax.getJSON("/onboarding/account/" + encodeURIComponent("" + accountId));
    };
    /**
     * Creates or updates an Onboarding.
     *
     * @param onboarding - The Onboarding object that is updated.
     *
     * @return A Promise with result data (saved Onboarding).
     */
    Onboardings.prototype.saveOnboarding = function (onboarding) {
        return this.ajax.postJSON("/onboarding", onboarding);
    };
    /**
     * Deletes an onboarding object from the storage
     *
     * @param id - Unique identifier for the object
     *
     * @return A Promise with result data "Object deleted".
     */
    Onboardings.prototype.deleteOnboarding = function (id) {
        return this.ajax.remove("/onboarding/" + encodeURIComponent("" + id));
    };
    /**
     * Sends a new pin code to the telephone number to be verified in onboarding.
     *
     * @param onboarding - The Onboarding object which contains the telephone number.
     *
     * @return A Promise with result data (true if sending succeeded).
     */
    Onboardings.prototype.sendSmsVerificationPin = function (onboarding) {
        return this.ajax.postJSON("/onboarding/verification/sms", onboarding);
    };
    /**
     * Commits onboarding and creates/updates the account.
     *
     * @param onboarding - The Onboarding object that is to be committed..
     *
     * @return A Promise with result data (committed Onboarding).
     */
    Onboardings.prototype.commitOnboarding = function (onboarding) {
        return this.ajax.postJSON("/onboarding/commit", onboarding);
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Onboardings.$inject = ["AjaxNg1"];
    return Onboardings;
}());
exports.Onboardings = Onboardings;

},{}],21:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * API for partner services, like pension, insurance and health care.
 */
var PartnerServices = /** @class */ (function () {
    function PartnerServices(ajax) {
        this.ajax = ajax;
    }
    /**
     * Returns a new Varma pension order with default values for the current account.
     */
    PartnerServices.prototype.getNewVarmaPensionOrder = function () {
        return this.ajax.getJSON("/partner-services/varma/pension/new");
    };
    /**
     * Validate the given Varma pension order in the server.
     */
    PartnerServices.prototype.validateVarmaPensionOrder = function (order) {
        return this.ajax.postJSON("/partner-services/varma/pension/validate", order);
    };
    /**
     * Send a new Varma pension order for later processing.
     */
    PartnerServices.prototype.sendVarmaPensionOrder = function (order) {
        return this.ajax.postJSON("/partner-services/varma/pension/order", order);
    };
    /**
     * Returns a new If insurance order with default values for the current account.
     */
    PartnerServices.prototype.getNewIfInsuranceOrder = function () {
        return this.ajax.getJSON("/partner-services/if/insurance/new");
    };
    /**
     * Validate the given If insurance order in the server.
     */
    PartnerServices.prototype.validateIfInsuranceOrder = function (order) {
        return this.ajax.postJSON("/partner-services/if/insurance/validate", order);
    };
    /**
     * Send a new If insurance order for later processing.
     */
    PartnerServices.prototype.sendIfInsuranceOrder = function (order) {
        return this.ajax.postJSON("/partner-services/if/insurance/order", order);
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    PartnerServices.$inject = ["AjaxNg1"];
    return PartnerServices;
}());
exports.PartnerServices = PartnerServices;

},{}],22:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var model_1 = require("../model");
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Methods for payment creation and processing.
 */
var Payments = /** @class */ (function (_super) {
    __extends(Payments, _super);
    function Payments(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/payments";
        return _this;
    }
    /** Client-side (synchronous) method for getting a new blank item as bases for UI binding. */
    Payments.prototype.getBlank = function () {
        return {
            payer: {},
            recipient: {},
            businessObjects: [],
            request: {},
        };
    };
    /**
     * List payments for the current user.
     *
     * @param status - Payment status filter. If null or empty, returns all statuses.
     *
     * @return A Promise with result data (list of payments).
     */
    Payments.prototype.getPayments = function (status) {
        if (!status) {
            return this.getAll();
        }
        var method = "/payments?";
        if (status) {
            status.forEach(function (item) { method += "status=" + encodeURIComponent("" + item) + "&"; });
        }
        method = method.replace(/[?&]$/, "");
        return this.ajax.getJSON(method);
    };
    /**
     * Gets a single payment object based on identifier.
     *
     * @param id - Unique identifier for the payment.
     *
     * @return A Promise with result data (Payment).
     */
    Payments.prototype.getPayment = function (id) {
        return this.getSingle(id);
    };
    /**
     * Deletes a payment.
     *
     * @param id - Unique identifier for the payment.
     *
     * @return A Promise with result data "Object deleted".
     */
    Payments.prototype.deletePayment = function (id) {
        return this.delete(id);
    };
    /**
     * OBSOLETE
     * @deprecated Creates a new SalaryGrossPayment (startPayment will replace this method).
     * @hidden
     *
     * @param calculationIds - Array of calculation ids.
     * @param successUrl - Return address after successful payment
     * @param cancelUrl - Return address after cancelled payment
     * @param sendEmails - Boolean indicating whether to send emails in the workflow
     *
     * @return A Promise with result data (created Payment).
     */
    Payments.prototype.createSalaryGrossPayment = function (calculationIds, successUrl, cancelUrl, sendEmails) {
        var method = "/payments/salaryGrossPayment?";
        calculationIds.forEach(function (item) { method += "calculationIds=" + encodeURIComponent("" + item) + "&"; });
        method += "successUrl=" + encodeURIComponent("" + successUrl) + "&";
        method += "cancelUrl=" + encodeURIComponent("" + cancelUrl) + "&";
        method += "sendEmails=" + encodeURIComponent("" + sendEmails);
        return this.ajax.postJSON(method, calculationIds);
    };
    /**
     * Creates/updates the SalaryGrossPayment.
     * If a payment for the same calculation ids exist, it will be updated and no new payment
     * is created.
     *
     * @param calculationIds - Array of calculation ids.
     * @param paymentMethod - Payment method.
     * @param successUrl - Return address after successful payment
     * @param cancelUrl - Return address after cancelled payment
     * @param sendEmails - Boolean indicating whether to send emails in the workflow
     *
     * @return A Promise with result data (created Payment).
     */
    Payments.prototype.startPayment = function (calculationIds, paymentMethod, successUrl, cancelUrl, sendEmails) {
        var method = "/payments?";
        calculationIds.forEach(function (item) { method += "calculationIds=" + encodeURIComponent("" + item) + "&"; });
        method += "paymentMethod=" + encodeURIComponent("" + paymentMethod) + "&";
        method += "successUrl=" + encodeURIComponent("" + successUrl) + "&";
        method += "cancelUrl=" + encodeURIComponent("" + cancelUrl) + "&";
        method += "sendEmails=" + encodeURIComponent("" + sendEmails);
        return this.ajax.postJSON(method, {});
    };
    /**
     * Gets a new finvoice object for the given payment.
     * @param id - The payment id which the finvoice will be returned for.
     * @param tableType - Accounting table type for the generated Finvoice.
     * @hidden - experimental
     */
    Payments.prototype.getFinvoice = function (id, tableType) {
        if (tableType === void 0) { tableType = model_1.AccountingReportTableType.Classic; }
        var method = this.baseUrl + "/" + id + "/finvoice?";
        method += "tableType=" + encodeURIComponent("" + tableType);
        return this.ajax.postJSON(method, "");
    };
    /**
     * Sends the finvoice object to operator.
     * @param finvocie - Finvoice for the delivery.
     *
     * @return Finvoice which was sent.
     * @hidden - experimental
     */
    Payments.prototype.sendFinvoice = function (finvoice) {
        var method = this.baseUrl + "/finvoice";
        return this.ajax.postJSON(method, finvoice);
    };
    /**
     * Returns the url for starting the payment process for the payroll.
     * @param calculationIds - Array of calculation ids.
     * @param paymentMethod - Payment method.
     * @param successUrl - Return address after successful payment
     * @param cancelUrl - Return address after cancelled payment
     * @param sendEmails - Boolean indicating whether to send emails in the workflow
     * @returns The url to the Paytrail payment page.
     */
    Payments.prototype.getPaytrailPaymentUrl = function (calculationIds, paymentMethod, successUrl, cancelUrl, sendEmails) {
        var url = this.ajax.getServerAddress() + "/SalaryPayment/PayCalculations?";
        calculationIds.forEach(function (item) { url += "calculationIds=" + encodeURIComponent("" + item) + "&"; });
        url += "successUrl=" + encodeURIComponent("" + successUrl) + "&";
        url += "cancelUrl=" + encodeURIComponent("" + cancelUrl) + "&";
        url += "sendEmails=" + encodeURIComponent("" + sendEmails) + "&";
        url += "paymentMethod=" + encodeURIComponent("" + paymentMethod) + "&";
        url += "access_token=" + encodeURIComponent("" + this.ajax.getCurrentToken());
        return url;
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Payments.$inject = ["AjaxNg1"];
    return Payments;
}(CrudApiBase_1.CrudApiBase));
exports.Payments = Payments;

},{"../model":73,"./CrudApiBase":13}],23:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Provides CRUD access for authenticated user to access a his/her own PayrollDetails objects
 */
var Payrolls = /** @class */ (function (_super) {
    __extends(Payrolls, _super);
    function Payrolls(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/v03-rc/api/payroll";
        return _this;
    }
    /** Client-side (synchronous) method for getting a new blank item as bases for UI binding. */
    Payrolls.prototype.getBlank = function () {
        return {
            input: {
                period: {},
                calculations: [],
            },
            info: null,
        };
    };
    /**
     * Validates a PayrollDetails object for payment.
     * @param payrollToValidate PayrollDetails that should be validated.
     * @returns The PayrollDetails object with Calculations added to the Result object and Validated.
     */
    Payrolls.prototype.validate = function (payrollToValidate) {
        return this.ajax.postJSON(this.baseUrl + "/validate", payrollToValidate);
    };
    /**
     * Starts the payment process for the payroll.
     * Creates and saves the calculations as well as the new payment object.
     * Updates the status of calculations and payroll to paymentStarted.
     * @param payroll PayrollDetails which is going to be paid.
     * @param paymentMethod - Payment method.
     * @param successUrl - Return address after successful payment
     * @param cancelUrl - Return address after cancelled payment
     * @param sendEmails - Boolean indicating whether to send emails in the workflow
     * @returns The PayrollDetails object with payment id.
     */
    Payrolls.prototype.startPayment = function (payroll, paymentMethod, successUrl, cancelUrl, sendEmails) {
        var method = this.baseUrl + "/payment?";
        method += "paymentMethod=" + encodeURIComponent("" + paymentMethod) + "&";
        method += "successUrl=" + encodeURIComponent("" + successUrl) + "&";
        method += "cancelUrl=" + encodeURIComponent("" + cancelUrl) + "&";
        method += "sendEmails=" + encodeURIComponent("" + sendEmails);
        return this.ajax.postJSON(method, payroll);
    };
    /**
     * Saves changes to to a Calculation that is part of a Payroll and returns the Paryoll validation data.
     * @param calc The calculation object that is updated.
     * @param payrollId Payroll ID where calculation belongs to.
     * Note, that the current implementation does not assure that the calculation is within a Payroll.
     * The ID is simply used for assuring corrrect data in Calculation.
     * @returns The Saved Payroll object with Calculations added to the Result object and Validated.
     */
    Payrolls.prototype.calculationSave = function (calc, payrollId) {
        var method = this.baseUrl + "/" + payrollId + "/calcs";
        return this.ajax.postJSON(method, calc);
    };
    /**
     * Adds existing calculations to the the payroll and saves the payroll object.
     * If calculation is read-only, a copy is made. If it is draft, the calculation is moved.
     * @param payroll The Payroll object to update and save.
     * @param calculationIds Array of calculation id's that are copied / moved to the Payroll list.
     * @returns The Saved Payroll object with Calculations added to the Result object and Validated.
     */
    Payrolls.prototype.addCalculations = function (payroll, calculationIds) {
        var method = this.baseUrl + "/add-calc?";
        method += "ids=" + calculationIds.join(",");
        return this.ajax.postJSON(method, payroll);
    };
    /**
     * Remove calculations from the payroll and saves the payroll object.
     * The calculations are completely deleted.
     * This can only be done if the calculations and the payroll have not been paid yet.
     * @param payroll The Payroll  object.
     * @param calculationIds Array of calculation id's that are deleted.
     * @returns The Saved Payroll object with Calculations removed from the Result object and Validated.
     */
    Payrolls.prototype.deleteCalculations = function (payroll, calculationIds) {
        var method = this.baseUrl + "/delete-calc?";
        method += "ids=" + calculationIds.join(",");
        return this.ajax.postJSON(method, payroll);
    };
    /**
     * Remove calculations from the payroll and saves the payroll object.
     * The calculations are unlinked and they become individual calculations in the draft list (and can then be processed individually).
     * This can only be done if the calculations and the payroll have not been paid yet.
     * @param payroll The Payroll  object.
     * @param calculationIds Array of calculation id's that are unlinked from the Payroll list.
     * @returns The Saved Payroll object with Calculations removed from the Result object and Validated.
     */
    Payrolls.prototype.unlinkCalculations = function (payroll, calculationIds) {
        var method = this.baseUrl + "/unlink-calc?";
        method += "ids=" + calculationIds.join(",");
        return this.ajax.postJSON(method, payroll);
    };
    /**
     * Adds new calculations to the the payroll and saves the payroll object.
     * The calculations are added based on employment relation ID's.
     * @param payroll The Payroll object to update and save.
     * @param employmentIds Array of employment relation id's for which the a new calculation is added to the Payroll list.
     * @returns The Saved Payroll object with Calculations added to the Result object and Validated.
     */
    Payrolls.prototype.addEmployments = function (payroll, employmentIds) {
        var method = this.baseUrl + "/add-employment?";
        method += "ids=" + employmentIds.join(",");
        return this.ajax.postJSON(method, payroll);
    };
    /**
     * Returns the url for starting the payment process for the payroll.
     * @param payrollId Payroll which is going to be paid.
     * @param paymentMethod - Payment method.
     * @param successUrl - Return address after successful payment
     * @param cancelUrl - Return address after cancelled payment
     * @param sendEmails - Boolean indicating whether to send emails in the workflow
     * @returns The url to the Paytrail payment page.
     */
    Payrolls.prototype.getPaytrailPaymentUrl = function (payrollId, paymentMethod, successUrl, cancelUrl, sendEmails) {
        var url = this.ajax.getServerAddress() + "/SalaryPayment/PayPayroll?";
        url += "payrollId=" + encodeURIComponent("" + payrollId) + "&";
        url += "successUrl=" + encodeURIComponent("" + successUrl) + "&";
        url += "cancelUrl=" + encodeURIComponent("" + cancelUrl) + "&";
        url += "sendEmails=" + encodeURIComponent("" + sendEmails) + "&";
        url += "paymentMethod=" + encodeURIComponent("" + paymentMethod) + "&";
        url += "version=3&";
        url += "access_token=" + encodeURIComponent("" + this.ajax.getCurrentToken());
        return url;
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Payrolls.$inject = ["AjaxNg1"];
    return Payrolls;
}(CrudApiBase_1.CrudApiBase));
exports.Payrolls = Payrolls;

},{"./CrudApiBase":13}],24:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Anonymous methods for accessing the Public Profiles (Osaajaprofiilit).
 * This is read-only access to third-party sites.
 * For modifying and non-public profiles, use MyProfiles autenticated service instead.
 */
var Profiles = /** @class */ (function () {
    function Profiles(ajax) {
        this.ajax = ajax;
    }
    /**
     * Gets the Cities in Finland. Use the key-property when searching for Profiles
     *
     * @return A Promise with result data (list of cities).
     */
    Profiles.prototype.getCities = function () {
        return this.ajax.getJSON("/pro/cities");
    };
    /**
     * Gets the Jobs that are defined for Profiles. Use the id-property when searching for Profiles
     * This method may later provide different Job categorizations for different purposes (e.g. different partners).
     *
     * @return A Promise with result data (list of jobs).
     */
    Profiles.prototype.getJobs = function () {
        return this.ajax.getJSON("/pro/jobs");
    };
    /**
     * Gets the Job Categories that are defined for Profiles. Use the id-property when searching for Profiles
     * This method may later provide different Job categorizations for different purposes (e.g. different partners).
     *
     * @return A Promise with result data (list of categories).
     */
    Profiles.prototype.getCategories = function () {
        return this.ajax.getJSON("/pro/categories");
    };
    /**
     * Gets a single profile - including the details.
     * Note that this unauthenticated method does not show contact details.
     *
     * @param id - The identifier of the profile.
     *
     * @return A Promise with result data (Profile).
     */
    Profiles.prototype.getProfile = function (id) {
        return this.ajax.getJSON("/pro/profiles/" + id);
    };
    /**
     * Search method for the public profiles.
     *
     * @param city - Filter by city key
     * @param job - Filter by Job key
     * @param category - Filter by job category key
     * @param searchText - Filter by search text
     *
     * @return A Promise with result data (search results object).
     */
    Profiles.prototype.search = function (city, job, category, searchText) {
        var method = "/pro/profiles?city=" + (city || "") + "&job=" + (job || "") + "&category=" + (category || "") + "&searchText=" + (searchText || "");
        return this.ajax.getJSON(method);
    };
    /**
     * Gets the profile for the current authenticated user
     *
     * @return A Promise with result data (Profile).
     */
    Profiles.prototype.getMyProfile = function () {
        return this.ajax.getJSON("/myprofiles/Default");
    };
    /**
     * Updates user's profile or creates a new one if none exists.
     *
     * @param profile - The profile information that should be updated
     *
     * @return A Promise with result data (Profile).
     */
    Profiles.prototype.saveMyProfile = function (profile) {
        return this.ajax.postJSON("/myprofiles", profile);
    };
    /**
     * Returns the url where to post the avatar image file
     */
    Profiles.prototype.getAvatarImageUploadUrl = function () {
        return this.ajax.getApiAddress() + "/myprofiles/avatarImage";
    };
    /**
     * Gets a contact for a single profile.
     *
     * @param id - The identifier of the profile.
     *
     * @return A Promise with result data (Contact).
     */
    Profiles.prototype.getContact = function (id) {
        var method = "/pro/profiles/{id}/contact".replace("{id}", id);
        return this.ajax.getJSON(method);
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Profiles.$inject = ["AjaxNg1"];
    return Profiles;
}());
exports.Profiles = Profiles;

},{}],25:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var model_1 = require("../model");
var util_1 = require("../util");
/**
 * Provides access to HTML reports on calculations
 */
var Reports = /** @class */ (function () {
    function Reports(ajax) {
        this.ajax = ajax;
    }
    /**
     * Gets a list of generated HTML/PDF/JSON reports by type.
     *
     * @param reportType - Type of reports to fetch.
     *
     * @return A Promise with result data (array of reports).
     */
    Reports.prototype.getReportsByType = function (reportType) {
        return this.ajax.getJSON("/reports/type/" + reportType);
    };
    /**
     * Gets a single generated HTML/PDF/JSON report by type and id.
     *
     * @param reportType - Type of the report to fetch.
     * @param id - Id of the report to fetch.
     * @param wait - Optional flag to indicate whether to wait for the report to be generated.
     *
     * @return A Promise with result data (report).
     */
    Reports.prototype.getReport = function (reportType, id, wait) {
        var method = "/reports/type/" + reportType + "/" + encodeURIComponent(id) + "?";
        method += "wait=" + encodeURIComponent("" + wait);
        return this.ajax.getJSON(method);
    };
    /**
     * Gets the monthly / quarterly/ yearly accounting data for the current account.
     *
     * @param refDate - Reference date for the period. Please note that even if the date is not the first day of the given period, the entire period is returned.
     * @param target  - Accounting target name : contains  default ruleset and other parameters for creating accounting entries.
     * @param periodType - Month, quarter, year or a custom period. The custom period requires endDate. Default value is the month.
     * @param endDate - End date for the period. Required only for the custom period.
     * @param minStatus - Minimum status level for the calculations to include in the data. The default level is PaymentSucceeded.
     * @param ruleSet - Optional additional ruleset for the target to use for creating the accounting entries.
     * @return A Promise with result data (Raw data for accounting purposes).
     */
    Reports.prototype.getAccountingDataForPeriod = function (refDate, target, periodType, endDate, minStatus, ruleSet) {
        if (target === void 0) { target = "default"; }
        if (periodType === void 0) { periodType = model_1.PeriodType.Month; }
        if (endDate === void 0) { endDate = null; }
        if (minStatus === void 0) { minStatus = null; }
        if (ruleSet === void 0) { ruleSet = null; }
        refDate = util_1.Dates.asDate(refDate) || util_1.Dates.getToday();
        return this.ajax.getJSON("/v03-rc/api/reports/data/accounting/" + encodeURIComponent(target) + "/" + refDate + "?periodType=" + periodType + (endDate ? "&endDate=" + endDate : "") + (minStatus ? "&minStatus=" + minStatus : "") + (ruleSet ? "&ruleSet=" + encodeURIComponent(ruleSet) : ""));
    };
    /**
     * Gets the accounting data based on given set of calculations.
     *
     * @param calculationIds - Calculations that are the bases for the report.
     * @param target  - Accounting target name : contains  default ruleset and other parameters for creating accounting entries.
     * @param ruleSet - Optional additional ruleset for the target to use for creating the accounting entries.
     * @return A Promise with result data (Raw data for accounting purposes).
     */
    Reports.prototype.getAccountingDataForCalculationIds = function (calculationIds, target, ruleSet) {
        if (target === void 0) { target = "default"; }
        var ids = calculationIds.map(function (x) { return "calculationIds=" + x; }).join("&");
        return this.ajax.getJSON("/v03-rc/api/reports/data/accounting/" + encodeURIComponent(target) + "?" + ids + (ruleSet ? "&ruleSet=" + encodeURIComponent(ruleSet) : ""));
    };
    /**
     * Gets the accounting data based on given report id.
     *
     * @param id - Saved report id containing accounting data.
     * @param target  - Accounting target name : contains  default ruleset and other parameters for creating accounting entries.
     * @param ruleSet - Optional additional ruleset for the target to use for creating the accounting entries.
     * @return A Promise with result data (Raw data for accounting purposes).
     */
    Reports.prototype.getAccountingData = function (id, target, ruleSet) {
        if (target === void 0) { target = "default"; }
        return this.ajax.getJSON("/v03-rc/api/reports/data/accounting/" + encodeURIComponent(target) + "/" + id + (ruleSet ? "?ruleSet=" + encodeURIComponent(ruleSet) : ""));
    };
    /**
     * Gets the accounting report based on given set of calculations.
     * This method can be used anonymously.
     *
     * @param calculations - Calculations that are the bases for the report.
     * @param target  - Accounting target name : contains  default ruleset and other parameters for creating accounting entries.
     * @param ruleSet - Optional additional ruleset for the target to use for creating the accounting entries.
     * @return A Promise with result data (Raw data for accounting purposes).
     */
    Reports.prototype.getAccountingDataForCalculations = function (calculations, target, ruleSet) {
        if (target === void 0) { target = "default"; }
        return this.ajax.postJSON("/v03-rc/api/reports/data/accounting/" + encodeURIComponent(target) + (ruleSet ? "?ruleSet=" + encodeURIComponent(ruleSet) : ""), calculations);
    };
    /**
     * Gets an HTML report based on Calculation ID.
     *
     * @param reportType - Type of the report to fetch. See the HtmlReportType enumeration for possible values.
     * @param calculationId - GUID for the calculation
     *
     * @return A Promise with result HTML.
     */
    Reports.prototype.getReportHtmlById = function (reportType, calculationId) {
        var method;
        if (!reportType) {
            return;
        }
        switch (reportType.toLowerCase()) {
            case "employer":
                method = "/reportpartials/employerCalculation/" + calculationId;
                break;
            case "employerpage2":
                method = "/reportpartials/employerCalculationAdditionalInfo/" + calculationId;
                break;
            case "worker":
                method = "/reportpartials/workerCalculation/" + calculationId;
                break;
            case "workerpage2":
                method = "/reportpartials/workerCalculationAdditionalInfo/" + calculationId;
                break;
            case "payments":
                method = "/reportpartials/paymentCalculation/" + calculationId;
                break;
            default:
                console.error("Unknown report partial type:" + reportType);
                return;
        }
        return this.ajax.getHTML(this.ajax.getServerAddress() + method);
    };
    /**
     * Gets an HTML report based on posted Calculation object.
     *
     * @param reportType - Type of the report to fetch. See the HtmlReportType enumeration for possible values.
     * @param calculation - The calculation object that is reported.
     *
     * @return A Promise with result HTML.
     */
    Reports.prototype.getReportHtmlWithPost = function (reportType, calculation) {
        var method;
        if (!reportType) {
            return;
        }
        switch (reportType.toLowerCase()) {
            case "employer":
                method = "/reportpartials/employerCalculationFromCalc";
                break;
            case "employerpage2":
                method = "/reportpartials/employerCalculationAdditionalInfoFromCalc";
                break;
            case "worker":
                method = "/reportpartials/workerCalculationFromCalc";
                break;
            case "workerpage2":
                method = "/reportpartials/workerCalculationAdditionalInfoFromCalc";
                break;
            case "payments":
                method = "/reportpartials/paymentCalculationFromCalc";
                break;
            default:
                console.error("Unknown report partial type:" + reportType);
                return;
        }
        return this.ajax.postHTML(this.ajax.getServerAddress() + method, calculation);
    };
    /**
     * Gets the monthly / quarterly/ yearly accounting data for the current account.
     *
     * @param refDate - Reference date for the period. Please note that even if the date is not the first day of the given period, the entire period is returned.
     * @param tableType  - Accounting table type.
     * @param periodType - Month, quarter, year or a custom period. The custom period requires endDate. Default value is the month.
     * @param endDate - End date for the period. Required only for the custom period.
     * @return A Promise with result data (Raw data for accounting purposes).
     */
    Reports.prototype.getAccountingReportTableForPeriod = function (refDate, tableType, periodType, endDate) {
        if (tableType === void 0) { tableType = model_1.AccountingReportTableType.Classic; }
        if (periodType === void 0) { periodType = model_1.PeriodType.Month; }
        if (endDate === void 0) { endDate = null; }
        refDate = util_1.Dates.asDate(refDate) || util_1.Dates.getToday();
        var method = "/reports/data/accounting/" + tableType + "/" + encodeURIComponent(refDate) + "?";
        method += "periodType=" + encodeURIComponent("" + periodType);
        if (endDate) {
            method += "&endDate=" + encodeURIComponent(endDate);
        }
        return this.ajax.getJSON(method);
    };
    /**
     * Gets the accounting report based on given set of calculations.
     *
     * @param calculationIds - Calculations that are the bases for the report.
     * @param tableType  - Accounting table type.
     * @return Account report based on the calculations.
     * @hidden - experimental
     */
    Reports.prototype.getAccountingReportTableForCalculationIds = function (calculationIds, tableType) {
        if (tableType === void 0) { tableType = model_1.AccountingReportTableType.Classic; }
        var method = "/reports/data/accounting/" + tableType + "?";
        calculationIds.forEach(function (x) { method += "calculationIds=" + encodeURIComponent("" + x) + "&"; });
        method = method.replace(/[?&]$/, "");
        return this.ajax.getJSON(method);
    };
    /**
     * Gets the accounting report based on given set of calculations.
     *
     * @param calculations - Calculations that are the bases for the report.
     * @param tableType  - Accounting table type.
     * @return Account report based on the calculations.
     * @hidden - experimental
     */
    Reports.prototype.getAccountingReportTableForCalculations = function (calculations, tableType) {
        if (tableType === void 0) { tableType = model_1.AccountingReportTableType.Classic; }
        var method = "/reports/data/accounting/" + tableType;
        return this.ajax.postJSON(method, calculations);
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Reports.$inject = ["AjaxNg1"];
    return Reports;
}());
exports.Reports = Reports;

},{"../model":73,"../util":90}],26:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Provides read-only access to the current user session
 */
var Session = /** @class */ (function () {
    function Session(ajax) {
        this.ajax = ajax;
    }
    /**
     * Checks whether the current browser session is authorized.
     *
     * @return A Promise with result data (boolean).
     */
    Session.prototype.isAuthorized = function () {
        return this.ajax.getJSON("/session/isAuthorized");
    };
    /**
     * Gets the current session information or null if there is no active session.
     * UserSession data is the Authorization object that provides information about the current session. Null, if there is no session.
     *
     * @return A Promise with result data (UserSession).
     */
    Session.prototype.getSession = function () {
        return this.ajax.getJSON("/session/current");
    };
    /**
     * Returns server address
     */
    Session.prototype.getServerAddress = function () {
        return this.ajax.getServerAddress();
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Session.$inject = ["AjaxNg1"];
    return Session;
}());
exports.Session = Session;

},{}],27:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var CrudApiBase_1 = require("../CrudApiBase");
/**
 * Provides CRUD access for accounting settings
 */
var AccountingSettingsApi = /** @class */ (function (_super) {
    __extends(AccountingSettingsApi, _super);
    function AccountingSettingsApi(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/v03-rc/api/settings/accounting";
        return _this;
    }
    /**
     * Client-side (synchronous) method for getting a new blank CRUD item as bases for UI binding.
     * The basic idea is that all the child object properties should be non-null to avoid null reference exceptions.
     * In special cases, when null is significant it may be used: e.g. Calculation.result is null untill the recalculation has been done.
     * Strings, dates and booleans may be null (false if bool), but typically just undefined.
     */
    AccountingSettingsApi.prototype.getBlank = function () {
        throw new Error("Not supported.");
    };
    /**
     * Makes an OData query to the service's main OData method.
     * @param query The options for the query: Filter, search sort etc.
     * This is either a strongly typed object or query string that is added directly.
     */
    AccountingSettingsApi.prototype.getOData = function (query) {
        throw new Error("Not supported.");
    };
    /**
     * Gets all the items of a given type.
     * @return A Promise with result data array.
     */
    AccountingSettingsApi.prototype.getAll = function () {
        throw new Error("Not supported.");
    };
    /**
     * Deletes an single item from the sotrage
     * @param id - Unique identifier for the object
     * @return A Promise with result data "Object deleted".
     */
    AccountingSettingsApi.prototype.delete = function (id) {
        throw new Error("Not supported.");
    };
    /**
     * Adds/updates the workflow event for the item.
     *
     * @param item - Item for which to set the workflow event.
     * @param wfEvent - Event to add or update.
     * @return Workflow data for the item.
     */
    AccountingSettingsApi.prototype.saveWorkflowEvent = function (item, wfEvent) {
        throw new Error("Not supported.");
    };
    /**
     * Deletes the worklflow item or items from the item.
     * @param item - Item for which to delete workflow events.
     * @param wfIdOrType - Event id or type.
     * @return A Promise with result data "Object deleted".
     */
    AccountingSettingsApi.prototype.deleteWorkflowEvent = function (item, wfIdOrType) {
        throw new Error("Not supported.");
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    AccountingSettingsApi.$inject = ["AjaxNg1"];
    return AccountingSettingsApi;
}(CrudApiBase_1.CrudApiBase));
exports.AccountingSettingsApi = AccountingSettingsApi;

},{"../CrudApiBase":13}],28:[function(require,module,exports){
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
__export(require("./AccountingSettingsApi"));

},{"./AccountingSettingsApi":27}],29:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var logic_1 = require("../logic");
var util_1 = require("../util");
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Provides CRUD functionality as well as business logic for storing and using Finnish Taxcards and calculating Withholding tax.
 */
var Taxcards = /** @class */ (function (_super) {
    __extends(Taxcards, _super);
    function Taxcards(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/v03-rc/api/taxcards";
        return _this;
    }
    /**
     * Client-side (synchronous) method for getting a new blank item as bases for UI binding.
     * You need to set the Personal ID to bind the taxcard to an account.
     */
    Taxcards.prototype.getBlank = function () {
        return logic_1.TaxCard2019Logic.getBlank(null);
    };
    /**
     * Saves a taxcard to the storage.
     * Removes empty incomeLog entries because they may be added by data binding in UI.
     * Entries are currently considered empty if both id and income are falsy: Typically income should be there,
     * but taxable income may be zero on a calculation (entry with id) and it makes sense to keep the entry still.
     * @param itemToSave - The item that is updated/inserted.
     * @return A Promise with result data as saved to the storage (contains id, createAt, owner etc.).
     */
    Taxcards.prototype.save = function (itemToSave) {
        itemToSave.incomeLog = itemToSave.incomeLog.filter(function (x) { return x.id || x.income; });
        return _super.prototype.save.call(this, itemToSave);
    };
    /**
     * Calculates the widhholding tax based on a given tax card.
     *
     * @param id - Identifier of the tax card.
     * @param income - New salary or other income, for which the widthholding tax is calculated.
     * @param endDate - End date for the salary payment period (salary that is calulated now). This is significant for the validity and cumulation of the tax card.
     *
     * @return A Promise with result data (TaxCardResult).
     */
    Taxcards.prototype.calculateWithId = function (id, income, endDate) {
        var method = this.baseUrl + "/calculate/" + encodeURIComponent("" + id) + "?income=" + util_1.Numeric.parseNumber(income) + "&endDate=" + util_1.Dates.asDate(endDate);
        return this.ajax.getJSON(method);
    };
    /**
     * Calculates the widhholding tax based on a given tax card
     *
     * @param income - New salary or other income, for which the widthholding tax is calculated.
     * @param taxCard - Tax card based on which the widthholding tax is calculated. This method will not connect to database in any way so the taxcard may or may not be stored.
     * @param endDate - End date for the salary payment period (salary that is calulated now). This is significant for the validity and cumulation of the tax card.
     *
     * @return A Promise with result data (TaxCardResult).
     */
    Taxcards.prototype.calculate = function (income, taxCard, endDate) {
        var method = this.baseUrl + "/calculate?income=" + util_1.Numeric.parseNumber(income) + "&endDate=" + util_1.Dates.asDate(endDate);
        return this.ajax.postJSON(method, taxCard);
    };
    /**
     * Gets all the current taxcards for the current Worker account:
     * The cards that the account has uploaded as well as the cards created by all Employers.
     * This method can only be run for a personal account (not for a Company account).
     * @returns The cards that the account has uploaded as well as the cards created by all Employers.
     * Only current cards (not expired) are provided.
     */
    Taxcards.prototype.getMyTaxcards = function () {
        var method = this.baseUrl + "/my";
        return this.ajax.getJSON(method);
    };
    /**
     * Gets all the current taxcards for an employment relation:
     * All the cards by the Employer, but also the latest card uploaded by the Worker herself.
     * @param employmentId The employment id for which to search the taxcards.
     * @returns The cards created by the Employer and also the latest card uploaded by the Worker herself.
     * Only current cards (not expired) are provided.
     */
    Taxcards.prototype.getEmploymentTaxcards = function (employmentId) {
        var method = this.baseUrl + "/employment/" + employmentId;
        return this.ajax.getJSON(method);
    };
    /**
     * Returns the url where to post the tax card file using form post ('multipart/form-data').
     */
    Taxcards.prototype.getTaxCardUploadUrl = function () {
        return "" + this.ajax.getServerAddress() + this.baseUrl + "/file";
    };
    /**
     * Returns the url where to get the tax card file
     */
    Taxcards.prototype.getTaxCardDownloadUrl = function (taxCard) {
        return (taxCard.card.fileUri) ? this.ajax.getApiAddress() + "/files/stream/" + taxCard.card.fileUri : null;
    };
    /**
     * Returns the url where to get the tax card preview image
     */
    Taxcards.prototype.getTaxCardPreviewUrl = function (taxCard) {
        return (taxCard.card.previewUri) ? this.ajax.getApiAddress() + "/files/preview/" + taxCard.card.previewUri : null;
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Taxcards.$inject = ["AjaxNg1"];
    return Taxcards;
}(CrudApiBase_1.CrudApiBase));
exports.Taxcards = Taxcards;

},{"../logic":66,"../util":90,"./CrudApiBase":13}],30:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Methods for testing the API.
 */
var Test = /** @class */ (function () {
    function Test(ajax) {
        this.ajax = ajax;
    }
    /**
     * Basic hello world message. Echoes the given message back.
     *
     * @param message - Message.
     *
     * @return A Promise with result data (message).
     */
    Test.prototype.hello = function (message) {
        return this.ajax.getJSON("/test/hello?message=" + encodeURIComponent("" + message));
    };
    /**
     * Test a long lasting request.
     *
     * @param seconds - Delay in seconds.
     *
     * @return A Promise with result data (Delay in seconds).
     */
    Test.prototype.delay = function (seconds) {
        return this.ajax.getJSON("/test/delay?seconds=" + encodeURIComponent("" + seconds));
    };
    /**
     * Test JSON serialization. Echoes a given object either in success callback or in the promise.
     *
     * @param testValues - TestValues object.
     *
     * @return A Promise with result.
     */
    Test.prototype.values = function (testValues) {
        return this.ajax.postJSON("/test/values", testValues);
    };
    /**
     * Creates a test account and returns test account details.
     *
     * @param testValues - Onboarding object.
     *
     * @return A Promise with result data (test accounts).
     */
    Test.prototype.createTestAccount = function (onboarding) {
        return this.ajax.postJSON("/test/accounts", onboarding);
    };
    /**
     * Deletes a test account and related objects
     *
     * @param accountId - Account id to delete.
     *
     * @return A Promise with result data "Object deleted".
     */
    Test.prototype.deleteTestAccount = function (accountId) {
        return this.ajax.remove("/test/accounts/" + encodeURIComponent("" + accountId));
    };
    /**
     * Test methods that throws an exception on server side.
     *
     * @param errorType Type of error
     * @param success Function that would theoretically be called if the call was not an error. Will never be called.
     *
     * @return A Promise if success parameter is null. For throwException,
     *        the promise is always rejected after the error is thrown in the server.
     */
    Test.prototype.throwException = function (errorType) {
        return this.ajax.getJSON("/test/exceptions/" + errorType);
    };
    /**
     * Delete the current account data and credentials (including Auth0 user).
     * Can be called only in a test environment.
     */
    Test.prototype.deleteCurrentAccount = function () {
        return this.ajax.remove("/accounts/current");
    };
    /**
     * Remove all calculations, workers etc. user objects except products and signature from the account.
     * Can be called only in a test environment.
     */
    Test.prototype.deleteCurrentAccountData = function () {
        return this.ajax.remove("/accounts/data/all");
    };
    /**
     * Remove all calculations, payrolls and payments from the account.
     * Can be called only in a test environment.
     */
    Test.prototype.deleteCurrentAccountCalculations = function () {
        return this.ajax.remove("/accounts/calculation/all");
    };
    /**
     * Remove workers including calculations, employment contracts and tax cards from the account.
     * Can be called only in a test environment.
     */
    Test.prototype.deleteCurrentAccountWorkers = function () {
        return this.ajax.remove("/accounts/worker/all");
    };
    /**
     * Remove all holiday year from all workers. Does not touch the default values of holidays in Worker Employment relation.
     * Can be called only in a test environment.
     */
    Test.prototype.deleteCurrentAccountHolidays = function () {
        return this.ajax.remove("/accounts/holidays/all");
    };
    /**
     * Remove pension and insurance from the account.
     * Can be called only in a test environment.
     */
    Test.prototype.deleteCurrentAccountPensionAndInsurance = function () {
        return this.ajax.remove("/accounts/product/pensionAndInsurance");
    };
    /**
     * Remove all products from the account.
     * Can be called only in a test environment.
     */
    Test.prototype.deleteCurrentAccountProducts = function () {
        return this.ajax.remove("/accounts/product/all");
    };
    /**
     * Remove the signature from the account.
     * Can be called only in a test environment.
     */
    Test.prototype.deleteCurrentAccountSignature = function () {
        return this.ajax.remove("/accounts/signature");
    };
    /**
     * Delete all empty accounts (company or worker) created by this account.
     * Can be called only in a test environment.
     */
    Test.prototype.deleteCurrentAccountAuthorizingAccounts = function () {
        return this.ajax.remove("/accounts/authorizingAccount/all");
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Test.$inject = ["AjaxNg1"];
    return Test;
}());
exports.Test = Test;

},{}],31:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var logic_1 = require("../logic");
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Provides CRUD access to Workers (employees) created by the employer
 * or to whom the employer has paid salaries.
 */
var Workers = /** @class */ (function (_super) {
    __extends(Workers, _super);
    function Workers(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/accounts/workers";
        return _this;
    }
    /** Client-side (synchronous) method for getting a new blank item as bases for UI binding. */
    Workers.prototype.getBlank = function () {
        return logic_1.WorkerLogic.getBlank();
    };
    /** Saves the Worker account ot the storage */
    Workers.prototype.save = function (itemToSave) {
        return _super.prototype.save.call(this, itemToSave);
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    Workers.$inject = ["AjaxNg1"];
    return Workers;
}(CrudApiBase_1.CrudApiBase));
exports.Workers = Workers;

},{"../logic":66,"./CrudApiBase":13}],32:[function(require,module,exports){
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var CrudApiBase_1 = require("./CrudApiBase");
/**
 * Methods for getting and saving yearly feedback data.
 */
var YearEnd = /** @class */ (function (_super) {
    __extends(YearEnd, _super);
    function YearEnd(ajax) {
        var _this = _super.call(this, ajax) || this;
        /** Base URL for details etc. */
        _this.baseUrl = "/yearEnd/feedback";
        return _this;
    }
    /**
     * Client-side (synchronous) method for getting a new blank CRUD item as bases for UI binding.
     * The basic idea is that all the child object properties should be non-null to avoid null reference exceptions.
     * In special cases, when null is significant it may be used: e.g. Calculation.result is null untill the recalculation has been done.
     * Strings, dates and booleans may be null (false if bool), but typically just undefined.
     */
    YearEnd.prototype.getBlank = function () {
        throw new Error("Not implemented");
    };
    /**
     * Gets a single item based on identier
     * @param id - Unique identifier for the object
     * @return A Promise with result data.
     */
    YearEnd.prototype.getSingle = function (id) {
        return _super.prototype.getAll.call(this).then(function (all) {
            if (all && all.length !== 0) {
                return all[0];
            }
            return null;
        });
    };
    /**
     * Deletes an single item from the sotrage
     * @param id - Unique identifier for the object
     * @return A Promise with result data "Object deleted".
     */
    YearEnd.prototype.delete = function (id) {
        throw new Error("Not implemented");
    };
    /**
     * For NG1-dependency injection
     * @hidden
     */
    YearEnd.$inject = ["AjaxNg1"];
    return YearEnd;
}(CrudApiBase_1.CrudApiBase));
exports.YearEnd = YearEnd;

},{"./CrudApiBase":13}],33:[function(require,module,exports){
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
__export(require("./Absences"));
__export(require("./Accounts"));
__export(require("./AjaxJQuery"));
__export(require("./AjaxXHR"));
__export(require("./Articles"));
__export(require("./AuthorizedAccounts"));
__export(require("./Calculations"));
__export(require("./Calculator"));
__export(require("./Certificates"));
__export(require("./Client"));
__export(require("./Cms"));
__export(require("./Credentials"));
__export(require("./CrudApiBase"));
__export(require("./EarningsPayments"));
__export(require("./ESalaryPayments"));
__export(require("./Files"));
__export(require("./HolidayYears"));
__export(require("./MessageThreads"));
__export(require("./OAuth2"));
__export(require("./Onboardings"));
__export(require("./PartnerServices"));
__export(require("./Payments"));
__export(require("./Payrolls"));
__export(require("./Profiles"));
__export(require("./Reports"));
__export(require("./Session"));
__export(require("./Settings"));
__export(require("./Taxcards"));
__export(require("./Test"));
__export(require("./Workers"));
__export(require("./YearEnd"));

},{"./Absences":1,"./Accounts":2,"./AjaxJQuery":3,"./AjaxXHR":4,"./Articles":5,"./AuthorizedAccounts":6,"./Calculations":7,"./Calculator":8,"./Certificates":9,"./Client":10,"./Cms":11,"./Credentials":12,"./CrudApiBase":13,"./ESalaryPayments":14,"./EarningsPayments":15,"./Files":16,"./HolidayYears":17,"./MessageThreads":18,"./OAuth2":19,"./Onboardings":20,"./PartnerServices":21,"./Payments":22,"./Payrolls":23,"./Profiles":24,"./Reports":25,"./Session":26,"./Settings":28,"./Taxcards":29,"./Test":30,"./Workers":31,"./YearEnd":32}],34:[function(require,module,exports){
/** Codegen namespace is interfaces and data that is generated in Salaxy server */
Object.defineProperty(exports, "__esModule", { value: true });
/* tslint:disable */
/**
 * Generated products data from the server.
 * To update, go to: https://test-api.salaxy.com/v02/api/accounts/products/anon
 * @hidden
 * TODO: Add language versioning to the server side and generation.
 * TODO: Can we package this entire namespace in a way that it is hidden to be internal only?
 */
exports.accountProductDefaults = {
    "baseService": {
        "campaignCode": null,
        "id": "baseService",
        "title": "Palkkaus.fi-tili",
        "status": "Palkkaamisen peruspalvelut",
        "description": "Digiajan palkanmaksupalvelu",
        "img": "https://cdn.salaxy.com/img/elems/product-logos/palkkaus.png",
        "articleId": "product_baseService",
        "enabled": true,
        "visible": true
    },
    "tax": {
        "paymentReferenceNumber": null,
        "isSalariesPaidThisYear": false,
        "isMonthlyReportingEnabled": true,
        "isYearlyReportingEnabled": true,
        "isNotificationsSelfHandling": false,
        "isPaymentsSelfHandling": false,
        "id": "tax",
        "title": "Yhteydet verottajaan",
        "status": "Ennakonpidätys ja ilmoitukset",
        "description": "Ennakonpidätykset ja Sotu-maksut",
        "img": "https://cdn.salaxy.com/img/elems/product-logos/tax.png",
        "articleId": "product_tax",
        "enabled": true,
        "visible": true
    },
    "unemployment": {
        "isSalariesPaidThisYear": false,
        "isPrepayments": false,
        "isNotificationsSelfHandling": false,
        "id": "unemployment",
        "title": "Työttömyysvakuutus (TVR)",
        "status": "Maksut ja ilmoitukset TVR:ään",
        "description": "Työttömyysturva rahoitetaan TVR-maksuilla",
        "img": "https://cdn.salaxy.com/img/elems/product-logos/tvr.png",
        "articleId": "product_unemployment",
        "enabled": true,
        "visible": true
    },
    "pension": {
        "status": "Ei sopimusta: TyEL maksetaan tilapäisenä työnantajana",
        "isPensionContractDone": false,
        "pensionCompany": "none",
        "pensionContractNumber": null,
        "isPensionSelfHandling": false,
        "isPendingContract": false,
        "enabled": true,
        "id": "pension",
        "title": "TyEL-eläkevakuutus",
        "description": "TyEL-vakuutus on työntekijän eläketurva",
        "img": "https://cdn.salaxy.com/img/elems/product-logos/varma-tyel.png",
        "articleId": "product_pension",
        "visible": true
    },
    "insurance": {
        "status": "Ei sopimusta - Huom! 1200 € :n sääntö.",
        "isPartnerInsurance": false,
        "isInsuranceContractDone": false,
        "insuranceCompany": "none",
        "insuranceContractNumber": null,
        "enabled": false,
        "id": "insurance",
        "title": "Työtapaturmavakuutus",
        "description": "Tapaturmavakuutus vakuuttaa työntekijäsi",
        "img": "https://cdn.salaxy.com/img/elems/product-logos/if.png",
        "articleId": "product_insurance",
        "visible": true
    },
    "accounting": {
        "status": "Ei käytössä",
        "accountantName": null,
        "accountantEmail": null,
        "accountantPhone": null,
        "enabled": false,
        "id": "accounting",
        "title": "Kirjanpitoraportit",
        "description": "Palkkalaskelmien tiedot helposti kirjanpitäjälle",
        "img": "https://cdn.salaxy.com/img/elems/product-logos/accounting.png",
        "articleId": "product_accounting",
        "visible": true
    },
    "healthCareHeltti": {
        "package": "notDefined",
        "industry": "notDefined",
        "status": "Ei sopimusta",
        "enabled": false,
        "id": "healthCareHeltti",
        "title": "Työterveyshuolto",
        "description": "Tuottavammat ja terveemmät työntekijät",
        "img": "https://cdn.salaxy.com/img/elems/product-logos/heltti.png",
        "articleId": "product_healthCareHeltti",
        "visible": true
    },
    "pensionEntrepreneur": {
        "status": "Ei YEL-sopimusta",
        "tempContractMarker": false,
        "enabled": false,
        "id": "pensionEntrepreneur",
        "title": "Yrittäjän eläke",
        "description": "YEL-vakuutus on yrittäjän eläketurva",
        "img": "https://cdn.salaxy.com/img/elems/product-logos/varma-yel.png",
        "articleId": "product_pensionEntrepreneur",
        "visible": true
    },
    "taxCard": {
        "currentCard": null,
        "status": "Ei verokorttia",
        "id": "taxCard",
        "title": "Verokortti (TT)",
        "description": "Työntekijän verokortti ja sen käsittely",
        "img": "https://cdn.salaxy.com/img/elems/product-logos/palkkaus.png",
        "articleId": "product_taxCard",
        "enabled": false,
        "visible": true
    }
};

},{}],35:[function(require,module,exports){
/* tslint:disable:max-line-length */
// tslint:disable:object-literal-key-quotes
// tslint:disable:trailing-comma
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * This data is generated from
 * ****************************************************
 * DEVELOPERS NOTE: COPY from https://test-api.salaxy.com/docs/EnumJson / http://localhost:82/docs/EnumJson
 * DO NOT EDIT DIRECTLY
 * @hidden
 */
exports.generatedEnumData = [
    {
        "name": "AbcSection",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "doNotShow"
            },
            {
                "order": 10,
                "name": "employment"
            },
            {
                "order": 20,
                "name": "insurance"
            },
            {
                "order": 30,
                "name": "salary"
            },
            {
                "order": 40,
                "name": "examples"
            },
            {
                "order": 50,
                "name": "palkkausGeneral"
            },
            {
                "order": 60,
                "name": "palkkausInstructions"
            },
            {
                "order": 100,
                "name": "blog"
            },
            {
                "order": 110,
                "name": "press"
            },
            {
                "order": 200,
                "name": "personEmployer"
            },
            {
                "order": 201,
                "name": "householdEmployer"
            },
            {
                "order": 210,
                "name": "worker"
            },
            {
                "order": 211,
                "name": "employee"
            },
            {
                "order": 220,
                "name": "entrepreneur"
            },
            {
                "order": 221,
                "name": "association"
            },
            {
                "order": 222,
                "name": "businessOwner"
            },
            {
                "order": 301,
                "name": "productLongDescription"
            },
            {
                "order": 302,
                "name": "documentTemplates"
            },
            {
                "order": 303,
                "name": "instructionsAndExamples"
            }
        ]
    },
    {
        "name": "AbsenceCauseCode",
        "description": null,
        "values": [
            {
                "order": 10,
                "name": "unpaidLeave"
            },
            {
                "order": 11,
                "name": "personalReason"
            },
            {
                "order": 1001,
                "name": "illness"
            },
            {
                "order": 1002,
                "name": "partTimeSickLeave"
            },
            {
                "order": 1003,
                "name": "parentalLeave"
            },
            {
                "order": 1004,
                "name": "specialMaternityLeave"
            },
            {
                "order": 1005,
                "name": "rehabilitation"
            },
            {
                "order": 1006,
                "name": "childIllness"
            },
            {
                "order": 1007,
                "name": "partTimeChildCareLeave"
            },
            {
                "order": 1008,
                "name": "training"
            },
            {
                "order": 1009,
                "name": "jobAlternationLeave"
            },
            {
                "order": 1010,
                "name": "studyLeave"
            },
            {
                "order": 1011,
                "name": "industrialAction"
            },
            {
                "order": 1012,
                "name": "interruptionInWorkProvision"
            },
            {
                "order": 1013,
                "name": "leaveOfAbsence"
            },
            {
                "order": 1014,
                "name": "militaryRefresherTraining"
            },
            {
                "order": 1015,
                "name": "militaryService"
            },
            {
                "order": 1016,
                "name": "layOff"
            },
            {
                "order": 1017,
                "name": "childCareLeave"
            },
            {
                "order": 1018,
                "name": "midWeekHoliday"
            },
            {
                "order": 1019,
                "name": "accruedHoliday"
            },
            {
                "order": 1020,
                "name": "occupationalAccident"
            },
            {
                "order": 1021,
                "name": "annualLeave"
            },
            {
                "order": 1022,
                "name": "partTimeAbsenceDueToRehabilitation"
            },
            {
                "order": 1099,
                "name": "other"
            }
        ]
    },
    {
        "name": "AccountingReportRowType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "debit"
            },
            {
                "order": 1,
                "name": "credit"
            },
            {
                "order": 2,
                "name": "total"
            },
            {
                "order": 3,
                "name": "groupHeader"
            },
            {
                "order": 4,
                "name": "groupTotal"
            },
            {
                "order": 5,
                "name": "childRow"
            }
        ]
    },
    {
        "name": "AccountingReportTableType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "classic"
            },
            {
                "order": 1,
                "name": "simple"
            }
        ]
    },
    {
        "name": "AgeGroupCode",
        "description": null,
        "values": [
            {
                "order": 1,
                "name": "a"
            },
            {
                "order": 2,
                "name": "b"
            },
            {
                "order": 3,
                "name": "c"
            },
            {
                "order": 4,
                "name": "u"
            }
        ]
    },
    {
        "name": "AgeRange",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "unknown"
            },
            {
                "order": 15,
                "name": "age_15"
            },
            {
                "order": 16,
                "name": "age16"
            },
            {
                "order": 17,
                "name": "age17"
            },
            {
                "order": 18,
                "name": "age18_52"
            },
            {
                "order": 53,
                "name": "age53_62"
            },
            {
                "order": 63,
                "name": "age63_64"
            },
            {
                "order": 65,
                "name": "age65_67"
            },
            {
                "order": 68,
                "name": "age68AndOVer"
            }
        ]
    },
    {
        "name": "AllowanceCode",
        "description": null,
        "values": [
            {
                "order": 1,
                "name": "mealAllowance"
            },
            {
                "order": 2,
                "name": "partialDailyAllowance"
            },
            {
                "order": 3,
                "name": "fullDailyAllowance"
            },
            {
                "order": 4,
                "name": "internationalDailyAllowance"
            }
        ]
    },
    {
        "name": "AnnualLeavePaymentKind",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "planned"
            },
            {
                "order": 101,
                "name": "manualSalary"
            },
            {
                "order": 102,
                "name": "manualCompensation"
            },
            {
                "order": 103,
                "name": "manualBonus"
            },
            {
                "order": 201,
                "name": "paidCalc"
            },
            {
                "order": 202,
                "name": "draftCalc"
            }
        ]
    },
    {
        "name": "ApiTestErrorType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "default"
            },
            {
                "order": 10,
                "name": "userFriendly"
            }
        ]
    },
    {
        "name": "ApiValidationErrorType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "general"
            },
            {
                "order": 10,
                "name": "required"
            },
            {
                "order": 20,
                "name": "invalid"
            },
            {
                "order": 30,
                "name": "warning"
            }
        ]
    },
    {
        "name": "AuthenticationMethod",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "emailPwdLocal"
            },
            {
                "order": 11,
                "name": "facebook"
            },
            {
                "order": 12,
                "name": "google"
            },
            {
                "order": 13,
                "name": "microsoft"
            },
            {
                "order": 14,
                "name": "linkedIn"
            },
            {
                "order": 15,
                "name": "auth0Database"
            },
            {
                "order": 16,
                "name": "x509"
            },
            {
                "order": 17,
                "name": "salaxy"
            },
            {
                "order": 18,
                "name": "test"
            },
            {
                "order": 1000,
                "name": "internalLocalhost"
            }
        ]
    },
    {
        "name": "AuthorizationStatus",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "oK"
            },
            {
                "order": -40,
                "name": "accessDenied"
            },
            {
                "order": -30,
                "name": "expiredOauthToken"
            },
            {
                "order": -20,
                "name": "invalidOAuthToken"
            },
            {
                "order": -10,
                "name": "noOauthToken"
            }
        ]
    },
    {
        "name": "AuthorizationType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "none"
            },
            {
                "order": 1,
                "name": "employerAuthorization"
            },
            {
                "order": 2,
                "name": "workerContract"
            },
            {
                "order": 3,
                "name": "companyContract"
            },
            {
                "order": 100,
                "name": "manual"
            },
            {
                "order": 999,
                "name": "temporary"
            }
        ]
    },
    {
        "name": "AvatarPictureType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "icon"
            },
            {
                "order": 1,
                "name": "uploaded"
            },
            {
                "order": 2,
                "name": "gravatar"
            }
        ]
    },
    {
        "name": "BankPaymentType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "unknown"
            },
            {
                "order": 1,
                "name": "error"
            },
            {
                "order": 10,
                "name": "paytrailBatch"
            },
            {
                "order": 11,
                "name": "netvisorPayment"
            },
            {
                "order": 20,
                "name": "salaryGrossPayment"
            },
            {
                "order": 21,
                "name": "refundPayment"
            },
            {
                "order": 22,
                "name": "partialRefundPayment"
            },
            {
                "order": 30,
                "name": "insuranceGrossPayment"
            },
            {
                "order": 50,
                "name": "netSalary"
            },
            {
                "order": 51,
                "name": "salaryAdvance"
            },
            {
                "order": 100,
                "name": "taxAccount"
            },
            {
                "order": 200,
                "name": "tvr"
            },
            {
                "order": 210,
                "name": "tvrRfnd"
            },
            {
                "order": 300,
                "name": "palkkausFees"
            },
            {
                "order": 310,
                "name": "bankFees"
            },
            {
                "order": 320,
                "name": "paytrailFees"
            },
            {
                "order": 501,
                "name": "insuranceLahiTapiola"
            },
            {
                "order": 1000,
                "name": "tyel"
            },
            {
                "order": 1101,
                "name": "tyelEteraContract"
            },
            {
                "order": 1102,
                "name": "tyelEteraTemp"
            },
            {
                "order": 1103,
                "name": "tyelEteraUnknown"
            },
            {
                "order": 1201,
                "name": "tyelEloContract"
            },
            {
                "order": 1202,
                "name": "tyelEloTemp"
            },
            {
                "order": 1203,
                "name": "tyelEloInitialImport"
            },
            {
                "order": 1301,
                "name": "tyelVarmaContract"
            },
            {
                "order": 1302,
                "name": "tyelVarmaTemp"
            },
            {
                "order": 1401,
                "name": "tyelIlmarinenContract"
            },
            {
                "order": 1402,
                "name": "tyelIlmarinenTemp"
            },
            {
                "order": 2000,
                "name": "union"
            },
            {
                "order": 2001,
                "name": "unionRaksa"
            },
            {
                "order": 10001,
                "name": "saldoYearBegin"
            },
            {
                "order": 10002,
                "name": "saldoYearEnd"
            }
        ]
    },
    {
        "name": "BenefitCode",
        "description": null,
        "values": [
            {
                "order": 1,
                "name": "accommodationBenefit"
            },
            {
                "order": 2,
                "name": "telephoneBenefit"
            },
            {
                "order": 3,
                "name": "mealBenefit"
            },
            {
                "order": 4,
                "name": "otherBenefits"
            }
        ]
    },
    {
        "name": "BlobFileType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "unknown"
            },
            {
                "order": 1,
                "name": "authorizationPdf"
            },
            {
                "order": 2,
                "name": "avatar"
            },
            {
                "order": 3,
                "name": "taxCard"
            },
            {
                "order": 4,
                "name": "expensesReceipt"
            },
            {
                "order": 5,
                "name": "raksaloki"
            },
            {
                "order": 6,
                "name": "template"
            },
            {
                "order": 7,
                "name": "eInvoice"
            },
            {
                "order": 8,
                "name": "temporary"
            },
            {
                "order": 100,
                "name": "monthlyReport"
            },
            {
                "order": 101,
                "name": "yearlyReport"
            },
            {
                "order": 102,
                "name": "calcReport"
            }
        ]
    },
    {
        "name": "BlobRepository",
        "description": null,
        "values": [
            {
                "order": 1,
                "name": "userFiles"
            },
            {
                "order": 2,
                "name": "versionHistory"
            },
            {
                "order": 3,
                "name": "systemFiles"
            },
            {
                "order": 4,
                "name": "payload"
            },
            {
                "order": 5,
                "name": "reports"
            },
            {
                "order": 6,
                "name": "cdnImages"
            },
            {
                "order": 100,
                "name": "gitContent"
            },
            {
                "order": 200,
                "name": "fileSystemContent"
            }
        ]
    },
    {
        "name": "CalcGroup",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "baseSalary"
            },
            {
                "order": 2,
                "name": "salaryAdditions"
            },
            {
                "order": 3,
                "name": "benefits"
            },
            {
                "order": 4,
                "name": "expenses"
            },
            {
                "order": 5,
                "name": "deductions"
            },
            {
                "order": 6,
                "name": "otherNoPayment"
            },
            {
                "order": 100,
                "name": "totals"
            },
            {
                "order": 200,
                "name": "disabled"
            }
        ]
    },
    {
        "name": "CalculationFlag",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "exclude"
            },
            {
                "order": 1,
                "name": "pensionInsurance"
            },
            {
                "order": 2,
                "name": "accidentInsurance"
            },
            {
                "order": 3,
                "name": "unemploymentInsurance"
            },
            {
                "order": 4,
                "name": "healthInsurance"
            },
            {
                "order": 10,
                "name": "insurancesDeduction"
            },
            {
                "order": 100,
                "name": "noTax"
            },
            {
                "order": 101,
                "name": "tax"
            },
            {
                "order": 102,
                "name": "taxDeduction"
            },
            {
                "order": 200,
                "name": "cfNoPayment"
            },
            {
                "order": 201,
                "name": "cfPayment"
            },
            {
                "order": 202,
                "name": "cfDeduction"
            },
            {
                "order": 203,
                "name": "cfDeductionAtSalaxy"
            }
        ]
    },
    {
        "name": "CalculationResultRowType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "totalBenefits"
            },
            {
                "order": 2,
                "name": "totalExpenses"
            },
            {
                "order": 3,
                "name": "totalSocialSecurityEmployer"
            },
            {
                "order": 4,
                "name": "totalSocialSecurityEmployerDebt"
            },
            {
                "order": 5,
                "name": "totalSocialSecurityEmployerPayment"
            },
            {
                "order": 6,
                "name": "totalPension"
            },
            {
                "order": 7,
                "name": "totalPensionPayment"
            },
            {
                "order": 8,
                "name": "totalPensionEmployer"
            },
            {
                "order": 9,
                "name": "totalPensionEmployerDebt"
            },
            {
                "order": 10,
                "name": "totalPensionWorker"
            },
            {
                "order": 11,
                "name": "totalUnemployment"
            },
            {
                "order": 12,
                "name": "totalUnemploymentPayment"
            },
            {
                "order": 13,
                "name": "totalUnemploymentEmployer"
            },
            {
                "order": 14,
                "name": "totalUnemploymentEmployerDebt"
            },
            {
                "order": 15,
                "name": "totalUnemploymentWorker"
            },
            {
                "order": 16,
                "name": "totalPalkkaus"
            },
            {
                "order": 17,
                "name": "totalSalary"
            },
            {
                "order": 18,
                "name": "totalTax"
            },
            {
                "order": 19,
                "name": "totalTaxPayment"
            },
            {
                "order": 20,
                "name": "totalPayment"
            },
            {
                "order": 21,
                "name": "totalWorkerPayment"
            }
        ]
    },
    {
        "name": "CalculationRowSource",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "salaryPage"
            },
            {
                "order": 1,
                "name": "tesSelection"
            },
            {
                "order": 2,
                "name": "manualRow"
            }
        ]
    },
    {
        "name": "CalculationRowType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "unknown"
            },
            {
                "order": 1,
                "name": "salary"
            },
            {
                "order": 2,
                "name": "hourlySalary"
            },
            {
                "order": 3,
                "name": "monthlySalary"
            },
            {
                "order": 4,
                "name": "totalWorkerPayment"
            },
            {
                "order": 5,
                "name": "totalEmployerPayment"
            },
            {
                "order": 9,
                "name": "compensation"
            },
            {
                "order": 10,
                "name": "overtime"
            },
            {
                "order": 11,
                "name": "tesWorktimeShortening"
            },
            {
                "order": 12,
                "name": "eveningAddition"
            },
            {
                "order": 13,
                "name": "nightimeAddition"
            },
            {
                "order": 14,
                "name": "saturdayAddition"
            },
            {
                "order": 15,
                "name": "sundayWork"
            },
            {
                "order": 19,
                "name": "otherAdditions"
            },
            {
                "order": 101,
                "name": "accomodationBenefit"
            },
            {
                "order": 102,
                "name": "mealBenefit"
            },
            {
                "order": 103,
                "name": "phoneBenefit"
            },
            {
                "order": 104,
                "name": "carBenefit"
            },
            {
                "order": 199,
                "name": "otherBenefit"
            },
            {
                "order": 201,
                "name": "holidayCompensation"
            },
            {
                "order": 202,
                "name": "holidayBonus"
            },
            {
                "order": 203,
                "name": "holidaySalary"
            },
            {
                "order": 301,
                "name": "dailyAllowance"
            },
            {
                "order": 302,
                "name": "dailyAllowanceHalf"
            },
            {
                "order": 303,
                "name": "mealCompensation"
            },
            {
                "order": 304,
                "name": "milageOwnCar"
            },
            {
                "order": 305,
                "name": "toolCompensation"
            },
            {
                "order": 306,
                "name": "expenses"
            },
            {
                "order": 307,
                "name": "milageDaily"
            },
            {
                "order": 308,
                "name": "milageOther"
            },
            {
                "order": 401,
                "name": "unionPayment"
            },
            {
                "order": 402,
                "name": "foreclosure"
            },
            {
                "order": 403,
                "name": "advance"
            },
            {
                "order": 404,
                "name": "foreclosureByPalkkaus"
            },
            {
                "order": 405,
                "name": "prepaidExpenses"
            },
            {
                "order": 406,
                "name": "otherDeductions"
            },
            {
                "order": 901,
                "name": "childCareSubsidy"
            },
            {
                "order": 902,
                "name": "chainsawReduction"
            },
            {
                "order": 1010,
                "name": "nonProfitOrg"
            },
            {
                "order": 1020,
                "name": "subsidisedCommute"
            },
            {
                "order": 1030,
                "name": "irIncomeType"
            },
            {
                "order": 1040,
                "name": "board"
            },
            {
                "order": 1050,
                "name": "remuneration"
            },
            {
                "order": 1060,
                "name": "otherCompensation"
            },
            {
                "order": 1070,
                "name": "workingTimeCompensation"
            },
            {
                "order": 1080,
                "name": "employmentTermination"
            },
            {
                "order": 9999,
                "name": "totals"
            }
        ]
    },
    {
        "name": "CalculationRowUnit",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "count"
            },
            {
                "order": 2,
                "name": "percent"
            },
            {
                "order": 3,
                "name": "days"
            },
            {
                "order": 4,
                "name": "kilometers"
            },
            {
                "order": 5,
                "name": "hours"
            }
        ]
    },
    {
        "name": "CalculationStatus",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "draft"
            },
            {
                "order": 1,
                "name": "paymentStarted"
            },
            {
                "order": 2,
                "name": "paymentSucceeded"
            },
            {
                "order": 3,
                "name": "paymentCanceled"
            },
            {
                "order": 4,
                "name": "paymentError"
            },
            {
                "order": 5,
                "name": "paymentWorkerCopy"
            },
            {
                "order": 6,
                "name": "workerRequested"
            },
            {
                "order": 7,
                "name": "workerRequestAccepted"
            },
            {
                "order": 8,
                "name": "workerRequestDeclined"
            },
            {
                "order": 9,
                "name": "paymentRefunded"
            },
            {
                "order": 200,
                "name": "payrollDraft"
            },
            {
                "order": 1000,
                "name": "template"
            }
        ]
    },
    {
        "name": "CarBenefitCode",
        "description": null,
        "values": [
            {
                "order": 1,
                "name": "limitedCarBenefit"
            },
            {
                "order": 2,
                "name": "fullCarBenefit"
            }
        ]
    },
    {
        "name": "CompanyType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "unknown"
            },
            {
                "order": 100,
                "name": "fiOy"
            },
            {
                "order": 101,
                "name": "fiTm"
            },
            {
                "order": 102,
                "name": "fiRy"
            },
            {
                "order": 103,
                "name": "fiYy"
            }
        ]
    },
    {
        "name": "ContractPartyType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "person"
            },
            {
                "order": 1,
                "name": "customContact"
            }
        ]
    },
    {
        "name": "EmploymentRelationType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "salary"
            },
            {
                "order": 2,
                "name": "hourlySalary"
            },
            {
                "order": 3,
                "name": "monthlySalary"
            },
            {
                "order": 100,
                "name": "compensation"
            },
            {
                "order": 101,
                "name": "boardMember"
            },
            {
                "order": 200,
                "name": "entrepreneur"
            },
            {
                "order": 201,
                "name": "farmer"
            },
            {
                "order": 301,
                "name": "employedByStateEmploymentFund"
            },
            {
                "order": 304,
                "name": "keyEmployee"
            },
            {
                "order": 308,
                "name": "athlete"
            },
            {
                "order": 309,
                "name": "performingArtist"
            }
        ]
    },
    {
        "name": "EmploymentSalaryType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "unknown"
            },
            {
                "order": 1,
                "name": "hourlyPay"
            },
            {
                "order": 2,
                "name": "montlyPay"
            },
            {
                "order": 3,
                "name": "otherPay"
            }
        ]
    },
    {
        "name": "EmploymentType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "unknown"
            },
            {
                "order": 1,
                "name": "job"
            },
            {
                "order": 2,
                "name": "partTime"
            },
            {
                "order": 3,
                "name": "fullTime"
            }
        ]
    },
    {
        "name": "EmploymentWorkHoursType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "hoursPerDay"
            },
            {
                "order": 1,
                "name": "hoursPerWeek"
            },
            {
                "order": 2,
                "name": "hourPerTwoWeeks"
            },
            {
                "order": 3,
                "name": "hourPerThreeWeeks"
            }
        ]
    },
    {
        "name": "ESalaryPaymentStatus",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "created"
            },
            {
                "order": 10,
                "name": "shared"
            },
            {
                "order": 100,
                "name": "opened"
            },
            {
                "order": 200,
                "name": "employerLinked"
            },
            {
                "order": 300,
                "name": "calculationCreated"
            },
            {
                "order": 400,
                "name": "paymentStarted"
            },
            {
                "order": 410,
                "name": "paymentSucceeded"
            },
            {
                "order": 450,
                "name": "paymentCanceled"
            }
        ]
    },
    {
        "name": "DateOfBirthAccuracy",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "assumption"
            },
            {
                "order": 1,
                "name": "ageBased"
            },
            {
                "order": 2,
                "name": "ageGroupBased"
            },
            {
                "order": 3,
                "name": "monthCorrect"
            },
            {
                "order": 10,
                "name": "exact"
            },
            {
                "order": 20,
                "name": "verified"
            }
        ]
    },
    {
        "name": "EmployerType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "unknown"
            },
            {
                "order": 10,
                "name": "miniEmployer"
            },
            {
                "order": 20,
                "name": "smallEmployer"
            },
            {
                "order": 40,
                "name": "fullTimeEmployer"
            },
            {
                "order": 41,
                "name": "tyelOwnContractEmployer"
            }
        ]
    },
    {
        "name": "FrameworkAgreement",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "notDefined"
            },
            {
                "order": 1,
                "name": "construction"
            },
            {
                "order": 3,
                "name": "mll"
            },
            {
                "order": 4,
                "name": "childCare"
            },
            {
                "order": 8,
                "name": "cleaning"
            },
            {
                "order": 10,
                "name": "santaClaus"
            },
            {
                "order": 1000,
                "name": "entrepreneur"
            },
            {
                "order": 9999,
                "name": "other"
            }
        ]
    },
    {
        "name": "Gender",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "unknown"
            },
            {
                "order": 1,
                "name": "male"
            },
            {
                "order": 2,
                "name": "female"
            }
        ]
    },
    {
        "name": "HelttiIndustry",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "notDefined"
            },
            {
                "order": 100,
                "name": "i"
            },
            {
                "order": 110,
                "name": "j"
            },
            {
                "order": 120,
                "name": "k"
            },
            {
                "order": 140,
                "name": "m"
            },
            {
                "order": 160,
                "name": "o"
            },
            {
                "order": 170,
                "name": "n"
            },
            {
                "order": 170,
                "name": "n"
            },
            {
                "order": 180,
                "name": "q"
            },
            {
                "order": 190,
                "name": "r"
            },
            {
                "order": 200,
                "name": "s"
            },
            {
                "order": 999,
                "name": "other"
            }
        ]
    },
    {
        "name": "HelttiProductPackage",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "notDefined"
            },
            {
                "order": 10,
                "name": "small"
            },
            {
                "order": 20,
                "name": "medium"
            },
            {
                "order": 30,
                "name": "large"
            }
        ]
    },
    {
        "name": "IncomeEarnerType",
        "description": null,
        "values": [
            {
                "order": 1,
                "name": "employedByStateEmploymentFund"
            },
            {
                "order": 2,
                "name": "jointOwnerWithPayer"
            },
            {
                "order": 3,
                "name": "partialOwner"
            },
            {
                "order": 4,
                "name": "keyEmployee"
            },
            {
                "order": 5,
                "name": "leasedEmployeeLivingAbroad"
            },
            {
                "order": 6,
                "name": "personWorkingInFrontierDistrict"
            },
            {
                "order": 7,
                "name": "personWorkingAbroad"
            },
            {
                "order": 8,
                "name": "athlete"
            },
            {
                "order": 9,
                "name": "performingArtist"
            },
            {
                "order": 10,
                "name": "restrictedPeriodInFinland"
            },
            {
                "order": 11,
                "name": "netOfTaxContract"
            },
            {
                "order": 12,
                "name": "organization"
            },
            {
                "order": 13,
                "name": "personWorkingOnAlandFerry"
            },
            {
                "order": 14,
                "name": "entrepreneurOrFarmerNoPensionRequired"
            },
        ]
    },
    {
        "name": "Holiday",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "newYearsDay"
            },
            {
                "order": 1,
                "name": "epiphany"
            },
            {
                "order": 2,
                "name": "goodFriday"
            },
            {
                "order": 3,
                "name": "easterSunday"
            },
            {
                "order": 4,
                "name": "easterSaturday"
            },
            {
                "order": 5,
                "name": "easterMonday"
            },
            {
                "order": 6,
                "name": "mayDay"
            },
            {
                "order": 7,
                "name": "ascensionDay"
            },
            {
                "order": 8,
                "name": "pentecost"
            },
            {
                "order": 9,
                "name": "midsummerEve"
            },
            {
                "order": 10,
                "name": "midsummerDay"
            },
            {
                "order": 11,
                "name": "allSaintsDay"
            },
            {
                "order": 12,
                "name": "independenceDay"
            },
            {
                "order": 13,
                "name": "christmasEve"
            },
            {
                "order": 14,
                "name": "christmasDay"
            },
            {
                "order": 15,
                "name": "stStephensDay"
            }
        ]
    },
    {
        "name": "HolidayAccrualSource",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "initial"
            },
            {
                "order": 1,
                "name": "manual"
            },
            {
                "order": 10,
                "name": "calcDraft"
            },
            {
                "order": 11,
                "name": "calcPaid"
            }
        ]
    },
    {
        "name": "HolidayBonusPaymentMethod",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "none"
            },
            {
                "order": 1,
                "name": "payForHolidaySalary"
            },
            {
                "order": 2,
                "name": "paySummerBonus"
            },
            {
                "order": 24,
                "name": "pay24Days"
            },
            {
                "order": 100,
                "name": "payAllBonus"
            }
        ]
    },
    {
        "name": "HolidayCode",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 10,
                "name": "permanent14Days"
            },
            {
                "order": 11,
                "name": "permanent35Hours"
            },
            {
                "order": 20,
                "name": "temporaryTimeOff"
            },
            {
                "order": 21,
                "name": "holidayCompensation"
            },
            {
                "order": 22,
                "name": "holidayCompensationIncluded"
            },
            {
                "order": 99,
                "name": "noHolidays"
            }
        ]
    },
    {
        "name": "HolidayGroup",
        "description": null,
        "values": [
            {
                "order": 1,
                "name": "official"
            },
            {
                "order": 2,
                "name": "nonBanking"
            },
            {
                "order": 4,
                "name": "holiday"
            }
        ]
    },
    {
        "name": "InsuranceCompany",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "none"
            },
            {
                "order": 1,
                "name": "lähiTapiola"
            },
            {
                "order": 2,
                "name": "pohjola"
            },
            {
                "order": 3,
                "name": "if"
            },
            {
                "order": 4,
                "name": "fennia"
            },
            {
                "order": 5,
                "name": "aVakuutus"
            },
            {
                "order": 6,
                "name": "aktia"
            },
            {
                "order": 7,
                "name": "pohjantähti"
            },
            {
                "order": 8,
                "name": "tryg"
            },
            {
                "order": 9,
                "name": "ålands"
            },
            {
                "order": 10,
                "name": "turva"
            },
            {
                "order": 11,
                "name": "redarnas"
            },
            {
                "order": 12,
                "name": "folksam"
            },
            {
                "order": 13,
                "name": "alandia"
            },
            {
                "order": 999999,
                "name": "other"
            },
            {
                "order": 1000000,
                "name": "pending"
            }
        ]
    },
    {
        "name": "IrFlags",
        "description": null,
        "values": [
            {
                "order": 10,
                "name": "noMoney"
            },
            {
                "order": 20,
                "name": "oneOff"
            },
            {
                "order": 30,
                "name": "unjustEnrichment"
            }
        ]
    },
    {
        "name": "IrInsuranceExceptions",
        "description": null,
        "values": [
            {
                "order": 501,
                "name": "includeAll"
            },
            {
                "order": 502,
                "name": "includePension"
            },
            {
                "order": 503,
                "name": "includeHealthInsurance"
            },
            {
                "order": 505,
                "name": "includeUnemployment"
            },
            {
                "order": 506,
                "name": "includeAccidentInsurance"
            },
            {
                "order": 601,
                "name": "excludeAll"
            },
            {
                "order": 602,
                "name": "excludePension"
            },
            {
                "order": 603,
                "name": "excludeHealthInsurance"
            },
            {
                "order": 605,
                "name": "excludeUnemployment"
            },
            {
                "order": 606,
                "name": "excludeAccidentInsurance"
            }
        ]
    },
    {
        "name": "IrRowSourceType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "manual"
            },
            {
                "order": 1,
                "name": "usecase"
            },
            {
                "order": 2,
                "name": "usecaseV02"
            }
        ]
    },
    {
        "name": "LegalEntityType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "person"
            },
            {
                "order": 2,
                "name": "company"
            },
            {
                "order": 3,
                "name": "personCreatedByEmployer"
            },
            {
                "order": 4,
                "name": "partner"
            }
        ]
    },
    {
        "name": "LegacyTaxcardType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "example"
            },
            {
                "order": 1,
                "name": "noTaxCard"
            },
            {
                "order": 2,
                "name": "sideIncome"
            },
            {
                "order": 3,
                "name": "noTaxPrepayment"
            },
            {
                "order": 4,
                "name": "taxCardA"
            },
            {
                "order": 5,
                "name": "taxCardB"
            },
            {
                "order": 6,
                "name": "freelancer"
            },
            {
                "order": 7,
                "name": "steps"
            },
            {
                "order": 99,
                "name": "others"
            }
        ]
    },
    {
        "name": "MessageType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "email"
            },
            {
                "order": 1,
                "name": "sms"
            }
        ]
    },
    {
        "name": "OnboardingStatus",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "created"
            },
            {
                "order": 10,
                "name": "open"
            },
            {
                "order": 100,
                "name": "done"
            },
            {
                "order": 100,
                "name": "done"
            }
        ]
    },
    {
        "name": "PalkkausCampaignPricing",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "none"
            },
            {
                "order": 1,
                "name": "campaignFirstUse"
            },
            {
                "order": 2,
                "name": "campaignAfterFirstUse"
            },
            {
                "order": 3,
                "name": "companyFreeTrial"
            }
        ]
    },
    {
        "name": "PartnerSite",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "unknown"
            },
            {
                "order": 1,
                "name": "palkkaus"
            },
            {
                "order": 2,
                "name": "palkkausIdentified"
            },
            {
                "order": 3,
                "name": "palkkausEmployerFillIn"
            },
            {
                "order": 10,
                "name": "example"
            },
            {
                "order": 100,
                "name": "dev"
            },
            {
                "order": 110,
                "name": "refugeeJobs"
            },
            {
                "order": 120,
                "name": "talkkarit"
            },
            {
                "order": 130,
                "name": "raksa"
            },
            {
                "order": 140,
                "name": "palkkaapakolainen"
            },
            {
                "order": 1010,
                "name": "careDotCom"
            },
            {
                "order": 1020,
                "name": "duunitori"
            },
            {
                "order": 1030,
                "name": "mol"
            }
        ]
    },
    {
        "name": "PaymentMethod",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "sepa"
            },
            {
                "order": 2,
                "name": "siirto"
            }
        ]
    },
    {
        "name": "PaymentStatus",
        "description": null,
        "values": [
            {
                "order": 1,
                "name": "new"
            },
            {
                "order": 100,
                "name": "sentToBank"
            },
            {
                "order": 101,
                "name": "bankTechApproval"
            },
            {
                "order": 102,
                "name": "bankDelivered"
            },
            {
                "order": 109,
                "name": "bankPartialError"
            },
            {
                "order": 110,
                "name": "bankError"
            },
            {
                "order": 1000,
                "name": "paid"
            },
            {
                "order": 8999,
                "name": "unknown"
            },
            {
                "order": 9999,
                "name": "cancelled"
            }
        ]
    },
    {
        "name": "PayrollCalculationHandling",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "default"
            },
            {
                "order": 1,
                "name": "entrepreneurPension"
            }
        ]
    },
    {
        "name": "PayrollStatus",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "draft"
            },
            {
                "order": 1,
                "name": "paymentStarted"
            },
            {
                "order": 2,
                "name": "paymentSucceeded"
            },
            {
                "order": 3,
                "name": "paymentCanceled"
            },
            {
                "order": 4,
                "name": "paymentError"
            },
            {
                "order": 1000,
                "name": "template"
            }
        ]
    },
    {
        "name": "PensionCalculation",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "employee"
            },
            {
                "order": 2,
                "name": "entrepreneur"
            },
            {
                "order": 3,
                "name": "farmer"
            },
            {
                "order": 4,
                "name": "partialOwner"
            },
            {
                "order": 5,
                "name": "athlete"
            },
            {
                "order": 6,
                "name": "compensation"
            },
            {
                "order": 7,
                "name": "boardRemuneration"
            },
            {
                "order": 8,
                "name": "smallEntrepreneur"
            },
            {
                "order": 9,
                "name": "smallFarmer"
            }
        ]
    },
    {
        "name": "PensionCompany",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "none"
            },
            {
                "order": 2,
                "name": "etera"
            },
            {
                "order": 3,
                "name": "ilmarinen"
            },
            {
                "order": 4,
                "name": "elo"
            },
            {
                "order": 5,
                "name": "pensionsAlandia"
            },
            {
                "order": 6,
                "name": "varma"
            },
            {
                "order": 7,
                "name": "veritas"
            },
            {
                "order": 8,
                "name": "apteekkien"
            },
            {
                "order": 9,
                "name": "verso"
            },
            {
                "order": 999999,
                "name": "other"
            }
        ]
    },
    {
        "name": "PeriodType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "month"
            },
            {
                "order": 1,
                "name": "quarter"
            },
            {
                "order": 2,
                "name": "year"
            },
            {
                "order": 99,
                "name": "custom"
            }
        ]
    },
    {
        "name": "PricingModel",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "palkkausFee"
            },
            {
                "order": 1,
                "name": "noFee"
            },
            {
                "order": 2,
                "name": "fixedFee"
            }
        ]
    },
    {
        "name": "ProductListFilter",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "available"
            },
            {
                "order": 1,
                "name": "all"
            }
        ]
    },
    {
        "name": "ReportCategory",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "all"
            },
            {
                "order": 1,
                "name": "monthly"
            },
            {
                "order": 2,
                "name": "yearly"
            }
        ]
    },
    {
        "name": "ReportType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "example"
            },
            {
                "order": 100,
                "name": "monthlyDetails"
            },
            {
                "order": 110,
                "name": "taxMonthly4001"
            },
            {
                "order": 120,
                "name": "monthlyPension"
            },
            {
                "order": 190,
                "name": "monthlyLiikekirjuri"
            },
            {
                "order": 200,
                "name": "monthlyRapko"
            },
            {
                "order": 1000,
                "name": "yearlyDetails"
            },
            {
                "order": 1001,
                "name": "yearEndReport"
            },
            {
                "order": 1010,
                "name": "yearlyWorkerSummary"
            },
            {
                "order": 1100,
                "name": "taxYearly7801"
            },
            {
                "order": 1200,
                "name": "unemployment"
            },
            {
                "order": 1210,
                "name": "insurance"
            },
            {
                "order": 1800,
                "name": "householdDeduction"
            },
            {
                "order": 1814,
                "name": "taxHouseholdDeduction14B"
            },
            {
                "order": 1815,
                "name": "taxHouseholdDeduction14BSpouseA"
            },
            {
                "order": 1816,
                "name": "taxHouseholdDeduction14BSpouseB"
            },
            {
                "order": 2000,
                "name": "salarySlip"
            },
            {
                "order": 2001,
                "name": "salarySlipPaid"
            },
            {
                "order": 2002,
                "name": "salarySlipCopy"
            },
            {
                "order": 2010,
                "name": "employerReport"
            },
            {
                "order": 2020,
                "name": "paymentReport"
            },
            {
                "order": 2030,
                "name": "earningsPaymentReport"
            },
            {
                "order": 2031,
                "name": "employersSeparateReport"
            },
            {
                "order": 2200,
                "name": "employmentContract"
            }
        ]
    },
    {
        "name": "Role",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "accountant"
            },
            {
                "order": 2,
                "name": "trustedPartner"
            },
            {
                "order": 3,
                "name": "accountantCandidate"
            },
            {
                "order": 4,
                "name": "pricingPartner"
            }
        ]
    },
    {
        "name": "SalaryKind",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "fixedSalary"
            },
            {
                "order": 2,
                "name": "hourlySalary"
            },
            {
                "order": 3,
                "name": "monthlySalary"
            },
            {
                "order": 50,
                "name": "compensation"
            },
            {
                "order": 100,
                "name": "totalWorkerPayment"
            },
            {
                "order": 101,
                "name": "totalEmployerPayment"
            }
        ]
    },
    {
        "name": "SalaryType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "tyel"
            },
            {
                "order": 1,
                "name": "yel"
            },
            {
                "order": 2,
                "name": "compensation"
            }
        ]
    },
    {
        "name": "SalaryPeriod",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "notDefined"
            },
            {
                "order": 1,
                "name": "hourly"
            },
            {
                "order": 2,
                "name": "monthly"
            },
            {
                "order": 3,
                "name": "fixed"
            }
        ]
    },
    {
        "name": "SalaryPerMonthRange",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "unknown"
            },
            {
                "order": 50,
                "name": "noPensionRequired"
            },
            {
                "order": 60,
                "name": "normal"
            }
        ]
    },
    {
        "name": "SalaryPerYearRange",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "zeroSalary"
            },
            {
                "order": 1,
                "name": "noReportingNecessary"
            },
            {
                "order": 200,
                "name": "noMonthlyReporting"
            },
            {
                "order": 1500,
                "name": "normal"
            }
        ]
    },
    {
        "name": "ServiceModel",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "shared"
            },
            {
                "order": 1,
                "name": "partnerOnly"
            }
        ]
    },
    {
        "name": "SharingLink",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "noSharing"
            },
            {
                "order": 1,
                "name": "unguessable"
            },
            {
                "order": 2,
                "name": "short"
            }
        ]
    },
    {
        "name": "TaxCardIncomeType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "unknown"
            },
            {
                "order": 1,
                "name": "salaxyCalculation"
            },
            {
                "order": 2,
                "name": "previousEmployerSalaries"
            },
            {
                "order": 3,
                "name": "externalSalaries"
            }
        ]
    },
    {
        "name": "TaxcardState",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "new"
            },
            {
                "order": 1,
                "name": "waiting"
            },
            {
                "order": 10,
                "name": "approved"
            },
            {
                "order": 11,
                "name": "rejected"
            },
            {
                "order": 100,
                "name": "employerAdded"
            },
            {
                "order": 200,
                "name": "verifiedVero"
            },
            {
                "order": 300,
                "name": "replaced"
            },
            {
                "order": 900,
                "name": "expired"
            }
        ]
    },
    {
        "name": "TaxcardKind",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "noTaxCard"
            },
            {
                "order": 10,
                "name": "defaultYearly"
            },
            {
                "order": 11,
                "name": "replacement"
            },
            {
                "order": 99,
                "name": "others"
            },
            {
                "order": 900,
                "name": "historical"
            }
        ]
    },
    {
        "name": "TaxDeductionWorkCategories",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "none"
            },
            {
                "order": 1,
                "name": "householdwork"
            },
            {
                "order": 2,
                "name": "carework"
            },
            {
                "order": 4,
                "name": "homeImprovement"
            },
            {
                "order": 8,
                "name": "ownPropety"
            },
            {
                "order": 16,
                "name": "relativesProperty"
            }
        ]
    },
    {
        "name": "TaxReportHandling",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "default"
            },
            {
                "order": 1,
                "name": "noZeroSalaryReport"
            },
            {
                "order": 2,
                "name": "noMonthlyReport"
            }
        ]
    },
    {
        "name": "TesSubtype",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "notSelected"
            },
            {
                "order": 100,
                "name": "constructionCarpenter"
            },
            {
                "order": 101,
                "name": "constructionFloor"
            },
            {
                "order": 105,
                "name": "constructionOther"
            },
            {
                "order": 109,
                "name": "constructionFreeContract"
            }
        ]
    },
    {
        "name": "TestEnum",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "valueZero"
            },
            {
                "order": 1,
                "name": "valueOne"
            },
            {
                "order": 2,
                "name": "valueTwo"
            },
            {
                "order": 3,
                "name": "valueThree"
            },
            {
                "order": 4,
                "name": "valueFour"
            },
            {
                "order": 5,
                "name": "valueFive"
            },
            {
                "order": 6,
                "name": "valueSix"
            },
            {
                "order": 7,
                "name": "valueSeven"
            },
            {
                "order": 8,
                "name": "valueEight"
            },
            {
                "order": 9,
                "name": "valueNine"
            },
            {
                "order": 10,
                "name": "valueTen"
            }
        ]
    },
    {
        "name": "UnionPaymentType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "notSelected"
            },
            {
                "order": 100,
                "name": "raksaNormal"
            },
            {
                "order": 101,
                "name": "raksaUnemploymentOnly"
            },
            {
                "order": 9999,
                "name": "other"
            }
        ]
    },
    {
        "name": "Unit",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "hours"
            },
            {
                "order": 2,
                "name": "days"
            },
            {
                "order": 3,
                "name": "weeks"
            },
            {
                "order": 5,
                "name": "period"
            },
            {
                "order": 1000,
                "name": "one"
            },
            {
                "order": 1001,
                "name": "count"
            },
            {
                "order": 1002,
                "name": "percent"
            },
            {
                "order": 1004,
                "name": "kilometers"
            },
            {
                "order": 2000,
                "name": "euro"
            }
        ]
    },
    {
        "name": "VarmaPensionOrderAction",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "newYel"
            },
            {
                "order": 2,
                "name": "newTyel"
            },
            {
                "order": 3,
                "name": "move"
            }
        ]
    },
    {
        "name": "VarmaPensionOrderYelPayer",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "entrepreneur"
            },
            {
                "order": 2,
                "name": "company"
            }
        ]
    },
    {
        "name": "WageBasis",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 10,
                "name": "monthly"
            },
            {
                "order": 20,
                "name": "hourly"
            },
            {
                "order": 30,
                "name": "performanceBased"
            },
            {
                "order": 999,
                "name": "other"
            }
        ]
    },
    {
        "name": "WebSiteUserRole",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "none"
            },
            {
                "order": 1,
                "name": "household"
            },
            {
                "order": 2,
                "name": "worker"
            },
            {
                "order": 4,
                "name": "company"
            }
        ]
    },
    {
        "name": "YearEndAdminCheck",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "notChecked"
            },
            {
                "order": 1,
                "name": "ok"
            },
            {
                "order": 2,
                "name": "okWithWarning"
            },
            {
                "order": 3,
                "name": "errors"
            }
        ]
    },
    {
        "name": "YearEndFeedbackCalculationType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "unknown"
            },
            {
                "order": 1,
                "name": "salaxyPayment"
            },
            {
                "order": 10,
                "name": "external"
            },
            {
                "order": 100,
                "name": "correction"
            }
        ]
    },
    {
        "name": "YearEndUserFeedback",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "notChecked"
            },
            {
                "order": 1,
                "name": "ok"
            },
            {
                "order": 2,
                "name": "okWithModifications"
            },
            {
                "order": 3,
                "name": "willHandleMyself"
            },
            {
                "order": 4,
                "name": "noYearlyReports"
            }
        ]
    },
    {
        "name": "YtjCompanyType",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "noCompanyType"
            },
            {
                "order": 1,
                "name": "housingCooperative"
            },
            {
                "order": 2,
                "name": "condominium"
            },
            {
                "order": 4,
                "name": "asoAssociation"
            },
            {
                "order": 5,
                "name": "openCompany"
            },
            {
                "order": 6,
                "name": "association"
            },
            {
                "order": 9,
                "name": "hypoAssociation"
            },
            {
                "order": 13,
                "name": "ky"
            },
            {
                "order": 14,
                "name": "osuuskunta"
            },
            {
                "order": 15,
                "name": "cooperativeBank"
            },
            {
                "order": 16,
                "name": "oy"
            },
            {
                "order": 18,
                "name": "foundation"
            },
            {
                "order": 20,
                "name": "savingsBank"
            },
            {
                "order": 21,
                "name": "financialAssociation"
            },
            {
                "order": 22,
                "name": "stateEstablishment"
            },
            {
                "order": 25,
                "name": "insuranceAssociation"
            },
            {
                "order": 26,
                "name": "privateEntrepreneur"
            },
            {
                "order": 29,
                "name": "otherAssociation"
            },
            {
                "order": 31,
                "name": "specialPurposeAssociation"
            },
            {
                "order": 35,
                "name": "forestCareAssociation"
            },
            {
                "order": 38,
                "name": "otherFinancialAssociation"
            },
            {
                "order": 58,
                "name": "mutualInsuranceAssociation"
            },
            {
                "order": 61,
                "name": "municipalEstablishment"
            },
            {
                "order": 62,
                "name": "federationOfMunicipalitiesEstablishment"
            },
            {
                "order": 64,
                "name": "alandFederation"
            },
            {
                "order": 83,
                "name": "europeanCooperative"
            },
            {
                "order": 84,
                "name": "europeanCooperativeBank"
            },
            {
                "order": 90,
                "name": "reindeerHerdingCooperative"
            },
            {
                "order": 999,
                "name": "unknown"
            }
        ]
    },
    {
        "name": "CarBenefitKind",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "limitedCarBenefit"
            },
            {
                "order": 2,
                "name": "fullCarBenefit"
            }
        ]
    },
    {
        "name": "UnionPaymentKind",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 100,
                "name": "raksaNormal"
            },
            {
                "order": 101,
                "name": "raksaUnemploymentOnly"
            },
            {
                "order": 9999,
                "name": "other"
            }
        ]
    },
    {
        "name": "NonProfitOrgKind",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 357,
                "name": "kilometreAllowance"
            },
            {
                "order": 358,
                "name": "dailyAllowance"
            },
            {
                "order": 1358,
                "name": "accomodationAllowance"
            }
        ]
    },
    {
        "name": "SubsidisedCommuteKind",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "noDeduction"
            },
            {
                "order": 2,
                "name": "singleDeduction"
            },
            {
                "order": 10,
                "name": "periodicalDeduction"
            }
        ]
    },
    {
        "name": "MealBenefitKind",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "cateringContract"
            },
            {
                "order": 2,
                "name": "mealTicket"
            },
            {
                "order": 3,
                "name": "taxableAmount"
            },
            {
                "order": 4,
                "name": "mealAllowance"
            },
            {
                "order": 5,
                "name": "institute"
            },
            {
                "order": 6,
                "name": "teacher"
            },
            {
                "order": 7,
                "name": "restaurantWorker"
            }
        ]
    },
    {
        "name": "DailyAllowanceKind",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 1,
                "name": "fullDailyAllowance"
            },
            {
                "order": 2,
                "name": "partialDailyAllowance"
            },
            {
                "order": 3,
                "name": "internationalDailyAllowance"
            },
            {
                "order": 4,
                "name": "mealAllowance"
            }
        ]
    },
    {
        "name": "IrIncomeTypeKind",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            }
        ]
    },
    {
        "name": "BoardKind",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            }
        ]
    },
    {
        "name": "RemunerationKind",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 202,
                "name": "initiativeFee"
            },
            {
                "order": 203,
                "name": "bonusPay"
            },
            {
                "order": 220,
                "name": "commission"
            },
            {
                "order": 223,
                "name": "performanceBonus"
            },
            {
                "order": 226,
                "name": "shareIssueForEmployees"
            },
            {
                "order": 233,
                "name": "profitSharingBonus"
            }
        ]
    },
    {
        "name": "OtherCompensationKind",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 210,
                "name": "meetingFee"
            },
            {
                "order": 214,
                "name": "lectureFee"
            },
            {
                "order": 215,
                "name": "positionOfTrustCompensation"
            },
            {
                "order": 225,
                "name": "accruedTimeOffCompensation"
            },
            {
                "order": 308,
                "name": "membershipOfGoverningBodyCompensation"
            },
            {
                "order": 310,
                "name": "monetaryGiftForEmployees"
            },
            {
                "order": 313,
                "name": "useCompensationAsEarnedIncome"
            },
            {
                "order": 314,
                "name": "useCompensationAsCapitalIncome"
            },
            {
                "order": 316,
                "name": "otherTaxableIncomeAsEarnedIncome"
            },
            {
                "order": 320,
                "name": "stockOptionsAndGrants"
            },
            {
                "order": 326,
                "name": "employeeInventionCompensation"
            },
            {
                "order": 332,
                "name": "capitalIncomePayment"
            },
            {
                "order": 339,
                "name": "workEffortBasedDividendsAsWage"
            },
            {
                "order": 340,
                "name": "workEffortBasedDividendsAsNonWage"
            },
            {
                "order": 343,
                "name": "employeeStockOption"
            },
            {
                "order": 361,
                "name": "employeeStockOptionWithLowerPrice"
            }
        ]
    },
    {
        "name": "WorkingTimeCompensationKind",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 205,
                "name": "emergencyWorkCompensation"
            },
            {
                "order": 206,
                "name": "eveningWorkCompensation"
            },
            {
                "order": 207,
                "name": "eveningShiftAllowance"
            },
            {
                "order": 211,
                "name": "saturdayPay"
            },
            {
                "order": 212,
                "name": "extraWorkPremium"
            },
            {
                "order": 216,
                "name": "otherCompensation"
            },
            {
                "order": 217,
                "name": "waitingTimeCompensation"
            },
            {
                "order": 221,
                "name": "sundayWorkCompensation"
            },
            {
                "order": 230,
                "name": "standByCompensation"
            },
            {
                "order": 232,
                "name": "weeklyRestCompensation"
            },
            {
                "order": 235,
                "name": "overtimeCompensation"
            },
            {
                "order": 236,
                "name": "nightWorkAllowance"
            },
            {
                "order": 237,
                "name": "nightShiftCompensation"
            }
        ]
    },
    {
        "name": "EmploymentTerminationKind",
        "description": null,
        "values": [
            {
                "order": 0,
                "name": "undefined"
            },
            {
                "order": 208,
                "name": "noticePeriodCompensation"
            },
            {
                "order": 224,
                "name": "monetaryWorkingTimeBankCompensation"
            },
            {
                "order": 229,
                "name": "terminationAndLayOffDamages"
            },
            {
                "order": 231,
                "name": "voluntaryTerminationCompensation"
            },
            {
                "order": 338,
                "name": "pensionPaidByEmployer"
            }
        ]
    }
];

},{}],36:[function(require,module,exports){
/** Codegen namespace is interfaces and data that is generated in Salaxy server */
Object.defineProperty(exports, "__esModule", { value: true });
/* tslint:disable */
/**
 * Generated in an an excel file: My Drive\Tech\Phase 5\Calc\Rows.xlsm
 * @hidden
 * TODO: Can we package this entire namespace in a way that it is hidden to be internal only?
 */
exports.housholdRows = [
    {
        order: 1,
        id: "salary",
        category: "salary",
        color: "#4a92e9",
        amountDefault: 1,
        amountInput: "hidden",
        totalInput: "hidden",
    },
    {
        order: 2,
        id: "hourlySalary",
        category: "salary",
        color: "#4a92e9",
    },
    {
        order: 3,
        id: "monthlySalary",
        category: "salary",
        color: "#4a92e9",
        amountDefault: 1,
        amountInput: "hidden",
        totalInput: "hidden",
    },
    {
        order: 4,
        id: "compensation",
        category: "salary",
        color: "#4a92e9",
        amountDefault: 1,
        amountInput: "hidden",
        totalInput: "hidden",
    },
    {
        order: 5,
        id: "totalWorkerPayment",
        category: "salaryCalc",
        color: "#4a92e9",
        amountDefault: 1,
        amountInput: "hidden",
        totalInput: "hidden",
    },
    {
        order: 6,
        id: "totalEmployerPayment",
        category: "salaryCalc",
        color: "#4a92e9",
        amountDefault: 1,
        amountInput: "hidden",
        totalInput: "hidden",
    },
    {
        order: 7,
        id: "board",
        category: "salary",
        color: "#4a92e9",
        amountDefault: 1,
    },
    {
        order: 8,
        id: "irIncomeType",
        category: "salary",
        color: "#4a92e9",
        amountDefault: 1,
    },
    {
        order: 10,
        id: "overtime",
        category: "salaryAdditions",
        color: "#15535d",
        amountDefault: 0.5,
        unit: "percent",
    },
    {
        order: 11,
        id: "tesWorktimeShortening",
        category: "salaryAdditions",
        color: "#15535d",
        favorites: 90,
        amountDefault: 0.077,
        unit: "percent",
    },
    {
        order: 12,
        id: "eveningAddition",
        category: "salaryAdditions",
        color: "#15535d",
        unit: "hour",
        Internal: "Lisää 'hours' palvelimelle",
    },
    {
        order: 13,
        id: "nightimeAddition",
        category: "salaryAdditions",
        color: "#15535d",
        unit: "hour",
        Internal: "Lisää 'hours' palvelimelle",
    },
    {
        order: 14,
        id: "saturdayAddition",
        category: "salaryAdditions",
        color: "#15535d",
        amountDefault: 0.5,
        unit: "percent",
    },
    {
        order: 15,
        id: "sundayWork",
        category: "salaryAdditions",
        color: "#15535d",
        favorites: 10,
    },
    {
        order: 19,
        id: "otherAdditions",
        category: "salaryAdditions",
        color: "#15535d",
        amountDefault: 1,
    },
    {
        order: 20,
        id: "remuneration",
        category: "salaryAdditions",
        color: "#15535d",
        amountDefault: 1,
    },
    {
        order: 21,
        id: "otherCompensation",
        category: "salaryAdditions",
        color: "#15535d",
        amountDefault: 1,
    },
    {
        order: 22,
        id: "workingTimeCompensation",
        category: "salaryAdditions",
        color: "#15535d",
        amountDefault: 1,
    },
    {
        order: 23,
        id: "employmentTermination",
        category: "salaryAdditions",
        color: "#15535d",
        amountDefault: 1,
    },
    {
        order: 101,
        id: "accomodationBenefit",
        category: "benefits",
        color: "#4fcdc4",
        amountDefault: 1,
    },
    {
        order: 102,
        id: "mealBenefit",
        category: "benefits",
        color: "#4fcdc4",
    },
    {
        order: 103,
        id: "phoneBenefit",
        category: "benefits",
        color: "#4fcdc4",
        amountDefault: 1,
        priceDefault: 20,
    },
    {
        order: 104,
        id: "carBenefit",
        category: "benefits",
        color: "#4fcdc4",
        amountDefault: 1,
        amountInput: "hidden",
    },
    {
        order: 199,
        id: "otherBenefit",
        category: "benefits",
        color: "#4fcdc4",
    },
    {
        order: 201,
        id: "holidayCompensation",
        category: "holidays",
        color: "#ffe66d",
        favorites: 80,
        amountDefault: 0.115,
        unit: "percent",
    },
    {
        order: 202,
        id: "holidayBonus",
        category: "holidays",
        color: "#ffe66d",
        unit: "percent",
    },
    {
        order: 203,
        id: "holidaySalary",
        category: "holidays",
        color: "#ffe66d",
        amountDefault: 1,
        amountInput: "hidden",
    },
    {
        order: 301,
        id: "dailyAllowance",
        category: "expenses",
        color: "#ffa900",
        favorites: 100,
        priceDefault: 43,
    },
    {
        order: 302,
        id: "dailyAllowanceHalf",
        category: "expenses",
        color: "#ffa900",
        priceDefault: 20,
        unit: "days",
    },
    {
        order: 303,
        id: "mealCompensation",
        category: "expenses",
        color: "#ffa900",
        priceDefault: 10.75,
        unit: "days",
    },
    {
        order: 304,
        id: "milageOwnCar",
        category: "expenses",
        color: "#ffa900",
        favorites: 20,
        priceDefault: 0.43,
        unit: "km",
    },
    {
        order: 305,
        id: "toolCompensation",
        category: "expenses",
        color: "#ffa900",
        favorites: 60,
        unit: "days",
    },
    {
        order: 306,
        id: "expenses",
        category: "expenses",
        color: "#ffa900",
        favorites: 70,
    },
    {
        order: 307,
        id: "milageDaily",
        category: "expenses",
        color: "#ffa900",
        favorites: 30,
        unit: "days",
    },
    {
        order: 308,
        id: "milageOther",
        category: "expenses",
        color: "#ffa900",
        unit: "days",
        Internal: "TES-laskennassa on nyt bugi, joka ohjaa päiväkohtaisen korvauksen "
            + "tähän. Kun se on fiksattu, niin muutetaan nämä tekstit.",
    },
    {
        order: 401,
        id: "unionPayment",
        category: "deductions",
        color: "#ff6738",
        priceInput: "hidden",
        unit: "percent",
    },
    {
        order: 402,
        id: "foreclosure",
        category: "deductions",
        color: "#ff6738",
        amountInput: "hidden",
        totalInput: "hidden",
    },
    {
        order: 403,
        id: "advance",
        category: "deductions",
        color: "#ff6738",
        favorites: 40,
        amountInput: "hidden",
        totalInput: "hidden",
    },
    {
        order: 405,
        id: "prepaidExpenses",
        category: "deductions",
        color: "#ff6738",
        amountInput: "hidden",
        totalInput: "hidden",
    },
    {
        order: 406,
        id: "otherDeductions",
        category: "deductions",
        color: "#ff6738",
        amountInput: "hidden",
        totalInput: "hidden",
    },
    {
        order: 901,
        id: "childCareSubsidy",
        category: "deductions",
        color: "#4fcdc4",
        favorites: 50,
        amountInput: "hidden",
        totalInput: "hidden",
    },
    {
        order: 1010,
        id: "nonProfitOrg",
        category: "expenses",
        color: "#ffa900",
    },
    {
        order: 1020,
        id: "subsidisedCommute",
        category: "benefits",
        color: "#4fcdc4",
        amountDefault: 1,
        amountInput: "hidden",
    },
];

},{}],37:[function(require,module,exports){
/* tslint:disable */
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Generated products data from the server.
 * @hidden
 * TODO: Add language versioning to an Excel file and implement code generation.
 */
exports.householdUsecaseTree = [
    {
        id: "childCare",
        label: "Lastenhoito",
        descr: "Tilapäinen tai jatkuva",
        icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/childcare.svg",
        children: [
            {
                id: "childCare/mll",
                uri: "https://secure.salaxy.com/v02/api/usecases/mll",
                label: "Tilapäinen lastenhoito",
                descr: "Palkka MLL:n suosituksen mukaan.",
                isHouseholdDeductible: true,
                icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/childcare.svg",
                badge: "https://cdn.salaxy.com/ng1/household-usecases/badge/mll.png",
                occupation: "53112",
            },
            {
                id: "childCare/kela",
                uri: "https://secure.salaxy.com/v02/api/usecases/childCare",
                label: "Yksityisen hoidon tuki",
                descr: "Lastenhoitaja kotona.",
                isChildcareSubsidy: true,
                icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/childcare.svg",
                badge: "https://cdn.salaxy.com/ng1/household-usecases/badge/kela.png",
                occupation: "53112",
            },
            {
                id: "childCare/other",
                uri: "https://secure.salaxy.com/v02/api/usecases/childCare",
                label: "Muu lastenhoito",
                descr: "Muu jatkuva tai tilapäinen lastenhoito",
                isHouseholdDeductible: true,
                icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/childcare.svg",
                occupation: "53112",
            },
        ],
    },
    {
        id: "construction",
        label: "Rakennus- ja remonttityö",
        descr: "Rakennusalan työehtosopimus.",
        uri: "https://secure.salaxy.com/v02/api/usecases/construction",
        icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/construction.svg",
        children: [
            {
                id: "construction/carpenter",
                label: "Kirvesmies",
                descr: "Kirvesmiehet ja rakennuspuusepät",
                icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/construction-carpenter.svg",
                subType: "constructionCarpenter",
                occupation: "71150",
            },
            {
                id: "construction/painter",
                label: "Maalaaminen",
                descr: "Rakennusmaalarit ym.",
                icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/construction-painter.svg",
                subType: "constructionCarpenter",
                occupation: "71310",
            },
            {
                id: "construction/roof",
                label: "Kattotyöt",
                descr: "Kattoasentajat ja -korjaajat",
                icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/construction-roof.svg",
                subType: "constructionCarpenter",
                occupation: "71210",
            },
            {
                id: "construction/floor",
                label: "Lattiatyöt",
                descr: "Lattianpäällystys",
                icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/construction-floor.svg",
                subType: "constructionFloor",
                occupation: "71110",
            },
            {
                id: "construction/renovation",
                label: "Muu remontointi",
                descr: "Asunnon tai vapaa-ajan asunnon remontointi",
                icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/construction-renovation.svg",
                subType: "constructionOther",
                isHouseholdDeductible: true,
                occupation: "71110",
            },
            {
                id: "construction/new",
                label: "Muu uudisrakentaminen",
                descr: "Uudisrakennukset",
                icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/construction-new.svg",
                subType: "constructionOther",
                isHouseholdDeductible: false,
                occupation: "71110",
            },
        ],
    },
    {
        id: "cleaning",
        label: "Kotisiivous",
        descr: "Kodin siivous ja kunnossapito",
        uri: "https://secure.salaxy.com/v02/api/usecases/cleaning",
        icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/cleaning.svg",
        children: [
            {
                id: "cleaning/91110",
                label: "Kotisiivous tai kotiapulainen",
                descr: "Siivoustyö tai kotiapulainen",
                isHouseholdDeductible: true,
                occupation: "91110",
                isContractLessThanYear: true
            },
            {
                id: "cleaning/51530",
                label: "Kiinteistöhuolto",
                descr: "Kiinteistöhuollon työntekijät",
                icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/cleaning-real-estate.svg",
                isHouseholdDeductible: true,
                occupation: "51530",
                isContractLessThanYear: true
            },
            {
                id: "cleaning/61132",
                label: "Puutarhanhoito",
                descr: "Puutarha- ja kasvihuonetyöntekijät",
                icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/cleaning-garden.svg",
                isHouseholdDeductible: true,
                occupation: "61132",
                isContractLessThanYear: true
            },
            {
                id: "cleaning/53221",
                label: "Kotityöpalvelu",
                descr: "Kotityöpalvelutyöntekijän työ",
                isHouseholdDeductible: true,
                occupation: "53221",
                isContractLessThanYear: true
            },
            {
                id: "cleaning/other",
                label: "Muut",
                descr: "Kodin muut työt",
                icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/cleaning-other.svg",
                isHouseholdDeductible: true,
                occupation: "other",
                isContractLessThanYear: true
            },
        ],
    },
    {
        id: "other",
        label: "Muu työ",
        descr: "Yleinen palkkalaskuri",
        uri: "https://secure.salaxy.com/v02/api/usecases/other",
        icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/other.svg",
        children: [
            {
                id: "other/53222",
                label: "Henkilökohtaiset avustajat, omaishoitajat ym.",
                isHouseholdDeductible: true,
                occupation: "53222",
            },
            {
                id: "other/61112",
                label: "Peltoviljelytyönjohtajat ja -työntekijät",
                occupation: "61112",
            },
            {
                id: "other/71110",
                label: "Talonrakentajat (sis. remonttimiehet)",
                isHouseholdDeductible: true,
                occupation: "71110",
            },
            {
                id: "other/91110",
                label: "Kotiapulaiset ja -siivoojat",
                isHouseholdDeductible: true,
                occupation: "91110",
            },
            {
                id: "other/53213",
                label: "Sosiaalialan hoitajat",
                isHouseholdDeductible: true,
                occupation: "53213",
            },
            {
                id: "other/53212",
                label: "Kehitysvammaisten hoitajat",
                isHouseholdDeductible: true,
                occupation: "53212",
            },
            {
                id: "other/71150",
                label: "Kirvesmiehet ja rakennuspuusepät",
                isHouseholdDeductible: true,
                occupation: "71150",
            },
            {
                id: "other/53112",
                label: "Perhepäivähoitajat (sis. kotitalousten lastenhoitajat)",
                isHouseholdDeductible: true,
                occupation: "53112",
            },
            {
                id: "other/53221",
                label: "Kotityöpalvelutyöntekijät",
                isHouseholdDeductible: true,
                occupation: "53221",
            },
            {
                id: "other/62100",
                label: "Metsurit ja metsätyöntekijät",
                icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/other.svg",
                occupation: "62100",
            },
            {
                id: "other/51530",
                label: "Kiinteistöhuollon työntekijät",
                isHouseholdDeductible: true,
                occupation: "51530",
            },
            {
                id: "other/61132",
                label: "Puutarha- ja kasvihuonetyönjohtajat ja - työntekijät",
                isHouseholdDeductible: true,
                occupation: "61132",
            },
            {
                id: "other/71310",
                label: "Rakennusmaalarit ym.",
                isHouseholdDeductible: true,
                icon: "https://cdn.salaxy.com/ng1/household-usecases/icon/other.svg",
                occupation: "71310",
            },
            {
                id: "other/71210",
                label: "Kattoasentajat ja -korjaajat",
                isHouseholdDeductible: true,
                occupation: "71210",
            },
            {
                id: "other/undefined",
                label: "Muu työ",
                occupation: "other",
            },
        ],
    },
];

},{}],38:[function(require,module,exports){
/* tslint:disable */
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Income types code-generated from the server.
 *
 * @generator https://test-api.salaxy.com/nir/incomeTypeCodes
 * Fetch this data from https://test-api.salaxy.com/nir/incomeTypeCodes
 * There is no automatic fetching because the data updated quite seldomly
 */
exports.incomeTypeCodes = [
    {
        "code": 101,
        "nameEn": "Total wages",
        "nameFi": "Palkka yhteissumma",
        "nameSv": "Lön totalt",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": true,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": "Reporting method 1 (codes 101-106) is not supported in this version",
        "description": "Ei käytössä: Palkkaus.fi-palvelussa ei käytetä ilmoitustapaa 1.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 102,
        "nameEn": "Total wages subject to earnings-related pension insurance contribution ",
        "nameFi": "Palkkasumma, joka on työeläkevakuutusmaksun alainen ",
        "nameSv": "Lönesumma som omfattas av arbetspensionsförsäkringsavgiften ",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": "Reporting method 1 (codes 101-106) is not supported in this version",
        "description": "Ei käytössä: Palkkaus.fi-palvelussa ei käytetä ilmoitustapaa 1.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 103,
        "nameEn": "Total wages subject to social insurance contributions",
        "nameFi": "Palkkasumma, joka on sosiaalivakuutusmaksujen alainen",
        "nameSv": "Lönesumma som omfattas av socialförsäkringsavgifter",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": "Reporting method 1 (codes 101-106) is not supported in this version",
        "description": "Ei käytössä: Palkkaus.fi-palvelussa ei käytetä ilmoitustapaa 1.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 104,
        "nameEn": "Total wages subject to health insurance contribution",
        "nameFi": "Palkkasumma, joka on sairausvakuutusmaksun alainen",
        "nameSv": "Lönesumma som omfattas av sjukförsäkringsavgiften",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": "Reporting method 1 (codes 101-106) is not supported in this version",
        "description": "Ei käytössä: Palkkaus.fi-palvelussa ei käytetä ilmoitustapaa 1.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 105,
        "nameEn": "Total wages subject to unemployment insurance contribution",
        "nameFi": "Palkkasumma, joka on työttömyysvakutuumaksun alainen",
        "nameSv": "Lönesumma som omfattas av arbetslöshetsförsäkringsavgiften",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": true,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": "Reporting method 1 (codes 101-106) is not supported in this version",
        "description": "Ei käytössä: Palkkaus.fi-palvelussa ei käytetä ilmoitustapaa 1.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 106,
        "nameEn": "Total wages subject to accident and occupational disease insurance contribution",
        "nameFi": "Palkkasumma, joka on työtapaturma- ja ammattitautivakuutusmaksun alainen",
        "nameSv": "Lönesumma som omfattas av arbetsolycksfalls- och yrkessjukdomsförsäkringsavgiften",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": true,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": "Reporting method 1 (codes 101-106) is not supported in this version",
        "description": "Ei käytössä: Palkkaus.fi-palvelussa ei käytetä ilmoitustapaa 1.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 201,
        "nameEn": "Time-rate pay",
        "nameFi": "Aikapalkka",
        "nameSv": "Tidlön",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "timeRatePay",
        "notSupportedError": null,
        "description": "Palkka, jota maksetaan työhön käytetyn ajan perusteella. Aikapalkka voidaan määritellä esimerkiksi kalenterikuukaudelle.",
        "taxAndSidecostsDescr": "Aikapalkasta toimitetaan ennakonpidätys ja maksetaan työnantajan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/wages"
        ],
        "calcGrouping": "baseSalary"
    },
    {
        "code": 202,
        "nameEn": "Initiative fee",
        "nameFi": "Aloitepalkkio",
        "nameSv": "Initiativarvode",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": true,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Kertapalkkio, joka maksetaan aloitteen tekijälle esimerkiksi toiminnan tai tuotteen kehittämiseen liittyvästä aloitteesta.",
        "taxAndSidecostsDescr": "Jos aloitepalkkio liittyy työsopimuksessa sovittuun työhön, palkkiota käsitellään palkkana eli ennakonpidätyksen toimittamisen lisäksi palkkiosta maksetaan sosiaalivakuutusmaksut.\r\n\r\nJos aloitepalkkion saaja ei ole palvelussuhteessa palkkion maksajaan tai aloite ei liity työntekijän työsopimuksessa sovittuun työhön, palkkiosta ei makseta sosiaalivakuutusmaksuja. Tällöin aloitepalkkiosta toimitetaan ennakonpidätys, ellei aloitepalkkion saaja kuulu ennakkoperintärekisteriin.\r\n\r\nOletuksena tulolajissa on, että se on sosiaalivakuutusmaksujen alainen.\r\n\r\nJos poikkeuksellisesti aloitepalkkio ei olisikaan edellä mainittujen maksujen alainen, suorituksen maksaja ilmoittaa vakuuttamistiedon erillisenä tietona.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/renumeration"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 203,
        "nameEn": "Bonus pay",
        "nameFi": "Bonuspalkka",
        "nameSv": "Bonuslön",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Kertaluonteinen palkkiopalkka, jonka suuruus määräytyy kokonaan tai osittain sen mukaan, kuinka hyvin tavoitteeksi asetettu työtulos saavutetaan. Työtuloksen mittana voi olla määrä, laatu tai jokin muu tulostekijä.\r\n\r\nBonuspalkka eroaa provisiopalkasta siten, että bonuspalkka on kertaluonteinen ja provisio on jatkuvaluonteinen palkkiopalkka. Kumpikin näistä perustuu henkilön tai ryhmän ennalta asetetun tavoitteen saavuttamiseen. Bonuspalkka eroaa voittopalkkiosta siten, että voittopalkkio maksetaan ilman ennalta sovittua suunnitelmaa, yrityksen voiton perusteella.",
        "taxAndSidecostsDescr": "Bonuspalkasta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/renumeration"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 204,
        "nameEn": "Complementary wage/salary paid during benefit period",
        "nameFi": "Etuusajalta maksettu täydennyspalkka",
        "nameSv": "Kompletteringslön för förmånstid",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Etuutta saavalle työntekijälle maksettu palkka, joka kattaa täyden palkan ja maksetun etuuden välisen erotuksen.\r\n\r\nMaksettu etuus voi olla esimerkiksi Kelan maksama sairauspäiväraha. Kun työnantaja maksaa etuusajalta täydennyspalkkaa, Kela maksaa etuuden suoraan työntekijälle, ei työnantajalle.",
        "taxAndSidecostsDescr": "Etuusajalta maksetusta täydennyspalkasta toimitetaan ennakonpidätys ja maksetaan työnantajan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/sickness"
        ],
        "calcGrouping": "baseSalary"
    },
    {
        "code": 205,
        "nameEn": "Emergency work compensation",
        "nameFi": "Hätätyökorvaus",
        "nameSv": "Ersättning för nödarbete",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Työaikakorvaus, joka maksetaan hätätyöstä. Hätätyöllä tarkoitetaan hätätilanteessa säännöllisen työajan ylittävänä aikana teetettävää työtä.",
        "taxAndSidecostsDescr": "Hätätyökorvauksesta toimitetaan ennakonpidätys ja maksetaan työnantajan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/workingTimeCompensation"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 206,
        "nameEn": "Evening work compensation",
        "nameFi": "Iltatyökorvaus",
        "nameSv": "Kvällsersättning",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "eveningWorkCompensation",
        "notSupportedError": null,
        "description": "Työaikakorvaus, joka maksetaan iltatyöstä. Iltatyökorvausta voidaan maksaa säännölliseltä työajalta tai säännöllisen työajan ylittävältä ajalta.",
        "taxAndSidecostsDescr": "Iltatyökorvauksesta toimitetaan ennakonpidätys ja maksetaan työnantajan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/workingTimeCompensation"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 207,
        "nameEn": "Evening shift allowance",
        "nameFi": "Iltavuorolisä",
        "nameSv": "Kvällsskiftstillägg",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "eveningShiftAllowance",
        "notSupportedError": null,
        "description": "Vuorotyökorvaus, joka maksetaan iltavuorosta.",
        "taxAndSidecostsDescr": "Iltavuorolisästä toimitetaan ennakonpidätys ja maksetaan työnantajan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/workingTimeCompensation"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 208,
        "nameEn": "Notice period compensation",
        "nameFi": "Irtisanomisajan korvaus",
        "nameSv": "Ersättning för uppsägningstid",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Korvaus, jonka työnantaja maksaa työntekijälle palvelussuhteen päättyessä ilman irtisanomisaikaa eli tilanteessa, jossa jätetään irtisanomisaika noudattamatta ja työsuhde päättyy heti (TSL 6:4). Tulolajilla ilmoitetaan myös korvaus, jonka työnantaja maksaa, kun työntekijä irtisanoutuu yli 200 päivää kestäneen lomautuksen johdosta sekä, kun työnantaja irtisanoo lomautettuna olevan työntekijän.\r\n\r\nTulolajilla ilmoitetaan vain sellaiset erät, jotka maksetaan työsuhteen päättyessä ilman irtisanomisaikaa. Irtisanomisajalta maksettu palkka ilmoitetaan muilla palkan suorituslajeilla, esim. Palkka yhteissumma- tai Aikapalkka-tulolajeilla.",
        "taxAndSidecostsDescr": "Irtisanomisajan korvauksesta toimitetaan ennakonpidätys, mutta ei makseta sosiaalivakuutusmaksuja.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/employmentTermination"
        ],
        "calcGrouping": "baseSalary"
    },
    {
        "code": 209,
        "nameEn": "Kilometre allowance (taxable)",
        "nameFi": "Kilometrikorvaus (veronalainen)",
        "nameSv": "Kilometerersättning (skattepliktig)",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "kilometreAllowanceTaxable",
        "notSupportedError": null,
        "description": "Kilometrikorvaus, joka ei täytä verovapaudelle asetettuja vaatimuksia.\r\n\r\nVeronalaista kilometrikorvausta voidaan maksaa sekä palvelussuhteessa oleville että muille henkilöille. Kilometrikorvauksen veronalaisuudelle on useita perusteita. Verohallinto on määrittänyt työnantajan palvelussuhteessa maksamille verovapaille kilometrikorvauksille enimmäismäärän, jonka ylittävältä osalta kilometrikorvaus on veronalaista ansiotuloa. Henkilölle toimeksiantosuhteessa maksettava kilometrikorvaus on kokonaan veronalaista ansiotuloa.\r\n\r\n**Tulolajilla ilmoitetaan vain palvelussuhteessa oleville maksetut veronalaiset kilometrikorvaukset.** Jos veronalainen kilometrikorvaus maksetaan toimeksiantosuhteessa olevalle henkilölle tai yhteisölle, korvaus ilmoitetaan työkorvauksena ja lisätään kustannus työkorvauksen määrää (ks. Työkorvaus-tulolajin selite).",
        "taxAndSidecostsDescr": "Tulosta toimitetaan ennakonpidätys ja se on sosiaalivakuutusmaksujen alainen.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/expenses",
            "https://palkkaus.fi/usecases/2019/travelExpenses"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 210,
        "nameEn": "Meeting fee",
        "nameFi": "Kokouspalkkio",
        "nameSv": "Mötesarvode",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": true,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Palkkio, joka maksetaan kokoukseen osallistumisesta.",
        "taxAndSidecostsDescr": "Kokouspalkkiosta toimitetaan ennakonpidätys.\r\n\r\nJos kokouspalkkion maksaminen perustuu palvelussuhteessa tehtyyn työhön, kokouspalkkiosta maksetaan sosiaalivakuutusmaksut. Jos kokouspalkkion saaja ei ole palvelussuhteessa, palkkion työeläkevakuutusmaksun ja työnantajan sairausvakuutusmaksun sekä työntekijän sairausvakuutuksen päivärahamaksun maksamisvelvollisuus vaihtelevat sovellettavan lain mukaan. Jos kokouspalkkion maksaminen ei perustu palvelusuhteessa tehtyyn työhön, työnantaja voi halutessaan vakuuttaa tulonsaajan vapaaehtoisesti eläkevakuutuksen osalta.\r\n\r\nOletuksena tulolajissa on, että se ei ole sosiaalivakuutusmaksujen alainen.\r\n\r\nJos kokouspalkkio on jonkun sosiaalivakuutusmaksun alainen, suorituksen maksaja ilmoittaa erillistä Vakuuttamistiedon tyyppi- tietoa käyttäen, että tulo on ilmoitetun vakuutusmaksun alainen.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/board",
            "https://palkkaus.fi/usecases/2019/otherFees"
        ],
        "calcGrouping": "baseSalary"
    },
    {
        "code": 211,
        "nameEn": "Saturday pay",
        "nameFi": "Lauantaityökorvaus",
        "nameSv": "Ersättning för lördagsarbete",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "saturdayPay",
        "notSupportedError": null,
        "description": "Työaikakorvaus, joka maksetaan lauantaityöstä. Lauantaityökorvausta voidaan maksaa säännölliseltä työajalta tai säännöllisen työajan ylittävältä ajalta.",
        "taxAndSidecostsDescr": "Korvauksesta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/workingTimeCompensation"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 212,
        "nameEn": "Extra work premium",
        "nameFi": "Lisätyökorvaus",
        "nameSv": "Ersättning för mertidsarbete",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Työaikakorvaus, joka maksetaan lisätyöstä.",
        "taxAndSidecostsDescr": "Korvauksesta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/workingTimeCompensation"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 213,
        "nameEn": "Holiday bonus",
        "nameFi": "Lomaraha",
        "nameSv": "Semesterpenning",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "holidayBonus",
        "notSupportedError": null,
        "description": "Työsopimuksen tai työ- tai virkaehtosopimuksen perusteella vuosilomapalkan lisäksi maksettava suoritus, jonka suuruus määräytyy alalla sovellettavan työehtosopimuksen tai edellisenä lomanmääräytymisvuonna ansaittujen lomapäivien lukumäärän mukaan.\r\n\r\nVuosilomapalkan lisää koskee erittely- ja ilmoitusvelvollisuus riippumatta siitä, käytetäänkö kyseisestä erästä nimitystä lomaraha. Tällainen erittely tarvitaan esimerkiksi Kelaa ja työttömyyskassaa sekä työtapaturman korvauskäsittelyä varten.",
        "taxAndSidecostsDescr": "Lomarahasta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/holidays"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 214,
        "nameEn": "Lecture fee",
        "nameFi": "Luentopalkkio",
        "nameSv": "Föreläsningsarvode",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": true,
        "taxDefault": 1,
        "transactionCode": "lectureFee",
        "notSupportedError": null,
        "description": "Palkkio, joka maksetaan luennon pitämisestä.",
        "taxAndSidecostsDescr": "Luentopalkkiosta toimitetaan ennakonpidätys. \r\n\r\nJos luentopalkkion maksaminen perustuu palvelussuhteessa tehtyyn työhön, luentopalkkiosta maksetaan sosiaalivakuutusmaksut. \r\n\r\nJos luentopalkkion saaja ei ole palvelussuhteessa, palkkion työeläkevakuutusmaksun ja työnantajan sairausvakuutusmaksun sekä työntekijän sairausvakuutuksen päivärahamaksun maksamisvelvollisuus vaihtelevat sovellettavan lain mukaan.\r\n\r\nOletuksena tulolajissa on, että se ei ole sosiaalivakuutusmaksujen alainen.\r\n\r\nJos luentopalkkio on jonkun sosiaalivakuutusmaksun alainen, suorituksen maksaja ilmoittaa erillistä Vakuuttamistiedon tyyppi- tietoa käyttäen, että tulo on ilmoitetun vakuutusmaksun alainen.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/otherFees"
        ],
        "calcGrouping": "baseSalary"
    },
    {
        "code": 215,
        "nameEn": "Compensation for acting in a position of trust",
        "nameFi": "Luottamustoimipalkkio",
        "nameSv": "Arvode för förtroendeuppdrag",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": true,
        "insuranceInformationAllowed": true,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Palkkio, joka maksetaan muusta luottamustoimen hoitamisesta kuin kokouksiin osallistumisesta.",
        "taxAndSidecostsDescr": "Luottamustoimipalkkiosta toimitetaan ennakonpidätys.\r\n\r\nLuottamustoimipalkkiota maksettaessa palkkion saaja ei yleensä ole palvelussuhteessa palkkion maksajaan, eikä palkkiosta näissä tapauksissa makseta sosiaalivakuutusmaksuja.\r\n\r\nYksityisellä sektorilla luottamustoimipalkkiosta maksetaan kuitenkin sairausvakuutusmaksu. Lisäksi maksetaan eläkevakuutusmaksu, jos palkkion maksaja on ottanut luottamustoimen hoitajalle vapaaehtoisen työeläkevakuutuksen. Tietyistä julkisen sektorin luottamustoimipalkkioista maksetaan työeläkevakuutusmaksu.\r\n\r\nOletuksena tulolajissa on, että se on työnantajan sairausvakuutusmaksun alainen ja työntekijän sairausvakuutuksen päivärahamaksun alainen. Sitä vastoin oletuksena on, että tulo ei ole eläkevakuutusmaksun, työttömyysvakuutusmaksun eikä työtapaturma- ja ammattitautivakuutusmaksun alainen.\r\n\r\nJos luottamustoimipalkkio on esimerkiksi eläke- ja työttömyysvakuutusmaksun alainen, suorituksen maksaja ilmoittaa vakuuttamistiedon erillisenä tietona näiden maksujen osalta. Samoin ilmoitetaan Vakuuttamistiedon tyyppi –tietoa käyttäen, jos luottamustoimipalkkio ei poikkeuksellisesti olisikaan sairausvakuutusmaksun alainen.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/board",
            "https://palkkaus.fi/usecases/2019/otherCompensation"
        ],
        "calcGrouping": "baseSalary"
    },
    {
        "code": 216,
        "nameEn": "Other compensation",
        "nameFi": "Muu maksettu lisä",
        "nameSv": "Annat betalt tillägg",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "otherCompensation",
        "notSupportedError": null,
        "description": "Muiden maksettujen työaika- ja poikkeustilakorvausten yhteissumma. Näitä ovat mm. aattotyökorvaukset, arkipyhäkorvaukset ja muut mahdolliset työehtosopimusten tai työsopimusten perusteella maksettavat korvaukset ja lisät.",
        "taxAndSidecostsDescr": "Muista maksetuista lisistä toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/workingTimeCompensation",
            "https://palkkaus.fi/usecases/2019/otherCompensation"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 217,
        "nameEn": "Waiting time compensation",
        "nameFi": "Odotusajan korvaus",
        "nameSv": "Lön för väntetid",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Korvaus, johon työntekijällä on oikeus, jos palkanmaksu viivästyy työsuhteen päätyttyä. Ellei toisin sovita, palkka tulee maksaa palkanmaksukauden viimeisenä päivänä. Odotusajan korvausta voidaan maksaa enintään kuudelta päivältä.",
        "taxAndSidecostsDescr": "Odotusajan korvauksesta toimitetaan ennakonpidätys, mutta ei makseta sosiaalivakuutusmaksuja.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/workingTimeCompensation"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 218,
        "nameEn": "Working condition compensation",
        "nameFi": "Olosuhdelisä",
        "nameSv": "Miljötillägg",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Palkanlisä, joka maksetaan työn tekemispaikan olosuhteiden perusteella. Olosuhdelisiä ovat esimerkiksi työehtosopimuksen tai työsopimuksen perusteella maksettavat lisä, kuten vaahdotuslisä, kylmänalueenlisä ja saaristolisä.",
        "taxAndSidecostsDescr": "Olosuhdelisästä toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/workingTimeCompensation",
            "https://palkkaus.fi/usecases/2019/otherCompensation"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 219,
        "nameEn": "Partial pay during sick leave",
        "nameFi": "Sairausajan osapalkka",
        "nameSv": "Dellön för sjuktiden",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": true,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Lain tai työ- tai virkaehtosopimukseen mukaisesti alennettu sairausajan palkka. Sairausajan osapalkkana ilmoitetaan se osa tuloista, jonka henkilö on saanut sairaana ollessaan alennettuna.",
        "taxAndSidecostsDescr": "Sairausajan osapalkasta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.\r\n\r\nJos osapalkkana maksetaan sellaisia eriä, jotka eivät ole sosiaalivakuutusmaksujen alaisia (esimerkiksi vahingonkorvaus päättämistilanteessa), suorituksen maksaja ilmoittaa vakuuttamistiedon erillistä Vakuuttamistiedon tyyppi –tietoa käyttäen.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/sickness"
        ],
        "calcGrouping": "baseSalary"
    },
    {
        "code": 220,
        "nameEn": "Commission",
        "nameFi": "Provisiopalkka",
        "nameSv": "Provisionslön",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Pysyvän palkan osan muodostava jatkuvaluonteinen palkkiopalkka, jonka määrästä on sovittu työsopimuksessa.",
        "taxAndSidecostsDescr": "Provisiopalkasta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/renumeration"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 221,
        "nameEn": "Sunday work compensation",
        "nameFi": "Sunnuntaityökorvaus",
        "nameSv": "Ersättning för söndagsarbete",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "sundayWorkCompensation",
        "notSupportedError": null,
        "description": "Sunnuntaityöstä maksettava työaikakorvaus. Sunnuntaityökorvausta voidaan maksaa säännölliseltä työajalta tai säännöllisen työajan ylittävältä ajalta.",
        "taxAndSidecostsDescr": "Korvauksesta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/workingTimeCompensation"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 222,
        "nameEn": "Benefit arising from synthetic option",
        "nameFi": "Synteettinen optio",
        "nameSv": "Syntetisk option",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Optio-oikeus, jonka perusteella tulonsaaja ei ole oikeutettu merkitsemään option kohde-etuutena olevia osakkeita option toteutushintaan, vaan hän saa toteutushinnan ja toteuttamishetken mukaisen osakkeen arvon erotuksen rahana (nettoarvon tilitys). Synteettinen optio ei oikeuta osakemerkintään.\r\n\r\nKäytännössä synteettisessä optiossa on kyse rahasuorituksesta, jonka suuruus määräytyy työnantajayhtiön osakekurssin kehityksen perusteella. Synteettinen optio -nimityksen sijaan järjestelyä saatetaan kutsua osakeperusteiseksi bonukseksi tai palkitsemisjärjestelmäksi.",
        "taxAndSidecostsDescr": "Optiona saatavasta edusta toimitetaan ennakonpidätys, mutta ei makseta sosiaalivakuutusmaksuja.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/enterprise"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 223,
        "nameEn": "Performance bonus",
        "nameFi": "Tulospalkkio",
        "nameSv": "Resultatpremie",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Palkka, joka maksetaan organisaation ennalta sovitun tulostavoitteen täyttymisen tai ylittymisen perusteella.",
        "taxAndSidecostsDescr": "Tulospalkkiosta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/renumeration"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 224,
        "nameEn": "Monetary compensation from a working time bank",
        "nameFi": "Työaikapankin rahakorvaus",
        "nameSv": "Penningersättning från arbetstidsbank",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Palkka, joka maksetaan työaikapankkiin säästetyn ajan perusteella.\r\n\r\nTyöaikapankista voi yleensä nostaa palkkaa vain poikkeustapauksissa kuten palvelussuhteen päättyessä tai työaikapankkia purettaessa. Joissakin työaikapankeissa on mahdollista nostaa palkkaa tai\r\nvapaa-aikaa myös velaksi.",
        "taxAndSidecostsDescr": "Työaikapankin rahakorvauksesta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/employmentTermination"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 225,
        "nameEn": "Compensation for accrued time off",
        "nameFi": "Työajantasauskorvaus",
        "nameSv": "Ersättning för arbetstidsutjämning",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "compensationForAccruedTimeOff",
        "notSupportedError": null,
        "description": "Työaikakorvaus, joka maksetaan ansionvähentymisestä, joka aiheutuu työajan tasaamisesta keskimääräiseen viikkotyöaikaan. \r\n\r\nTyöajantasauskorvausta maksetaan säännölliseltä työajalta. Esimerkiksi niin sanottu pekkaskorvaus on työajantasauskorvaus.",
        "taxAndSidecostsDescr": "Korvauksesta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/otherCompensation"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 226,
        "nameEn": "Share issue for employees",
        "nameFi": "Työsuhteeseen perustuva osakeanti",
        "nameSv": "Aktieemission som grundar sig på arbetsförhållande",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": true,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Yhtiön omalle henkilökunnalle suunnattu osakeanti. Etu työsuhteeseen perustuvasta oikeudesta merkitä työnantajayrityksen osakkeita on veronalaista ansiotuloa.\r\n\r\nJos etu on henkilökunnan enemmistön käytettävissä, tulolajilla ilmoitetaan ainoastaan 10 %:n alennuksen ylittävä osuus. Jos etu ei ole henkilökunnan enemmistön käytettävissä, saatava alennus on palkkaa koko määrältään. Tällöin suorituksen ilmoittamisessa käytetään palkan muita tulolajeja.\r\n\r\nMerkintäetu koskee myös yhteisön osuuksia.",
        "taxAndSidecostsDescr": "Työsuhteeseen perustuvasta osakeannista toimitetaan ennakonpidätys, mutta tulo ei ole sosiaalivakuutusmaksujen alainen.\r\n\r\nJos työsuhteeseen perustuva osakeanti on edellä mainittujen maksujen alainen, suorituksen maksaja ilmoittaa vakuuttamistiedon erillistä Vakuuttamistiedon tyyppi- tietoja käyttäen.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/renumeration"
        ],
        "calcGrouping": "benefits"
    },
    {
        "code": 227,
        "nameEn": "Contract pay ",
        "nameFi": "Urakkapalkka ",
        "nameSv": "Ackordslön ",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "contractPay",
        "notSupportedError": null,
        "description": "Suorituspalkka, joka maksetaan ennalta sovitun työkokonaisuuden suorittamisen perusteella. Urakkapalkkaan sisältyy sekä kiinteä että muuttuva osa.",
        "taxAndSidecostsDescr": "Urakkapalkasta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/wages"
        ],
        "calcGrouping": "baseSalary"
    },
    {
        "code": 229,
        "nameEn": "Damages in conjunction with termination and lay-off",
        "nameFi": "Vahingonkorvaus päättämis- ja lomautustilanteissa",
        "nameSv": "Skadestånd vid avslutande av ett anställningsförhållande eller permittering",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Korvaus, jota työnantaja on velvollinen maksamaan, kun työnantaja on päättänyt palvelussuhteen henkilön työsopimuslain, kunnallisesta viranhaltijasta annetun lain tai valtion virkamieslain vastaisesti. Kohdassa ilmoitetaan myös korvaus työsuhteen purkamisesta (TSL 8:1, 55/2001) sekä korvaus perusteettomasta lomauttamisesta.\r\n\r\nPalvelussuhteen perusteettoman päättämisen johdosta maksettava korvaus voi perustua tuomioistuimen tuomioon, tuomioistuimen vahvistamaan sovintoon, palvelussuhteen osapuolia edustavien järjestöjen väliseen neuvottelutulokseen tai palvelussuhteen osapuolten väliseen sopimukseen.\r\n\r\nVahingonkorvaus päättämis- tai lomautustilanteessa tai muu siihen verrattava korvaus ei ole veronalaista tuloa, ellei sitä ole saatu veronalaisen tulon sijaan tai korvaukseksi elatuksen vähentymisestä. Veronalaista tuloa eivät myöskään ole laissa tarkemmin määritellyt hyvitykset yhteistoimintavelvoitteiden laiminlyönneistä.\r\n\r\nTulolajilla ilmoitetaan vain veronalaiset määrät eli esimerkiksi ei yhteistoimintalain tai tasa-arvolain nojalla maksettuja verovapaita hyvityksi. Verovapaita vahingonkorvauksia ei ilmoiteta tulorekisteriin.\r\n\r\nTulolajilla ei ilmoiteta irtisanomisen yhteydessä maksettavia työsuoritukseen perustuvia korvauksia vaan ne ilmoitetaan muilla palkan suorituslajeilla, esim. Palkka yhteissumma- tai Aikapalkka-tulolajeilla.",
        "taxAndSidecostsDescr": "Veronalaisesta vahingonkorvauksesta toimitetaan ennakonpidätys, mutta ei makseta sosiaalivakuutusmaksuja.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/employmentTermination"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 230,
        "nameEn": "Stand-by compensation",
        "nameFi": "Varallaolokorvaus",
        "nameSv": "Beredskapsersättning",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Palkka, joka maksetaan siitä, että työntekijä on tavoitettavissa ja työnantaja voi tarvittaessa kutsua hänet hoitamaan palvelussuhteeseen kuuluvia tehtäviä.",
        "taxAndSidecostsDescr": "Varallaolokorvauksesta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/workingTimeCompensation"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 231,
        "nameEn": "Voluntary compensation in conjunction with termination of employment",
        "nameFi": "Vapaaehtoinen korvaus päättämistilanteessa",
        "nameSv": "Frivillig ersättning vid avslutande av ett anställningsförhållande",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Korvaus, jonka työnantaja maksaa vapaaehtoisesti irtisanomis- tai purkamistilanteessa tai silloin, kun palvelussuhde päätetään sopimalla.\r\n\r\nPäättämistilanteessa maksettavia vapaaehtoisia korvauksia ovat esimerkiksi toimitusjohtajan erokorvaus (niin sanottu kultainen kädenpuristus), erokorvaus, eroraha ja tukipaketti. Korvaus voidaan\r\nmyöntää myös muuna kuin rahana.",
        "taxAndSidecostsDescr": "Päättämiskorvauksesta toimitetaan ennakonpidätys, mutta ei makseta sosiaalivakuutusmaksuja.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/employmentTermination"
        ],
        "calcGrouping": "baseSalary"
    },
    {
        "code": 232,
        "nameEn": "Weekly rest compensation",
        "nameFi": "Viikkolepokorvaus",
        "nameSv": "Ersättning för veckovila",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Työaikakorvaus, jota maksetaan viikkolevon aikana tehdystä työstä.",
        "taxAndSidecostsDescr": "Viikkolepokorvauksesta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/workingTimeCompensation"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 233,
        "nameEn": "Profit-sharing bonus",
        "nameFi": "Voittopalkkio",
        "nameSv": "Vinstarvode",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": true,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Työntekijöille ilman ennalta sovittua suunnitelmaa yhtiökokouksen päätöksellä jaettava palkkio, joka muodostuu yrityksen voiton perusteella.",
        "taxAndSidecostsDescr": "Muista kuin henkilöstörahastoon siirrettävistä voittopalkkiosta toimitetaan ennakonpidätys. Yrityksen henkilöstörahastoon maksamasta voittopalkkiosta tai henkilöstörahastosääntöjen mukaan työntekijän suoraan käteisenä nostamasta voittopalkkiosta ei makseta sosiaalivakuutusmaksuja.\r\n\r\nJos yrityksessä ei ole henkilöstörahastolain mukaista henkilöstörahastoa, voittopalkkiosta ei makseta sosiaalivakuutusmaksuja, jos voittopalkkio maksetaan työntekijälle yhtiökokouksen päätöksen perusteella voitonjakona tai käteisenä voittopalkkiona edellyttäen, että käteinen voittopalkkio maksetaan koko henkilöstölle eikä sillä pyritä korvaamaan työehtosopimuksen tai työsopimuksen edellyttämää palkkausjärjestelmää. Lisäksi edellytetään, että käteisen palkkion määräytymisperusteet ovat työntekijän eläkelain 70 §:n 3 momentin 10 kohdan ja henkilöstörahastolain 2 §:n 2 ja 3 kohdan mukaiset ja että yhtiön vapaan pääoman määrä on suurempi kuin yhtiökokouksessa päätettävän käteisen voittopalkkion ja osakkeenomistajille maksettavien osinkojen yhteismäärä. Laissa työttömyysetuuksien rahoituksesta on vastaavanlainen säännös, samoin työtapaturma- ja ammattitautilaissa.\r\n\r\nOletuksena tulolajissa on, ettei se ole sosiaalivakuutusmaksujen alainen. \r\n\r\nJos voittopalkkio on edellä mainittujen maksujen alainen, suorituksen maksaja ilmoittaa vakuuttamistiedon erillistä Vakuuttamistiedon tyyppi- tietoryhmää käyttäen.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/renumeration"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 234,
        "nameEn": "Annual holiday compensation",
        "nameFi": "Vuosilomakorvaus",
        "nameSv": "Semesterersättning",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "annualHolidayCompensation",
        "notSupportedError": null,
        "description": "Vuosiloman antamisen sijaan suoritettava rahallinen korvaus. Vuosilomakorvausta voidaan maksaa työsuhteen aikana tai työsuhteen päättyessä.\r\n\r\nTulolajilla ilmoitetaan myös **rakennusalan lomaraha**. Työehtosopimuksessa lomakorvaus, lomapalkka ja lomaraha on yhdistetty lomaraha-nimiseksi korvaukseksi, joka on 18,5 % lomanmääräytymisvuoden ansioista. Pääsääntöisesti rakennusalan lomakorvauksessa on 1/3 lomarahaa ja 2/3 lomapalkkaa tai lomakorvausta riippuen siitä, jatkuuko työsuhde vai päättyikö se.",
        "taxAndSidecostsDescr": "Vuosilomakorvauksesta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/holidays"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 235,
        "nameEn": "Overtime compensation",
        "nameFi": "Ylityökorvaus",
        "nameSv": "Övertidsersättning",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "overTimeCompensation",
        "notSupportedError": null,
        "description": "Ylityöstä maksettava työaikakorvaus. Ylityönä pidetään työtä, joka tehdään työnantajan aloitteesta sovitun ylityöaikarajan ylittävänä aikana.",
        "taxAndSidecostsDescr": "Ylityökorvauksesta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/workingTimeCompensation"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 236,
        "nameEn": "Night work allowance",
        "nameFi": "Yötyökorvaus",
        "nameSv": "Nattersättning",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "nightWorkAllowance",
        "notSupportedError": null,
        "description": "Työaikakorvaus, jota maksetaan yötyöstä.",
        "taxAndSidecostsDescr": "Yötyökorvauksesta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/workingTimeCompensation"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 237,
        "nameEn": "Night shift compensation",
        "nameFi": "Yövuorolisä",
        "nameSv": "Nattskiftstillägg",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "nightShiftCompensation",
        "notSupportedError": null,
        "description": "Vuorotyökorvaus, joka maksetaan yövuorosta.",
        "taxAndSidecostsDescr": "Ylivuorolisästä toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/workingTimeCompensation"
        ],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 301,
        "nameEn": "Accommodation benefit",
        "nameFi": "Asuntoetu",
        "nameSv": "Bostadsförmån",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "accommodationBenefit",
        "notSupportedError": null,
        "description": "Luontoisetu, joka syntyy, kun työnantaja antaa työntekijän käyttöön omistamansa tai hallitsemansa asunnon palvelussuhteeseen liittyvän vuokrasuhteen perusteella tai palkkaan sisältyvänä etuna.\r\n\r\nPalkkaus.fi-palvelussa asuntoetu ilmoitetaan aina tällä tulolajilla, ei koskaan 'Muu luontoisetu'-tulolajilla.",
        "taxAndSidecostsDescr": "Asuntoedusta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/benefits"
        ],
        "calcGrouping": "benefits"
    },
    {
        "code": 302,
        "nameEn": "Interest benefit for a housing loan",
        "nameFi": "Asuntolainan korkoetu",
        "nameSv": "Ränteförmån för bostadslån",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Veronalainen henkilökuntaetu, joka muodostuu silloin, kun työnantaja perii työntekijälle myöntämästään asuntolainasta vuotuista korkoa, joka on alempi kuin yleisesti markkinoilla käytössä oleva viitekorko.",
        "taxAndSidecostsDescr": "Asuntolainan korkoetu on ennakonpidätyksen alainen, mutta siitä ei makseta sosiaalivakuutusmaksuja.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/enterprise"
        ],
        "calcGrouping": "benefits"
    },
    {
        "code": 303,
        "nameEn": "Meal allowance",
        "nameFi": "Ateriakorvaus",
        "nameSv": "Måltidsersättning",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "mealAllowance",
        "notSupportedError": null,
        "description": "Verovapaa kustannusten korvaus ateriointikuluista, jotka johtuvat työmatkasta.\r\n\r\nAteriakorvaus voidaan maksaa verovapaasti, jos työntekijällä ei ole mahdollisuutta aterioida ruokailutauon aikana tavanomaisella ruokailupaikallaan, eikä ruokailua ole järjestetty esimerkiksi kurssipakettiin kuuluvana työnantajan kustantamana ruokailuna. **Verovapaata ateriakorvausta ei voi maksaa samasta työmatkasta yhtä aikaa verovapaan päivärahan kanssa.**\r\n\r\nAteriakorvauksen perusteista ja verovapaista enimmäismääristä säädetään vuosittain annettavissa Verohallinnon päätöksissä verovapaista matkakustannusten korvauksista.\r\n\r\nKohdassa ilmoitetaan vain verovapaiden ateriakorvausten määrät. Jos maksettu korvaus ylittää Verohallinnon päätöksen enimmäismäärät tai maksetaan vastoin päätöksessä säädettyjä perusteita, suoritus ilmoitetaan sosiaalivakuutusmaksujen alaisena palkkana.\r\n\r\nAteriakorvaus voidaan ilmoittaa erikseen, mutta saatu korvaus on ilmoitettava vähintään yhteissummana Päiväraha -tulolajilla. Tällöin on lisäksi ilmoitettava tulolajiin liittyvän Korvauksen tyyppi-lisätiedon avulla, että Päiväraha-tulolajilla ilmoitettu korvaus sisältää ateriakorvauksen.\r\n\r\nJos ateriakorvaus ilmoitetaan erikseen, sitä ei lisätä enää Päiväraha -tulolajilla ilmoitettaviin määriin.",
        "taxAndSidecostsDescr": "Verovapaasta ateriakorvauksesta ei toimiteta ennakonpidätystä eikä makseta sosiaalivakuutusmaksuja.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/travelExpenses"
        ],
        "calcGrouping": "expenses"
    },
    {
        "code": 304,
        "nameEn": "Car benefit",
        "nameFi": "Autoetu",
        "nameSv": "Bilförmån",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "carBenefit",
        "notSupportedError": null,
        "description": "Luontoisetu, joka syntyy, kun työnantaja antaa työntekijän tai tämän perheen käyttöön omistamansa tai hallitsemansa auton, jonka yksityiskäyttö on sallittu.\r\n\r\nAutoetu on ilmoitettava siinäkin tapauksessa, että työntekijä on maksanut luontoisedusta työnantajalle luontoisedun raha-arvoa vastaavan tai sitä suuremman korvauksen, eikä palkkaan lisättävää määrää ole jäänyt lainkaan. Peritty summa ilmoitetaan erikseen Autoedusta peritty korvaus- erittelylajilla.",
        "taxAndSidecostsDescr": "Autoedusta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/carBenefit",
            "https://palkkaus.fi/usecases/2019/benefits"
        ],
        "calcGrouping": "benefits"
    },
    {
        "code": 308,
        "nameEn": "Compensation for membership of a governing body",
        "nameFi": "Hallintoelimen jäsenyydestä maksettu palkkio",
        "nameSv": "Arvode för medlemskap i förvaltningsorgan",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": true,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Luottamustoimipalkkio, joka maksetaan yhteisön hallituksen tai vastaavan hallintoelimen jäsenyyden perusteella.\r\n\r\nJos henkilölle maksetaan palkkiota hallintoelimen jäsenyydestä, hänelle voidaan maksaa myös verovapaita matkakustannusten korvauksia työmatkasta aiheutuneiden kulujen perusteella, jos verovapaiden korvausten muut edellytykset täyttyvät.",
        "taxAndSidecostsDescr": "Jos hallintoelimen jäsenestä maksettavan palkkion saaja ei ole palvelussuhteessa, työeläkevakuutusmaksujen maksaminen palkkiosta on yksityisellä sektorilla vapaaehtoista. Julkisella alalla hallintoelimen jäsenyydestä maksettavista palkkioista suoritetaan tällöinkin sosiaalivakuutusmaksut. Jos palkkion perusteella ei henkilöön sovellettavien työeläkelakien mukaan ole tarvinnut maksaa työntekijän työeläkemaksua, suorituksesta ei makseta työnantajan sairausvakuutusmaksua eikä työntekijän päivärahamaksua, vaikka työeläkevakuutusmaksu olisikin maksettu vapaaehtoisesti. Palkkio on työtapaturma- ja ammattitautivakuutusmaksun alainen, jos se maksetaan palvelussuhteessa olevalle.\r\n\r\nHallintoelimen jäsenyydestä maksettavasta palkkiosta toimitetaan ennakonpidätys.\r\n\r\nOletuksena tulolajissa on, että hallintoelimen jäsenyydestä maksettu palkkio ei ole sosiaalivakuutusmaksujen alainen. Olennaista maksuvelvollisuuden kannalta muilla kuin julkisella alalla on se, onko palkkio maksettu työ- tai muussa palvelussuhteessa.\r\n\r\nJos palkkionsaaja on palvelusuhteessa ja palkkio on jonkun sosiaalivakuutusmaksun alainen, suorituksen maksaja ilmoittaa erillistä Vakuuttamistiedon tyyppitietoa käyttäen, että tulo on ilmoitetun vakuutusmaksun alainen.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/board"
        ],
        "calcGrouping": "baseSalary"
    },
    {
        "code": 309,
        "nameEn": "Share of reserve and surplus drawn from personnel fund (taxable 80%)",
        "nameFi": "Henkilöstörahastosta nostettu rahasto-osuus ja ylijäämä (veronalainen 80%)",
        "nameSv": "Fondandel och överskott som tagits ut ur en personalfond (skattepliktig till 80 %)",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Rahasto-osuus, joka maksetaan työntekijälle henkilöstörahastosta. Henkilörahastoon osoitetut varat jaetaan rahasto-osuutena nostettaviin eriin ja käteisenä nostettaviin eriin.\r\n\r\nHenkilöstörahastosta nostetusta rahasto-osuudesta 20 % on verovapaata ja 80 %:n veronalaisesta ansiotulo-osuudesta toimitetaan ennakonpidätys. Henkilöstörahastosta nostettua ylijäämää kohdellaan verotuksessa samalla tavalla kuin henkilöstörahastosta nostettua rahasto-osuutta. Ks. Verohallinnon ohje Henkilöstörahastosta saatavien tulojen verotus (A69/200/2014).\r\n\r\nTulolajilla ilmoitetaan vain veronalainen osuus.",
        "taxAndSidecostsDescr": "Nostetusta rahasto-osuudesta toimitetaan ennakonpidätys, mutta ei makseta sosiaalivakuutusmaksuja. Sitä vastoin henkilöstörahastoon maksamisen sijaan suoraan henkilölle käteisenä nostetusta rahastoosuudesta, jota ei makseta rahastoon vaan työnantaja maksaa sen suoraan jäsenelle, maksetaan sosiaalivakuutusmaksut. Kohdassa ilmoitetaan vain rahastosta rahasto-osuutena nostetut erät. Jos suoritus on nostettu käteisenä, se ilmoitetaan tavallisena palkkana.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "benefits"
    },
    {
        "code": 310,
        "nameEn": "Monetary gift for employees",
        "nameFi": "Henkilöstölle annettu rahalahja",
        "nameSv": "Penninggåva till personalen",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": true,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Työnantajalta rahana tai siihen verrattavana suorituksena saatu lahja.",
        "taxAndSidecostsDescr": "Rahalahja katsotaan veronalaiseksi tuloksi, josta on toimitettava ennakonpidätys, mutta josta ei makseta sosiaalivakuutusmaksuja, jos rahalahja on annettu työntekijän merkkipäivän johdosta.\r\n\r\nJos rahalahja on annettu muutoin kuin työntekijän omana merkkipäivänä, maksetaan suorituksesta sosiaalivakuutusmaksut.\r\n\r\nOletuksena tulolajissa on, että tulo on sosiaalivakuutusmaksujen alainen. \r\n\r\nJos annettu rahalahja ei ole sosiaalivakuutusmaksujen alainen, suorituksen maksaja ilmoittaa vakuuttamistiedon erikseen Vakuuttamistiedon tyyppi- tietoryhmää käyttäen.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 311,
        "nameEn": "Kilometre allowance (tax-exempt)",
        "nameFi": "Kilometrikorvaus (verovapaa)",
        "nameSv": "Kilometerersättning (skattefri)",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "kilometreAllowanceTaxExempt",
        "notSupportedError": null,
        "description": "Henkilön oman tai hänen hallinnassaan olevan kulkuneuvon käytöstä suoritettava kilometrikorvaus, joka täyttää verovapaudelle asetetut vaatimukset.\r\n\r\nVerovapaata kilometrikorvausta voidaan maksaa palvelussuhteessa oleville ja henkilöille, jotka eivät ole palvelussuhteessa, mutta joille maksetaan verolainsäädännön mukaista palkkaa, esimerkiksi kokouspalkkion yhteydessä.\r\n\r\nJos kilometrikorvaus on maksettu vastoin Verohallinnon päätöksen mukaisia aika- ja kilometrirajoja, ne eivät ole miltään osin verovapaita.\r\n\r\nJos kilokorvaukset on maksettu Verohallinnon päätöksen mukaan, mutta suurempina kuin päätöksessä on määrätty verovapaaksi, osa korvauksista on veronalaista ja osa verovapaata. Veronalaiset kilometrikorvaukset ilmoitetaan erikseen omalla tulolajillaan tai palkan tulolajeilla.\r\n\r\nLiikenteenharjoittajan antaman tositteen (esimerkiksi junalipun) perusteella tulonsaajalle maksetut matkustamiskustannusten korvaukset ovat verovapaita, eikä niitä ilmoiteta.\r\n\r\n**Rakennusalalla maksettavat asunnon ja työpaikan väliset matkakustannusten korvaukset**\r\n\r\nRakennusalan työehtosopimuksen mukaan päivittäisistä asunnon ja erityisen työntekemispaikan välisistä matkoista maksetaan matkakustannusten korvausta (”tossurahaa”) erityisen taulukon mukaan eikä Verohallinnon päätöksen mukaisina kilometrikorvauksina. Työehtosopimuksen mukainen korvaus on kuitenkin pienempi kuin Verohallinnon päätöksen mukaiset kilometrikorvaukset, joten korvaus on verovapaata. \r\n\r\nRakennusalan tossurahan yhteydessä ei tarvitse ilmoittaa kilometrimäärää.",
        "taxAndSidecostsDescr": "Kohdassa ilmoitetaan vain verovapaiden kilometrikorvausten määrät. Summasta ei toimiteta ennakonpidätystä eikä makseta sosiaalivakuutusmaksuja.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/travelExpenses"
        ],
        "calcGrouping": "expenses"
    },
    {
        "code": 312,
        "nameEn": "Treatment fee for municipal veterinarian",
        "nameFi": "Kunnaneläinlääkärin toimenpidepalkkio",
        "nameSv": "Åtgärdsarvode för kommunal veterinär",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": "Not supported for companies / associations",
        "description": "Vain kunnat käyttävät tätä tulolajia.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 313,
        "nameEn": "Compensation for use, earned income",
        "nameFi": "Käyttökorvaus ansiotuloa",
        "nameSv": "Bruksersättning som förvärvsinkomst",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Korvaus, joka suoritetaan tekijänoikeuden, teollisoikeuden tai teollisia, kaupallisia tai tieteellisiä kokemuksia koskevien tietojen luovuttamisesta tai käyttöoikeudesta.",
        "taxAndSidecostsDescr": "Käyttökorvausta voidaan maksaa ennakkoperintärekisteriin kuuluvalle tai kuulumattomalle korvauksen saajalle. Käyttökorvaus on veronalaista ansiotuloa ja siitä toimitetaan ennakonpidätys, jos korvauksen saaja ei kuulu ennakkoperintärekisteriin.\r\n\r\nTulolajilla on ilmoitettava kaikki käyttökorvaukset, joista on toimitettu ennakonpidätys. Luonnollisille henkilöille maksetut käyttökorvaukset on ilmoitettava, vaikka niistä ei ole toimitettu ennakonpidätystä. Myös ennakkoperintärekisteriin merkitylle luonnolliselle henkilölle maksetut käyttökorvaukset on ilmoitettava.\r\n\r\nTulolajilla ilmoitetaan myös yhtymän, yhteisön tai yhteenliittymän saamat käyttökorvaukset (mutta niitä ei voi ilmoittaa Palkkaus.fi-palvelussa).\r\n\r\nTulolajilla ilmoitetaan lisäksi rajoitetusti verovelvolliselle maksetut rojalti. Jos rojalti eli käyttökorvaus on maksettu rajoitetusti verovelvolliselle luonnolliselle henkilölle, tiedot on ilmoitettava tulorekisteriin, vaikka tulonsaaja olisikin ennakkoperintärekisterissä eikä suorituksesta olisi peritty lähdeveroa.\r\n\r\nKäyttökorvauksesta ei makseta sosiaalivakuutusmaksuja.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 314,
        "nameEn": "Compensation for use, capital income",
        "nameFi": "Käyttökorvaus pääomatuloa",
        "nameSv": "Bruksersättning som kapitalinkomst",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Korvaus, joka suoritetaan tekijänoikeuden, teollisoikeuden tai teollisia, kaupallisia tai tieteellisiä kokemuksia koskevien tietojen luovuttamisesta tai käyttöoikeudesta.\r\n\r\nJos tekijänoikeus on siirtynyt perintönä tai testamentilla tai se on hankittu vastiketta vastaan, sen käyttämisestä saatu korvaus on henkilölle Suomesta saatuna tulona ennakonpidätyksenalaista pääomatuloa ennakkoperintärekisterimerkinnästä huolimatta.",
        "taxAndSidecostsDescr": "Tulolajilla ilmoitetaan kaikki käyttökorvaukset, joista on toimitettu ennakonpidätys. Luonnollisille henkilöille maksetut käyttökorvaukset on ilmoitettava, vaikka niistä ei ole toimitettu ennakonpidätystä. Myös ennakkoperintärekisteriin merkitylle luonnolliselle henkilölle maksetut käyttökorvaukset on ilmoitettava.\r\n\r\nKäyttökorvauksesta ei makseta sosiaalivakuutusmaksuja.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 315,
        "nameEn": "Other taxable benefit for employees",
        "nameFi": "Muu henkilöstölle suunnattu veronalainen etu",
        "nameSv": "Annan skattepliktig förmån till personalen",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": true,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Työnantajan henkilökunnalle kollektiivisesti myöntämä muu kuin rahana annettava veronalainen etu.\r\n\r\nVeronalaisena etuna pidetään esimerkiksi vuosittain laissa säädetyn enimmäismäärän 400 euroa ylittävää omaehtoiseen liikuntaan ja kulttuuriin annettua etua.",
        "taxAndSidecostsDescr": "Jos etu on annettu kollektiivisesti koko henkilökunnalle, etu ei ole sosiaalivakuutusmaksujen alainen.\r\n\r\nOletuksena tulolajissa on, ettei etu ole sosiaalivakuutusmaksujen alainen.\r\n\r\nJos etu on annettu vain osalle henkilökuntaa, etu on kokonaisuudessaan veronalainen ja etu on sosiaalivakuutusmaksujen alainen. Tällöin suorituksen maksaja ilmoittaa vakuuttamistiedon erillistä Vakuuttamistiedon tyyppi- tietoryhmää käyttäen.\r\n\r\nTulolajia käytetään myös tilanteessa, jossa työnantaja maksaa työntekijälle päivärahaa Verohallinnon päätöstä lievemmin perustein. Tällöin vakuuttamistiedon tyyppi-tiedon avulla voidaan ilmoittaa, jos työnantaja maksaa työntekijälle päivärahaa työehtosopimuksen perusteella Verohallinnon päätöstä lievemmin perustein, jolloin tulo ei ole työeläke-, työttömyyseikä työtapaturma- ja ammattitautivakuutusmaksun alainen.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "benefits"
    },
    {
        "code": 316,
        "nameEn": "Other taxable income deemed earned income",
        "nameFi": "Muu veronalainen ansiotulo",
        "nameSv": "Övriga skattepliktiga förvärvsinkomster",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "otherTaxableBenefitForEmployees",
        "notSupportedError": null,
        "description": "Tulolajilla ilmoitetaan muiden veronalaisten ansiotuloa olevien suoritusten yhteissumma.\r\n\r\nTulolajilla ilmoitetaan veronalaiset satunnaiset palkkiot ja palkinnot silloin, kun saaja ei ole työsuhteessa antajaan eikä suoritus ole työkorvausta. Tällaisia ovat esimerkiksi työsuhteeseen perustumaton kilpailupalkinto, asiakasyrityksen henkilökuntaan kuuluvalle tai muutoin asiakassuhteen perusteella annettu etu (esimerkiksi matka, lahjakortti tai esine), löytöpalkkio, pankin maksama niin sanottu tarkkaavaisuuspalkkio, taidekilpailun palkinto sekä kunnan asukkailleen maksama matkakorvaus.",
        "taxAndSidecostsDescr": "Muu veronalainen ansiotulo on ennakonpidätyksen alainen, mutta siitä ei makseta sosiaalivakuutusmaksuja. Merkitystä ilmoittamisen kannalta ei ole sillä, onko tulosta voitu toimittaa ennakonpidätys vai ei.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 317,
        "nameEn": "Other fringe benefit",
        "nameFi": "Muu  luontoisetu",
        "nameSv": "Övriga naturaförmåner",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": true,
        "taxDefault": 1,
        "transactionCode": "otherFringeBenefit",
        "notSupportedError": null,
        "description": "Tulolajilla ilmoitetaan työnantajan muuna kuin rahana antamat verotettavat edut, esimeriksi autotalli-, moottoripyörä- ja vene-etu, palkaksi katsotut henki- ja eläkevakuutusmaksut, yksilöimättömästä lahjakortista syntyvä etu ja merimiespalveluksessa olevan henkilön merimiehenä saama luontoisetu.\r\n\r\nPalkkaus.fi-palvelussa asunto-, auto-, puhelin- ja ravintoetu sekä työsuhdematkalipun erät tulee aina ilmoittaa omalla tulolajillaan. Niitä ei lisätä 'Muu luontoisetu' kohtaan.\r\n\r\nJos tulonsaajalta peritään korvaus edusta, luontoisedun arvo ilmoitetaan täysimääräisenä tulolajilla ennen perityn korvauksen vähentämistä.\r\n\r\nJos verotusarvoa ei ole erikseen vahvistettu Verohallinnon antamassa päätöksessä, luontoisedun arvo on sen käypä arvo. Etu on ilmoitettava, vaikka työntekijälle ei maksettaisi lainkaan rahapalkkaa tai rahapalkka ei riittäisi ennakonpidätyksen täysimääräiseen toimittamiseen.",
        "taxAndSidecostsDescr": "Luontoisedut ovat ennakonpidätyksen alaisia ja niistä maksetaan sosiaalivakuutusmaksut. Jos edusta ei ole voitu toimittaa ennakonpidätystä rahapalkan vähyyden vuoksi, ennakonpidätystä ei ilmoiteta, jos maksaja ei ole todella perinyt veroa.\r\n\r\nJos luontoisetu ei poikkeuksellisesti olisikaan edellä mainittujen maksujen alainen, suorituksen maksaja ilmoittaa vakuuttamistiedon erillistä Vakuuttamistiedon tyyppi -tietoryhmää. Tällainen tilanne on esimerkiksi silloin, kun työnantaja on maksanut työntekijän puolesta tämän eläke- tai työttömyysvakuutusmaksut, jolloin tulonsaajalle muodostuu luontoisetu työantajan maksamien maksujen osalta. Tuloa ei kuitenkaan pidetä eläke- eikä työttömyysvakuutusmaksun perusteena olevana työtulona. Etu on tällöinkin sairausvakuutusmaksun alainen.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/benefits"
        ],
        "calcGrouping": "benefits"
    },
    {
        "code": 319,
        "nameEn": "Kinship carer's fee",
        "nameFi": "Omaishoitajan palkkio",
        "nameSv": "Arvode för närståendevårdare",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": "Not supported for companies / associations",
        "description": "Vain kunnat käyttävät tätä tulolajia.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 320,
        "nameEn": "Stock options and grants",
        "nameFi": "Osakepalkkio",
        "nameSv": "Aktiepremie",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": true,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Palkkio, joka annetaan työnantajayrityksen osakkeina tai sovitun palkkion sijaan rahasummana, joka vastaa osakkeiden arvoa.",
        "taxAndSidecostsDescr": "Osakepalkkiosta toimitetaan ennakonpidätys, mutta ei makseta sosiaalivakuutusmaksuja, jos työntekijällä on kannustinjärjestelmän perusteella mahdollisuus saada työnantajayrityksen (tai sen kanssa samaan konserniin kuuluvan yhtiön tai muuhun vastaavaan taloudelliseen yhteenliittymään kuuluvan yhtiön) arvopaperipörssissä noteerattuja osakkeita ja edun arvo riippuu kyseisten osakkeiden arvon kehityksestä palkkion lupaamisen jälkeisenä, yli vuoden mittaisena aikana. Muussa kuin edellä mainituissa tapauksissa osakepalkkio on sosiaalivakuutusmaksujen alaista tuloa.\r\n\r\nOletuksena tulolajissa on, että se on eläkevakuutusmaksun alainen, mutta ei muiden sosiaalivakuutusmaksujen alainen.\r\n\r\nJos osakepalkkio on sosiaalivakuutusmaksujen alainen tai ei ole eläkevakuutusmaksun alainen, suorituksen maksaja ilmoittaa vakuuttamistiedon erillistä Vakuuttamistiedon tyyppi- tietoa käyttäen.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "benefits"
    },
    {
        "code": 321,
        "nameEn": "Wages paid by substitute payer: the employer pays for the employer's social insurance contributions (earnings-related pension, health, unemployment, and accident and occupational disease insurance)",
        "nameFi": "Sijaismaksajan maksama palkka, josta työnantaja maksaa työnantajan sosiaalivakuutusmaksut (työeläke-, sairaus-, työttömyys- sekä työtapaturma- ja ammattitautivakuutus)",
        "nameSv": "Lön som betalats av ställföreträdande betalare för vilken arbetsgivaren betalar arbetsgivarens socialförsäkringsavgifter (arbetspensions-, sjuk-, arbetslöshets- samt arbetsolycksfalls- och yrkessjukdomsförsäkringsavgift)",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "wagesPaidBySubstitutePayerIncludingSocialInsurance",
        "notSupportedError": null,
        "description": "Varsinainen työnantaja ilmoittaa sellaiset sosiaalivakuutusmaksujen perusteena olevat palkat yhteensä, jotka sijaismaksaja on maksanut ja joista sijaismaksaja on toimittanut ennakonpidätyksen.\r\n\r\nHUOM: Kotitalous ilmoittaa Yksityisen hoidon tuen tällä tulolajilla!\r\n\r\nVarsinaisen työnantajan antaman tiedon perusteella tuloa ei lueta tulonsaajalle verotuksessa tuloksi, mutta tieto tarvitaan tulonsaajakohtaisesti, koska henkilölle karttuu eläkettä maksetun tulon perusteella.\r\n\r\nTulolajia käytetään myös silloin, kun varsinainen työnantaja maksaa palkkaturvana maksettujen palkkojen perusteella työnantajan sosiaalivakuutusmaksut.\r\n\r\nVaikka sijaismaksaja on maksanut palkan tulonsaajille, varsinainen työnantaja on vastuussa työnantajan sosiaalivakuutusmaksujen maksamisesta. Tämän vuoksi varsinaisen työnantajan on ilmoitettava sijaismaksajan maksamat palkat tulonsaajakohtaisesti käyttäen erityisesti sijaismaksajatilanteita varten tarkoitettuja niin sanottuja infotulolajeja.\r\n\r\nSijaismaksaja ilmoittaa tiedot omalta osaltaan tulorekisteriin käyttäen muita tulolajeja sekä ohjaustietoa ”Sijaismaksaja – Kyllä”. Sijaismaksajan tiedon perusteella tulo verotetaan tulonsaajalla. Työntekijältä perittävät maksut peritään ja maksetaan sijaismaksajan maksaman palkan perusteella. Sijaismaksaja ei pääsääntöisesti kuitenkaan maksa työnantajan sosiaalivakuutusmaksuja, vaan niiden maksamisesta on vastuussa varsinainen työnantaja.\r\n\r\nSijaismaksajia voivat olla esimerkiksi ulosottovirastot, Kela, kunnat, Elinkeino-. liikenne- ja ympäristökeskukset, konkurssipesät ja takaajat. Ilmoittamista on kuvattu tarkemmin asiakasohjeessa\r\nTietojen ilmoittaminen tulorekisteriin: sijaismaksajan maksamat suoritukset.",
        "taxAndSidecostsDescr": "Tulolaji on työnantajan sosiaalivakuutusmaksujen alainen.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/substitutePayer"
        ],
        "calcGrouping": "otherNoPayment"
    },
    {
        "code": 322,
        "nameEn": "Wages paid by substitute payer: employer pays for employer's earnings-related pension insurance contribution",
        "nameFi": "Sijaismaksajan maksama palkka, josta työnantaja maksaa työnantajan työeläkevakuutusmaksun",
        "nameSv": "Lön som ställföreträdande betalare betalat och för vilken arbetsgivaren betalar arbetsgivarens arbetspensionsförsäkringsavgift",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "wagesPaidBySubstitutePayerIncludingEarningsRelatedPensionInsurance",
        "notSupportedError": null,
        "description": "Varsinainen työnantaja ilmoittaa sellaiset eläkevakuutusmaksujen perusteena olevat palkat yhteensä, jotka sijaismaksaja on maksanut ja joista sijaismaksaja on toimittanut ennakonpidätyksen, mutta joista työnantaja vastaa eläkevakuutusmaksusta. \r\n\r\nTulolajia käytetään myös silloin, kun varsinainen työnantaja maksaa palkkaturvana maksettujen palkkojen perusteella työnantajan eläkevakuutusmaksun. Sijaismaksajia voivat olla esimerkiksi ulosottovirastot, Kela, kunnat, Elinkeino-. liikenne- ja ympäristökeskukset, konkurssipesät ja takaajat.",
        "taxAndSidecostsDescr": "Tulolajia käytetään vain silloin, jos maksettu tulo on ollut vain eläkevakuutusmaksun alainen.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/substitutePayer"
        ],
        "calcGrouping": "otherNoPayment"
    },
    {
        "code": 323,
        "nameEn": "Wages paid by substitute payer: employer pays for employer's unemployment insurance contribution",
        "nameFi": "Sijaismaksajan maksama palkka, josta työnantaja maksaa työnantajan työttömyysvakuutusmaksun",
        "nameSv": "Lön som ställföreträdande betalare betalat och för vilken arbetsgivaren betalar arbetsgivarens arbetslöshetsförsäkringsavgift",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": true,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "wagesPaidBySubstitutePayerIncludingUnemploymentInsurance",
        "notSupportedError": null,
        "description": "Varsinainen työnantaja ilmoittaa sellaiset työttömyysvakuutusmaksujen perusteena olevat palkat yhteensä, jotka sijaismaksaja on maksanut ja joista sijaismaksaja on toimittanut ennakonpidätyksen, mutta joista työnantaja vastaa työttömyysvakuutusmaksusta.\r\n\r\nTulolajia käytetään myös silloin, kun varsinainen työnantaja maksaa palkkaturvana maksettujen palkkojen perusteella työnantajan työttömyysvakuutusmaksun.\r\n\r\nSijaismaksajia voivat olla esimerkiksi ulosottovirastot, Kela, kunnat, Elinkeino-. liikenne- ja ympäristökeskukset, konkurssipesät ja takaajat.",
        "taxAndSidecostsDescr": "Tulolajia käytetään vain silloin, jos maksettu tulo on ollut vain työttömyysvakuutusmaksun alainen.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/substitutePayer"
        ],
        "calcGrouping": "otherNoPayment"
    },
    {
        "code": 324,
        "nameEn": "Wages paid by substitute payer, employer pays for accident and occupational disease insurance contribution",
        "nameFi": "Sijaismaksajan maksama palkka, josta työnantaja maksaa työtapaturma- ja ammattitautivakuutusmaksun",
        "nameSv": "Lön som ställföreträdande betalare betalat och för vilken arbetsgivaren betalar arbetsolycksfalls- och yrkessjukdomsförsäkringsavgiften",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": true,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "wagesPaidBySubstitutePayerIncludingAccidentAndOccupationalDiseaseInsurance",
        "notSupportedError": null,
        "description": "Varsinainen työnantaja ilmoittaa sellaiset työtapaturma- ja ammattitautivakuutusmaksujen perusteena olevat palkat yhteensä, jotka sijaismaksaja on maksanut ja joista sijaismaksaja on toimittanut ennakonpidätyksen, mutta joista työnantaja vastaa työtapaturma- ja ammattitautivakuutusmaksusta.\r\n\r\nTulolajia käytetään myös silloin, kun varsinainen työnantaja maksaa palkkaturvana maksettujen palkkojen perusteella työtapaturma- ja ammattitautivakuutusmaksun.\r\n\r\nSijaismaksajia voivat olla esimerkiksi ulosottovirastot, Kela, kunnat, Elinkeino-. liikenne- ja ympäristökeskukset, konkurssipesät ja takaajat.",
        "taxAndSidecostsDescr": "Tulolajia käytetään vain silloin, jos maksettu tulo on ollut vain työtapaturma- ja ammattitautivakuutusmaksun alainen.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/substitutePayer"
        ],
        "calcGrouping": "otherNoPayment"
    },
    {
        "code": 325,
        "nameEn": "Wages paid by substitute payer, employer pays for employer's health insurance contribution",
        "nameFi": "Sijaismaksajan maksama palkka, josta työnantaja maksaa työnantajan sairausvakuutusmaksun",
        "nameSv": "Lön som ställföreträdande betalare betalat och för vilken arbetsgivaren betalar arbetsgivarens sjukförsäkringsavgift",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "wagesPaidBySubstitutePayerIncludingHealthInsurance",
        "notSupportedError": null,
        "description": "Varsinainen työnantaja ilmoittaa sellaiset sairausvakuutusmaksujen perusteena olevat palkat yhteensä, jotka sijaismaksaja on maksanut ja joista sijaismaksaja on toimittanut ennakonpidätyksen, mutta joista työnantaja vastaa työnantajan sairausvakuutusmaksusta.\r\n\r\nTulolajia käytetään myös silloin, kun varsinainen työnantaja maksaa palkkaturvana maksettujen palkkojen perusteella työnantajan sairausvakuutusmaksun.\r\n\r\nSijaismaksajia voivat olla esimerkiksi ulosottovirastot, Kela, kunnat, Elinkeino-. liikenne- ja ympäristökeskukset, konkurssipesät ja takaajat.",
        "taxAndSidecostsDescr": "Tulolajia käytetään vain silloin, jos maksettu tulo on ollut vain sairausvakuutusmaksun alainen.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/substitutePayer"
        ],
        "calcGrouping": "otherNoPayment"
    },
    {
        "code": 326,
        "nameEn": "Compensation for employee invention",
        "nameFi": "Palkkio työsuhdekeksinnöstä",
        "nameSv": "Arvode för arbetstagares uppfinning",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": true,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Palkkio, joka maksetaan työsuhdekeksinnöstä.",
        "taxAndSidecostsDescr": "Jos palkkion saajan työsuhteeseen kuuluviin tehtäviin ei kuulu keksiminen, palkkiota työsuhdekeksinnöstä käsitellään käyttökorvauksena eli palkkiosta ei makseta sosiaalivakuutusmaksuja. Tällöin työsuhdekeksinnöstä maksettavasta palkkiosta toimitetaan ennakonpidätys, ellei palkkion saaja kuulu ennakkoperintärekisteriin.\r\n\r\nJos tulonsaajan työsopimuksessa sovittuihin työtehtäviin kuuluu keksiminen, palkkiota käsitellään palkkana, eli palkkiosta maksetaan ennakonpidätyksen toimittamisen lisäksi sosiaalivakuutusmaksut.\r\n\r\nOletuksena tulolajissa on, että se ei ole sosiaalivakuutusmaksujen alainen. \r\n\r\nJos palkkio työsuhdekeksinnöstä on jonkun sosiaalivakuutusmaksun alainen, suorituksen maksaja ilmoittaa erillistä Vakuuttamistiedon tyyppi- tietoa käyttäen, että tulo on ilmoitetun vakuutusmaksun alainen.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 327,
        "nameEn": "Reimbursement of private caretaker's expenses",
        "nameFi": "Perhehoitajan kustannusten korvaus",
        "nameSv": "Kostnadsersättning för familjevårdare",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": "Not supported for companies / associations",
        "description": "Vain kunnat käyttävät tätä tulolajia.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 328,
        "nameEn": "Private caretaker's fee",
        "nameFi": "Perhehoitajan palkkio",
        "nameSv": "Arvode för familjevårdare",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": "Not supported for companies / associations",
        "description": "Vain kunnat käyttävät tätä tulolajia.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 329,
        "nameEn": "Reimbursement of family day care provider's expenses",
        "nameFi": "Perhepäivähoitajan kustannusten korvaus",
        "nameSv": "Kostnadsersättning för familjedagvårdare",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": "Not supported for companies / associations",
        "description": "Vain kunnat käyttävät tätä tulolajia.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 330,
        "nameEn": "Telephone benefit",
        "nameFi": "Puhelinetu",
        "nameSv": "Telefonförmån",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "telephoneBenefit",
        "notSupportedError": null,
        "description": "Luontoisetu, joka syntyy, kun työnantaja maksaa työntekijän puhelinliittymän kulut vapaa-ajalla tapahtuvan yksityiskäytön osalta.\r\n\r\nPalkkaus.fi-palvelussa puhelinetu ilmoitetaan aina tällä tulolajilla, ei koskaan 'Muu luotoisetu'-tulolajilla.",
        "taxAndSidecostsDescr": "Puhelinedusta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/benefits"
        ],
        "calcGrouping": "benefits"
    },
    {
        "code": 331,
        "nameEn": "Daily allowance",
        "nameFi": "Päiväraha",
        "nameSv": "Dagtraktamente ",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "dailyAllowance",
        "notSupportedError": null,
        "description": "Päiväraha on verovapaa kustannusten korvaus kohtuullisesta ruokailu- ja muiden elantokustannusten lisäyksestä, joka korvauksen saajalle aiheutuu työmatkasta.\r\n\r\nKohtaan merkitään verovapaiden päivärahojen ja ateriakorvausten yhteismäärä. Päiväraha-tulolajilla ilmoitettu tulo voi olla:\r\n\r\n- kotimaan kokopäiväraha,\r\n- kotimaan osapäiväraha,\r\n- ulkomaan päiväraha tai \r\n- ulkomaan työskentelyyn liittyvät verovapaat kustannusten korvaukset.\r\n\r\nPalkkaus.fi-palvelussa Ateriakorvaukset ilmoitetaan aina erillisellä Ateriakorvaus-tulolajia.\r\n\r\nJos päivärahan tyypiksi on merkitty ulkomaan työskentelyyn liittyvät kustannusten korvaukset, kohtaan merkitään seuraavat tulonsaajan saamat verovapaat edut, jotka liittyvät ulkomaan työskentelyyn:\r\n\r\n- verovelvollisen ja hänen perheenjäsenensä muutto- ja matkakustannukset työntekovaltioon ja takaisin\r\n- työnantajan ulkomailla kustantama tavanomainen yksityinen palveluhenkilöstö\r\n- työnantajan kustantama lasten perus- ja lukiotason koulutus.\r\n\r\nTulolajilla ei ilmoiteta yömatkarahaa eikä rajanylitysrahaa. Näitä eriä ei ilmoiteta tulorekisteriin.\r\n\r\nKohtaan merkitään vain verovapaiden päivärahojen ja ateriakorvausten yhteismäärä. Verohallinto vahvistaa vuosittain verovapaat määrät antamallaan päätöksellä verovapaista matkakustannusten korvauksista.\r\n\r\nJos päivärahat tai muut kohdassa mainitut korvaukset on maksettu Verohallinnon päätöstä lievemmin perustein, korvaukset ilmoitetaan tulolajilla Palkka yhteissumma tai Muu maksettu lisä, jolloin ne ovat myös sosiaalivakuutusmaksujen alaisia.\r\n\r\nJos lievemmin perustein maksetuista korvauksista on sovittu työehtosopimuksella, korvaus ei ole eläke-, työttömyys- eikä työtapaturma- ja ammattitautivakuutusmaksun alainen. Näissä tilanteissa suorituksen\r\nmaksaja ilmoittaa tulon Palkka yhteissumma-tulolajilla tai Muu henkilöstölle suunnattu veronalainen etu, ja samalla ilmoittaa, mikä osuus suorituksesta on eläkevakuutusmaksun, työttömyysvakuutusmaksun sekä työtapaturma- ja ammattitautivakuutusmaksun alainen.\r\n\r\nTulolajin yhteydessä on annettava lisätiedot, mitä eri päivärahoja yhteissumma sisältää.",
        "taxAndSidecostsDescr": "Päivärahat eivät ole sosiaalivakuutusmaksun alaisia.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/travelExpenses"
        ],
        "calcGrouping": "expenses"
    },
    {
        "code": 332,
        "nameEn": "Capital income payment",
        "nameFi": "Pääomatuloa oleva suoritus",
        "nameSv": "Prestation i form av kapitalinkomst",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Suoritus, joka on saajalleen pääomatuloa. Tällainen on esimerkiksi työntekijälle tai osakkaalle maksettu korko, kuten palkkasaatavan korko tai pääomatuloa oleva takausprovisio.",
        "taxAndSidecostsDescr": "Suoritukset ovat ennakonpidätyksen alaisia, mutta eivät sosiaalivakuutusmaksun alaisia. \r\nViivästyskorko on vapautettu Verohallinnon päätöksellä (A136/200/2016) ennakonpidätyksen toimittamisesta.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 334,
        "nameEn": "Meal benefit",
        "nameFi": "Ravintoetu",
        "nameSv": "Kostförmån",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "mealBenefit",
        "notSupportedError": null,
        "description": "Luontoisetu, joka syntyy, kun työnantaja tarjoaa työntekijälleen aterian. Työnantaja voi tukea ruokailukustannuksia ruokailulipukkeella tai muulla kohdennetulla maksuvälineellä taikka järjestämällä työpaikkaruokailun.\r\n\r\nRavintoedun verotusarvo määräytyy Verohallinnon päätöksen mukaisena vuosittain vahvistettavana arvona.\r\n\r\nPalkkaus.fi-palvelussa ravintoetu ilmoitetaan aina tällä tulolajilla, ei koskaan 'Muu luotoisetu'-tulolajilla.\r\n\r\nJos työnantaja perii työntekijältä ravintoedusta sen verotusarvoa vastaavan korvauksen, tulorekisteriin ilmoitetaan tieto Ravintoedusta peritty korvaus vastaa verotusarvoa: Kyllä.",
        "taxAndSidecostsDescr": "Ravintoedusta toimitetaan ennakonpidätys ja maksetaan sosiaalivakuutusmaksut.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/benefits"
        ],
        "calcGrouping": "benefits"
    },
    {
        "code": 335,
        "nameEn": "Reimbursement of costs, paid to conciliator",
        "nameFi": "Sovittelijan kulukorvaus",
        "nameSv": "Kostnadsersättning för medlare",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Veronalainen kustannusten korvaus, joka maksetaan vapaaehtoiselle sovittelijalle sovittelusta aiheutuneista kustannuksista.\r\n\r\nSovittelijan kulukorvaus on veronalaista ansiotuloa, joka otetaan huomioon suorituksen saajan verotuksessa saman suuruisena vähennyksenä ilman suorituksen saajan esittämää eri selvitystä.",
        "taxAndSidecostsDescr": "Kulukorvauksista ei toimiteta ennakonpidätystä eikä makseta sosiaalivakuutusmaksuja.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/expenses"
        ],
        "calcGrouping": "expenses"
    },
    {
        "code": 336,
        "nameEn": "Non-wage compensation for work",
        "nameFi": "Työkorvaus",
        "nameSv": "Arbetsersättning",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": "nonWageCompensationForWork",
        "notSupportedError": null,
        "description": "Muussa kuin palvelussuhteessa tehdystä työstä maksettava tai maksettavaksi sovittu vastike, josta tulee toimittaa ennakonpidätys, jos saaja ei ole ennakkoperintärekisterissä, mutta josta ei pääsääntöisesti makseta sosiaalivakuutusmaksuja.\r\n\r\nTyökorvausta voidaan maksaa ennakkoperintärekisteriin kuuluvalle tai kuulumattomalle työn suorittajalle. Työkorvaus on veronalaista ansiotuloa ja siitä toimitetaan ennakonpidätys, jos saaja ei kuulu ennakkoperintärekisteriin. Työkorvausta on esimerkiksi tukiperheelle maksettu korvaus.\r\n\r\nTyökorvauksesta on annettava ilmoitus, jos tulonsaaja ei kuulu ennakkoperintärekisteriin tai, jos maksajana on julkisten alojen eläkelakien piiriin (JuEL) kuuluva suorituksen maksaja ja tulonsaaja on luonnollinen henkilö, joka kuuluu ennakkoperintärekisteriin, mutta hänellä ei ole yrittäjän eläkelakien mukaista vakuutusta. Koska ilmoitus tehdään aina, kun tulonsaaja ei kuulu ennakkoperintärekisteriin, saajana voi olla myös muu kuin luonnollinen henkilö, kuten yhdistys, osakeyhtiö, avoin yhtiö tai kommandiittiyhtiö. Näitä maksuja ei kuitenkaan voi tehdä Palkkaus.fi-palvelun kautta.\r\n\r\nRajoitetusti verovelvolliselle yritykselle maksetut työkorvaukset on ilmoitettava, jos maksaja on perinyt yritykseltä lähdeveron. Rajoitetusti verovelvolliselle luonnolliselle henkilölle maksettu työkorvaus on ilmoitettava aina riippumatta siitä, onko lähdeveroa peritty, esimerkiksi rajoitetusti verovelvollisen urheilijan ja taiteilijan saama palkkio on ilmoitettava.\r\n\r\n**Työkorvauksiin liittyvät kustannusten korvaukset**\r\n\r\nJos palkkio tai muu suorituksen määrä on maksettu työkorvauksena, saajalla ei voi olla verovapaisiin kuluihin merkittäviä kustannusten korvauksia.\r\n\r\nTyökorvauksiin liittyvät kustannusten korvaukset lisätään tulon määrään yhtenä summana muun palkkion kanssa. Työkorvauksen yhteydessä maksetut kustannusten korvaukset eivät ole verovapaita. Jos veronalainen kilometrikorvaus maksetaan toimeksiantosuhteessa olevalle henkilölle tai yhteisölle, korvaus ilmoitetaan työkorvauksena, eikä tulolajia kilometrikorvaus (veronalainen) saa käyttää.\r\n\r\nTyökorvauksen saaja voi vaatia matkakustannuksia vähennettäväksi esitäytetyllä veroilmoituksellaan. Elinkeinotoiminnan harjoittaja vähentää kuitenkin matkakustannukset kirjanpidossaan.\r\n\r\nTyökorvauksesta ei yleensä voi ennen ennakonpidätyksen toimittamista vähentää työstä aiheutuneita kustannusten korvauksia. Poikkeuksena ovat vain luonnollisille henkilöille työmatkasta maksetut kustannusten korvaukset, joista ei tarvitse toimittaa ennakonpidätystä, jos niiden perusteet ja määrät ovat sen mukaisia kuin Verohallinnon vuosittain antamassa päätöksessä verovapaista matkakustannusten korvauksista on määrätty. Nämäkään korvaukset eivät ole verovapaita, joten ne ilmoitetaan työkorvauksen yhteissummassa.",
        "taxAndSidecostsDescr": "Työkorvauksesta ei pääsääntöisesti makseta sosiaalivakuutusmaksuja. Julkisten alojen eläkelakien piiriin kuuluva työnantaja maksaa yksityishenkilön toimeksiantosopimuksen perusteella työeläkevakuutusmaksut, jos toimeksisaaja ei toimi yrittäjänä eli hänellä ei ole yrittäjän eläkelain mukaista vakuutusta. Lisäksi tulonsaaja maksaa työkorvauksesta työntekijän sairausvakuutuksen päivärahamaksun. Oletuksena tulolajissa on, ettei tulo ole sosiaalivakuutusmaksujen alainen.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/wages"
        ],
        "calcGrouping": "baseSalary"
    },
    {
        "code": 337,
        "nameEn": "Supplementary daily allowance paid by employer-specific health insurance fund",
        "nameFi": "Työnantajakohtaisen sairaskassan maksama täydennyspäiväraha",
        "nameSv": "Kompletteringsdagpenning som betalats av en arbetsgivarspecifik sjukkassa",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": "Not supported for companies / associations",
        "description": "Vain sairauskassat käyttävät tätä tulolajia",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 338,
        "nameEn": "Pension paid by employer",
        "nameFi": "Työnantajan maksama eläke",
        "nameSv": "Pension som arbetsgivaren betalat ut",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Eläke, jonka työnantaja maksaa entiselle työntekijälleen tai tämän edunsaajalle aiemman palvelussuhteen perusteella.",
        "taxAndSidecostsDescr": "Tulo on ennakonpidätyksen alainen. Työnantajan maksamasta eläkkeestä ei makseta sosiaalivakuutusmaksuja.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/employmentTermination"
        ],
        "calcGrouping": "benefits"
    },
    {
        "code": 339,
        "nameEn": "Dividends/profit surplus based on work effort (wages)",
        "nameFi": "Työpanokseen perustuva osinko tai ylijäämä (palkka)",
        "nameSv": "Dividend eller överskott (lön) som baserar sig på arbetsinsats",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Osakkaalle palkkana maksettava osinko, jonka jakoperusteena on osingonsaajan tai tämän intressipiiriin kuuluvan henkilön työpanos.",
        "taxAndSidecostsDescr": "Työpanokseen perustuvasta osingosta toimitetaan ennakonpidätys. Yhtiön osakkaalle jaettavasta osingosta ei makseta työeläkevakuutus-, työttömyysvakuutus- eikä työtapaturma- ja ammattitautivakuutuksen maksua, vaikka osinko katsottaisiin työpanokseen perustuvaa osinkoa koskevien erityissäännösten perusteella verotuksessa palkaksi. Työpanokseen perustuvasta osingosta maksetaan työnantajan sairausvakuutusmaksu ja osingon määrä on työntekijän sairausvakuutuksen päivärahamaksun perusteena.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 340,
        "nameEn": "Dividends/profit surplus (wages) based on work effort (non-wage)",
        "nameFi": "Työpanokseen perustuva osinko tai ylijäämä (työkorvaus)",
        "nameSv": "Dividend eller överskott (arbetsersättning) som baserar sig på arbetsinsats",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Osakkaalle työkorvauksena maksettava osinko, jonka jakoperusteena on osingonsaajan tai tämän intressipiiriin kuuluvan henkilön työpanos.\r\n\r\nIlmoitus on annettava työkorvauksena verotettavasta työpanokseen perustuvasta osingosta tai ylijäämästä siinäkin tapauksessa, että saaja on merkitty ennakkoperintärekisteriin.",
        "taxAndSidecostsDescr": "Työpanokseen perustuvasta osingosta (työkorvausta) toimitetaan ennakonpidätys, ellei saaja ole ennakkoperintärekisterissä. Suorituksesta ei makseta sosiaalivakuutusmaksuja. Tulo on kuitenkin työntekijän sairausvakuutuksen päivärahamaksun alainen.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "salaryAdditions"
    },
    {
        "code": 341,
        "nameEn": "Employer-subsidised commuter ticket, tax-exempt share",
        "nameFi": "Työsuhdematkalipun verovapaa osuus",
        "nameSv": "Skattefri andel av personalbiljett",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Tulolajilla ilmoitetaan työnantajan työntekijälle kustantaman julkisen liikenteen henkilökohtainen joukkoliikennelipun verovapaa osuus.\r\n\r\nOsa työsuhdematkalipun arvosta on verovapaata ja osa veronalaista. Veronalainen osuus työsuhdematkalipusta on luontoisetua. Työnantajan työntekijälle antama enintään 300 euron arvoinen joukkoliikenteen henkilökohtainen matkalippu asunnon ja työpaikan välistä matkaa varten on verovapaata tuloa. Lisäksi matkalippu on verovapaata tuloa 750 euron ylittävältä osalta 3 400 euroon asti. Työsuhdematkalipusta on aina annettava ilmoitus, myös silloin kun verotettavaa etua tai vähennettävää määrää ei ole.\r\n\r\nEsimerkki: Työnantaja on antanut työntekijälle 300 euron työsuhdematkalipun. Luontoisetua ei synny.\r\n\r\n- Työsuhdematkalipun verovapaa osuus-tulolajilla ilmoitetaan 300 euroa\r\n\r\nJos palkansaaja ostaa matkalipun itse ja työnantaja maksaa työntekijälle matkalipun hinnan tai osan siitä, työnantajan maksama korvaus katsotaan kokonaisuudessaan työntekijän palkaksi. Tällöin työntekijälle maksettu lipun hinta ilmoitetaan vain palkkana.",
        "taxAndSidecostsDescr": "Verovapaasta osuudesta ei toimiteta ennakonpidätystä eikä makseta sosiaalivakuutusmaksuja.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/subsidisedCommute",
            "https://palkkaus.fi/usecases/2019/benefits"
        ],
        "calcGrouping": "benefits"
    },
    {
        "code": 342,
        "nameEn": "Employer-subsidised commuter ticket, taxable share",
        "nameFi": "Työsuhdematkalipun palkaksi katsottu osuus",
        "nameSv": "Andel av personalbiljett som betraktas som lön",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Tulolajilla ilmoitetaan työnantajan työntekijälle kustantaman julkisen liikenteen henkilökohtainen joukkoliikennelipun palkaksi katsottava osuus.\r\n\r\nOsa työsuhdematkalipun arvosta on verovapaata ja osa veronalaista. Veronalainen osuus työsuhdematkalipusta on luontoisetua. Työnantajan työntekijälle antama enintään 300 euron arvoinen joukkoliikenteen\r\nhenkilökohtainen matkalippu asunnon ja työpaikan välistä matkaa varten on verovapaata tuloa. Lisäksi matkalippu on verovapaata tuloa 750 euron ylittävältä osalta 3 400 euroon asti. Työsuhdematkalipusta on aina annettava ilmoitus, myös silloin kun verotettavaa etua ei ole.\r\n\r\nTyösuhdematkalipun palkaksi katsottava osuus ja verovapaa osuus on eriteltävä, koska ne vaikuttavat työntekijän kodin ja työpaikan välisten matkakulujen vähennyskelpoisuuteen.\r\n\r\nPalkaksi katsottavana osuutena ilmoitetaan se osuus edun arvosta, josta työnantaja on jo vähentänyt mahdollisesti tulonsaajalta perimänsä korvauksen.\r\n\r\nJos palkansaaja ostaa matkalipun itse ja työnantaja maksaa työntekijälle matkalipun hinnan tai osan siitä, työnantajan maksama korvaus katsotaan kokonaisuudessaan työntekijän palkaksi. Tällöin työntekijälle maksettu lipun hinta ilmoitetaan vain palkkana.\r\n\r\nEsimerkki: Työnantaja on antanut työntekijälle 800 euron arvoisen työsuhdematkalipun. Työnantaja ei peri työntekijältä korvausta lipun hinnasta. Koska työsuhdematkalippu on veronalaista siltä osin kuin edun arvon ylittää 300 euroa ja alittaa 750 euroa, veronalaista luontoisetua syntyy 450 euroa. Työntekijä saa verovapaata etua 350 euroa. \r\n\r\n- Työsuhdematkalipun palkaksi katsottu osuus-tulolajilla ilmoitetaan palkaksi katsottu määrä 450 euroa.\r\n- Työsuhdematkalipun verovapaa osuus-tulolajilla ilmoitetaan 350 euroa\r\n\r\nEsimerkki: Työnantaja on antanut työntekijälle 5 000 euron arvoisen työsuhdematkalipun. Työnantaja ei peri työntekijältä korvausta lipun hinnasta. Veronalaista luontoisetua ja palkkaa on 2 050 euroa. Työntekijä saa verovapaata etua 2 950 euroa. \r\n\r\n- Työsuhdematkalipun palkaksi katsottu osuus-tulolajilla ilmoitetaan luontoisedun määrä 2 050 euroa.\r\n- Työsuhdematkalipun verovapaa osuus-tulolajilla ilmoitetaan verovapaan edun määrä 2 950 euroa.\r\n\r\nTyösuhdematkalipun palkaksi katsottua osuus ilmoitetaan ainoastaan omalla tulolajillaan, eikä sitä lisätä Muu luontoisetu-tulolajiin etuihin.",
        "taxAndSidecostsDescr": "Palkaksi katsottu osuus on ennakonpidätyksen ja sosiaalivakuutusmaksujen alainen.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/subsidisedCommute",
            "https://palkkaus.fi/usecases/2019/benefits"
        ],
        "calcGrouping": "benefits"
    },
    {
        "code": 343,
        "nameEn": "Employee stock option",
        "nameFi": "Työsuhdeoptio",
        "nameSv": "Anställningsoption",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Palkkio, joka annetaan työnantajayrityksen option muodossa.",
        "taxAndSidecostsDescr": "Työsuhdeoptiosta saatavasta edusta toimitetaan ennakonpidätys.\r\n\r\nTyösuhdeoptio on tuloverotuksen kohteena optiota käytettäessä. Työsuhdeoptiosta ei mene sosiaalivakuutusmaksuja sitä käytettäessä.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "benefits"
    },
    {
        "code": 350,
        "nameEn": "Wages transferred to athletes' special fund",
        "nameFi": "Urheilijarahastoon siirretty palkka",
        "nameSv": "Lön som överförs till en idrottsfond",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": true,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Urheilutulon siirtäminen urheilijarahastoon tulojen jaksottamista varten. Urheilijalla on oikeus siirtää osa urheilutulosta urheilijarahastoon. Rahastoinnista sovitaan urheilijan, työnantajan ja mahdollisesti sponsorin kesken.\r\n\r\nUrheilutulo voi muodostua urheilijan palkasta tai palkkiosta. Tulolajilla ilmoitetaan vain rahastoon siirretty palkka. Siirto urheilurahastoon on tarkoitettu urheiluajan jälkeisen toimeentulon turvaamiseen.",
        "taxAndSidecostsDescr": "Urheilijan palkasta maksetaan työnantajan sairausvakuutusmaksu rahastoon siirrettävän palkan osalta. Urheilija maksaa tulosta veroa vasta silloin, kun tulo\r\nmaksetaan hänelle rahastosta. Rahastoitavasta palkasta toimitetaan ennakonpidätys ja maksetaan sairausvakuutuksen päivärahamaksu vasta silloin, kun\r\npalkka maksetaan rahastosta urheilijalle.\r\n\r\nUrheilutulon rahastointi ei vaikuta urheilijan tapaturma- ja eläketurvasta annetussa laissa eriteltyjen\r\nvakuutusmaksujen maksamiseen.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/athlete"
        ],
        "calcGrouping": "benefits"
    },
    {
        "code": 351,
        "nameEn": "Wages paid from athletes' special fund",
        "nameFi": "Urheilijarahastosta maksettu palkka",
        "nameSv": "Lön från en idrottsfond",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": "Not supported for companies / associations",
        "description": "Vain urheilijarahaston käyttöön: Tulolajilla ilmoitetaan vain rahastosta maksettu palkka.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 352,
        "nameEn": "Wages for insurance purposes",
        "nameFi": "Vakuutuspalkka",
        "nameSv": "Försäkringslön",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": true,
        "insuranceInformationAllowed": true,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": "TODO: Check",
        "description": "HUOM: Palkkaus.fi-perusversio ei tue kaikkia kansainvälisiä tilanteita oikein! Jos maksat palkkoja ulkomailla työskentelevälle henkilölle, ota ensin yhteyttä asiakaspalveluun.\r\n\r\nLaskennallinen palkka, joka olisi maksettava, jos ulkomailla tehtyä työtä vastaava työ tehtäisiin Suomessa. Vakuutuspalkkaa ulkomaantyössä käytetään sosiaalivakuuttamisessa maksujen ja etuuksien määräytymisen perusteena todellisen palkan sijaan.\r\n\r\nEri toimijoiden kesken on omat sääntönsä siitä, milloin määräytymisen perusteena käytetään vakuutuspalkkaa ja milloin todellista maksettua palkkaa. Aiheeseen liittyvä tarkempi ohje löytyy Eläketurvakeskuksen soveltamisohjeista: Vakuutuspalkka eläkkeen perusteena olevana työansiona.",
        "taxAndSidecostsDescr": "Oletuksena tulolajissa on, että se on sosiaalivakuutusmaksujen alainen.\r\n\r\nJos vakuutuspalkka ei poikkeuksellisesti olisikaan jonkun tai joidenkin sosiaalivakuutusmaksujen alainen, suorituksen maksaja ilmoittaa vakuuttamistiedon erillistä Vakuuttamistiedon tyyppi- tietoa käyttäen.",
        "isSupported": false,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 353,
        "nameEn": "Taxable reimbursement of expenses",
        "nameFi": "Veronalainen kustannusten korvaus",
        "nameSv": "Skattepliktig kostnadsersättning",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "taxableReimburementOfExpenses",
        "notSupportedError": null,
        "description": "Veronalaisilla kustannusten korvauksilla tarkoitetaan työn suorittajalle työtehtävien hoitamisesta aiheutuneista kustannuksista maksettavaa veronalaista korvausta. Tulolajilla ilmoitetaan kaikkien sellaisten veronalaisten kustannusten korvausten yhteissumma, jota ei eritellä muilla tulolajeilla.\r\n\r\nKohdassa ilmoitetaan vain palkansaajalle maksettuja välittömästi työstä aiheutuneita kustannusten korvauksia, joita työnantaja ei ole lukenut mukaan palkan määrään toimittaessaan ennakonpidätystä (ennakkoperintälain 15 §).\r\n\r\nTyönantaja voi korvata palkansaajalle työstä välittömästi aiheutuneet kustannukset. Tällaisia ovat muun muassa kustannukset, jotka ovat aiheutuneet työvälineiden ja materiaalin hankkimisesta, tarveaineista ja suoja-asujen hankkimisesta aiheutuvat kustannukset. Esimerkiksi rakennusalalla maksetaan työehtosopimukseen perustuvaa työvälinekorvausta.\r\n\r\nTyönantaja ei toimita veronalaisista kustannusten korvauksista ennakonpidätystä eikä maksa sosiaalivakuutusmaksuja. Korvaukset ovat kuitenkin palkansaajan veronalaista tuloa. Palkansaajan tulee vaatia todelliset kustannukset vähennettäviksi esitäytetyllä veroilmoituksellaan.\r\n\r\nJos työntekijä on hankkinut työnantajan puolesta työvälineitä ja työmateriaaleja, niiden kustannuksia ei ilmoiteta, jos työnantaja on korvannut ne työntekijälle tositetta vastaan.",
        "taxAndSidecostsDescr": "Työnantaja ei toimita veronalaisista kustannusten korvauksista ennakonpidätystä eikä maksa sosiaalivakuutusmaksuja.\r\n\r\nKorvaukset ovat kuitenkin palkansaajan veronalaista tuloa. Palkansaajan tulee vaatia todelliset kustannukset vähennettäviksi esitäytetyllä veroilmoituksellaan.\r\n\r\nJos työntekijä on hankkinut työnantajan puolesta työvälineitä ja työmateriaaleja, niiden kustannuksia ei ilmoiteta, jos työnantaja on korvannut ne työntekijälle tositetta vastaan.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/expenses"
        ],
        "calcGrouping": "expenses"
    },
    {
        "code": 354,
        "nameEn": "Private day care allowance municipal supplement",
        "nameFi": "Yksityisen hoidon tuen kuntalisä",
        "nameSv": "Kommuntillägg till stöd för privat vård",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": "Not supported for companies / associations",
        "description": "Vain kunnat käyttävät tätä tulolajia.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 355,
        "nameEn": "Private day care allowance (wages)",
        "nameFi": "Yksityisen hoidon tuki (palkka)",
        "nameSv": "Stöd för privat vård (lön)",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": "Not supported for companies / associations",
        "description": "Vain Kela käyttää tätä tulolajia.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 356,
        "nameEn": "Private day care allowance (non-wage)",
        "nameFi": "Yksityisen hoidon tuki (työkorvaus)",
        "nameSv": "Stöd för privat vård (arbetsersättning)",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 1,
        "transactionCode": null,
        "notSupportedError": "Not supported for companies / associations",
        "description": "Vain Kela käyttää tätä tulolajia.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 357,
        "nameEn": "Kilometre allowance paid by non-profit organisation",
        "nameFi": "Yleishyödyllisen yhteisön maksama kilometrikorvaus",
        "nameSv": "Kilometerersättning som betalats ut av ett allmännyttigt samfund",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "kilometreAllowancePaidByNonProfitOrganisation",
        "notSupportedError": null,
        "description": "Kilometrikorvaus, jonka yleishyödyllinen yhteisö maksaa korvauksettomaan vapaaehtoistyöhön osallistuvalle.\r\n\r\nYleishyödyllisen yhteisön hyväksi sen toimeksiannosta tehty matka rinnastetaan työmatkaan silloinkin, kun suorituksen saaja ei ole palvelussuhteessa maksajaan eikä muutoin saa palkkaa työstä, johon matka liittyy.\r\n\r\nTulolajilla ilmoitetaan vain vapaaehtoistyöhön osallistuville maksetut korvaukset. Jos verovapaat korvaukset liittyvät yhteisön maksamaan palkkaan, ne ilmoitetaan tulolajilla Kilometrikorvaus (verovapaa) (311).\r\n\r\nTulolajilla ilmoitetaan vain tuloverolain (1535/1992) 71 § 3 momentin mukaiset verovapaat kilometrikorvaukset. Lainkohdan mukaan matkakustannusten korvauksesta, jonka yleishyödyllinen yhteisö maksaa, on verovapaata tuloa: matkustamiskustannusten korvaus, jota voidaan suorittaa myös verovelvollisen asunnolta tehdystä matkasta. Matkustamiskustannusten korvauksesta muulla kuin julkisella kulkuneuvolla tehdystä matkasta on verovapaata enintään 2 000 euroa kalenterivuodelta.\r\n\r\nTulolajilla ilmoitetaan vain verovapaat määrät. Jos yleishyödyllinen yhteisö maksaa kilometrikorvauksia enemmän kuin tuloverolain 71 § 3 momentissa säädetään, ylimenevä osa ilmoitetaan työkorvauksena.",
        "taxAndSidecostsDescr": "Korvauksesta ei makseta sosiaalivakuutusmaksuja.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/travelExpenses"
        ],
        "calcGrouping": "baseSalary"
    },
    {
        "code": 358,
        "nameEn": "Daily allowance paid by non-profit organisation",
        "nameFi": "Yleishyödyllisen yhteisön maksama päiväraha",
        "nameSv": "Dagtraktamente som betalats ut av ett allmännyttigt samfund",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Työmatkapäiväraha, jonka yleishyödyllinen yhteisö maksaa korvauksettomaan vapaaehtoistyöhön osallistuvalle.\r\n\r\nTulolajilla ilmoitetaan vain vapaaehtoistyöhön osallistuville maksetut päivärahat. Jos verovapaa päiväraha liittyy yhteisön maksamaan palkkaan, se ilmoitetaan tulolajilla Päiväraha (331).\r\n\r\nKohdassa ilmoitetaan vain tuloverolain 71 § 3 momentin mukaiset verovapaat korvaukset. Lainkohdan mukaan matkakustannusten korvauksesta, jonka yleishyödyllinen yhteisö maksaa, on verovapaata tuloa:\r\n\r\n- päiväraha enintään 20 päivältä kalenterivuodessa\r\n- majoittumiskorvaus.\r\n\r\nTulolajilla ilmoitetaan vain verovapaat määrät. Jos yleishyödyllinen yhteisö maksaan päivärahaa enemmän kuin tuloverolain 7 § momentissa säädetään, ylimenevä osa ilmoitetaan työkorvauksena.",
        "taxAndSidecostsDescr": "Päivärahasta ei makseta sosiaalivakuutusmaksuja.",
        "isSupported": true,
        "paymentDefault": 1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/travelExpenses"
        ],
        "calcGrouping": "baseSalary"
    },
    {
        "code": 359,
        "nameEn": "Unjust enrichment",
        "nameFi": "Perusteeton etu",
        "nameSv": "Ogrundad förmån",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": "Not supported: Does not fit Palkkaus.fi-process.",
        "description": "Perusteeton etu -tulolajia käytetään vain, jos aiheettomasti maksettu suoritus havaitaan ennen ensimmäisen ilmoituksen lähettämistä, eikä tuloa ole aiemmin ilmoitettu muuna tulona tulorekisteriin.\r\n\r\nTämä ei tyypillisesti ole mahdollista Palkkaus.fi-maksuprosessissa. Ota yhteys asiakaspalveluun, jos haluat oikeasti käyttää tätä tyyppiä.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 1,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 361,
        "nameEn": "Employee stock option with a subscription price lower than the market price at the time of issue",
        "nameFi": "Työsuhdeoptio, jonka merkintähinta on luovutusajankohtana alhaisempi kuin markkinahinta",
        "nameSv": "Anställningsoption vars teckningspris är lägre än marknadspriset vid överlåtelsetidpunkten",
        "isNegativeSupported": false,
        "pensionInsurance": true,
        "accidentInsurance": true,
        "unemploymentInsurance": true,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Palkkio, joka annetaan työnantajayrityksen option muodossa ja jossa työntekijältä peritty option merkintähinta option luovutusajankohtana on selvästi alhaisempi kuin osakkeen markkinahinta.\r\n\r\nKäytettäessä optiota etu ilmoitetaan tulolajilla Työsuhdeoptio.",
        "taxAndSidecostsDescr": "Tulo on työeläke-, työttömyys- sekä työtapaturma- ja ammattitautivakuutusmaksun alainen.\r\n\r\nTyösuhdeoptioetu ei ole optio-oikeutta luovutettaessa tuloverotuksen alaista eikä siitä määrätä työnantajan sairausvakuutusmaksua. \r\n\r\nKäytettäessä optiota etu ilmoitetaan tulolajilla Työsuhdeoptio.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "benefits"
    },
    {
        "code": 401,
        "nameEn": "Compensation collected for car benefit",
        "nameFi": "Autoedusta peritty korvaus",
        "nameSv": "Ersättning för bilförmån",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": -1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Luontoisedun omavastuuosuus, jonka työntekijä maksaa autoedun verotusarvosta.\r\n\r\nAutoedun omavastuuosuus alentaa verotettavaa etua tai poistaa sen kokonaan. Jos autoedun omavastuuosuus on autoedun verotusarvoa alempi, autoedun arvon ja autoedusta perityn korvauksen erotus on työntekijän veronalaista palkkaa. Jos omavastuuosuus vastaa autoedun verotusarvoa, verotettavaa etua ei synny. Tällöinkin peritty korvaus on ilmoitettava. Tällöin on lisäksi ilmoitettava edun määrä Autoetu-tulolajilla.\r\n\r\nAutoedun arvo ilmoitetaan täysimääräisenä Autoetu-tulolajilla ja Autoedusta peritty korvaustulolajilla työntekijältä perityn omavastuuosuuden määrä. \r\n\r\nAutoetu on ilmoitettava siinäkin tapauksessa, että suorituksen maksaja on perinyt tulonsaajalta luontoisedusta luontoisedun rahaarvoa vastaavan tai sitä suuremman korvauksen, eikä palkkaan lisättävää määrää ole jäänyt lainkaan.\r\n\r\nTyönantaja voi periä autoedun omavastuuosuuden työntekijän nettopalkasta.",
        "taxAndSidecostsDescr": "Ilmoitettu summa vähentää ennakonpidätyksen ja sosiaalimaksujen pohjana olevaa palkkaa ja vähennetään oletuksena asiakasvaratilin kautta maksetusta palkasta.",
        "isSupported": true,
        "paymentDefault": -1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/carBenefit",
            "https://palkkaus.fi/usecases/2019/benefits"
        ],
        "calcGrouping": "deductions"
    },
    {
        "code": 402,
        "nameEn": "Withholding tax",
        "nameFi": "Ennakonpidätys",
        "nameSv": "Förskottsinnehållning",
        "isNegativeSupported": true,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "withholdingTax",
        "notSupportedError": null,
        "description": "Ennakkoperintä, jossa suorituksen maksaja vähentää verovelvolliselle maksettavasta rahamäärästä ennakonpidätysprosentin mukaan lasketun veron.\r\n\r\nEnnakonpidätys voidaan ilmoittaa ilmoituksella yhteissummana, vaikka tulolajeja olisi ilmoitettu useita.",
        "taxAndSidecostsDescr": "",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "totals"
    },
    {
        "code": 403,
        "nameEn": "Elected official fee",
        "nameFi": "Luottamushenkilömaksu",
        "nameSv": "Avgift för förtroendevald",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": "Not supported for companies / associations",
        "description": "Luottamushenkilömaksua voivat ilmoittaa vain kunta ja kuntayhtymä.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 404,
        "nameEn": "Tax at source",
        "nameFi": "Lähdevero",
        "nameSv": "Källskatt",
        "isNegativeSupported": true,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": "International scenarios are not supported inthis version.",
        "description": "Palkkaus.fi-perusversio ei tue kaikkia kansainvälisiä tilanteita oikein! Jos maksat palkkoja ulkomailla työskentelevälle henkilölle, ota ensin yhteyttä asiakaspalveluun.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 405,
        "nameEn": "Tax at source deduction",
        "nameFi": "Lähdeverovähennys",
        "nameSv": "Källskatteavdrag",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": "International scenarios are not supported inthis version.",
        "description": "Palkkaus.fi-perusversio ei tue kaikkia kansainvälisiä tilanteita oikein! Jos maksat palkkoja ulkomailla työskentelevälle henkilölle, ota ensin yhteyttä asiakaspalveluun.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 406,
        "nameEn": "Wages paid",
        "nameFi": "Maksettava palkka",
        "nameSv": "Lön som ska betalas ut",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "wagesPaid",
        "notSupportedError": null,
        "description": "Rahapalkka, joka maksetaan ennakonpidätyksen, työntekijän sosiaalivakuutusmaksujen ja muiden vähennettävien erien vähentämisen jälkeen työntekijälle.\r\n\r\nMuihin vähennettäviin eriin voivat kuulua esimerkiksi luontoiseduista työntekijältä perittävät maksut, työnantajan pidättämät työttömyyskassan ja ammattiliiton jäsenmaksut sekä ulosottomaksut.\r\n\r\nTyönantajalle kuuluvia kulueriä, kuten esim. työmatkoilta maksettavia hotellimaksuja, matkalippukuluja tai mahdollisia työterveydenhuollon maksuja ei ilmoiteta Maksettava palkka-tulolajilla.",
        "taxAndSidecostsDescr": "",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "totals"
    },
    {
        "code": 407,
        "nameEn": "Reimbursement collected for other fringe benefits",
        "nameFi": "Muista luontoiseduista peritty korvaus",
        "nameSv": "Ersättning för andra naturaförmåner",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": true,
        "taxDefault": -1,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Osuus luontoisedun arvosta, jonka työntekijä maksaa itse.\r\n\r\nKohdassa ilmoitetaan summa, joka työntekijältä on peritty muista luontoiseduista kuin autoedusta tai työsuhdematkalippuedusta.\r\n\r\nLuontoisedun arvo ilmoitetaan täysimääräisenä omalla tulolajillaan ja Muista luontoiseduista peritty korvaus-tulolajilla työntekijältä perityn omavastuuosuuden määrä.\r\n\r\nJos ravintoedusta peritty korvaus vastaa verotusarvoa, perittyä korvausta ei ilmoiteta Muusta luontoisedusta peritty korvaus-erittelylajilla. Tällöin käytetään vain tietoa Ravintoedusta peritty korvaus vastaa verotusarvoa – ”Kyllä (true)”.\r\n\r\nTyönantaja voi periä korvauksen luontoiseduista työntekijän nettopalkasta.",
        "taxAndSidecostsDescr": "Ilmoitettu summa vähentää oletuksena ennakonpidätyksen ja sosiaalimaksujen pohjana olevaa palkkaa ja vähennetään asiakasvaratilin kautta maksetusta palkasta.\r\n\r\nJos Muu luontoisetu -tulolajilla ilmoitettu luontoisetu ei ole sosiaalivakuutusmaksujen alainen ja suorituksen maksaja on ilmoittanut tämän käyttämällä Vakuuttamistiedon tyyppi - tietoryhmää, vastaava Vakuuttamistiedon tyyppi -tieto on lisättävä myös Muista luontoiseduista peritty korvaus -tulolajiin siltä osin, kun peritty korvaus kohdistuu siihen osaan etua, joka ei ole sosiaalivakuutusmaksujen alainen, ks. asiakasohje Tietojen ilmoittaminen tulorekisteriin: luontoisedut ja kustannusten korvaukset.",
        "isSupported": true,
        "paymentDefault": -1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/benefits"
        ],
        "calcGrouping": "deductions"
    },
    {
        "code": 408,
        "nameEn": "Other item deductible from net wage or salary",
        "nameFi": "Nettopalkasta vähennettävä muu erä",
        "nameSv": "Övriga poster som ska dras av från nettolönen",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "otherItemDeductibleFromNetWage",
        "notSupportedError": null,
        "description": "Erät, jotka palkan maksaja vähentää nettopalkasta ennen kuin maksaa suorituksen tulonsaajalle.\r\n\r\nNettopalkasta voidaan vähentää suorituksia lain tai sopimuksen perusteella. Lain perusteella tehtäviä vähennyksiä ovat esimeriksi ulosmittaukset. Työnantaja voi kuitata omia saataviaan työntekijän palkasta. Työntekijän nettopalkasta voidaan vähentää maksuja, joiden perimisestä on työnantajan ja työntekijän kesken sovittu. Nettopalkasta vähennettäviä eriä ovat esim. työttömyyskassan ja ammattiyhdistysten jäsenmaksut sekä pysäköintihallimaksut.\r\n\r\nJos ulosmittaus on jo ilmoitettu erikseen, ei sitä ilmoiteta enää tällä erittelylajilla yhteissummassa.",
        "taxAndSidecostsDescr": "Vähennetään nettopalkasta - ei vaikuta ennakonpidätykseen tai sosiaalimaksuihin.",
        "isSupported": true,
        "paymentDefault": -1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/deductions"
        ],
        "calcGrouping": "deductions"
    },
    {
        "code": 409,
        "nameEn": "Net wage or salary",
        "nameFi": "Nettopalkka",
        "nameSv": "Nettolön",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "netWage",
        "notSupportedError": null,
        "description": "Palkka, josta on toimitettu ennakonpidätys ja maksettu työntekijän sosiaalivakuutusmaksut. \r\n\r\nNettopalkka on eri asia kuin työntekijälle maksettava palkka.",
        "taxAndSidecostsDescr": "",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "totals"
    },
    {
        "code": 410,
        "nameEn": "Employer-paid premium for collective additional pension insurance",
        "nameFi": "Työnantajan maksaman kollektiivisen lisäeläkevakuutuksen maksu",
        "nameSv": "Kollektiv tilläggspensionsförsäkringsavgift som betalats av arbetsgivaren",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Työnantajan osuus kollektiivisen lisäeläkkeen kattamiseksi maksettavasta lisäeläkevakuutuksen maksusta.\r\n\r\nMaksu ilmoitetaan vain, jos työntekijä maksaa itse osan maksuista. Jos työnantaja maksaa kollektiivisen lisäeläketurvan maksut kokonaan, tietoja ei ilmoiteta laisinkaan palkkatietoilmoituksella. \r\n\r\nKohdassa ilmoitetaan vain 6.5.2004 tai sen jälkeen otetun kollektiivisen lisäeläketurvan maksut. Jos työntekijä on ollut vakuutettuna ennen 6.5.2004, häneltä perityt maksut ilmoitetaan vain Työntekijän työeläkevakuutusmaksu-kohdassa.\r\n\r\nMaksut ilmoitetaan tässä kohdassa myös silloin, kun uusi työntekijä on tullut 6.5.2004 jälkeen mukaan työnantajan ennen tuota päivää ottamaan kollektiiviseen vakuutusjärjestelmään.",
        "taxAndSidecostsDescr": "",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/pension"
        ],
        "calcGrouping": "benefits"
    },
    {
        "code": 411,
        "nameEn": "Employer-paid premium for collective additional pension insurance, employee's contribution",
        "nameFi": "Työnantajan maksaman kollektiivisen lisäeläkevakuutuksen työntekijältä peritty osuus",
        "nameSv": "Andel av kollektiv tilläggspensionsförsäkringsavgift som betalats av arbetsgivaren och som debiteras arbetstagaren",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Työntekijän osuus kollektiivisen lisäeläkkeen kattamiseksi maksettavasta lisäeläkevakuutuksen maksusta.\r\n\r\nMaksu ilmoitetaan vain, jos työntekijä maksaa itse osan maksuista. Jos työnantaja maksaa kollektiivisen lisäeläketurvan maksut kokonaan, tietoja ei ilmoiteta lainkaan palkkatietoilmoituksella. \r\n\r\nKohdassa ilmoitetaan vain 6.5.2004 tai sen jälkeen otetun kollektiivisen lisäeläketurvan maksut. Jos työntekijä on ollut vakuutettuna ennen 6.5.2004, häneltä perityt maksut ilmoitetaan vain Työntekijän työeläkevakuutusmaksut-kohdassa.\r\n\r\nMaksut ilmoitetaan kohdassa myös silloin, kun uusi työntekijä on tullut 6.5.2004 jälkeen mukaan työnantajan ennen tuota päivää ottamaan kollektiiviseen vakuutusjärjestelmään.",
        "taxAndSidecostsDescr": "Vähennetään oletuksena nettopalkasta. Ei vaikuta ennakonpidätykseen tai sosiaalimaksuihin.",
        "isSupported": true,
        "paymentDefault": -1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/pension"
        ],
        "calcGrouping": "deductions"
    },
    {
        "code": 412,
        "nameEn": "Employee's health insurance contribution",
        "nameFi": "Työntekijän sairausvakuutusmaksu",
        "nameSv": "Arbetstagarens sjukförsäkringsavgift",
        "isNegativeSupported": true,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": "International scenarios are not supported inthis version.",
        "description": "Yleisesti verovelvollisella tulonsaajalla sairausvakuutusmaksu sisältyy aina ennakonpidätykseen, eikä yleisesti verovelvollisten osalta tule ilmoittaa erikseen työntekijän sairausvakuutusmaksua.\r\n\r\nRajoitetusti verovelvollisen sairausvakuutusmaksu on perittävä erikseen lähdeveron lisäksi, ellei rajoitetusti verovelvollinen ole hakeutunut verotusmenettelystä annetun lain mukaiseen verotukseen, jolloin sairausvakuutusmaksu sisältyy ennakonpidätykseen tai ennakkoveroon. \r\n\r\nHUOM: Palkkaus.fi-perusversio ei tue kaikkia kansainvälisiä tilanteita oikein! Jos maksat palkkoja ulkomailla työskentelevälle henkilölle, ota ensin yhteyttä asiakaspalveluun.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 413,
        "nameEn": "Employee's pension insurance contribution",
        "nameFi": "Työntekijän työeläkevakuutusmaksu",
        "nameSv": "Arbetspensionsförsäkringsavgift för arbetstagare",
        "isNegativeSupported": true,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "employeesPensionInsuranceContribution",
        "notSupportedError": null,
        "description": "Bruttopalkan perusteella määräytyvä työeläkevakuutusmaksu, jolla työntekijä osallistuu työeläkevakuutuksen rahoittamiseen.\r\n\r\nTyöntekijän työeläkevakuutusmaksu vähennetään työntekijän nettopalkasta.",
        "taxAndSidecostsDescr": "",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "totals"
    },
    {
        "code": 414,
        "nameEn": "Employee's unemployment insurance contribution",
        "nameFi": "Työntekijän työttömyysvakuutusmaksu",
        "nameSv": "Arbetstagarens arbetslöshetsförsäkringsavgift",
        "isNegativeSupported": true,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "employeesUnemploymentInsuranceContribution",
        "notSupportedError": null,
        "description": "Bruttopalkan perusteella määräytyvä työttömyysvakuutusmaksu, jolla työntekijä osallistuu työttömyysvakuutuksen rahoittamiseen.\r\n\r\nTyöntekijän työttömyysvakuutusmaksu vähennetään työntekijän nettopalkasta.",
        "taxAndSidecostsDescr": "",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "totals"
    },
    {
        "code": 415,
        "nameEn": "Reimbursement for employer-subsidised commuter ticket",
        "nameFi": "Työsuhdematkalipusta peritty korvaus",
        "nameSv": "Ersättning för personalbiljett",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Luontoisedun omavastuuosuus, jonka työntekijä maksaa työsuhdematkalipun euromääräisestä arvosta.\r\n\r\nOsa työsuhdematkalipun arvosta on verovapaata ja osa veronalaista. Veronalainen osuus työsuhdematkalipusta on luontoisetua. Työnantajan työntekijälle antama enintään 300 euron arvoinen joukkoliikenteen henkilökohtainen matkalippu asunnon ja työpaikan välistä matkaa varten on verovapaata tuloa. Lisäksi matkalippu on verovapaata tuloa 750 euron ylittävältä osalta 3 400 euroon asti. Työsuhdematkalipusta on aina annettava ilmoitus, myös silloin kun verotettavaa etua ei ole.\r\n\r\nJos palkansaaja ostaa matkalipun itse ja työnantaja maksaa työntekijälle matkalipun hinnan tai osan siitä, työnantajan maksama korvaus katsotaan kokonaisuudessaan työntekijän palkaksi. Tällöin työntekijälle maksettu lipun hinta ilmoitetaan vain palkkana.\r\n\r\nTyönantaja voi periä työsuhdematkalipun omavastuuosuuden työntekijän nettopalkasta.\r\n\r\nEsimerkki: Työnantaja on antanut työntekijälle 1 000 euron arvoisen työsuhdematkalipun. Työnantaja perii työntekijän nettopalkasta 200 euroa. Veronalaista luontoisetua ja palkkaa on 250 euroa. Työntekijä saa verovapaata etua 550 euroa.\r\n\r\n- Työsuhdematkalipun palkaksi katsottu osuus -tulolajilla ilmoitetaan palkaksi katsottu määrä 250 euroa.\r\n- Työsuhdematkalipusta peritty korvaus-erittelylajilla ilmoitetaan työntekijältä peritty määrä 200 euroa.\r\n- Työsuhdematkalipun verovapaa osuus- tulolajilla ilmoitetaan verovapaan edun määrä 550 euroa.\r\n\r\nEsimerkki: Työnantaja on antanut työntekijälle 1 000 euron arvoisen työsuhdematkalipun. Työnantaja perii työntekijän nettopalkasta 500 euroa. Veronalaisen luontoisedun määrä on 450 euroa. Koska peritty korvaus on suurempi kuin edun verotusarvo, verotettavaa luontoisetua ei synny. Työntekijä saa verovapaata etua 500 euroa.\r\n\r\n- Työsuhdematkalipusta peritty korvaus -erittelylajilla ilmoitetaan työntekijältä peritty määrä 500 euroa.\r\n- Työsuhdematkalipun verovapaa osuus-tulolajilla ilmoitetaan 500 euroa.",
        "taxAndSidecostsDescr": "Vähennetään oletuksena nettopalkasta. Ei vaikuta ennakonpidätykseen tai sosiaalimaksuihin, sillä summa pitää olla jo vähennetty kohdasta 342 'Työsuhdematkalipun palkaksi katsottu osuus'.",
        "isSupported": true,
        "paymentDefault": -1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/subsidisedCommute",
            "https://palkkaus.fi/usecases/2019/benefits"
        ],
        "calcGrouping": "deductions"
    },
    {
        "code": 416,
        "nameEn": "Tax paid abroad",
        "nameFi": "Ulkomaille maksettu vero",
        "nameSv": "Skatt som betalats till utlandet",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": "International scenarios are not supported inthis version.",
        "description": "Palkkaus.fi-perusversio ei tue kaikkia kansainvälisiä tilanteita oikein! Jos maksat palkkoja ulkomailla työskentelevälle henkilölle, ota ensin yhteyttä asiakaspalveluun.",
        "taxAndSidecostsDescr": "",
        "isSupported": false,
        "paymentDefault": 0,
        "usecases": [],
        "calcGrouping": "disabled"
    },
    {
        "code": 417,
        "nameEn": "Distraint",
        "nameFi": "Ulosmittaus",
        "nameSv": "Utmätning",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": "distraint",
        "notSupportedError": null,
        "description": "Perittäväksi tulleen velan maksamiseksi tehtävä pidätys. Ulosmitattava määrä lasketaan nettotulosta.\r\n\r\nUlosmitattaessa velallisen ja hänen perheensä toimeentuloa varten tulee kuitenkin jättää suojaosuus.",
        "taxAndSidecostsDescr": "Vähennetään oletuksena nettopalkasta. Ei vaikuta ennakonpidätykseen tai sosiaalimaksuihin.",
        "isSupported": true,
        "paymentDefault": -1,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/deductions"
        ],
        "calcGrouping": "deductions"
    },
    {
        "code": 418,
        "nameEn": "Voluntary individual pension insurance premium",
        "nameFi": "Vapaaehtoisen yksilöllisen eläkevakuutuksen maksu",
        "nameSv": "Försäkringsavgift för en individuell, frivillig pensionsförsäkring",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": 0,
        "transactionCode": null,
        "notSupportedError": null,
        "description": "Lakisääteistä eläketurvaa täydentävän tietylle henkilölle kohdistetun eläkevakuutuksen maksu. Vapaaehtoisen yksilöllisen eläkevakuutuksen maksu voi olla jatkuva tai kertamaksullinen.\r\n\r\nKohtaan merkitään työntekijälle otetun vapaaehtoisen yksilöllisen eläkevakuutuksen maksut. Samoin ilmoitetaan myös sellaisen yksilöllisen eläkevakuutuksen maksut, joka on otettu avoimen yhtiön yhtiömiehelle, kommandiittiyhtiön vastuunalaiselle yhtiömiehelle tai sellaisen osakeyhtiön osakkaalle, joka ei ole työeläkevakuutettu.\r\n\r\nJos työnantajan ottaman vapaaehtoisen yksilöllisen eläkevakuutuksen maksut ylittävät 8 500 euroa, ne ovat veronalaista tuloa, joista maksetaan myös työnantajan sosiaalivakuutusmaksut. Jos maksut ylittävät 8 500 euroa vuodessa, suorituksen maksaja ilmoittaa ylimenevät maksut muuna luontoisetuina. \r\n\r\nEsimerkki: Työnantaja maksaa työntekijälle ottamansa vapaaehtoisen yksilöllisen eläkevakuutuksen maksuja vuodessa 12000 euroa. Työnantaja ilmoittaa tiedot seuraavasti:\r\n\r\n- Vapaaehtoisen yksilöllisen eläkevakuutuksen maksu 8 500 euroa.\r\n- Muu verotettava luontoisetu 3 500 euroa.\r\n\r\nKohtaan merkitään vain vapaaehtoisen yksilöllisen eläkevakuutuksen maksut. Jos työnantaja on maksanut työntekijän puolesta työntekijän pakollisia eläkevakuutusmaksuja, työttömyysvakuutusmaksuja ja työntekijän itsensä ottaman vapaaehtoisen eläkevakuutuksen maksuja, nämä ilmoitetaan Muu luontoisetu-tulolajilla.",
        "taxAndSidecostsDescr": "",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/pension"
        ],
        "calcGrouping": "benefits"
    },
    {
        "code": 419,
        "nameEn": "Deduction before withholding",
        "nameFi": "Vähennys ennen ennakonpidätystä",
        "nameSv": "Avdrag före förskottsinnehållning",
        "isNegativeSupported": false,
        "pensionInsurance": false,
        "accidentInsurance": false,
        "unemploymentInsurance": false,
        "healthInsurance": false,
        "insuranceInformationAllowed": false,
        "taxDefault": -1,
        "transactionCode": "deductionBeforeWithholding",
        "notSupportedError": null,
        "description": "Työntekijän itsensä maksama työn tekemisestä aiheutunut välitön kustannus, jonka työnantaja vähentää bruttopalkasta ennen ennakonpidätyksen osuuden määrittämistä. Tällaisia kustannuksia ovat muun muassa palkansaajan maksamat kustannukset moottorisahan käytöstä ja muut työvälineistä aiheutuneet kustannukset. Samoin tällaisia kustannuksia ovat myös menot työmatkoista, jos työnantaja ei maksa niistä verovapaita korvauksia palkan lisäksi.\r\n\r\nKohtaan merkitään vähennys, joka on tehty ennen ennakonpidätyksen toimittamista. Vähennysten osuuden tulee sisältyä myös tulolajilla ilmoitettuun palkkaan.\r\n\r\n**Esimerkki**: Työntekijä on maksanut itse moottorisahan käytöstä aiheutuneet 4 500 euron kustannukset. Työntekijälle maksettu koko vuoden palkka on 20 000 euroa, josta sahatyön osuus on 14 000 euroa. Työntekijä on vaatinut ennakkoperinnässä vähennystä käyttökustannuksista 40 %:n mukaisesti sahatyöstä maksetun palkan määrästä eli 5 600 euroa. Ennakonpidätys on toimitettu ennakkoperintälain (1118/1996) 15 § mukaisesti 14 400 eurosta (20 000 - 5 600).\r\n\r\nPalkan tulolajilla ilmoitetaan 20 000 euroa ja Vähennys ennen ennakonpidätystä -erittelylajilla ilmoitetaan 5 600 euroa. Työntekijän tulee vaatia esitäytetyllä veroilmoituksellaan moottorisahavähennystä ja selvittää sahatyöstä maksetun palkan määrä. Lopullisessa verotuksessa vähennys lasketaan sahatyöstä maksetun palkan (14 000 euroa) osuudesta.\r\n\r\nJos työnantaja on maksanut moottorisahan käytöstä aiheutuneet kustannukset, katso ilmoittaminen kohdasta: Veronalaiset kustannusten korvaukset. \r\n\r\n**Esimerkki**: Pelimannille luvataan soittokeikasta 200 euroa. Matkustaminen ja matkustamisen kustannukset eivät vaikuta maksettavaan bruttomäärään. Matkakustannuksia ei siis korvata.\r\n\r\nTyönantaja voi laskea määrän, josta toimittaa ennakonpidätyksen siten, että vähentää työntekijän antaman selvityksen perusteella saman määrän, jonka voisi korvata verovapaasti. Esimerkiksi matkustamiskustannuksia 51 km x 41 snt/km eli 20,91 snt ja osapäivärahan 19 euroa vastaavat määrät, jolloin pidätyksenalaiseksi määräksi jää 160,09 euroa. Samasta määrästä maksetaan myös työnantajan sairausvakuutusmaksu. \r\n\r\nPalkan tulolajilla ilmoitetaan 200 euroa, Vähennys ennen ennakonpidätystä -erittelylajilla ilmoitetaan 39,91 euroa. Verovapaiden matkakustannusten korvausten tulolajeilla ei tehdä merkintöjä. \r\n\r\nTyöntekijän on vaadittava vähennyksiä veroilmoituksessaan ja vähennys on yleensä alempi kuin ennakonpidätyksen yhteydessä.",
        "taxAndSidecostsDescr": "Ilmoitettu summa vähentää ennakonpidätyksen ja sosiaalimaksujen pohjana olevaa palkkaa ja vähennetään oletuksena asiakasvaratilin kautta maksetusta palkasta.\r\n\r\nJos samalla maksukerralla maksetaan sosiaalivakuutusmaksun alaista palkkaa ja sellaista EPL 13 §:n muista palkkaa, joka ei ole sosiaalivakuutusmaksujen perusteena ja jompaankumpaan tuloon kohdistuu kuluja, jotka vähennetään ennen ennakonpidätyksen toimittamista, maksajan on annettava tiedot palkoista kahdella eri ilmoituksella ja eriteltävä, kumpaan tuloon vähennys kohdistuu.",
        "isSupported": true,
        "paymentDefault": 0,
        "usecases": [
            "https://palkkaus.fi/usecases/2019/deductions"
        ],
        "calcGrouping": "deductions"
    }
];

},{}],39:[function(require,module,exports){
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
__export(require("./accountProductDefaults"));
__export(require("./enumerations"));
__export(require("./householdRows"));
__export(require("./householdUseCaseTree"));
__export(require("./vismaSignOriginalMethods"));
__export(require("./incomeTypeCodes"));
__export(require("./yearlyChangingNumbersYears"));
__export(require("./yearlyHolidaysYears"));

},{"./accountProductDefaults":34,"./enumerations":35,"./householdRows":36,"./householdUseCaseTree":37,"./incomeTypeCodes":38,"./vismaSignOriginalMethods":40,"./yearlyChangingNumbersYears":41,"./yearlyHolidaysYears":42}],40:[function(require,module,exports){
/* tslint:disable */
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Authentication methods for VismaSign.
 * This is the raw list of methods as returned by https://www.onnistuu.fi/api/v1/auth/methods
 * We will override most of these images as the ones below are pretty outdated.
 * @hidden
 */
exports.vismaSignOriginalMethods = [{
        "identifier": "tupas-osuuspankki",
        "name": "Osuuspankki",
        "image": "https://www.onnistuu.fi/img/banks/op_white_bgr-14.gif"
    },
    {
        "identifier": "tupas-nordea",
        "name": "Nordea",
        "image": "https://www.onnistuu.fi/img/banks/nordea_button_70x70px.gif"
    },
    {
        "identifier": "tupas-danske",
        "name": "Danske Bank",
        "image": "https://www.onnistuu.fi/img/banks/danskebank.png"
    },
    {
        "identifier": "tupas-spankki",
        "name": "S-Pankki",
        "image": "https://www.onnistuu.fi/img/banks/s-pankki.png"
    },
    {
        "identifier": "tupas-handelsbanken",
        "name": "Handelsbanken",
        "image": "https://www.onnistuu.fi/img/banks/handelsbanken_painike.jpg"
    },
    {
        "identifier": "tupas-elisa",
        "name": "Mobiilivarmenne",
        "image": "https://www.onnistuu.fi/img/banks/elisa.png"
    },
    {
        "identifier": "tupas-aktia",
        "name": "Aktia",
        "image": "https://www.onnistuu.fi/img/banks/aktia.png"
    },
    {
        "identifier": "tupas-poppankki",
        "name": "POP Pankki",
        "image": "https://www.onnistuu.fi/img/banks/POPmaksunappi.png"
    },
    {
        "identifier": "tupas-sp",
        "name": "S\u00e4\u00e4st\u00f6pankki",
        "image": "https://www.onnistuu.fi/img/banks/Spmaksunappi.png"
    },
    {
        "identifier": "tupas-omasp",
        "name": "Oma S\u00e4\u00e4st\u00f6pankki",
        "image": "https://www.onnistuu.fi/img/banks/omasp.png"
    },
    {
        "identifier": "tupas-alandsbanken",
        "name": "\u00c5landsbanken",
        "image": "https://www.onnistuu.fi/img/banks/alandsbanken.gif"
    }];

},{}],41:[function(require,module,exports){
/* tslint:disable */
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Yearly changing numbers. Contains side cost percentages.
 *
 */
exports.yearlyChangingNumbersYears = [
    {
        "year": 2018,
        "sideCosts": {
            "unemploymentTotalPercent": 0.0255,
            "unemploymentEmployerPercent": 0.0065,
            "unemploymentWorkerPercent": 0.019,
            "tyelIncomeLimit": 58.27,
            "tyelBasePercent": 0.253,
            "tyelWorkerPercent": 0.0635,
            "tyel53Percent": 0.0785,
            "tyelContractEmployerLimit": 8346,
            "socSecPercent": 0.0086,
            "illnessInsurancePercent": 0.0153,
            "taxFreeDailyAllowance": 42,
            "taxFreeDailyHalfAllowance": 19,
            "taxFreeMealAllowance": 10.5,
            "taxFreeKmAllowance": 0.42,
            "unionPaymentRaksaA": 0.0155,
            "unionPaymentRaksaAoTa": 0.0055,
            "stepsTaxCardLimit1": 10500,
            "stepsTaxCardLimit2": 17950
        }
    },
    {
        "year": 2019,
        "sideCosts": {
            "unemploymentTotalPercent": 0.02,
            "unemploymentEmployerPercent": 0.005,
            "unemploymentWorkerPercent": 0.015,
            "tyelIncomeLimit": 59.36,
            "tyelBasePercent": 0.252,
            "tyelWorkerPercent": 0.0675,
            "tyel53Percent": 0.0825,
            "tyelContractEmployerLimit": 8502,
            "socSecPercent": 0.0077,
            "illnessInsurancePercent": 0.0154,
            "taxFreeDailyAllowance": 42,
            "taxFreeDailyHalfAllowance": 19,
            "taxFreeMealAllowance": 10.5,
            "taxFreeKmAllowance": 0.43,
            "unionPaymentRaksaA": 0.0149,
            "unionPaymentRaksaAoTa": 0.0052,
            "stepsTaxCardLimit1": 10500,
            "stepsTaxCardLimit2": 17950
        }
    },
    {
        "year": 2020,
        "sideCosts": {
            "unemploymentTotalPercent": 0.0170,
            "unemploymentEmployerPercent": 0.0045,
            "unemploymentWorkerPercent": 0.0125,
            "unemploymentPartialOwnerWorkerPercent": 0.0065,
            "tyelIncomeLimit": 60.57,
            "tyelBasePercent": 0.253,
            "tyelWorkerPercent": 0.0715,
            "tyel53Percent": 0.0865,
            "tyelContractEmployerLimit": 8676.0,
            "socSecPercent": 0.0134,
            "illnessInsurancePercent": 0.0186,
            "taxFreeDailyAllowance": 43.0,
            "taxFreeDailyHalfAllowance": 20.0,
            "taxFreeMealAllowance": 10.75,
            "taxFreeKmAllowance": 0.43,
            "unionPaymentRaksaA": 0.0149,
            "unionPaymentRaksaAoTa": 0.0052,
            "stepsTaxCardLimit1": 10500,
            "stepsTaxCardLimit2": 17950,
            "palkkausVatPercent": 0.24
        },
    }
];

},{}],42:[function(require,module,exports){
/* tslint:disable */
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Yearly holidays.
 */
exports.yearlyHolidaysYears = [
    {
        "year": 2018,
        "holidays": {
            "newYearsDay": {
                "date": "2018-01-01",
                "holiday": "newYearsDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "uudenvuodenpäivä",
                "name": "New Year's Day"
            },
            "epiphany": {
                "date": "2018-01-06",
                "holiday": "epiphany",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "loppiainen",
                "name": "Epiphany"
            },
            "goodFriday": {
                "date": "2018-03-30",
                "holiday": "goodFriday",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pitkäperjantai",
                "name": "Good Friday"
            },
            "easterSaturday": {
                "date": "2018-03-31",
                "holiday": "easterSaturday",
                "holidayGroups": [
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pääsiäislauantai",
                "name": "Easter Saturday"
            },
            "easterSunday": {
                "date": "2018-04-01",
                "holiday": "easterSunday",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pääsiäispäivä",
                "name": "Easter Sunday"
            },
            "easterMonday": {
                "date": "2018-04-02",
                "holiday": "easterMonday",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "2. pääsiäispäivä",
                "name": "Easter Monday"
            },
            "mayDay": {
                "date": "2018-05-01",
                "holiday": "mayDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "vappu",
                "name": "May Day"
            },
            "ascensionDay": {
                "date": "2018-05-10",
                "holiday": "ascensionDay",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "helatorstai",
                "name": "Ascension Day"
            },
            "pentecost": {
                "date": "2018-05-20",
                "holiday": "pentecost",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "helluntaipäivä",
                "name": "Pentecost"
            },
            "midsummerEve": {
                "date": "2018-06-22",
                "holiday": "midsummerEve",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "juhannusaatto",
                "name": "Midsummer Eve"
            },
            "midsummerDay": {
                "date": "2018-06-23",
                "holiday": "midsummerDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "juhannuspäivä",
                "name": "Midsummer Day"
            },
            "allSaintsDay": {
                "date": "2018-11-24",
                "holiday": "allSaintsDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pyhäinpäivä",
                "name": "All Saints' Day"
            },
            "independenceDay": {
                "date": "2018-12-06",
                "holiday": "independenceDay",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "itsenäisyyspäivä",
                "name": "Independence Day"
            },
            "christmasEve": {
                "date": "2018-12-24",
                "holiday": "christmasEve",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "jouluaatto",
                "name": "Christmas Eve"
            },
            "christmasDay": {
                "date": "2018-12-25",
                "holiday": "christmasDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "joulupäivä",
                "name": "Christmas Day"
            },
            "stStephensDay": {
                "date": "2018-12-26",
                "holiday": "stStephensDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "2. joulupäivä",
                "name": "St. Stephen's Day"
            }
        }
    },
    {
        "year": 2019,
        "holidays": {
            "newYearsDay": {
                "date": "2019-01-01",
                "holiday": "newYearsDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "uudenvuodenpäivä",
                "name": "New Year's Day"
            },
            "epiphany": {
                "date": "2019-01-06",
                "holiday": "epiphany",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "loppiainen",
                "name": "Epiphany"
            },
            "goodFriday": {
                "date": "2019-04-19",
                "holiday": "goodFriday",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pitkäperjantai",
                "name": "Good Friday"
            },
            "easterSaturday": {
                "date": "2019-04-20",
                "holiday": "easterSaturday",
                "holidayGroups": [
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pääsiäislauantai",
                "name": "Easter Saturday"
            },
            "easterSunday": {
                "date": "2019-04-21",
                "holiday": "easterSunday",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pääsiäispäivä",
                "name": "Easter Sunday"
            },
            "easterMonday": {
                "date": "2019-04-22",
                "holiday": "easterMonday",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "2. pääsiäispäivä",
                "name": "Easter Monday"
            },
            "mayDay": {
                "date": "2019-05-01",
                "holiday": "mayDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "vappu",
                "name": "May Day"
            },
            "ascensionDay": {
                "date": "2019-05-30",
                "holiday": "ascensionDay",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "helatorstai",
                "name": "Ascension Day"
            },
            "pentecost": {
                "date": "2019-06-09",
                "holiday": "pentecost",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "helluntaipäivä",
                "name": "Pentecost"
            },
            "midsummerEve": {
                "date": "2019-06-21",
                "holiday": "midsummerEve",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "juhannusaatto",
                "name": "Midsummer Eve"
            },
            "midsummerDay": {
                "date": "2019-06-22",
                "holiday": "midsummerDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "juhannuspäivä",
                "name": "Midsummer Day"
            },
            "allSaintsDay": {
                "date": "2019-11-23",
                "holiday": "allSaintsDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pyhäinpäivä",
                "name": "All Saints' Day"
            },
            "independenceDay": {
                "date": "2019-12-06",
                "holiday": "independenceDay",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "itsenäisyyspäivä",
                "name": "Independence Day"
            },
            "christmasEve": {
                "date": "2019-12-24",
                "holiday": "christmasEve",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "jouluaatto",
                "name": "Christmas Eve"
            },
            "christmasDay": {
                "date": "2019-12-25",
                "holiday": "christmasDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "joulupäivä",
                "name": "Christmas Day"
            },
            "stStephensDay": {
                "date": "2019-12-26",
                "holiday": "stStephensDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "2. joulupäivä",
                "name": "St. Stephen's Day"
            }
        }
    },
    {
        "year": 2020,
        "holidays": {
            "newYearsDay": {
                "date": "2020-01-01",
                "holiday": "newYearsDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "uudenvuodenpäivä",
                "name": "New Year's Day"
            },
            "epiphany": {
                "date": "2020-01-06",
                "holiday": "epiphany",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "loppiainen",
                "name": "Epiphany"
            },
            "goodFriday": {
                "date": "2020-04-10",
                "holiday": "goodFriday",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pitkäperjantai",
                "name": "Good Friday"
            },
            "easterSaturday": {
                "date": "2020-04-11",
                "holiday": "easterSaturday",
                "holidayGroups": [
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pääsiäislauantai",
                "name": "Easter Saturday"
            },
            "easterSunday": {
                "date": "2020-04-12",
                "holiday": "easterSunday",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pääsiäispäivä",
                "name": "Easter Sunday"
            },
            "easterMonday": {
                "date": "2020-04-13",
                "holiday": "easterMonday",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "2. pääsiäispäivä",
                "name": "Easter Monday"
            },
            "mayDay": {
                "date": "2020-05-01",
                "holiday": "mayDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "vappu",
                "name": "May Day"
            },
            "ascensionDay": {
                "date": "2020-05-21",
                "holiday": "ascensionDay",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "helatorstai",
                "name": "Ascension Day"
            },
            "pentecost": {
                "date": "2020-05-31",
                "holiday": "pentecost",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "helluntaipäivä",
                "name": "Pentecost"
            },
            "midsummerEve": {
                "date": "2020-06-19",
                "holiday": "midsummerEve",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "juhannusaatto",
                "name": "Midsummer Eve"
            },
            "midsummerDay": {
                "date": "2020-06-20",
                "holiday": "midsummerDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "juhannuspäivä",
                "name": "Midsummer Day"
            },
            "allSaintsDay": {
                "date": "2020-11-21",
                "holiday": "allSaintsDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pyhäinpäivä",
                "name": "All Saints' Day"
            },
            "independenceDay": {
                "date": "2020-12-06",
                "holiday": "independenceDay",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "itsenäisyyspäivä",
                "name": "Independence Day"
            },
            "christmasEve": {
                "date": "2020-12-24",
                "holiday": "christmasEve",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "jouluaatto",
                "name": "Christmas Eve"
            },
            "christmasDay": {
                "date": "2020-12-25",
                "holiday": "christmasDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "joulupäivä",
                "name": "Christmas Day"
            },
            "stStephensDay": {
                "date": "2020-12-26",
                "holiday": "stStephensDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "2. joulupäivä",
                "name": "St. Stephen's Day"
            }
        }
    },
    {
        "year": 2021,
        "holidays": {
            "newYearsDay": {
                "date": "2021-01-01",
                "holiday": "newYearsDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "uudenvuodenpäivä",
                "name": "New Year's Day"
            },
            "epiphany": {
                "date": "2021-01-06",
                "holiday": "epiphany",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "loppiainen",
                "name": "Epiphany"
            },
            "goodFriday": {
                "date": "2021-04-02",
                "holiday": "goodFriday",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pitkäperjantai",
                "name": "Good Friday"
            },
            "easterSaturday": {
                "date": "2021-04-03",
                "holiday": "easterSaturday",
                "holidayGroups": [
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pääsiäislauantai",
                "name": "Easter Saturday"
            },
            "easterSunday": {
                "date": "2021-04-04",
                "holiday": "easterSunday",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pääsiäispäivä",
                "name": "Easter Sunday"
            },
            "easterMonday": {
                "date": "2021-04-05",
                "holiday": "easterMonday",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "2. pääsiäispäivä",
                "name": "Easter Monday"
            },
            "mayDay": {
                "date": "2021-05-01",
                "holiday": "mayDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "vappu",
                "name": "May Day"
            },
            "ascensionDay": {
                "date": "2021-05-13",
                "holiday": "ascensionDay",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "helatorstai",
                "name": "Ascension Day"
            },
            "pentecost": {
                "date": "2021-05-23",
                "holiday": "pentecost",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "helluntaipäivä",
                "name": "Pentecost"
            },
            "midsummerEve": {
                "date": "2021-06-25",
                "holiday": "midsummerEve",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "juhannusaatto",
                "name": "Midsummer Eve"
            },
            "midsummerDay": {
                "date": "2021-06-26",
                "holiday": "midsummerDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "juhannuspäivä",
                "name": "Midsummer Day"
            },
            "allSaintsDay": {
                "date": "2021-11-20",
                "holiday": "allSaintsDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pyhäinpäivä",
                "name": "All Saints' Day"
            },
            "independenceDay": {
                "date": "2021-12-06",
                "holiday": "independenceDay",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "itsenäisyyspäivä",
                "name": "Independence Day"
            },
            "christmasEve": {
                "date": "2021-12-24",
                "holiday": "christmasEve",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "jouluaatto",
                "name": "Christmas Eve"
            },
            "christmasDay": {
                "date": "2021-12-25",
                "holiday": "christmasDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "joulupäivä",
                "name": "Christmas Day"
            },
            "stStephensDay": {
                "date": "2021-12-26",
                "holiday": "stStephensDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "2. joulupäivä",
                "name": "St. Stephen's Day"
            }
        }
    },
    {
        "year": 2022,
        "holidays": {
            "newYearsDay": {
                "date": "2022-01-01",
                "holiday": "newYearsDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "uudenvuodenpäivä",
                "name": "New Year's Day"
            },
            "epiphany": {
                "date": "2022-01-06",
                "holiday": "epiphany",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "loppiainen",
                "name": "Epiphany"
            },
            "goodFriday": {
                "date": "2022-04-15",
                "holiday": "goodFriday",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pitkäperjantai",
                "name": "Good Friday"
            },
            "easterSaturday": {
                "date": "2022-04-16",
                "holiday": "easterSaturday",
                "holidayGroups": [
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pääsiäislauantai",
                "name": "Easter Saturday"
            },
            "easterSunday": {
                "date": "2022-04-17",
                "holiday": "easterSunday",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pääsiäispäivä",
                "name": "Easter Sunday"
            },
            "easterMonday": {
                "date": "2022-04-18",
                "holiday": "easterMonday",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "2. pääsiäispäivä",
                "name": "Easter Monday"
            },
            "mayDay": {
                "date": "2022-05-01",
                "holiday": "mayDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "vappu",
                "name": "May Day"
            },
            "ascensionDay": {
                "date": "2022-05-26",
                "holiday": "ascensionDay",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "helatorstai",
                "name": "Ascension Day"
            },
            "pentecost": {
                "date": "2022-06-05",
                "holiday": "pentecost",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "helluntaipäivä",
                "name": "Pentecost"
            },
            "midsummerEve": {
                "date": "2022-06-24",
                "holiday": "midsummerEve",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "juhannusaatto",
                "name": "Midsummer Eve"
            },
            "midsummerDay": {
                "date": "2022-06-25",
                "holiday": "midsummerDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "juhannuspäivä",
                "name": "Midsummer Day"
            },
            "allSaintsDay": {
                "date": "2022-11-19",
                "holiday": "allSaintsDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "pyhäinpäivä",
                "name": "All Saints' Day"
            },
            "independenceDay": {
                "date": "2022-12-06",
                "holiday": "independenceDay",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "itsenäisyyspäivä",
                "name": "Independence Day"
            },
            "christmasEve": {
                "date": "2022-12-24",
                "holiday": "christmasEve",
                "holidayGroups": [
                    "official",
                    "holiday"
                ],
                "localName": "jouluaatto",
                "name": "Christmas Eve"
            },
            "christmasDay": {
                "date": "2022-12-25",
                "holiday": "christmasDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "joulupäivä",
                "name": "Christmas Day"
            },
            "stStephensDay": {
                "date": "2022-12-26",
                "holiday": "stStephensDay",
                "holidayGroups": [
                    "official",
                    "nonBanking",
                    "holiday"
                ],
                "localName": "2. joulupäivä",
                "name": "St. Stephen's Day"
            }
        }
    }
];

},{}],43:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/* tslint:disable */
var _dictionary = _dictionary || {};
_dictionary["en"] = {
    "SALAXY": {
        "ENUM": {
            "AbcSection": {
                "association": {
                    "description": "",
                    "label": "Associations"
                },
                "blog": {
                    "description": "",
                    "label": "Blog"
                },
                "businessOwner": {
                    "description": "",
                    "label": "Entrepreneur"
                },
                "documentTemplates": {
                    "description": "",
                    "label": "Documents and forms"
                },
                "doNotShow": {
                    "description": "",
                    "label": "Not shown to user (Admin only)"
                },
                "employee": {
                    "description": "",
                    "label": "Employee"
                },
                "employment": {
                    "description": "",
                    "label": "Employment relationship and contract"
                },
                "entrepreneur": {
                    "description": "",
                    "label": "Company or community"
                },
                "examples": {
                    "description": "",
                    "label": "Examples of hiring situations"
                },
                "householdEmployer": {
                    "description": "",
                    "label": "Household"
                },
                "instructionsAndExamples": {
                    "description": "",
                    "label": "User manual"
                },
                "insurance": {
                    "description": "",
                    "label": "Insurances and pensions"
                },
                "palkkausGeneral": {
                    "description": "",
                    "label": "Information about Palkkaus.fi service"
                },
                "palkkausInstructions": {
                    "description": "",
                    "label": "User manuals"
                },
                "personEmployer": {
                    "description": "",
                    "label": "Household employee"
                },
                "press": {
                    "description": "",
                    "label": "Releases and material"
                },
                "productLongDescription": {
                    "description": "",
                    "label": "Product description"
                },
                "salary": {
                    "description": "",
                    "label": "Payroll calculation and salary payment"
                },
                "undefined": {
                    "description": "",
                    "label": "New article / undefined"
                },
                "worker": {
                    "description": "",
                    "label": "Employer"
                }
            },
            "AgeRange": {
                "age_15": {
                    "description": "",
                    "label": "15 yrs"
                },
                "age16": {
                    "description": "",
                    "label": "16 yrs"
                },
                "age17": {
                    "description": "",
                    "label": "17 yrs"
                },
                "age18_52": {
                    "description": "",
                    "label": "18-52 yrs"
                },
                "age53_62": {
                    "description": "",
                    "label": "53-62 yrs"
                },
                "age63_64": {
                    "description": "",
                    "label": "63-64 yrs"
                },
                "age65_67": {
                    "description": "",
                    "label": "65-67 yrs"
                },
                "age68AndOVer": {
                    "description": "",
                    "label": "68 yrs and over"
                },
                "unknown": {
                    "description": "",
                    "label": "Unknown"
                }
            },
            "ApiTestErrorType": {
                "default": {
                    "description": "",
                    "label": "Default"
                },
                "userFriendly": {
                    "description": "",
                    "label": "User friendly"
                }
            },
            "ApiValidationErrorType": {
                "general": {
                    "label": "General"
                },
                "invalid": {
                    "label": "Invalid"
                },
                "required": {
                    "label": "Required"
                },
                "warning": {
                    "label": ""
                }
            },
            "AuthenticationMethod": {
                "auth0Database": {
                    "description": "",
                    "label": "Email-Password authentication"
                },
                "emailPwdLocal": {
                    "description": "",
                    "label": "Database"
                },
                "facebook": {
                    "description": "",
                    "label": "Facebook account"
                },
                "google": {
                    "description": "",
                    "label": "Google or Gmail account"
                },
                "internalLocalhost": {
                    "description": "",
                    "label": "Internal"
                },
                "linkedIn": {
                    "description": "",
                    "label": "LinkedIn account"
                },
                "microsoft": {
                    "description": "",
                    "label": "Microsoft account"
                },
                "salaxy": {
                    "description": "",
                    "label": "Proxy to another account"
                },
                "test": {
                    "description": "",
                    "label": "Temporary test credential"
                },
                "undefined": {
                    "description": "",
                    "label": "Unknown"
                },
                "x509": {
                    "description": "",
                    "label": "X.509 certicate"
                }
            },
            "AuthorizationStatus": {
                "accessDenied": {
                    "description": "",
                    "label": "Access Denied"
                },
                "expiredOauthTokdescription": "",
                "expiredOauthToklabel": "Session expired",
                "invalidOAuthTokdescription": "",
                "invalidOAuthToklabel": "Error in authentication",
                "noOauthTokdescription": "",
                "noOauthToklabel": "No Oauth Token",
                "oK": {
                    "description": "",
                    "label": "OK"
                },
                "undefined": {
                    "description": "",
                    "label": "Undefined"
                }
            },
            "AuthorizationType": {
                "companyContract": {
                    "description": "",
                    "label": "Employer contract"
                },
                "employerAuthorization": {
                    "description": "",
                    "label": "Power of attorney"
                },
                "manual": {
                    "description": "",
                    "label": "Power of attorney submitted separately"
                },
                "none": {
                    "description": "",
                    "label": "Authentication failed"
                },
                "temporary": {
                    "description": "",
                    "label": "Temporary identification"
                },
                "workerContract": {
                    "description": "",
                    "label": "Employee contract"
                }
            },
            "AvatarPictureType": {
                "gravatar": {
                    "description": "",
                    "label": "Gravatar"
                },
                "icon": {
                    "description": "",
                    "label": "Icon"
                },
                "uploaded": {
                    "description": "",
                    "label": "Picture from own computer"
                }
            },
            "BlobFileType": {
                "authorizationPdf": {
                    "description": "",
                    "label": "Power of attorney"
                },
                "avatar": {
                    "description": "",
                    "label": "Icon"
                },
                "calcReport": {
                    "description": "",
                    "label": ""
                },
                "expensesReceipt": {
                    "description": "",
                    "label": "Expense receipt"
                },
                "monthlyReport": {
                    "description": "",
                    "label": "Monthly Report"
                },
                "raksaloki": {
                    "description": "",
                    "label": "Expense receipt"
                },
                "taxCard": {
                    "description": "",
                    "label": "Tax Card"
                },
                "template": {
                    "description": "",
                    "label": "Template"
                },
                "unknown": {
                    "description": "",
                    "label": "Unknown"
                },
                "yearlyReport": {
                    "description": "",
                    "label": "Yearly Report"
                }
            },
            "BlobRepository": {
                "cdnImages": {
                    "description": "",
                    "label": ""
                },
                "fileSystemContent": {
                    "description": "",
                    "label": ""
                },
                "gitContent": {
                    "description": "",
                    "label": ""
                },
                "payload": {
                    "description": "",
                    "label": ""
                },
                "reports": {
                    "description": "",
                    "label": ""
                },
                "systemFiles": {
                    "description": "",
                    "label": ""
                },
                "userFiles": {
                    "description": "",
                    "label": ""
                },
                "versionHistory": {
                    "description": "",
                    "label": ""
                }
            },
            "CalculationRowSource": {
                "manualRow": {
                    "description": "",
                    "label": "Additional row"
                },
                "salaryPage": {
                    "description": "",
                    "label": "Salary Page"
                },
                "tesSelection": {
                    "description": "",
                    "label": "Use case"
                }
            },
            "CalculationRowType": {
                "accomodationBenefit": {
                    "amountLabel": "",
                    "description": "Taxable value of employee accomodation benefit.",
                    "iconText": "",
                    "label": "Accomodation benefit",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "advance": {
                    "amountLabel": "",
                    "description": "Salary advance deducation. Salary paid in advance and deducted from net salary.",
                    "iconText": "",
                    "label": "Salary advance",
                    "moreInfo": "",
                    "priceLabel": "Paid in advance"
                },
                "board": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "chainsawReduction": {
                    "amountLabel": "",
                    "description": "Deduction for use of chainsaw, special cases (pre payment law 15 §, pre payment regulation 15 §).",
                    "iconText": "",
                    "label": "Choose…",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "childCareSubsidy": {
                    "amountLabel": "",
                    "description": "KELA support to communal workers for childcare. Affects incidental expenses.",
                    "iconText": "KELA",
                    "label": "Childcare subsidy",
                    "moreInfo": "",
                    "priceLabel": "Paid for by KELA"
                },
                "compensation": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "Work compensation",
                    "moreInfo": "",
                    "priceLabel": "Work compensation"
                },
                "dailyAllowanceHalf": {
                    "amountLabel": "Days",
                    "description": "Half day allowance, 19 euros per day, if commute is more than 6 hours or over 15 km.",
                    "iconText": 19,
                    "label": "Half day allowance",
                    "moreInfo": "",
                    "priceLabel": "Euro / day"
                },
                "employmentTermination": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "eveningAddition": {
                    "amountLabel": "Hours",
                    "description": "Addition for evening work according to collective bargaining agreement.",
                    "iconText": "EVNG",
                    "label": "Evening shift addition",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "expenses": {
                    "amountLabel": "",
                    "description": "Employee expense claims (use of taxi, office supplies etc.).",
                    "iconText": "expense",
                    "label": "Expense claim",
                    "moreInfo": "",
                    "priceLabel": "Expense claim"
                },
                "foreclosure": {
                    "amountLabel": "",
                    "description": "Employee salary foreclosure, paid directly to bailiff.",
                    "iconText": "",
                    "label": "Salary foreclosure",
                    "moreInfo": "",
                    "priceLabel": "Sum"
                },
                "foreclosureByPalkkaus": {
                    "amountLabel": "",
                    "description": "Employee salary foreclosure made by Palkkaus.fi, paid directly to bailiff.",
                    "iconText": "",
                    "label": "Salary foreclosure made by Palkkaus.fi",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "holidayBonus": {
                    "amountLabel": "Percent",
                    "description": "Holiday bonus according to collective bargaining agreement.",
                    "iconText": "CBA",
                    "label": "Holiday bonus",
                    "moreInfo": "",
                    "priceLabel": "Salary for holiday period"
                },
                "holidayCompensation": {
                    "amountLabel": "Percent",
                    "description": "Taxable value of employee holiday compensation if holiday is not held.",
                    "iconText": "11,5%",
                    "label": "Holiday compensation",
                    "moreInfo": "",
                    "priceLabel": "Salary amount"
                },
                "holidaySalary": {
                    "amountLabel": "",
                    "description": "Salary for annual holiday.",
                    "iconText": "vacation",
                    "label": "Holiday salary",
                    "moreInfo": "",
                    "priceLabel": "Salary for holiday period"
                },
                "hourlySalary": {
                    "amountLabel": "",
                    "description": "Salary payment based on hours put in.",
                    "iconText": "h",
                    "label": "Hourly salary",
                    "moreInfo": "",
                    "priceLabel": "Hourly salary"
                },
                "irIncomeType": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "mealCompensation": {
                    "amountLabel": "Days",
                    "description": "Meal compensation when daily allowence is not paid.",
                    "iconText": "meal",
                    "label": "Meal compensation",
                    "moreInfo": "",
                    "priceLabel": "Compensation / day"
                },
                "milageDaily": {
                    "amountLabel": "Days",
                    "description": "Mileage compensation accoring to collective bargaining agreement.",
                    "iconText": "km",
                    "label": "Daily mileage compensation",
                    "moreInfo": "",
                    "priceLabel": "Compensation / day"
                },
                "milageOther": {
                    "amountLabel": "Days",
                    "description": "Mileage compensation due to other justifications.",
                    "iconText": "km",
                    "label": "Other mileage compensation",
                    "moreInfo": "",
                    "priceLabel": "Compensation / day"
                },
                "milageOwnCar": {
                    "amountLabel": "",
                    "description": "Mileage compensation due to use of own car.",
                    "iconText": "0,43€",
                    "label": "Mileage compensation, own car",
                    "moreInfo": "",
                    "priceLabel": "Compensation / km"
                },
                "monthlySalary": {
                    "amountLabel": "",
                    "description": "Fixed monthly income.",
                    "iconText": "month",
                    "label": "Monthly salary",
                    "moreInfo": "",
                    "priceLabel": "Monthly salary"
                },
                "nightimeAddition": {
                    "amountLabel": "Hours",
                    "description": "Addition for nighttime work according to collective bargaining agreement.",
                    "iconText": "NIGHT",
                    "label": "Night shift addition",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "otherAdditions": {
                    "amountLabel": "",
                    "description": "Other additions according to collective bargaining agreement.",
                    "iconText": "addition",
                    "label": "Other additions",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "otherBenefit": {
                    "amountLabel": "",
                    "description": "Taxable value of other employee benefits.",
                    "iconText": "Benefit",
                    "label": "Other benefits",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "otherCompensation": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "otherDeductions": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "overtime": {
                    "amountLabel": "Percent",
                    "description": "Overtime payments.",
                    "iconText": "over",
                    "label": "Overtime work compensation",
                    "moreInfo": "",
                    "priceLabel": "Salary amount"
                },
                "phoneBenefit": {
                    "amountLabel": "Months",
                    "description": "Taxable value of employee mobile phone benefit.",
                    "iconText": 20,
                    "label": "Mobile phone benefit",
                    "moreInfo": "",
                    "priceLabel": "Mobile phone benefit / mon"
                },
                "prepaidExpenses": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "remuneration": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "salary": {
                    "amountLabel": "",
                    "description": "Lump sum for work effort.",
                    "iconText": "D",
                    "label": "Salary or commission",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "saturdayAddition": {
                    "amountLabel": "Percent",
                    "description": "Addition for Saturday work according to collective bargaining agreement.",
                    "iconText": "SAT",
                    "label": "Saturday addition",
                    "moreInfo": "",
                    "priceLabel": "Salary amount"
                },
                "sundayWork": {
                    "amountLabel": "",
                    "description": "Addition for Sunday work according to collective bargaining agreement.",
                    "iconText": "SUN",
                    "label": "Sunday or public holiday addition",
                    "moreInfo": "",
                    "priceLabel": "Salary amount"
                },
                "tesWorktimeShortening": {
                    "amountLabel": "Percent",
                    "description": "Separate salary portion that is defined by the sector/industry collective bargaining agreement. Aka. \"pekkaspäivät\" in Finnish.",
                    "iconText": "CBA",
                    "label": "Compensation for accrued time off",
                    "moreInfo": "",
                    "priceLabel": "Salary amount"
                },
                "toolCompensation": {
                    "amountLabel": "Days",
                    "description": "Compensation for use of own tools for work. Compensation defined according to collective bargaining agreement.",
                    "iconText": "",
                    "label": "Work tool compensation",
                    "moreInfo": "",
                    "priceLabel": "Compensation / day"
                },
                "totalEmployerPayment": {
                    "amountLabel": "",
                    "description": "Total cost calculation: what a salary payment will cost for the employer.",
                    "iconText": "sum",
                    "label": "Total cost",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "totals": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "Total",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "totalWorkerPayment": {
                    "amountLabel": "",
                    "description": "Net salary calculation: what is left when tax deductions etc. are made from gross salary.",
                    "iconText": "net",
                    "label": "Net salary",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "unknown": {
                    "amountLabel": "",
                    "description": "Row type undefined.",
                    "iconText": "",
                    "label": "Choose…",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "workingTimeCompensation": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "carBenefit": {
                    "label": "",
                    "description": "",
                    "iconText": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "unionPayment": {
                    "amountLabel": "",
                    "description": "Employee union payment made directly to trade union, if employer chooses to do so.",
                    "iconText": "Trade union",
                    "label": "Union payment",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "dailyAllowance": {
                    "amountLabel": "Days",
                    "description": "Daily allowance, 40 euros per day, if commute is more than 10 hours or over 15 km.",
                    "iconText": 40,
                    "label": "Daily allowance",
                    "moreInfo": "",
                    "priceLabel": "Euro / day"
                },
                "mealBenefit": {
                    "amountLabel": "",
                    "description": "Taxable value of employee meal benefit.",
                    "iconText": "food",
                    "label": "Meal benefit",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "nonProfitOrg": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "subsidisedCommute": {
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                }
            },
            "CalculationRowUnit": {
                "count": {
                    "description": "",
                    "label": "amount"
                },
                "days": {
                    "description": "",
                    "label": "days"
                },
                "kilometers": {
                    "description": "",
                    "label": "km"
                },
                "percent": {
                    "description": "",
                    "label": "%"
                },
                "undefined": {
                    "description": "",
                    "label": ""
                }
            },
            "CalculationStatus": {
                "draft": {
                    "description": "",
                    "label": "Draft"
                },
                "externalPaymentCanceled": {
                    "description": "",
                    "label": "Payment canceled outside of Salaxy-service"
                },
                "externalPaymentError": {
                    "description": "",
                    "label": "Errors (outside of Salaxy-service)"
                },
                "externalPaymentStarted": {
                    "description": "",
                    "label": "Payment initiated outside of Salaxy-service"
                },
                "externalPaymentSucceeded": {
                    "description": "",
                    "label": "Payment completed outside of Salaxy-service"
                },
                "paymentCanceled": {
                    "description": "",
                    "label": "Payment canceled"
                },
                "paymentError": {
                    "description": "",
                    "label": "Error in payment"
                },
                "paymentRefunded": {
                    "description": "",
                    "label": "Payment canceled and refunded"
                },
                "paymentStarted": {
                    "description": "",
                    "label": "Payment started"
                },
                "paymentSucceeded": {
                    "description": "",
                    "label": "Payment succeeded"
                },
                "paymentWorkerCopy": {
                    "description": "",
                    "label": "Copy for employee"
                },
                "template": {
                    "description": "",
                    "label": "Template"
                },
                "workerRequestAccepted": {
                    "description": "",
                    "label": "Payslip made by employee accepted"
                },
                "workerRequestDeclined": {
                    "description": "",
                    "label": "Payslip made by employee rejected"
                },
                "workerRequested": {
                    "description": "",
                    "label": "Payslip made by employee"
                },
                "payrollDraft": {
                    "description": "",
                    "label": ""
                },
                "proDraft": {
                    "label": ""
                }
            },
            "CompanyType": {
                "fiOy": {
                    "description": "",
                    "label": "Limited companies, also and public limited companies"
                },
                "fiRy": {
                    "description": "",
                    "label": "Associations"
                },
                "fiTm": {
                    "description": "",
                    "label": "Private trader or farmer"
                },
                "fiYy": {
                    "description": "",
                    "label": "Other, e.g. limited partnerships, open companies etc."
                },
                "unknown": {
                    "description": "",
                    "label": ""
                }
            },
            "ContractPartyType": {
                "customContact": {
                    "description": "",
                    "label": ""
                },
                "person": {
                    "description": "",
                    "label": ""
                }
            },
            "DateOfBirthAccuracy": {
                "ageBased": {
                    "description": "",
                    "label": "Age Based"
                },
                "ageGroupBased": {
                    "description": "",
                    "label": "Age Group Based"
                },
                "assumption": {
                    "description": "",
                    "label": "Assumption"
                },
                "exact": {
                    "description": "",
                    "label": "Exact date"
                },
                "monthCorrect": {
                    "description": "",
                    "label": "Month Correct"
                },
                "verified": {
                    "description": "",
                    "label": "Verified"
                }
            },
            "EmployerType": {
                "fullTimeEmployer": {
                    "description": "",
                    "label": "Ongoing contract or over 8178 € / 6 months"
                },
                "miniEmployer": {
                    "description": "",
                    "label": "Under 1300 € per year"
                },
                "smallEmployer": {
                    "description": "",
                    "label": "1300 € or more per year"
                },
                "tyelOwnContractEmployer": {
                    "description": "",
                    "label": "TyEL-annual contract or taken care of by customer"
                },
                "unknown": {
                    "description": "",
                    "label": "Unknown"
                }
            },
            "EmploymentContract": {
                "annualLeave": {
                    "label": ""
                },
                "benefitsException": {
                    "label": ""
                },
                "noticeException": {
                    "label": ""
                },
                "otherTerms": {
                    "label": ""
                }
            },
            "EmploymentRelationType": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "salary": {
                    "label": "",
                    "description": ""
                },
                "hourlySalary": {
                    "label": "",
                    "description": ""
                },
                "monthlySalary": {
                    "label": "",
                    "description": ""
                },
                "compensation": {
                    "label": "",
                    "description": ""
                },
                "boardMember": {
                    "label": "",
                    "description": ""
                },
                "entrepreneur": {
                    "label": "",
                    "description": ""
                },
                "entrepreneurNew": {
                    "label": "",
                    "description": ""
                },
                "farmer": {
                    "label": "",
                    "description": ""
                },
                "athlete": {
                    "label": "",
                    "description": ""
                },
                "employedByStateEmploymentFund": {
                    "label": "",
                    "description": ""
                },
                "keyEmployee": {
                    "label": "",
                    "description": ""
                },
                "performingArtist": {
                    "label": "",
                    "description": ""
                }
            },
            "EmploymentSalaryType": {
                "hourlyPay": {
                    "description": "",
                    "label": "Hourly salary",
                    "metricAbbrev": "/h"
                },
                "montlyPay": {
                    "description": "",
                    "label": "Monthly salary",
                    "metricAbbrev": "/mo"
                },
                "otherPay": {
                    "description": "",
                    "label": "Other"
                },
                "unknown": {
                    "description": "",
                    "label": "Choose…"
                }
            },
            "EmploymentType": {
                "fullTime": {
                    "description": "",
                    "label": "Permanent employment"
                },
                "job": {
                    "description": "",
                    "label": "One-off work"
                },
                "partTime": {
                    "description": "",
                    "label": "Part-time employment"
                },
                "unknown": {
                    "description": "",
                    "label": "Choose…"
                }
            },
            "EmploymentWorkHoursType": {
                "hourPerThreeWeeks": {
                    "description": "",
                    "label": "Hours/three weeks"
                },
                "hourPerTwoWeeks": {
                    "description": "",
                    "label": "Hours/two weeks"
                },
                "hoursPerDay": {
                    "description": "",
                    "label": "Hours/day"
                },
                "hoursPerWeek": {
                    "description": "",
                    "label": "Hours/week"
                }
            },
            "FrameworkAgreement": {
                "childCare": {
                    "description": "Permanent nanny and subsidies.",
                    "label": "Other childcare"
                },
                "cleaning": {
                    "description": "Cleaning and real estate work.",
                    "label": "Cleaning- and real estate sector"
                },
                "construction": {
                    "description": "Work according to construction sector colloctive bargaining agreement.",
                    "label": "Construction and renovation work"
                },
                "entrepreneur": {
                    "description": "Entrepreneurs salary.",
                    "label": "Entrepreneur"
                },
                "mll": {
                    "description": "Salary for MLL nanny.",
                    "label": "MLL recommondations"
                },
                "notDefined": {
                    "description": "Collective bargaining agreement or recommendation undefined.",
                    "label": "Undefined"
                },
                "other": {
                    "description": "Other work och no collective bargaining agreement.",
                    "label": "Other work"
                },
                "santaClaus": {
                    "description": "Santa Claus home visit.",
                    "label": "Santa Claus"
                }
            },
            "Gender": {
                "female": {
                    "description": "",
                    "label": "Female"
                },
                "male": {
                    "description": "",
                    "label": "Male"
                },
                "unknown": {
                    "description": "",
                    "label": ""
                }
            },
            "HelttiIndustry": {
                "i": {
                    "description": "",
                    "label": "Housing and hopsitality operations"
                },
                "j": {
                    "description": "",
                    "label": "Information systems and communication"
                },
                "k": {
                    "description": "",
                    "label": "Finance and insurance operations"
                },
                "m": {
                    "description": "",
                    "label": "Professionell, vetenskaplig och teknisk verksamhet"
                },
                "n": {
                    "description": "",
                    "label": "Administrative and support operations"
                },
                "notDefined": {
                    "description": "",
                    "label": "Choose…"
                },
                "o": {
                    "description": "",
                    "label": "Public administration and national defense"
                },
                "other": {
                    "description": "",
                    "label": "Other industry"
                },
                "q": {
                    "description": "",
                    "label": "Health and social service operations"
                },
                "r": {
                    "description": "",
                    "label": "Arts, entertainment and recreational operations"
                },
                "s": {
                    "description": "",
                    "label": "Other service operations"
                }
            },
            "HelttiProductPackage": {
                "large": {
                    "description": "",
                    "label": "Hifi"
                },
                "medium": {
                    "description": "",
                    "label": "Growth"
                },
                "notDefined": {
                    "description": "",
                    "label": "No contract"
                },
                "small": {
                    "description": "",
                    "label": "Start"
                }
            },
            "HouseHoldUseCaseTree": {
                "childCare": {
                    "description": "",
                    "kela": {
                        "description": "",
                        "label": ""
                    },
                    "label": "",
                    "mll": {
                        "description": "",
                        "label": ""
                    },
                    "other": {
                        "description": "",
                        "label": ""
                    }
                },
                "cleaning": {
                    "51530": {
                        "description": "",
                        "label": ""
                    },
                    "53221": {
                        "description": "",
                        "label": ""
                    },
                    "61132": {
                        "description": "",
                        "label": ""
                    },
                    "91110": {
                        "description": "",
                        "label": ""
                    },
                    "description": "",
                    "label": "",
                    "other": {
                        "description": "",
                        "label": ""
                    }
                },
                "construction": {
                    "carpenter": {
                        "description": "",
                        "label": ""
                    },
                    "description": "",
                    "floor": {
                        "description": "",
                        "label": ""
                    },
                    "label": "",
                    "new": {
                        "description": "",
                        "label": ""
                    },
                    "painter": {
                        "description": "",
                        "label": ""
                    },
                    "renovation": {
                        "description": "",
                        "label": ""
                    },
                    "roof": {
                        "description": "",
                        "label": ""
                    }
                },
                "other": {
                    "51530": {
                        "description": "",
                        "label": "Building caretakers"
                    },
                    "53112": {
                        "description": "",
                        "label": "Private childminders"
                    },
                    "53212": {
                        "description": "",
                        "label": "Mental handicap nurses"
                    },
                    "53213": {
                        "description": "",
                        "label": "Social work assistants"
                    },
                    "53221": {
                        "description": "",
                        "label": "Household service workers"
                    },
                    "53222": {
                        "description": "",
                        "label": "Personal care workers, family carers, etc."
                    },
                    "61112": {
                        "description": "",
                        "label": "Field crop supervisors and workers"
                    },
                    "61132": {
                        "description": "",
                        "label": "Gardeners, horticultural and nursery growers and workers"
                    },
                    "62100": {
                        "description": "",
                        "label": "Forestry and related workers"
                    },
                    "71110": {
                        "description": "",
                        "label": "House builders"
                    },
                    "71150": {
                        "description": "",
                        "label": "Carpenters and joiners"
                    },
                    "71210": {
                        "description": "",
                        "label": "Roofers"
                    },
                    "71310": {
                        "description": "",
                        "label": "Painters and related workers"
                    },
                    "91110": {
                        "description": "",
                        "label": "Domestic cleaners and helpers"
                    },
                    "description": "",
                    "label": "Other",
                    "undefined": {
                        "description": "",
                        "label": "Other"
                    }
                }
            },
            "InsuranceCompany": {
                "aktia": {
                    "description": "",
                    "label": "Aktia"
                },
                "alandia": {
                    "description": "",
                    "label": "Alandia"
                },
                "ålands": {
                    "description": "",
                    "label": "Ålands"
                },
                "aVakuutus": {
                    "description": "",
                    "label": "A-Vakuutus"
                },
                "fennia": {
                    "description": "",
                    "label": "Fennia"
                },
                "folksam": {
                    "description": "",
                    "label": "Folksam"
                },
                "if": {
                    "description": "",
                    "label": "If"
                },
                "lähiTapiola": {
                    "description": "",
                    "label": "LähiTapiola"
                },
                "none": {
                    "description": "",
                    "label": "(Choose insurance company)"
                },
                "other": {
                    "description": "",
                    "label": "Other company"
                },
                "pohjantähti": {
                    "description": "",
                    "label": "Pohjantähti"
                },
                "pohjola": {
                    "description": "",
                    "label": "OP Vakuutus"
                },
                "redarnas": {
                    "description": "",
                    "label": "Redarnas"
                },
                "tryg": {
                    "description": "",
                    "label": "Tryg"
                },
                "turva": {
                    "description": "",
                    "label": "Turva"
                }
            },
            "LegalEntityType": {
                "company": {
                    "description": "",
                    "label": "Business ID"
                },
                "partner": {
                    "description": "",
                    "label": "Partner"
                },
                "person": {
                    "description": "",
                    "label": "Person"
                },
                "personCreatedByEmployer": {
                    "description": "",
                    "label": "Employee"
                },
                "undefined": {
                    "description": "",
                    "label": "Unknown"
                }
            },
            "MessageType": {
                "email": {
                    "description": "",
                    "label": "E-mail"
                },
                "sms": {
                    "description": "",
                    "label": "SMS"
                }
            },
            "OnboardingStatus": {
                "created": {
                    "description": "",
                    "label": "Created"
                },
                "done": {
                    "description": "",
                    "label": "Done"
                },
                "opdescription": "",
                "oplabel": "In progress"
            },
            "PalkkausCampaignPricing": {
                "campaignAfterFirstUse": {
                    "description": "",
                    "label": ""
                },
                "campaignFirstUse": {
                    "description": "",
                    "label": ""
                },
                "companyFreeTrial": {
                    "description": "",
                    "label": ""
                },
                "none": {
                    "description": "",
                    "label": ""
                }
            },
            "PartnerSite": {
                "careDotCom": {
                    "description": "",
                    "label": ""
                },
                "dev": {
                    "description": "",
                    "label": ""
                },
                "duunitori": {
                    "description": "",
                    "label": ""
                },
                "example": {
                    "description": "",
                    "label": ""
                },
                "mol": {
                    "description": "",
                    "label": ""
                },
                "palkkaapakolaindescription": "",
                "palkkaapakolainlabel": "",
                "palkkaus": {
                    "description": "",
                    "label": ""
                },
                "palkkausEmployerFillIn": {
                    "description": "",
                    "label": ""
                },
                "palkkausIdentified": {
                    "description": "",
                    "label": ""
                },
                "raksa": {
                    "description": "",
                    "label": ""
                },
                "refugeeJobs": {
                    "description": "",
                    "label": ""
                },
                "talkkarit": {
                    "description": "",
                    "label": ""
                },
                "unknown": {
                    "description": "",
                    "label": ""
                }
            },
            "PaymentStatus": {
                "bankDelivered": {
                    "description": "",
                    "label": "Approved by bank"
                },
                "bankError": {
                    "description": "",
                    "label": "Error in bank"
                },
                "bankPartialError": {
                    "description": "",
                    "label": "Error in bank"
                },
                "bankTechApproval": {
                    "description": "",
                    "label": "Received by bank"
                },
                "cancelled": {
                    "description": "",
                    "label": "Payment canceled"
                },
                "new": {
                    "description": "",
                    "label": "New"
                },
                "paid": {
                    "description": "",
                    "label": "Payment made"
                },
                "sentToBank": {
                    "description": "",
                    "label": "Sent to bank"
                },
                "unknown": {
                    "description": "",
                    "label": "Unknown"
                }
            },
            "PayrollStatus": {
                "draft": {
                    "label": "Draft"
                },
                "paymentStarted": {
                    "label": "Payment started"
                },
                "paymentSucceeded": {
                    "label": "Payment succeeded"
                },
                "paymentCanceled": {
                    "label": "Payment canceled"
                },
                "paymentError": {
                    "label": "Error in payment"
                },
                "template": {
                    "label": "Template"
                }
            },
            "PensionCompany": {
                "elo": {
                    "description": "",
                    "label": "Elo"
                },
                "etera": {
                    "description": "",
                    "label": "Etera"
                },
                "ilmarindescription": "",
                "ilmarinen": {
                    "label": "Ilmarinen"
                },
                "none": {
                    "description": "",
                    "label": "Choose…"
                },
                "other": {
                    "description": "",
                    "label": "Other company"
                },
                "pensionsAlandia": {
                    "description": "",
                    "label": "Alandia"
                },
                "varma": {
                    "description": "",
                    "label": "Varma"
                },
                "veritas": {
                    "description": "",
                    "label": "Veritas"
                },
                "apteekkien": {
                    "description": "",
                    "label": "Apteekkien Eläkekassa"
                },
                "verso": {
                    "description": "",
                    "label": "Verso"
                }
            },
            "PensionCalculation": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "employee": {
                    "label": "",
                    "description": ""
                },
                "entrepreneur": {
                    "label": "",
                    "description": ""
                },
                "smallEntrepreneur": {
                    "label": "",
                    "description": ""
                },
                "partialOwner": {
                    "label": "",
                    "description": ""
                },
                "farmer": {
                    "label": "",
                    "description": ""
                },
                "smallFarmer": {
                    "label": "",
                    "description": ""
                },
                "athlete": {
                    "label": "",
                    "description": ""
                },
                "compensation": {
                    "label": "",
                    "description": ""
                },
                "boardRemuneration": {
                    "label": "",
                    "description": ""
                }
            },
            "Product": {
                "accounting": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "baseService": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "healthCareHeltti": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "insurance": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "pension": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "pensionEntrepreneur": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "tax": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "taxCard": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "unemployment": {
                    "description": "",
                    "label": "",
                    "status": "",
                    "statusTVR": ""
                }
            },
            "ProductListFilter": {
                "all": {
                    "description": "",
                    "label": ""
                },
                "available": {
                    "description": "",
                    "label": ""
                }
            },
            "Profession": {
                "0": {
                    "label": "Armed forces"
                },
                "1": {
                    "label": "Managers"
                },
                "2": {
                    "label": "Professionals"
                },
                "3": {
                    "label": "Technicians and associate professionals"
                },
                "4": {
                    "label": "Clerical support workers"
                },
                "5": {
                    "label": "Service and sales workers"
                },
                "6": {
                    "label": "Skilled agricultural, forestry and fishery workers"
                },
                "7": {
                    "label": "Craft and related trades workers"
                },
                "8": {
                    "label": "Plant and machine operators, and assemblers"
                },
                "9": {
                    "label": "Elementary occupations"
                },
                "11": {
                    "label": "Chief executives, senior officials and legislators"
                },
                "12": {
                    "label": "Administrative and commercial managers"
                },
                "13": {
                    "label": "Production and specialised services managers"
                },
                "14": {
                    "label": "Hospitality, retail and other services managers"
                },
                "21": {
                    "label": "Science and engineering professionals"
                },
                "22": {
                    "label": "Health professionals"
                },
                "23": {
                    "label": "Teaching professionals"
                },
                "24": {
                    "label": "Business and administration professionals"
                },
                "25": {
                    "label": "Information and communications technology professionals"
                },
                "26": {
                    "label": "Legal, social and cultural professionals"
                },
                "31": {
                    "label": "Science and engineering associate professionals"
                },
                "32": {
                    "label": "Health associate professionals"
                },
                "33": {
                    "label": "Business and administration associate professionals"
                },
                "34": {
                    "label": "Legal, social, cultural and related associate professionals"
                },
                "35": {
                    "label": "Information and communications technicians"
                },
                "41": {
                    "label": "General and keyboard clerks"
                },
                "42": {
                    "label": "Customer services clerks"
                },
                "43": {
                    "label": "Numerical and material recording clerks"
                },
                "44": {
                    "label": "Other clerical support workers"
                },
                "51": {
                    "label": "Personal service workers"
                },
                "52": {
                    "label": "Sales workers"
                },
                "53": {
                    "label": "Personal care workers"
                },
                "54": {
                    "label": "Protective services workers"
                },
                "61": {
                    "label": "Market-oriented skilled agricultural workers"
                },
                "62": {
                    "label": "Market-oriented skilled forestry, fishery and hunting workers"
                },
                "63": {
                    "label": "Subsistence farmers, fishers, hunters and gatherers"
                },
                "71": {
                    "label": "Building and related trades workers, excluding electricians"
                },
                "72": {
                    "label": "Metal, machinery and related trades workers"
                },
                "73": {
                    "label": "Handicraft and printing workers"
                },
                "74": {
                    "label": "Electrical and electronic trades workers"
                },
                "75": {
                    "label": "Food processing, wood working, garment and other craft and related trades workers"
                },
                "81": {
                    "label": "Stationary plant and machine operators"
                },
                "82": {
                    "label": "Assemblers"
                },
                "83": {
                    "label": "Drivers and mobile plant operators"
                },
                "91": {
                    "label": "Cleaners and helpers"
                },
                "92": {
                    "label": "Agricultural, forestry and fishery labourers"
                },
                "93": {
                    "label": "Labourers in mining, construction, manufacturing and transport"
                },
                "94": {
                    "label": "Food preparation assistants"
                },
                "95": {
                    "label": "Street and related sales and service workers"
                },
                "96": {
                    "label": "Refuse workers and other elementary workers"
                },
                "111": {
                    "label": "Legislators and senior officials"
                },
                "112": {
                    "label": "Managing directors and chief executives"
                },
                "121": {
                    "label": "Business services and administration managers"
                },
                "122": {
                    "label": "Sales, marketing and development managers"
                },
                "131": {
                    "label": "Production managers in agriculture, forestry and fisheries"
                },
                "132": {
                    "label": "Manufacturing, mining, construction, and distribution managers"
                },
                "133": {
                    "label": "Information and communications technology service managers"
                },
                "134": {
                    "label": "Professional services managers"
                },
                "141": {
                    "label": "Hotel and restaurant managers"
                },
                "142": {
                    "label": "Retail and wholesale trade managers"
                },
                "143": {
                    "label": "Other services managers"
                },
                "211": {
                    "label": "Physical and earth science professionals"
                },
                "212": {
                    "label": "Mathematicians, actuaries and statisticians"
                },
                "213": {
                    "label": "Life science professionals"
                },
                "214": {
                    "label": "Engineering professionals (excluding electrotechnology)"
                },
                "215": {
                    "label": "Electrotechnology engineers"
                },
                "216": {
                    "label": "Architects, planners, surveyors and designers"
                },
                "221": {
                    "label": "Medical doctors"
                },
                "222": {
                    "label": "Nursing and midwifery professionals"
                },
                "223": {
                    "label": "Traditional and complementary medicine professionals"
                },
                "224": {
                    "label": "Paramedical practitioners"
                },
                "225": {
                    "label": "Veterinarians"
                },
                "226": {
                    "label": "Other health professionals"
                },
                "231": {
                    "label": "University and higher education teachers"
                },
                "232": {
                    "label": "Vocational education teachers"
                },
                "233": {
                    "label": "Secondary education teachers"
                },
                "234": {
                    "label": "Primary school and early childhood teachers"
                },
                "235": {
                    "label": "Other teaching professionals"
                },
                "241": {
                    "label": "Finance professionals"
                },
                "242": {
                    "label": "Administration professionals"
                },
                "243": {
                    "label": "Sales, marketing and public relations professionals"
                },
                "251": {
                    "label": "Software and applications developers and analysts"
                },
                "252": {
                    "label": "Database and network professionals"
                },
                "261": {
                    "label": "Legal professionals"
                },
                "262": {
                    "label": "Librarians, archivists and curators"
                },
                "263": {
                    "label": "Social and religious professionals"
                },
                "264": {
                    "label": "Authors, journalists and linguists"
                },
                "265": {
                    "label": "Creative and performing artists"
                },
                "311": {
                    "label": "Physical and engineering science technicians"
                },
                "312": {
                    "label": "Mining, manufacturing and construction supervisors"
                },
                "313": {
                    "label": "Process control technicians"
                },
                "314": {
                    "label": "Life science technicians and related associate professionals"
                },
                "315": {
                    "label": "Ship and aircraft controllers and technicians"
                },
                "321": {
                    "label": "Medical and pharmaceutical technicians"
                },
                "322": {
                    "label": "Nursing and midwifery associate professionals"
                },
                "323": {
                    "label": "Traditional and complementary medicine associate professionals"
                },
                "324": {
                    "label": "Veterinary technicians and assistants"
                },
                "325": {
                    "label": "Other health associate professionals"
                },
                "331": {
                    "label": "Financial and mathematical associate professionals"
                },
                "332": {
                    "label": "Sales and purchasing agents and brokers"
                },
                "333": {
                    "label": "Business services agents"
                },
                "334": {
                    "label": "Administrative and specialised secretaries"
                },
                "335": {
                    "label": "Regulatory government associate professionals"
                },
                "341": {
                    "label": "Legal, social and religious associate professionals"
                },
                "342": {
                    "label": "Sports and fitness workers"
                },
                "343": {
                    "label": "Artistic, cultural and culinary associate professionals"
                },
                "351": {
                    "label": "Information and communications technology operations and user support technicians"
                },
                "352": {
                    "label": "Telecommunications and broadcasting technicians"
                },
                "411": {
                    "label": "General office clerks"
                },
                "412": {
                    "label": "Secretaries (general)"
                },
                "413": {
                    "label": "Keyboard operators"
                },
                "421": {
                    "label": "Tellers, money collectors and related clerks"
                },
                "422": {
                    "label": "Client information workers"
                },
                "431": {
                    "label": "Numerical clerks"
                },
                "432": {
                    "label": "Material-recording and transport clerks"
                },
                "441": {
                    "label": "Other clerical support workers"
                },
                "511": {
                    "label": "Travel attendants, conductors and guides"
                },
                "512": {
                    "label": "Cooks"
                },
                "513": {
                    "label": "Waiters and bartenders"
                },
                "514": {
                    "label": "Hairdressers, beauticians and related workers"
                },
                "515": {
                    "label": "Building and housekeeping supervisors"
                },
                "516": {
                    "label": "Other personal services workers"
                },
                "521": {
                    "label": "Street and market salespersons"
                },
                "522": {
                    "label": "Shop salespersons"
                },
                "523": {
                    "label": "Cashiers and ticket clerks"
                },
                "524": {
                    "label": "Other sales workers"
                },
                "531": {
                    "label": "Child care workers and teachers' aides"
                },
                "532": {
                    "label": "Personal care workers in health services"
                },
                "541": {
                    "label": "Protective services workers"
                },
                "611": {
                    "label": "Market gardeners and crop growers"
                },
                "612": {
                    "label": "Animal producers"
                },
                "613": {
                    "label": "Mixed crop and animal producers"
                },
                "621": {
                    "label": "Forestry and related workers"
                },
                "622": {
                    "label": "Fishery workers, hunters and trappers"
                },
                "631": {
                    "label": "Subsistence crop farmers"
                },
                "632": {
                    "label": "Subsistence livestock farmers"
                },
                "633": {
                    "label": "Subsistence mixed crop and livestock farmers"
                },
                "634": {
                    "label": "Subsistence fishers, hunters, trappers and gatherers"
                },
                "711": {
                    "label": "Building frame and related trades workers"
                },
                "712": {
                    "label": "Building finishers and related trades workers"
                },
                "713": {
                    "label": "Painters, building structure cleaners and related trades workers"
                },
                "721": {
                    "label": "Sheet and structural metal workers, moulders and welders, and related workers"
                },
                "722": {
                    "label": "Blacksmiths, toolmakers and related trades workers"
                },
                "723": {
                    "label": "Machinery mechanics and repairers"
                },
                "731": {
                    "label": "Handicraft workers"
                },
                "732": {
                    "label": "Printing trades workers"
                },
                "741": {
                    "label": "Electrical equipment installers and repairers"
                },
                "742": {
                    "label": "Electronics and telecommunications installers and repairers"
                },
                "751": {
                    "label": "Food processing and related trades workers"
                },
                "752": {
                    "label": "Wood treaters, cabinet-makers and related trades workers"
                },
                "753": {
                    "label": "Garment and related trades workers"
                },
                "754": {
                    "label": "Other craft and related workers"
                },
                "811": {
                    "label": "Mining and mineral processing plant operators"
                },
                "812": {
                    "label": "Metal processing and finishing plant operators"
                },
                "813": {
                    "label": "Chemical and photographic products plant and machine operators"
                },
                "814": {
                    "label": "Rubber, plastic and paper products machine operators"
                },
                "815": {
                    "label": "Textile, fur and leather products machine operators"
                },
                "816": {
                    "label": "Food and related products machine operators"
                },
                "817": {
                    "label": "Wood processing and papermaking plant operators"
                },
                "818": {
                    "label": "Other stationary plant and machine operators"
                },
                "821": {
                    "label": "Assemblers"
                },
                "831": {
                    "label": "Locomotive engine drivers and related workers"
                },
                "832": {
                    "label": "Car, van and motorcycle drivers"
                },
                "833": {
                    "label": "Heavy truck and bus drivers"
                },
                "834": {
                    "label": "Mobile plant operators"
                },
                "835": {
                    "label": "Ships' deck crews and related workers"
                },
                "911": {
                    "label": "Domestic, hotel and office cleaners and helpers"
                },
                "912": {
                    "label": "Vehicle, window, laundry and other hand cleaning workers"
                },
                "921": {
                    "label": "Agricultural, forestry and fishery labourers"
                },
                "931": {
                    "label": "Mining and construction labourers"
                },
                "932": {
                    "label": "Manufacturing labourers"
                },
                "933": {
                    "label": "Transport and storage labourers"
                },
                "941": {
                    "label": "Food preparation assistants"
                },
                "951": {
                    "label": "Street and related service workers"
                },
                "952": {
                    "label": "Street vendors (excluding food)"
                },
                "961": {
                    "label": "Refuse workers"
                },
                "962": {
                    "label": "Other elementary workers"
                },
                "1111": {
                    "label": "Legislators"
                },
                "1112": {
                    "label": "Senior government officials"
                },
                "1113": {
                    "label": "Traditional chiefs and heads of village"
                },
                "1114": {
                    "label": "Senior officials of special-interest organizations"
                },
                "1120": {
                    "label": "Managing directors and chief executives"
                },
                "1211": {
                    "label": "Finance managers"
                },
                "1212": {
                    "label": "Human resource managers"
                },
                "1213": {
                    "label": "Policy and planning managers"
                },
                "1219": {
                    "label": "Business services and administration managers not elsewhere classified"
                },
                "1221": {
                    "label": "Sales and marketing managers"
                },
                "1222": {
                    "label": "Advertising and public relations managers"
                },
                "1223": {
                    "label": "Research and development managers"
                },
                "1311": {
                    "label": "Agricultural and forestry production managers"
                },
                "1312": {
                    "label": "Aquaculture and fisheries production managers"
                },
                "1321": {
                    "label": "Manufacturing managers"
                },
                "1322": {
                    "label": "Mining managers"
                },
                "1323": {
                    "label": "Construction managers"
                },
                "1324": {
                    "label": "Supply, distribution and related managers"
                },
                "1330": {
                    "label": "Information and communications technology service managers"
                },
                "1341": {
                    "label": "Child care services managers"
                },
                "1342": {
                    "label": "Health services managers"
                },
                "1343": {
                    "label": "Aged care services managers"
                },
                "1344": {
                    "label": "Social welfare managers"
                },
                "1345": {
                    "label": "Education managers"
                },
                "1346": {
                    "label": "Financial and insurance services branch managers"
                },
                "1349": {
                    "label": "Professional services managers not elsewhere classified"
                },
                "1411": {
                    "label": "Hotel managers"
                },
                "1412": {
                    "label": "Restaurant managers"
                },
                "1420": {
                    "label": "Retail and wholesale trade managers"
                },
                "1431": {
                    "label": "Sports, recreation and cultural centre managers"
                },
                "1439": {
                    "label": "Services managers not elsewhere classified"
                },
                "2111": {
                    "label": "Physicists and astronomers"
                },
                "2112": {
                    "label": "Meteorologists"
                },
                "2113": {
                    "label": "Chemists"
                },
                "2114": {
                    "label": "Geologists and geophysicists"
                },
                "2120": {
                    "label": "Mathematicians, actuaries and statisticians"
                },
                "2131": {
                    "label": "Biologists, botanists, zoologists and related professionals"
                },
                "2132": {
                    "label": "Farming, forestry and fisheries advisers"
                },
                "2133": {
                    "label": "Environmental protection professionals"
                },
                "2141": {
                    "label": "Industrial and production engineers"
                },
                "2142": {
                    "label": "Civil engineers"
                },
                "2143": {
                    "label": "Environmental engineers"
                },
                "2144": {
                    "label": "Mechanical engineers"
                },
                "2145": {
                    "label": "Chemical engineers"
                },
                "2146": {
                    "label": "Mining engineers, metallurgists and related professionals"
                },
                "2149": {
                    "label": "Engineering professionals not elsewhere classified"
                },
                "2151": {
                    "label": "Electrical engineers"
                },
                "2152": {
                    "label": "Electronics engineers"
                },
                "2153": {
                    "label": "Telecommunications engineers"
                },
                "2161": {
                    "label": "Building architects"
                },
                "2162": {
                    "label": "Landscape architects"
                },
                "2163": {
                    "label": "Product and garment designers"
                },
                "2164": {
                    "label": "Town and traffic planners"
                },
                "2165": {
                    "label": "Cartographers and surveyors"
                },
                "2166": {
                    "label": "Graphic and multimedia designers"
                },
                "2211": {
                    "label": "Generalist medical practitioners"
                },
                "2212": {
                    "label": "Specialist medical practitioners"
                },
                "2221": {
                    "label": "Nursing professionals"
                },
                "2222": {
                    "label": "Midwifery professionals"
                },
                "2230": {
                    "label": "Traditional and complementary medicine professionals"
                },
                "2240": {
                    "label": "Paramedical practitioners"
                },
                "2250": {
                    "label": "Veterinarians"
                },
                "2261": {
                    "label": "Dentists"
                },
                "2262": {
                    "label": "Pharmacists"
                },
                "2263": {
                    "label": "Environmental and occupational health and hygiene professionals"
                },
                "2264": {
                    "label": "Physiotherapists"
                },
                "2265": {
                    "label": "Dieticians and nutritionists"
                },
                "2266": {
                    "label": "Audiologists and speech therapists"
                },
                "2267": {
                    "label": "Optometrists and ophthalmic opticians"
                },
                "2269": {
                    "label": "Health professionals not elsewhere classified"
                },
                "2310": {
                    "label": "University and higher education teachers"
                },
                "2320": {
                    "label": "Vocational education teachers"
                },
                "2330": {
                    "label": "Secondary education teachers"
                },
                "2341": {
                    "label": "Primary school teachers"
                },
                "2342": {
                    "label": "Early childhood educators"
                },
                "2351": {
                    "label": "Education methods specialists"
                },
                "2352": {
                    "label": "Special needs teachers"
                },
                "2353": {
                    "label": "Other language teachers"
                },
                "2354": {
                    "label": "Other music teachers"
                },
                "2355": {
                    "label": "Other arts teachers"
                },
                "2356": {
                    "label": "Information technology trainers"
                },
                "2359": {
                    "label": "Teaching professionals not elsewhere classified"
                },
                "2411": {
                    "label": "Accountants"
                },
                "2412": {
                    "label": "Financial and investment advisers"
                },
                "2413": {
                    "label": "Financial analysts"
                },
                "2421": {
                    "label": "Management and organization analysts"
                },
                "2422": {
                    "label": "Policy administration professionals"
                },
                "2423": {
                    "label": "Personnel and careers professionals"
                },
                "2424": {
                    "label": "Training and staff development professionals"
                },
                "2431": {
                    "label": "Advertising and marketing professionals"
                },
                "2432": {
                    "label": "Public relations professionals"
                },
                "2433": {
                    "label": "Technical and medical sales professionals (excluding ICT)"
                },
                "2434": {
                    "label": "Information and communications technology sales professionals"
                },
                "2511": {
                    "label": "Systems analysts"
                },
                "2512": {
                    "label": "Software developers"
                },
                "2513": {
                    "label": "Web and multimedia developers"
                },
                "2514": {
                    "label": "Applications programmers"
                },
                "2519": {
                    "label": "Software and applications developers and analysts not elsewhere classified"
                },
                "2521": {
                    "label": "Database designers and administrators"
                },
                "2522": {
                    "label": "Systems administrators"
                },
                "2523": {
                    "label": "Computer network professionals"
                },
                "2529": {
                    "label": "Database and network professionals not elsewhere classified"
                },
                "2611": {
                    "label": "Lawyers"
                },
                "2612": {
                    "label": "Judges"
                },
                "2619": {
                    "label": "Legal professionals not elsewhere classified"
                },
                "2621": {
                    "label": "Archivists and curators"
                },
                "2622": {
                    "label": "Librarians and related information professionals"
                },
                "2631": {
                    "label": "Economists"
                },
                "2632": {
                    "label": "Sociologists, anthropologists and related professionals"
                },
                "2633": {
                    "label": "Philosophers, historians and political scientists"
                },
                "2634": {
                    "label": "Psychologists"
                },
                "2635": {
                    "label": "Social work and counselling professionals"
                },
                "2636": {
                    "label": "Religious professionals"
                },
                "2641": {
                    "label": "Authors and related writers"
                },
                "2642": {
                    "label": "Journalists"
                },
                "2643": {
                    "label": "Translators, interpreters and other linguists"
                },
                "2651": {
                    "label": "Visual artists"
                },
                "2652": {
                    "label": "Musicians, singers and composers"
                },
                "2653": {
                    "label": "Dancers and choreographers"
                },
                "2654": {
                    "label": "Film, stage and related directors and producers"
                },
                "2655": {
                    "label": "Actors"
                },
                "2656": {
                    "label": "Announcers on radio, television and other media"
                },
                "2659": {
                    "label": "Creative and performing artists not elsewhere classified"
                },
                "3111": {
                    "label": "Chemical and physical science technicians"
                },
                "3112": {
                    "label": "Civil engineering technicians"
                },
                "3113": {
                    "label": "Electrical engineering technicians"
                },
                "3114": {
                    "label": "Electronics engineering technicians"
                },
                "3115": {
                    "label": "Mechanical engineering technicians"
                },
                "3116": {
                    "label": "Chemical engineering technicians"
                },
                "3117": {
                    "label": "Mining and metallurgical technicians"
                },
                "3118": {
                    "label": "Draughtspersons"
                },
                "3119": {
                    "label": "Physical and engineering science technicians not elsewhere classified"
                },
                "3121": {
                    "label": "Mining supervisors"
                },
                "3122": {
                    "label": "Manufacturing supervisors"
                },
                "3123": {
                    "label": "Construction supervisors"
                },
                "3131": {
                    "label": "Power production plant operators"
                },
                "3132": {
                    "label": "Incinerator and water treatment plant operators"
                },
                "3133": {
                    "label": "Chemical processing plant controllers"
                },
                "3134": {
                    "label": "Petroleum and natural gas refining plant operators"
                },
                "3135": {
                    "label": "Metal production process controllers"
                },
                "3139": {
                    "label": "Process control technicians not elsewhere classified"
                },
                "3141": {
                    "label": "Life science technicians (excluding medical)"
                },
                "3142": {
                    "label": "Agricultural technicians"
                },
                "3143": {
                    "label": "Forestry technicians"
                },
                "3151": {
                    "label": "Ships' engineers"
                },
                "3152": {
                    "label": "Ships' deck officers and pilots"
                },
                "3153": {
                    "label": "Aircraft pilots and related associate professionals"
                },
                "3154": {
                    "label": "Air traffic controllers"
                },
                "3155": {
                    "label": "Air traffic safety electronics technicians"
                },
                "3211": {
                    "label": "Medical imaging and therapeutic equipment technicians"
                },
                "3212": {
                    "label": "Medical and pathology laboratory technicians"
                },
                "3213": {
                    "label": "Pharmaceutical technicians and assistants"
                },
                "3214": {
                    "label": "Medical and dental prosthetic technicians"
                },
                "3221": {
                    "label": "Nursing associate professionals"
                },
                "3222": {
                    "label": "Midwifery associate professionals"
                },
                "3230": {
                    "label": "Traditional and complementary medicine associate professionals"
                },
                "3240": {
                    "label": "Veterinary technicians and assistants"
                },
                "3251": {
                    "label": "Dental assistants and therapists"
                },
                "3252": {
                    "label": "Medical records and health information technicians"
                },
                "3253": {
                    "label": "Community health workers"
                },
                "3254": {
                    "label": "Dispensing opticians"
                },
                "3255": {
                    "label": "Physiotherapy technicians and assistants"
                },
                "3256": {
                    "label": "Medical assistants"
                },
                "3257": {
                    "label": "Environmental and occupational health inspectors and associates"
                },
                "3258": {
                    "label": "Ambulance workers"
                },
                "3259": {
                    "label": "Health associate professionals not elsewhere classified"
                },
                "3311": {
                    "label": "Securities and finance dealers and brokers"
                },
                "3312": {
                    "label": "Credit and loans officers"
                },
                "3313": {
                    "label": "Accounting associate professionals"
                },
                "3314": {
                    "label": "Statistical, mathematical and related associate professionals"
                },
                "3315": {
                    "label": "Valuers and loss assessors"
                },
                "3321": {
                    "label": "Insurance representatives"
                },
                "3322": {
                    "label": "Commercial sales representatives"
                },
                "3323": {
                    "label": "Buyers"
                },
                "3324": {
                    "label": "Trade brokers"
                },
                "3331": {
                    "label": "Clearing and forwarding agents"
                },
                "3332": {
                    "label": "Conference and event planners"
                },
                "3333": {
                    "label": "Employment agents and contractors"
                },
                "3334": {
                    "label": "Real estate agents and property managers"
                },
                "3339": {
                    "label": "Business services agents not elsewhere classified"
                },
                "3341": {
                    "label": "Office supervisors"
                },
                "3342": {
                    "label": "Legal secretaries"
                },
                "3343": {
                    "label": "Administrative and executive secretaries"
                },
                "3344": {
                    "label": "Medical secretaries"
                },
                "3351": {
                    "label": "Customs and border inspectors"
                },
                "3352": {
                    "label": "Government tax and excise officials"
                },
                "3353": {
                    "label": "Government social benefits officials"
                },
                "3354": {
                    "label": "Government licensing officials"
                },
                "3355": {
                    "label": "Police inspectors and detectives"
                },
                "3359": {
                    "label": "Regulatory government associate professionals not elsewhere classified"
                },
                "3411": {
                    "label": "Legal and Related Associate Professionals"
                },
                "3412": {
                    "label": "Social work associate professionals"
                },
                "3413": {
                    "label": "Religious associate professionals"
                },
                "3421": {
                    "label": "Athletes and sports players"
                },
                "3422": {
                    "label": "Sports coaches, instructors and officials"
                },
                "3423": {
                    "label": "Fitness and recreation instructors and program leaders"
                },
                "3431": {
                    "label": "Photographers"
                },
                "3432": {
                    "label": "Interior designers and decorators"
                },
                "3433": {
                    "label": "Gallery, museum and library technicians"
                },
                "3434": {
                    "label": "Chefs"
                },
                "3435": {
                    "label": "Other artistic and cultural associate professionals"
                },
                "3511": {
                    "label": "Information and communications technology operations technicians"
                },
                "3512": {
                    "label": "Information and communications technology user support technicians"
                },
                "3513": {
                    "label": "Computer network and systems technicians"
                },
                "3514": {
                    "label": "Web technicians"
                },
                "3521": {
                    "label": "Broadcasting and audio-visual technicians"
                },
                "3522": {
                    "label": "Telecommunications engineering technicians"
                },
                "4110": {
                    "label": "General office clerks"
                },
                "4120": {
                    "label": "Secretaries (general)"
                },
                "4131": {
                    "label": "Typists and word processing operators"
                },
                "4132": {
                    "label": "Data entry clerks"
                },
                "4211": {
                    "label": "Bank tellers and related clerks"
                },
                "4212": {
                    "label": "Bookmakers, croupiers and related gaming workers"
                },
                "4213": {
                    "label": "Pawnbrokers and money-lenders"
                },
                "4214": {
                    "label": "Debt-collectors and related workers"
                },
                "4221": {
                    "label": "Travel consultants and clerks"
                },
                "4222": {
                    "label": "Contact centre information clerks"
                },
                "4223": {
                    "label": "Telephone switchboard operators"
                },
                "4224": {
                    "label": "Hotel receptionists"
                },
                "4225": {
                    "label": "Enquiry clerks"
                },
                "4226": {
                    "label": "Receptionists (general)"
                },
                "4227": {
                    "label": "Survey and market research interviewers"
                },
                "4229": {
                    "label": "Client information workers not elsewhere classified"
                },
                "4311": {
                    "label": "Accounting and bookkeeping clerks"
                },
                "4312": {
                    "label": "Statistical, finance and insurance clerks"
                },
                "4313": {
                    "label": "Payroll clerks"
                },
                "4321": {
                    "label": "Stock clerks"
                },
                "4322": {
                    "label": "Production clerks"
                },
                "4323": {
                    "label": "Transport clerks"
                },
                "4411": {
                    "label": "Library clerks"
                },
                "4412": {
                    "label": "Mail carriers and sorting clerks"
                },
                "4413": {
                    "label": "Coding, proof-reading and related clerks"
                },
                "4414": {
                    "label": "Scribes and related workers"
                },
                "4415": {
                    "label": "Filing and copying clerks"
                },
                "4416": {
                    "label": "Personnel clerks"
                },
                "4419": {
                    "label": "Clerical support workers not elsewhere classified"
                },
                "5111": {
                    "label": "Travel attendants and travel stewards"
                },
                "5112": {
                    "label": "Transport conductors"
                },
                "5113": {
                    "label": "Travel guides"
                },
                "5120": {
                    "label": "Cooks"
                },
                "5131": {
                    "label": "Waiters"
                },
                "5132": {
                    "label": "Bartenders"
                },
                "5141": {
                    "label": "Hairdressers"
                },
                "5142": {
                    "label": "Beauticians and related workers"
                },
                "5151": {
                    "label": "Cleaning and housekeeping supervisors in offices, hotels and other establishments"
                },
                "5152": {
                    "label": "Domestic housekeepers"
                },
                "5153": {
                    "label": "Building caretakers"
                },
                "5161": {
                    "label": "Astrologers, fortune-tellers and related workers"
                },
                "5162": {
                    "label": "Companions and valets"
                },
                "5163": {
                    "label": "Undertakers and embalmers"
                },
                "5164": {
                    "label": "Pet groomers and animal care workers"
                },
                "5165": {
                    "label": "Driving instructors"
                },
                "5169": {
                    "label": "Personal services workers not elsewhere classified"
                },
                "5211": {
                    "label": "Stall and market salespersons"
                },
                "5212": {
                    "label": "Street food salespersons"
                },
                "5221": {
                    "label": "Shop keepers"
                },
                "5222": {
                    "label": "Shop supervisors"
                },
                "5223": {
                    "label": "Shop sales assistants"
                },
                "5230": {
                    "label": "Cashiers and ticket clerks"
                },
                "5241": {
                    "label": "Fashion and other models"
                },
                "5242": {
                    "label": "Sales demonstrators"
                },
                "5243": {
                    "label": "Door to door salespersons"
                },
                "5244": {
                    "label": "Contact centre salespersons"
                },
                "5245": {
                    "label": "Service station attendants"
                },
                "5246": {
                    "label": "Food service counter attendants"
                },
                "5249": {
                    "label": "Sales workers not elsewhere classified"
                },
                "5311": {
                    "label": "Child care workers"
                },
                "5312": {
                    "label": "Teachers' aides"
                },
                "5321": {
                    "label": "Health care assistants"
                },
                "5322": {
                    "label": "Home-based personal care workers"
                },
                "5329": {
                    "label": "Personal care workers in health services not elsewhere classified"
                },
                "5411": {
                    "label": "Fire-fighters"
                },
                "5412": {
                    "label": "Police officers"
                },
                "5413": {
                    "label": "Prison guards"
                },
                "5414": {
                    "label": "Security guards"
                },
                "5419": {
                    "label": "Protective services workers not elsewhere classified"
                },
                "6111": {
                    "label": "Field crop and vegetable growers"
                },
                "6112": {
                    "label": "Tree and shrub crop growers"
                },
                "6113": {
                    "label": "Gardeners, horticultural and nursery growers"
                },
                "6114": {
                    "label": "Mixed crop growers"
                },
                "6121": {
                    "label": "Livestock and dairy producers"
                },
                "6122": {
                    "label": "Poultry producers"
                },
                "6123": {
                    "label": "Apiarists and sericulturists"
                },
                "6129": {
                    "label": "Animal producers not elsewhere classified"
                },
                "6130": {
                    "label": "Mixed crop and animal producers"
                },
                "6210": {
                    "label": "Forestry and related workers"
                },
                "6221": {
                    "label": "Aquaculture workers"
                },
                "6222": {
                    "label": "Inland and coastal waters fishery workers"
                },
                "6223": {
                    "label": "Deep-sea fishery workers"
                },
                "6224": {
                    "label": "Hunters and trappers"
                },
                "6310": {
                    "label": "Subsistence crop farmers"
                },
                "6320": {
                    "label": "Subsistence livestock farmers"
                },
                "6330": {
                    "label": "Subsistence mixed crop and livestock farmers"
                },
                "6340": {
                    "label": "Subsistence fishers, hunters, trappers and gatherers"
                },
                "7111": {
                    "label": "House builders"
                },
                "7112": {
                    "label": "Bricklayers and related workers"
                },
                "7113": {
                    "label": "Stonemasons, stone cutters, splitters and carvers"
                },
                "7114": {
                    "label": "Concrete placers, concrete finishers and related workers"
                },
                "7115": {
                    "label": "Carpenters and joiners"
                },
                "7119": {
                    "label": "Building frame and related trades workers not elsewhere classified"
                },
                "7121": {
                    "label": "Roofers"
                },
                "7122": {
                    "label": "Floor layers and tile setters"
                },
                "7123": {
                    "label": "Plasterers"
                },
                "7124": {
                    "label": "Insulation workers"
                },
                "7125": {
                    "label": "Glaziers"
                },
                "7126": {
                    "label": "Plumbers and pipe fitters"
                },
                "7127": {
                    "label": "Air conditioning and refrigeration mechanics"
                },
                "7131": {
                    "label": "Painters and related workers"
                },
                "7132": {
                    "label": "Spray painters and varnishers"
                },
                "7133": {
                    "label": "Building structure cleaners"
                },
                "7211": {
                    "label": "Metal moulders and coremakers"
                },
                "7212": {
                    "label": "Welders and flamecutters"
                },
                "7213": {
                    "label": "Sheet-metal workers"
                },
                "7214": {
                    "label": "Structural-metal preparers and erectors"
                },
                "7215": {
                    "label": "Riggers and cable splicers"
                },
                "7221": {
                    "label": "Blacksmiths, hammersmiths and forging press workers"
                },
                "7222": {
                    "label": "Toolmakers and related workers"
                },
                "7223": {
                    "label": "Metal working machine tool setters and operators"
                },
                "7224": {
                    "label": "Metal polishers, wheel grinders and tool sharpeners"
                },
                "7231": {
                    "label": "Motor vehicle mechanics and repairers"
                },
                "7232": {
                    "label": "Aircraft engine mechanics and repairers"
                },
                "7233": {
                    "label": "Agricultural and industrial machinery mechanics and repairers"
                },
                "7234": {
                    "label": "Bicycle and related repairers"
                },
                "7311": {
                    "label": "Precision-instrument makers and repairers"
                },
                "7312": {
                    "label": "Musical instrument makers and tuners"
                },
                "7313": {
                    "label": "Jewellery and precious-metal workers"
                },
                "7314": {
                    "label": "Potters and related workers"
                },
                "7315": {
                    "label": "Glass makers, cutters, grinders and finishers"
                },
                "7316": {
                    "label": "Sign writers, decorative painters, engravers and etchers"
                },
                "7317": {
                    "label": "Handicraft workers in wood, basketry and related materials"
                },
                "7318": {
                    "label": "Handicraft workers in textile, leather and related materials"
                },
                "7319": {
                    "label": "Handicraft workers not elsewhere classified"
                },
                "7321": {
                    "label": "Pre-press technicians"
                },
                "7322": {
                    "label": "Printers"
                },
                "7323": {
                    "label": "Print finishing and binding workers"
                },
                "7411": {
                    "label": "Building and related electricians"
                },
                "7412": {
                    "label": "Electrical mechanics and fitters"
                },
                "7413": {
                    "label": "Electrical line installers and repairers"
                },
                "7421": {
                    "label": "Electronics mechanics and servicers"
                },
                "7422": {
                    "label": "Information and communications technology installers and servicers"
                },
                "7511": {
                    "label": "Butchers, fishmongers and related food preparers"
                },
                "7512": {
                    "label": "Bakers, pastry-cooks and confectionery makers"
                },
                "7513": {
                    "label": "Dairy-products makers"
                },
                "7514": {
                    "label": "Fruit, vegetable and related preservers"
                },
                "7515": {
                    "label": "Food and beverage tasters and graders"
                },
                "7516": {
                    "label": "Tobacco preparers and tobacco products makers"
                },
                "7521": {
                    "label": "Wood treaters"
                },
                "7522": {
                    "label": "Cabinet-makers and related workers"
                },
                "7523": {
                    "label": "Woodworking-machine tool setters and operators"
                },
                "7531": {
                    "label": "Tailors, dressmakers, furriers and hatters"
                },
                "7532": {
                    "label": "Garment and related pattern-makers and cutters"
                },
                "7533": {
                    "label": "Sewing, embroidery and related workers"
                },
                "7534": {
                    "label": "Upholsterers and related workers"
                },
                "7535": {
                    "label": "Pelt dressers, tanners and fellmongers"
                },
                "7536": {
                    "label": "Shoemakers and related workers"
                },
                "7541": {
                    "label": "Underwater divers"
                },
                "7542": {
                    "label": "Shotfirers and blasters"
                },
                "7543": {
                    "label": "Product graders and testers (excluding foods and beverages)"
                },
                "7544": {
                    "label": "Fumigators and other pest and weed controllers"
                },
                "7549": {
                    "label": "Craft and related workers not elsewhere classified"
                },
                "8111": {
                    "label": "Miners and quarriers"
                },
                "8112": {
                    "label": "Mineral and stone processing plant operators"
                },
                "8113": {
                    "label": "Well drillers and borers and related workers"
                },
                "8114": {
                    "label": "Cement, stone and other mineral products machine operators"
                },
                "8121": {
                    "label": "Metal processing plant operators"
                },
                "8122": {
                    "label": "Metal finishing, plating and coating machine operators"
                },
                "8131": {
                    "label": "Chemical products plant and machine operators"
                },
                "8132": {
                    "label": "Photographic products machine operators"
                },
                "8141": {
                    "label": "Rubber products machine operators"
                },
                "8142": {
                    "label": "Plastic products machine operators"
                },
                "8143": {
                    "label": "Paper products machine operators"
                },
                "8151": {
                    "label": "Fibre preparing, spinning and winding machine operators"
                },
                "8152": {
                    "label": "Weaving and knitting machine operators"
                },
                "8153": {
                    "label": "Sewing machine operators"
                },
                "8154": {
                    "label": "Bleaching, dyeing and fabric cleaning machine operators"
                },
                "8155": {
                    "label": "Fur and leather preparing machine operators"
                },
                "8156": {
                    "label": "Shoemaking and related machine operators"
                },
                "8157": {
                    "label": "Laundry machine operators"
                },
                "8159": {
                    "label": "Textile, fur and leather products machine operators not elsewhere classified"
                },
                "8160": {
                    "label": "Food and related products machine operators"
                },
                "8171": {
                    "label": "Pulp and papermaking plant operators"
                },
                "8172": {
                    "label": "Wood processing plant operators"
                },
                "8181": {
                    "label": "Glass and ceramics plant operators"
                },
                "8182": {
                    "label": "Steam engine and boiler operators"
                },
                "8183": {
                    "label": "Packing, bottling and labelling machine operators"
                },
                "8189": {
                    "label": "Stationary plant and machine operators not elsewhere classified"
                },
                "8211": {
                    "label": "Mechanical machinery assemblers"
                },
                "8212": {
                    "label": "Electrical and electronic equipment assemblers"
                },
                "8219": {
                    "label": "Assemblers not elsewhere classified"
                },
                "8311": {
                    "label": "Locomotive engine drivers"
                },
                "8312": {
                    "label": "Railway brake, signal and switch operators"
                },
                "8321": {
                    "label": "Motorcycle drivers"
                },
                "8322": {
                    "label": "Car, taxi and van drivers"
                },
                "8331": {
                    "label": "Bus and tram drivers"
                },
                "8332": {
                    "label": "Heavy truck and lorry drivers"
                },
                "8341": {
                    "label": "Mobile farm and forestry plant operators"
                },
                "8342": {
                    "label": "Earthmoving and related plant operators"
                },
                "8343": {
                    "label": "Crane, hoist and related plant operators"
                },
                "8344": {
                    "label": "Lifting truck operators"
                },
                "8350": {
                    "label": "Ships' deck crews and related workers"
                },
                "9111": {
                    "label": "Domestic cleaners and helpers"
                },
                "9112": {
                    "label": "Cleaners and helpers in offices, hotels and other establishments"
                },
                "9121": {
                    "label": "Hand launderers and pressers"
                },
                "9122": {
                    "label": "Vehicle cleaners"
                },
                "9123": {
                    "label": "Window cleaners"
                },
                "9129": {
                    "label": "Other cleaning workers"
                },
                "9211": {
                    "label": "Crop farm labourers"
                },
                "9212": {
                    "label": "Livestock farm labourers"
                },
                "9213": {
                    "label": "Mixed crop and livestock farm labourers"
                },
                "9214": {
                    "label": "Garden and horticultural labourers"
                },
                "9215": {
                    "label": "Forestry labourers"
                },
                "9216": {
                    "label": "Fishery and aquaculture labourers"
                },
                "9311": {
                    "label": "Mining and quarrying labourers"
                },
                "9312": {
                    "label": "Civil engineering labourers"
                },
                "9313": {
                    "label": "Building construction labourers"
                },
                "9321": {
                    "label": "Hand packers"
                },
                "9329": {
                    "label": "Manufacturing labourers not elsewhere classified"
                },
                "9331": {
                    "label": "Hand and pedal vehicle drivers"
                },
                "9332": {
                    "label": "Drivers of animal-drawn vehicles and machinery"
                },
                "9333": {
                    "label": "Freight handlers"
                },
                "9334": {
                    "label": "Shelf fillers"
                },
                "9411": {
                    "label": "Fast food preparers"
                },
                "9412": {
                    "label": "Kitchen helpers"
                },
                "9510": {
                    "label": "Street and related service workers"
                },
                "9520": {
                    "label": "Street vendors (excluding food)"
                },
                "9611": {
                    "label": "Garbage and recycling collectors"
                },
                "9612": {
                    "label": "Refuse sorters"
                },
                "9613": {
                    "label": "Sweepers and related labourers"
                },
                "9621": {
                    "label": "Messengers, package deliverers and luggage porters"
                },
                "9622": {
                    "label": "Odd job persons"
                },
                "9623": {
                    "label": "Meter readers and vending-machine collectors"
                },
                "9624": {
                    "label": "Water and firewood collectors"
                },
                "9629": {
                    "label": "Elementary workers not elsewhere classified"
                },
                "11121": {
                    "label": "Senior central government officials"
                },
                "11122": {
                    "label": "Senior district and local government officials and senior officials"
                },
                "11141": {
                    "label": "Senior officials of employers', workers' and other economic-interest organisations"
                },
                "11142": {
                    "label": "Senior officials of humanitarian and other special-interest organisations"
                },
                "21321": {
                    "label": "Agronomists and fishery professionals"
                },
                "21322": {
                    "label": "Forestry professionals"
                },
                "21531": {
                    "label": "Telecommunications researchers"
                },
                "21532": {
                    "label": "Information technology researchers"
                },
                "22121": {
                    "label": "Senior physicians"
                },
                "22122": {
                    "label": "Specialists"
                },
                "22211": {
                    "label": "Matrons"
                },
                "22212": {
                    "label": "Ward sisters"
                },
                "23101": {
                    "label": "Professors"
                },
                "23102": {
                    "label": "Lecturers and senior assistants (university)"
                },
                "23103": {
                    "label": "Assistants and part-time lecturers (university)"
                },
                "23104": {
                    "label": "Head teachers (polytechnics)"
                },
                "23105": {
                    "label": "Lecturers (polytechnics)"
                },
                "23106": {
                    "label": "Part-time lecturers, etc. (polytechnics)"
                },
                "23301": {
                    "label": "Teachers in mathematical subjects"
                },
                "23302": {
                    "label": "Native language and literature teachers"
                },
                "23303": {
                    "label": "Crafts and art teachers"
                },
                "23304": {
                    "label": "Other secondary education teaching professionals"
                },
                "23411": {
                    "label": "Class teachers in primary education"
                },
                "23412": {
                    "label": "Subject teachers in primary education"
                },
                "23591": {
                    "label": "Career counsellors"
                },
                "23592": {
                    "label": "Other teaching professionals"
                },
                "26211": {
                    "label": "Archivists"
                },
                "26212": {
                    "label": "Curators"
                },
                "26351": {
                    "label": "Social workers, etc."
                },
                "26352": {
                    "label": "Social planners, etc."
                },
                "26421": {
                    "label": "Managing editors and subeditors"
                },
                "26422": {
                    "label": "Journalists"
                },
                "26423": {
                    "label": "Radio and television journalists"
                },
                "31121": {
                    "label": "Building construction technicians"
                },
                "31122": {
                    "label": "Civil engineering technicians"
                },
                "31123": {
                    "label": "Cartographic and surveying technicians"
                },
                "31521": {
                    "label": "Large ships' officers and mates"
                },
                "31522": {
                    "label": "Small ships' officers"
                },
                "31523": {
                    "label": "Harbour traffic controllers and harbour masters"
                },
                "32141": {
                    "label": "Dental technicians"
                },
                "32142": {
                    "label": "Prosthetist-orthotists"
                },
                "32211": {
                    "label": "Nurses"
                },
                "32212": {
                    "label": "Public health nurses"
                },
                "32591": {
                    "label": "Occupational therapists"
                },
                "32592": {
                    "label": "Other therapists"
                },
                "33341": {
                    "label": "Estate agents"
                },
                "33342": {
                    "label": "Property managers"
                },
                "34111": {
                    "label": "Legal and related business associate professionals"
                },
                "34112": {
                    "label": "Agents, officials and other organisation associate professionals"
                },
                "34113": {
                    "label": "Consumer advisers, etc."
                },
                "34121": {
                    "label": "Social instructors"
                },
                "34122": {
                    "label": "Youth leaders (not parishes)"
                },
                "34123": {
                    "label": "Work and craft leaders"
                },
                "34131": {
                    "label": "Deacons and deaconesses"
                },
                "34139": {
                    "label": "Other religious associate professionals"
                },
                "34351": {
                    "label": "Producer's assistants and other stagecraft associate professionals"
                },
                "34359": {
                    "label": "Other artistic and cultural associate professionals"
                },
                "42291": {
                    "label": "Emergency officers"
                },
                "42299": {
                    "label": "Other client information clerks not elsewhere classified"
                },
                "43231": {
                    "label": "Rail traffic controllers, traffic co-ordinators, etc."
                },
                "43239": {
                    "label": "Other transport clerks"
                },
                "44121": {
                    "label": "Mail carriers"
                },
                "44122": {
                    "label": "Porters"
                },
                "51201": {
                    "label": "Cooks"
                },
                "51202": {
                    "label": "Restaurant services supervisors and shift managers"
                },
                "51631": {
                    "label": "Undertakers and related funeral workers"
                },
                "51632": {
                    "label": "Other funeral workers"
                },
                "53111": {
                    "label": "Childminders in kindergartens and other institutions"
                },
                "53112": {
                    "label": "Private childminders"
                },
                "53113": {
                    "label": "Children's club leaders"
                },
                "53211": {
                    "label": "Practical mental nurses"
                },
                "53212": {
                    "label": "Mental handicap nurses"
                },
                "53213": {
                    "label": "Social work assistants"
                },
                "53219": {
                    "label": "Other practical nurses"
                },
                "53221": {
                    "label": "Household service workers"
                },
                "53222": {
                    "label": "Personal care workers, family carers, etc."
                },
                "53291": {
                    "label": "Dental assistants"
                },
                "53292": {
                    "label": "Equipment maintenance assistants"
                },
                "53293": {
                    "label": "Pharmaceutical assistants"
                },
                "53294": {
                    "label": "Massage therapists and practical rehabilitation nurses"
                },
                "61111": {
                    "label": "Crop growers"
                },
                "61112": {
                    "label": "Field crop supervisors and workers"
                },
                "61131": {
                    "label": "Gardeners, horticultural and nursery growers"
                },
                "61132": {
                    "label": "Gardeners, horticultural and nursery growers and workers"
                },
                "61211": {
                    "label": "Dairy and livestock producers"
                },
                "61212": {
                    "label": "Dairy and livestock workers"
                },
                "61213": {
                    "label": "Pet producers"
                },
                "61214": {
                    "label": "Farm relief workers"
                },
                "61291": {
                    "label": "Fur and reindeer producers"
                },
                "61299": {
                    "label": "Animal workers not elsewhere classified"
                },
                "62211": {
                    "label": "Fish farmers"
                },
                "62212": {
                    "label": "Fishery supervisors and workers"
                },
                "74211": {
                    "label": "Electronics installers and repairers"
                },
                "74212": {
                    "label": "Automation installers and repairers"
                },
                "81821": {
                    "label": "Power-production and waste treatment plant workers"
                },
                "81822": {
                    "label": "Other plant workers, etc."
                },
                "83441": {
                    "label": "Stevedores"
                },
                "83442": {
                    "label": "Lifting-truck operators, etc."
                },
                "91121": {
                    "label": "Office cleaners, etc."
                },
                "91122": {
                    "label": "Hotel cleaners"
                },
                "91123": {
                    "label": "Hospital and institutional helpers"
                },
                "91124": {
                    "label": "Kindergarten assistants"
                },
                "91129": {
                    "label": "Other cleaners not elsewhere classified"
                },
                "01": {
                    "label": "Commissioned armed forces officers"
                },
                "011": {
                    "label": "Commissioned armed forces officers"
                },
                "0110": {
                    "label": "Commissioned armed forces officers"
                },
                "02": {
                    "label": "Non-commissioned armed forces officers"
                },
                "021": {
                    "label": "Non-commissioned armed forces officers"
                },
                "0210": {
                    "label": "Non-commissioned armed forces officers"
                },
                "03": {
                    "label": "Armed forces occupations, other ranks"
                },
                "031": {
                    "label": "Armded forces occupations, other ranks"
                },
                "0310": {
                    "label": "Armed forces occupations, other ranks"
                },
                "#X": {
                    "label": "Unknown"
                },
                "#XX": {
                    "label": "Unknown"
                },
                "#XXX": {
                    "label": "Unknown"
                },
                "#XXXX": {
                    "label": "Unknown"
                },
                "#XXXXX": {
                    "label": "Unknown"
                }
            },
            "ReportCategory": {
                "all": {
                    "description": "",
                    "label": ""
                },
                "monthly": {
                    "description": "",
                    "label": ""
                },
                "yearly": {
                    "description": "",
                    "label": ""
                }
            },
            "ReportType": {
                "employerReport": {
                    "description": "",
                    "label": "Employer Report"
                },
                "employmentContract": {
                    "description": "",
                    "label": "Employment Contract"
                },
                "example": {
                    "description": "",
                    "label": "Example"
                },
                "householdDeduction": {
                    "description": "",
                    "label": "Household Deduction"
                },
                "insurance": {
                    "description": "",
                    "label": "Insurance"
                },
                "monthlyDetails": {
                    "description": "",
                    "label": "Monthly Details"
                },
                "monthlyLiikekirjuri": {
                    "description": "",
                    "label": "Monthly Liikekirjuri"
                },
                "monthlyPension": {
                    "description": "",
                    "label": "Monthly Pension"
                },
                "monthlyRapko": {
                    "description": "",
                    "label": "Monthly Rapko"
                },
                "paymentReport": {
                    "description": "",
                    "label": "Payment Report"
                },
                "salarySlip": {
                    "description": "",
                    "label": "Salary Slip"
                },
                "salarySlipPaid": {
                    "description": "",
                    "label": "Salary Slip Paid"
                },
                "taxHouseholdDeduction14B": {
                    "description": "",
                    "label": "Tax Household Deduction14B"
                },
                "taxHouseholdDeduction14BSpouseA": {
                    "description": "",
                    "label": "Tax Household Deduction14BSpouse A"
                },
                "taxHouseholdDeduction14BSpouseB": {
                    "description": "",
                    "label": "Tax Household Deduction14BSpouse B"
                },
                "taxMonthly4001": {
                    "description": "",
                    "label": "Tax Monthly4001"
                },
                "taxYearly7801": {
                    "description": "",
                    "label": "Tax Yearly7801"
                },
                "undefined": {
                    "description": "",
                    "label": "Undefined"
                },
                "unemployment": {
                    "description": "",
                    "label": "Unemployment"
                },
                "yearEndReport": {
                    "description": "",
                    "label": "Year End Report"
                },
                "yearlyDetails": {
                    "description": "",
                    "label": "Yearly Details"
                },
                "yearlyWorkerSummary": {
                    "description": "",
                    "label": "Yearly Worker Summary"
                }
            },
            "SalaryKind": {
                "compensation": {
                    "description": "",
                    "label": "Compensation"
                },
                "fixedSalary": {
                    "description": "",
                    "label": "Fixed Salary"
                },
                "hourlySalary": {
                    "description": "",
                    "label": "Hourly Salary"
                },
                "monthlySalary": {
                    "description": "",
                    "label": "Monthly Salary"
                },
                "totalEmployerPayment": {
                    "description": "",
                    "label": "Total Employer Payment"
                },
                "totalWorkerPayment": {
                    "description": "",
                    "label": "Total Worker Payment"
                },
                "undefined": {
                    "description": "",
                    "label": "Undefined"
                }
            },
            "SalaryPeriod": {
                "fixed": {
                    "description": "",
                    "label": ""
                },
                "hourly": {
                    "description": "",
                    "label": ""
                },
                "monthly": {
                    "description": "",
                    "label": ""
                },
                "notDefined": {
                    "description": "",
                    "label": ""
                }
            },
            "SalaryPerMonthRange": {
                "noPensionRequired": {
                    "description": "",
                    "label": "Under 57,10 €"
                },
                "normal": {
                    "description": "",
                    "label": "57,10 € or over"
                },
                "unknown": {
                    "description": "",
                    "label": "Unknown"
                }
            },
            "SalaryPerYearRange": {
                "noMonthlyReporting": {
                    "description": "",
                    "label": "202 - 1500 €"
                },
                "noReportingNecessary": {
                    "description": "",
                    "label": "2 - 200 €"
                },
                "normal": {
                    "description": "",
                    "label": "Over 1500 €"
                },
                "zeroSalary": {
                    "description": "",
                    "label": 1
                }
            },
            "TaxCardIncomeType": {
                "externalSalaries": {
                    "description": "",
                    "label": "External Salaries"
                },
                "previousEmployerSalaries": {
                    "description": "Salaries earned earlier under this year. Mark them here as one total sum in euros.",
                    "label": "Salary paid by former employers"
                },
                "salaxyCalculation": {
                    "description": "",
                    "label": "Salaxy Calculation"
                },
                "unknown": {
                    "description": "",
                    "label": "Unknown"
                }
            },
            "TaxCardState": {
                "approved": {
                    "description": "",
                    "label": "Accepted"
                },
                "new": {
                    "description": "",
                    "label": "New"
                },
                "rejected": {
                    "description": "",
                    "label": "Rejected"
                },
                "waiting": {
                    "description": "",
                    "label": "Pending"
                }
            },
            "TaxCardType": {
                "example": {
                    "description": "",
                    "label": "Example of tax card"
                },
                "freelancer": {
                    "description": "",
                    "label": "Freelancer"
                },
                "noTaxCard": {
                    "description": "",
                    "label": "No tax card"
                },
                "noTaxPrepayment": {
                    "description": "",
                    "label": "No withholding tax"
                },
                "others": {
                    "description": "",
                    "label": "Other"
                },
                "sideIncome": {
                    "description": "",
                    "label": "Secondary income"
                },
                "steps": {
                    "description": "",
                    "label": ""
                },
                "taxCardA": {
                    "description": "",
                    "label": "A"
                },
                "taxCardB": {
                    "description": "",
                    "label": "B"
                }
            },
            "TaxDeductionWorkCategories": {
                "carework": {
                    "description": "",
                    "label": "Nursing and care work"
                },
                "homeImprovement": {
                    "description": "",
                    "label": "Home improvement work"
                },
                "householdwork": {
                    "description": "",
                    "label": "Household work"
                },
                "none": {
                    "description": "",
                    "label": "Choose…"
                },
                "ownPropety": {
                    "description": "",
                    "label": "Leisure home in own use"
                },
                "relativesProperty": {
                    "description": "",
                    "label": "Leisure home of parents or relatives"
                }
            },
            "TesSubtype": {
                "constructionCarpenter": {
                    "description": "",
                    "label": ""
                },
                "constructionFloor": {
                    "description": "",
                    "label": ""
                },
                "constructionFreeContract": {
                    "description": "",
                    "label": ""
                },
                "constructionOther": {
                    "description": "",
                    "label": ""
                },
                "notSelected": {
                    "description": "",
                    "label": ""
                }
            },
            "TestEnum": {
                "valueEight": {
                    "description": "",
                    "label": ""
                },
                "valueFive": {
                    "description": "",
                    "label": ""
                },
                "valueFour": {
                    "description": "",
                    "label": ""
                },
                "valueNine": {
                    "description": "",
                    "label": ""
                },
                "valueOne": {
                    "description": "",
                    "label": ""
                },
                "valueSevdescription": "",
                "valueSevlabel": "",
                "valueSix": {
                    "description": "",
                    "label": ""
                },
                "valueTdescription": "",
                "valueThree": {
                    "description": "",
                    "label": ""
                },
                "valueTlabel": "",
                "valueTwo": {
                    "description": "",
                    "label": ""
                },
                "valueZero": {
                    "description": "",
                    "label": ""
                }
            },
            "UnionPaymentType": {
                "notSelected": {
                    "description": "",
                    "label": "No membership"
                },
                "other": {
                    "description": "",
                    "label": "Other union"
                },
                "raksaNormal": {
                    "description": "",
                    "label": ""
                },
                "raksaUnemploymentOnly": {
                    "description": "",
                    "label": ""
                }
            },
            "WebSiteUserRole": {
                "company": {
                    "description": "",
                    "label": "Entrepreneur"
                },
                "household": {
                    "description": "",
                    "label": "Employer"
                },
                "none": {
                    "description": "",
                    "label": "Choose…"
                },
                "worker": {
                    "description": "",
                    "label": "Employee"
                }
            },
            "YtjCompanyType": {
                "alandFederation": {
                    "description": "",
                    "label": "Ålandian enterprise"
                },
                "asoAssociation": {
                    "description": "",
                    "label": "Housing right association"
                },
                "association": {
                    "description": "",
                    "label": "Non-profit association"
                },
                "condominium": {
                    "description": "",
                    "label": "Housing company"
                },
                "cooperativeBank": {
                    "description": "",
                    "label": "Bank cooperative"
                },
                "europeanCooperative": {
                    "description": "",
                    "label": "European cooperative"
                },
                "europeanCooperativeBank": {
                    "description": "",
                    "label": "European bank cooperative"
                },
                "federationOfMunicipalitiesEstablishment": {
                    "description": "",
                    "label": "Federal enterprise"
                },
                "financialAssociation": {
                    "description": "",
                    "label": "Financial association"
                },
                "forestCareAssociation": {
                    "description": "",
                    "label": "Forestry association"
                },
                "foundation": {
                    "description": "",
                    "label": "Foundation"
                },
                "housingCooperative": {
                    "description": "",
                    "label": "Housing cooperative"
                },
                "hypoAssociation": {
                    "description": "",
                    "label": "Mortgage society"
                },
                "insuranceAssociation": {
                    "description": "",
                    "label": "Insurance association"
                },
                "ky": {
                    "description": "",
                    "label": "Limited partnership"
                },
                "municipalEstablishment": {
                    "description": "",
                    "label": "Municipial enterprise"
                },
                "mutualInsuranceAssociation": {
                    "description": "",
                    "label": "Mutual insurance association"
                },
                "noCompanyType": {
                    "description": "",
                    "label": "No company form"
                },
                "openCompany": {
                    "description": "",
                    "label": "Open company"
                },
                "osuuskunta": {
                    "description": "",
                    "label": "Cooperative"
                },
                "otherAssociation": {
                    "description": "",
                    "label": "Other association"
                },
                "otherFinancialAssociation": {
                    "description": "",
                    "label": "Other financial association"
                },
                "oy": {
                    "description": "",
                    "label": "Limited company"
                },
                "privateEntrepreneur": {
                    "description": "",
                    "label": "Private trader, trade name"
                },
                "reindeerHerdingCooperative": {
                    "description": "",
                    "label": "Reindeer grazing association"
                },
                "savingsBank": {
                    "description": "",
                    "label": "Savings bank"
                },
                "specialPurposeAssociation": {
                    "description": "",
                    "label": "Association based on special legislation"
                },
                "stateEstablishment": {
                    "description": "",
                    "label": "State-owned enterprise"
                },
                "unknown": {
                    "description": "",
                    "label": "Unknown company form"
                }
            },
            "TaxcardKind": {
                "undefined": {
                    "label": ""
                },
                "noTaxCard": {
                    "label": ""
                },
                "defaultYearly": {
                    "label": ""
                },
                "replacement": {
                    "label": ""
                },
                "others": {
                    "label": ""
                },
                "historical": {
                    "label": ""
                }
            },
            "CarBenefitCode": {
                "limitedCarBenefit": {
                    "label": ""
                },
                "fullCarBenefit": {
                    "label": ""
                }
            },
            "AgeGroupCode": {
                "a": {
                    "label": ""
                },
                "b": {
                    "label": ""
                },
                "c": {
                    "label": ""
                },
                "u": {
                    "label": ""
                }
            },
            "AllowanceCode": {
                "mealAllowance": {
                    "label": ""
                },
                "partialDailyAllowance": {
                    "label": ""
                },
                "fullDailyAllowance": {
                    "label": ""
                },
                "internationalDailyAllowance": {
                    "label": ""
                },
                "expensesWorkingAbroad": {
                    "label": ""
                }
            },
            "BoardKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                }
            },
            "IrFlags": {
                "noMoney": {
                    "label": ""
                },
                "oneOff": {
                    "label": ""
                },
                "unjustEnrichment": {
                    "label": ""
                }
            },
            "CalculationFlag": {
                "exclude": {
                    "label": ""
                },
                "pensionInsurance": {
                    "label": ""
                },
                "accidentInsurance": {
                    "label": ""
                },
                "unemploymentInsurance": {
                    "label": ""
                },
                "healthInsurance": {
                    "label": ""
                },
                "noTax": {
                    "label": ""
                },
                "tax": {
                    "label": ""
                },
                "taxDeduction": {
                    "label": ""
                },
                "cfNoPayment": {
                    "label": ""
                },
                "cfPayment": {
                    "label": ""
                },
                "cfDeduction": {
                    "label": ""
                },
                "cfDeductionAtSalaxy": {
                    "label": ""
                }
            },
            "IrInsuranceExceptions": {
                "includeAll": {
                    "label": ""
                },
                "includePension": {
                    "label": ""
                },
                "includeHealthInsurance": {
                    "label": ""
                },
                "includeUnemployment": {
                    "label": ""
                },
                "includeAccidentInsurance": {
                    "label": ""
                },
                "excludeAll": {
                    "label": ""
                },
                "excludePension": {
                    "label": ""
                },
                "excludeHealthInsurance": {
                    "label": ""
                },
                "excludeUnemployment": {
                    "label": ""
                },
                "excludeAccidentInsurance": {
                    "label": ""
                }
            },
            "UnionPaymentKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "raksaNormal": {
                    "label": "",
                    "description": ""
                },
                "raksaUnemploymentOnly": {
                    "label": "",
                    "description": ""
                },
                "other": {
                    "label": "",
                    "description": ""
                }
            },
            "SubsidisedCommuteKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "noDeduction": {
                    "label": "",
                    "description": ""
                },
                "singleDeduction": {
                    "label": "",
                    "description": ""
                },
                "periodicalDeduction": {
                    "label": "",
                    "description": ""
                }
            },
            "NonProfitOrgKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "kilometreAllowance": {
                    "label": "",
                    "description": ""
                },
                "dailyAllowance": {
                    "label": "",
                    "description": ""
                },
                "accomodationAllowance": {
                    "label": "",
                    "description": ""
                }
            },
            "MealBenefitKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "cateringContract": {
                    "label": "",
                    "description": ""
                },
                "mealTicket": {
                    "label": "",
                    "description": ""
                },
                "taxableAmount": {
                    "label": "",
                    "description": ""
                },
                "mealAllowance": {
                    "label": "",
                    "description": ""
                },
                "institute": {
                    "label": "",
                    "description": ""
                },
                "teacher": {
                    "label": "",
                    "description": ""
                },
                "restaurantWorker": {
                    "label": "",
                    "description": ""
                }
            },
            "DailyAllowanceKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "fullDailyAllowance": {
                    "label": "",
                    "description": ""
                },
                "partialDailyAllowance": {
                    "label": "",
                    "description": ""
                },
                "internationalDailyAllowance": {
                    "label": "",
                    "description": ""
                },
                "mealAllowance": {
                    "label": "",
                    "description": ""
                }
            },
            "CarBenefitKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "limitedCarBenefit": {
                    "label": "",
                    "description": ""
                },
                "fullCarBenefit": {
                    "label": "",
                    "description": ""
                }
            },
            "EmploymentTerminationKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "noticePeriodCompensation": {
                    "label": "",
                    "description": ""
                },
                "monetaryWorkingTimeBankCompensation": {
                    "label": "",
                    "description": ""
                },
                "terminationAndLayOffDamages": {
                    "label": "",
                    "description": ""
                },
                "voluntaryTerminationCompensation": {
                    "label": "",
                    "description": ""
                },
                "pensionPaidByEmployer": {
                    "label": "",
                    "description": ""
                }
            },
            "IrIncomeTypeKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                }
            },
            "OtherCompensationKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "meetingFee": {
                    "label": "",
                    "description": ""
                },
                "lectureFee": {
                    "label": "",
                    "description": ""
                },
                "positionOfTrustCompensation": {
                    "label": "",
                    "description": ""
                },
                "accruedTimeOffCompensation": {
                    "label": "",
                    "description": ""
                },
                "membershipOfGoverningBodyCompensation": {
                    "label": "",
                    "description": ""
                },
                "monetaryGiftForEmployees": {
                    "label": "",
                    "description": ""
                },
                "useCompensationAsEarnedIncome": {
                    "label": "",
                    "description": ""
                },
                "useCompensationAsCapitalIncome": {
                    "label": "",
                    "description": ""
                },
                "otherTaxableIncomeAsEarnedIncome": {
                    "label": "",
                    "description": ""
                },
                "stockOptionsAndGrants": {
                    "label": "",
                    "description": ""
                },
                "employeeInventionCompensation": {
                    "label": "",
                    "description": ""
                },
                "capitalIncomePayment": {
                    "label": "",
                    "description": ""
                },
                "workEffortBasedDividendsAsWage": {
                    "label": "",
                    "description": ""
                },
                "workEffortBasedDividendsAsNonWage": {
                    "label": "",
                    "description": ""
                },
                "employeeStockOption": {
                    "label": "",
                    "description": ""
                },
                "employeeStockOptionWithLowerPrice": {
                    "label": "",
                    "description": ""
                }
            },
            "RemunerationKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "initiativeFee": {
                    "label": "",
                    "description": ""
                },
                "bonusPay": {
                    "label": "",
                    "description": ""
                },
                "commission": {
                    "label": "",
                    "description": ""
                },
                "performanceBonus": {
                    "label": "",
                    "description": ""
                },
                "shareIssueForEmployees": {
                    "label": "",
                    "description": ""
                },
                "profitSharingBonus": {
                    "label": "",
                    "description": ""
                }
            },
            "WorkingTimeCompensationKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "emergencyWorkCompensation": {
                    "label": "",
                    "description": ""
                },
                "eveningWorkCompensation": {
                    "label": "",
                    "description": ""
                },
                "eveningShiftAllowance": {
                    "label": "",
                    "description": ""
                },
                "saturdayPay": {
                    "label": "",
                    "description": ""
                },
                "extraWorkPremium": {
                    "label": "",
                    "description": ""
                },
                "otherCompensation": {
                    "label": "",
                    "description": ""
                },
                "waitingTimeCompensation": {
                    "label": "",
                    "description": ""
                },
                "sundayWorkCompensation": {
                    "label": "",
                    "description": ""
                },
                "standByCompensation": {
                    "label": "",
                    "description": ""
                },
                "weeklyRestCompensation": {
                    "label": "",
                    "description": ""
                },
                "overtimeCompensation": {
                    "label": "",
                    "description": ""
                },
                "nightWorkAllowance": {
                    "label": "",
                    "description": ""
                },
                "nightShiftCompensation": {
                    "label": "",
                    "description": ""
                }
            },
            "HolidayYearInitType": {
                "ignore": {
                    "label": ""
                },
                "createEmpty": {
                    "label": ""
                },
                "createMonths": {
                    "label": ""
                },
                "createFromCalcs": {
                    "label": ""
                }
            },
            "HolidayCode": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "permanent14Days": {
                    "label": "",
                    "description": ""
                },
                "permanent35Hours": {
                    "label": "",
                    "description": ""
                },
                "temporaryTimeOff": {
                    "label": "",
                    "description": ""
                },
                "holidayCompensation": {
                    "label": "",
                    "description": ""
                },
                "holidayCompensationIncluded": {
                    "label": "",
                    "description": ""
                },
                "noHolidays": {
                    "label": "",
                    "description": ""
                }
            },
            "HolidayAccrualKind": {
                "manual": {
                    "label": ""
                },
                "saldo": {
                    "label": ""
                },
                "calculation": {
                    "label": ""
                },
                "holiday": {
                    "label": ""
                },
                "holidayCompensated": {
                    "label": ""
                }
            },
            "AbsenceCauseCode": {
                "unpaidLeave": {
                    "label": ""
                },
                "personalReason": {
                    "label": ""
                },
                "illness": {
                    "label": "Illness"
                },
                "partTimeSickLeave": {
                    "label": "Part-time sick leave"
                },
                "parentalLeave": {
                    "label": "Maternity, paternity and parental leave"
                },
                "specialMaternityLeave": {
                    "label": "Special maternity leave"
                },
                "rehabilitation": {
                    "label": "Rehabilitation"
                },
                "childIllness": {
                    "label": "Child's illness or a compelling family reason"
                },
                "partTimeChildCareLeave": {
                    "label": "Part-time child care leave"
                },
                "training": {
                    "label": "Training, education"
                },
                "jobAlternationLeave": {
                    "label": "Job alternation leave"
                },
                "studyLeave": {
                    "label": "Study leave"
                },
                "industrialAction": {
                    "label": "Industrial action or lock-out"
                },
                "interruptionInWorkProvision": {
                    "label": "Interruption in work provision"
                },
                "leaveOfAbsence": {
                    "label": "Leave of absence"
                },
                "militaryRefresherTraining": {
                    "label": "Military refresher training"
                },
                "militaryService": {
                    "label": "Military or non-military service"
                },
                "layOff": {
                    "label": "Lay-off"
                },
                "childCareLeave": {
                    "label": "Child care leave"
                },
                "midWeekHoliday": {
                    "label": "Mid-week holiday"
                },
                "accruedHoliday": {
                    "label": "Accrued holiday"
                },
                "occupationalAccident": {
                    "label": "Occupational accident"
                },
                "annualLeave": {
                    "label": "Annual leave"
                },
                "partTimeAbsenceDueToRehabilitation": {
                    "label": "Part-time absence due to rehabilitation"
                },
                "other": {
                    "label": "Other"
                }
            },
            "AnnualLeavePaymentKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "manualSalary": {
                    "label": "",
                    "description": ""
                },
                "manualCompensation": {
                    "label": "",
                    "description": ""
                },
                "manualBonus": {
                    "label": "",
                    "description": ""
                },
                "paidCalc": {
                    "label": "",
                    "description": ""
                },
                "draftCalc": {
                    "label": "",
                    "description": ""
                },
                "info": {
                    "label": "",
                    "description": ""
                },
                "startSaldo": {
                    "label": "",
                    "description": ""
                },
                "endSaldo": {
                    "label": "",
                    "description": ""
                },
                "total": {
                    "label": "",
                    "description": ""
                }
            },
            "HolidayBonusPaymentMethod": {
                "none": {
                    "label": ""
                },
                "payForHolidaySalary": {
                    "label": ""
                },
                "paySummerBonus": {
                    "label": ""
                },
                "pay24Days": {
                    "label": ""
                },
                "payAllBonus": {
                    "label": ""
                }
            },
            "PeriodType": {
                "month": {
                    "label": ""
                },
                "quarter": {
                    "label": ""
                },
                "year": {
                    "label": ""
                },
                "custom": {
                    "label": ""
                }
            },
            "PricingModel": {
                "palkkausFee": {
                    "label": ""
                },
                "noFee": {
                    "label": ""
                },
                "fixedFee": {
                    "label": ""
                }
            },
            "ServiceModel": {
                "shared": {
                    "label": ""
                },
                "partnerOnly": {
                    "label": ""
                }
            },
            "WageBasis": {
                "undefined": {
                    "label": ""
                },
                "monthly": {
                    "label": ""
                },
                "hourly": {
                    "label": ""
                },
                "performanceBased": {
                    "label": ""
                },
                "other": {
                    "label": ""
                }
            }
        },
        "UI_TERMS": {
            "add": "Add",
            "addNew": "Add new",
            "addRow": "Add row",
            "areYouSure": "Are you sure?",
            "back": "Back",
            "calculate": "Calculate",
            "calculations": "Calculations",
            "cancel": "Cancel",
            "cancelEditing": "Cancel editing",
            "choose": "Choose…",
            "orChoose": "",
            "chooseWorkDateRange": "",
            "chooseWorkDuration": "",
            "clear": "Clear",
            "close": "Close",
            "confirm": "Confirm",
            "copy": "Copy",
            "copyToClipboard": "",
            "copyAsNew": "Copy as new",
            "copyAsRequest": "Copy as Request",
            "dateNotChosen": "date has not been chosen",
            "delete": "Delete",
            "demo": "DEMO",
            "dismiss": "Dismiss",
            "done": "Done",
            "edit": "Edit",
            "gotIt": "Got it",
            "isDeleting": "Deleting...",
            "isSaving": "Saving...",
            "learnMore": "Learn more",
            "login": "Log in",
            "logout": "Log out",
            "logoutAlt": "End current session",
            "minCharacters": "Start with at least 3 letters...",
            "moreInfo": "More info",
            "navigation": "Navigation",
            "newCalculation": "New calculation",
            "previous": "Previous",
            "next": "Next",
            "no": "No",
            "noteRequiredField": "* Required Field",
            "noThanks": "No thanks",
            "ok": "OK",
            "oldVersion": "old version",
            "pay": "Pay",
            "pleaseWait": "Please wait...",
            "postpone": "Not now",
            "printable": "Printable",
            "recalculate": "Recalculate",
            "register": "Register",
            "save": "Save",
            "saveEdited": "Save changes",
            "makeOrder": "",
            "search": "Search...",
            "searchByName": "Search by name...",
            "select": "Select",
            "selectAlt": "Select...",
            "sendEmail": "Send an email",
            "show": "Show",
            "skip": "Skip",
            "sureToDeleteRecord": "Are you sure to delete this record.",
            "today": "Today",
            "updateCalculation": "Update calculation",
            "updatingCalculation": "Updating calculation...",
            "use": "",
            "yes": "Yes",
            "dateFormats": {
                "dm": "d.m."
            },
            "loading": "Loading...",
            "monthShort0": "Dec",
            "monthShort1": "Jan",
            "monthShort2": "Feb",
            "monthShort3": "Mar",
            "monthShort4": "Apr",
            "monthShort5": "May",
            "monthShort6": "Jun",
            "monthShort7": "Jul",
            "monthShort8": "Aug",
            "monthShort9": "Sep",
            "monthShort10": "Oct",
            "monthShort11": "Nov",
            "monthShort12": "Dec",
            "week2": "2 weeks",
            "monthHalf": "Half a month",
            "otherPeriod": "Other period"
        },
        "VALIDATION": {
            "IncompleteAdvancePayment": {
                "label": "",
                "description": ""
            },
            "IncompletePensionPayment": {
                "label": "",
                "description": ""
            },
            "IncompleteUnemploymentInsurancePayment": {
                "label": "",
                "description": ""
            },
            "IncompleteUnionPayment": {
                "label": "",
                "description": ""
            },
            "IncompleteOtherDeductions": {
                "label": "",
                "description": ""
            },
            "IncompletePrepaidExpenses": {
                "label": "",
                "description": ""
            },
            "MissingOccupationCode": {
                "label": "",
                "description": ""
            },
            "IllegalWorkerForCompanyType": {
                "label": "",
                "description": ""
            },
            "NegativeRowTotalNotSupported": {
                "label": "",
                "description": ""
            },
            "ValidationErrors": {
                "sxyEmail": "",
                "sxyMobilePhone": "",
                "minlength": "",
                "maxlength": "",
                "sxyIban": "",
                "sxyTaxPercent": "",
                "sxyCurrency": "",
                "sxyPersonalIdFi": "",
                "sxyCompanyIdFi": "",
                "sxyPostalCodeFi": "",
                "sxySmsVerificationCode": "",
                "sxyNumber": "",
                "sxyInteger": "",
                "sxyPensionContractNumber": "",
                "sxyTemporaryPensionContractNumber": "",
                "required": ""
            },
            "Payroll": {
                "NoCalculations": {
                    "label": ""
                },
                "Calc": {
                    "TotalGreaterThan0": {
                        "label": ""
                    },
                    "FirstNameNotEmpty": {
                        "label": ""
                    },
                    "LastNameNotEmpty": {
                        "label": ""
                    },
                    "SocialSecurityNumber": {
                        "label": ""
                    },
                    "SocialSecurityNumber_InTest": {
                        "label": ""
                    },
                    "IbanNotEmpty": {
                        "label": ""
                    },
                    "IbanInvalid": {
                        "label": ""
                    },
                    "EmailAddress": {
                        "label": ""
                    },
                    "TelephoneOrEmailNotEmpty": {
                        "label": ""
                    },
                    "TaxCardType": {
                        "label": ""
                    },
                    "TaxPercent": {
                        "label": ""
                    },
                    "PayrollIdConflict": {
                        "label": ""
                    },
                    "InvalidStatusForPayroll": {
                        "label": ""
                    }
                }
            },
            "Files": {
                "MaxFileSize": "",
                "Empty": "",
                "NoFiles": "",
                "SaveError": "",
                "ContentTypeError": ""
            }
        }
    },
    "": [
        "",
        "",
        "",
        "",
        "",
        ""
    ]
};
_dictionary["fi"] = {
    "SALAXY": {
        "ENUM": {
            "AbcSection": {
                "association": {
                    "description": "",
                    "label": "Yhdistyksille"
                },
                "blog": {
                    "description": "",
                    "label": "Blogi"
                },
                "businessOwner": {
                    "description": "",
                    "label": "Yrittäjä"
                },
                "documentTemplates": {
                    "description": "",
                    "label": "Dokumenttipohjat ja lomakkeet"
                },
                "doNotShow": {
                    "description": "",
                    "label": "Ei näytetä käyttäjälle (vain Admin)"
                },
                "employee": {
                    "description": "",
                    "label": "Työntekijä"
                },
                "employment": {
                    "description": "",
                    "label": "Työsuhde ja työsopimus"
                },
                "entrepreneur": {
                    "description": "",
                    "label": "Yritys tai yhteisö"
                },
                "examples": {
                    "description": "",
                    "label": "Esimerkkejä palkkaustilanteista"
                },
                "householdEmployer": {
                    "description": "",
                    "label": "Kotitalous"
                },
                "instructionsAndExamples": {
                    "description": "",
                    "label": "Käyttöohjeet"
                },
                "insurance": {
                    "description": "",
                    "label": "Vakuutukset ja eläke"
                },
                "palkkausGeneral": {
                    "description": "",
                    "label": "Tietoa Palkkaus.fi -palvelusta"
                },
                "palkkausInstructions": {
                    "description": "",
                    "label": "Käyttöohjeita"
                },
                "personEmployer": {
                    "description": "",
                    "label": "Kotitalous työnantajana"
                },
                "press": {
                    "description": "",
                    "label": "Tiedotteet ja materiaali"
                },
                "productLongDescription": {
                    "description": "",
                    "label": "Tuotekuvaus"
                },
                "salary": {
                    "description": "",
                    "label": "Palkanlaskenta ja palkanmaksu"
                },
                "undefined": {
                    "description": "",
                    "label": "Uudet artikkelit / ei määritetty"
                },
                "worker": {
                    "description": "",
                    "label": "Työntekijälle"
                }
            },
            "AgeRange": {
                "age_15": {
                    "description": "",
                    "label": "-15v"
                },
                "age16": {
                    "description": "",
                    "label": "16v"
                },
                "age17": {
                    "description": "",
                    "label": "17v"
                },
                "age18_52": {
                    "description": "",
                    "label": "18-52v"
                },
                "age53_62": {
                    "description": "",
                    "label": "53-62v"
                },
                "age63_64": {
                    "description": "",
                    "label": "63-64v"
                },
                "age65_67": {
                    "description": "",
                    "label": "65-67v"
                },
                "age68AndOVer": {
                    "description": "",
                    "label": "68v-"
                },
                "unknown": {
                    "description": "",
                    "label": "Ei tiedossa"
                }
            },
            "ApiTestErrorType": {
                "default": {
                    "description": "",
                    "label": "Oletus"
                },
                "userFriendly": {
                    "description": "",
                    "label": "User Friendly"
                }
            },
            "ApiValidationErrorType": {
                "general": {
                    "label": "Yleisvirhe"
                },
                "invalid": {
                    "label": "Virhe"
                },
                "required": {
                    "label": "Arvo puuttuu"
                },
                "warning": {
                    "label": "Varoitus"
                }
            },
            "AuthenticationMethod": {
                "auth0Database": {
                    "description": "",
                    "label": "Sähköpostitunnistus"
                },
                "emailPwdLocal": {
                    "description": "",
                    "label": "Tietokanta"
                },
                "facebook": {
                    "description": "",
                    "label": "Facebook -tili"
                },
                "google": {
                    "description": "",
                    "label": "Google / Gmail authentication"
                },
                "internalLocalhost": {
                    "description": "",
                    "label": ""
                },
                "linkedIn": {
                    "description": "",
                    "label": "LinkedIn authentication"
                },
                "microsoft": {
                    "description": "",
                    "label": "Microsoft -tili"
                },
                "salaxy": {
                    "description": "",
                    "label": ""
                },
                "test": {
                    "description": "",
                    "label": ""
                },
                "undefined": {
                    "description": "",
                    "label": "Tuntematon"
                },
                "x509": {
                    "description": "",
                    "label": ""
                }
            },
            "AuthorizationStatus": {
                "accessDenied": {
                    "description": "",
                    "label": "Pääsy kielletty"
                },
                "expiredOauthTokdescription": "",
                "expiredOauthToklabel": "Istunto vanheutunut",
                "invalidOAuthTokdescription": "",
                "invalidOAuthToklabel": "Virhe tunnistuksessa",
                "noOauthTokdescription": "",
                "noOauthToklabel": "Virhe tunnistuksessa (ei tokenia)",
                "oK": {
                    "description": "",
                    "label": "OK"
                },
                "undefined": {
                    "description": "",
                    "label": "Ei määritetty"
                }
            },
            "AuthorizationType": {
                "companyContract": {
                    "description": "",
                    "label": "Työnantajan sopimus"
                },
                "employerAuthorization": {
                    "description": "",
                    "label": "Valtakirja"
                },
                "manual": {
                    "description": "",
                    "label": "Valtakirja toimitettu erikseen"
                },
                "none": {
                    "description": "",
                    "label": "Ei tunnistettu"
                },
                "temporary": {
                    "description": "",
                    "label": "Temp tunnistus"
                },
                "workerContract": {
                    "description": "",
                    "label": "Työntekijän sopimus"
                }
            },
            "AvatarPictureType": {
                "gravatar": {
                    "description": "",
                    "label": "Gravatar"
                },
                "icon": {
                    "description": "",
                    "label": "Kuvake"
                },
                "uploaded": {
                    "description": "",
                    "label": "Kuva omalta koneelta"
                }
            },
            "BlobFileType": {
                "authorizationPdf": {
                    "description": "",
                    "label": "Valtakirja"
                },
                "avatar": {
                    "description": "",
                    "label": "Ikoni"
                },
                "calcReport": {
                    "description": "",
                    "label": ""
                },
                "expensesReceipt": {
                    "description": "",
                    "label": "Kulukuitti"
                },
                "monthlyReport": {
                    "description": "",
                    "label": "Kuukausiraportti"
                },
                "raksaloki": {
                    "description": "",
                    "label": "Kulukuitti"
                },
                "taxCard": {
                    "description": "",
                    "label": "Verokortti"
                },
                "template": {
                    "description": "",
                    "label": "Kaavain"
                },
                "unknown": {
                    "description": "",
                    "label": ""
                },
                "yearlyReport": {
                    "description": "",
                    "label": "Vuosiraportti"
                }
            },
            "BlobRepository": {
                "cdnImages": {
                    "description": "",
                    "label": "Content Delivery Network (CDN)"
                },
                "fileSystemContent": {
                    "description": "",
                    "label": "Content in local file system (localhost/dev/test only)"
                },
                "gitContent": {
                    "description": "",
                    "label": "Content in GIT"
                },
                "payload": {
                    "description": "",
                    "label": "Payload of large objects"
                },
                "reports": {
                    "description": "",
                    "label": "Backoffice reports"
                },
                "systemFiles": {
                    "description": "",
                    "label": "System Files"
                },
                "userFiles": {
                    "description": "",
                    "label": "User Files"
                },
                "versionHistory": {
                    "description": "",
                    "label": "Version History"
                }
            },
            "CalculationRowSource": {
                "manualRow": {
                    "description": "",
                    "label": "Lisärivi"
                },
                "salaryPage": {
                    "description": "",
                    "label": "Pääpalkka"
                },
                "tesSelection": {
                    "description": "",
                    "label": "Käyttötapaus"
                }
            },
            "CalculationRowType": {
                "accomodationBenefit": {
                    "amountLabel": "Kuukausia",
                    "description": "Työnantajan maksaman asunnon verotusarvo.",
                    "iconText": "as",
                    "label": "Asuntoetu",
                    "moreInfo": "",
                    "priceLabel": "Asuntoetu / kk"
                },
                "advance": {
                    "amountLabel": "Määrä",
                    "description": "Palkasta on saatettu jo maksaa ennakkoa. Tällöin tämä osuus vähennetään maksettavasta nettomaksusta.",
                    "iconText": "adv",
                    "label": "Palkkaennakko",
                    "moreInfo": "",
                    "priceLabel": "Maksettu ennakko"
                },
                "board": {
                    "amountLabel": "Määrä",
                    "description": "Hallintoelimen jäsenyydestä maksettu palkkio",
                    "iconText": "hal",
                    "label": "Hallituspalkkio",
                    "moreInfo": "Luottamustoimipalkkio, joka maksetaan yhteisön hallituksen tai vastaavan hallintoelimen jäsenyyden perusteella. ",
                    "priceLabel": "Hinta"
                },
                "chainsawReduction": {
                    "amountLabel": "",
                    "description": "Moottorisahavähennys erikoistapauksena (Ennakkoperintälaki 15 §, Ennakkoperintäasetus 18 §)",
                    "iconText": "",
                    "label": "Valitse...",
                    "moreInfo": "",
                    "priceLabel": "Määrä"
                },
                "childCareSubsidy": {
                    "amountLabel": "Määrä",
                    "description": "KELA:n ja kuntien työntekijälle suoraan maksama tuki lastenhoidosta.",
                    "iconText": "KELA",
                    "label": "Yksityisen hoidon tuki",
                    "moreInfo": "KELA:n maksama yksityisen hoidon tuki vaikuttaa sivukuihin, sillä työnantaja maksaa esim. työeläkkeen myös siltä osin. Tämä summa tulee riveinä työnantajan maksaman palkan päälle.",
                    "priceLabel": "KELA maksaa"
                },
                "compensation": {
                    "amountLabel": "Määrä",
                    "description": "Työstä, tehtävästä tai palveluksesta maksettu korvaus, joka ei ole palkkaa.",
                    "iconText": "T",
                    "label": "Työkorvaus",
                    "moreInfo": "",
                    "priceLabel": "Työkorvaus"
                },
                "dailyAllowanceHalf": {
                    "amountLabel": "Päiviä",
                    "description": "Päiväraha, kun työmatka on yli 6-10 tuntia.",
                    "iconText": 19,
                    "label": "Osapäiväraha",
                    "moreInfo": "Päivärahaa maksetaan 19 euroa, jos työmatka on yli 6 tuntia. Matkakohde pitää olla 15 km päässä joko asunnosta tai varsinaisesta työpaikasta.",
                    "priceLabel": "Euroa / päivä"
                },
                "employmentTermination": {
                    "amountLabel": "Määrä",
                    "description": "Tulorekisterin tulolajeissa oleva työsuhteen päättämiseen liittyvä korvaus",
                    "iconText": "off",
                    "label": "Työsuhteen päättäminen",
                    "moreInfo": "",
                    "priceLabel": "Hinta"
                },
                "eveningAddition": {
                    "amountLabel": "Tuntia",
                    "description": "Korvaus iltatyöstä työsopimuksen tai työehtosopimuksen mukaan.",
                    "iconText": "ILTA",
                    "label": "Iltavuorolisä",
                    "moreInfo": "",
                    "priceLabel": "Lisä (per tunti)"
                },
                "expenses": {
                    "amountLabel": "Määrä",
                    "description": "Kulukorvaukset (esim. taksi, tarvikkeet) maksetaan yleensä kuittien perusteella.",
                    "iconText": "kulu",
                    "label": "Kulukorvaus",
                    "moreInfo": "",
                    "priceLabel": "Kulukorvaus"
                },
                "foreclosure": {
                    "amountLabel": "Määrä",
                    "description": "Työnantajan suoraan ulosottomiehelle maksama ulosottopidätys. Tehdään palkasta maksukiellon perusteella.",
                    "iconText": "ulos",
                    "label": "Ulosmittaus (työnantaja)",
                    "moreInfo": "",
                    "priceLabel": "Summa"
                },
                "foreclosureByPalkkaus": {
                    "amountLabel": "",
                    "description": "Palkkaus.fi-palvelun maksama ulosottopidätys. Tehdään palkasta ulosottomiehen lähettämän maksukiellon perusteella.",
                    "iconText": "",
                    "label": "Ulosmittaus (Palkkaus.fi)",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "holidayBonus": {
                    "amountLabel": "Prosentti",
                    "description": "Työehtosopimuksissa (TES) määritetty lomaraha (ent. lomaltapaluuraha).",
                    "iconText": "TES",
                    "label": "Lomaraha",
                    "moreInfo": "",
                    "priceLabel": "Loma-ajan palkka"
                },
                "holidayCompensation": {
                    "amountLabel": "Prosentti",
                    "description": "Korvaus loma-ajan palkasta, jos lomaa ei pidetä.",
                    "iconText": "11,5%",
                    "label": "Lomakorvaus",
                    "moreInfo": "",
                    "priceLabel": "Palkkasumma"
                },
                "holidaySalary": {
                    "amountLabel": "",
                    "description": "Palkka loma-ajalta.",
                    "iconText": "loma",
                    "label": "Loma-ajan palkka",
                    "moreInfo": "",
                    "priceLabel": "Loma-ajan palkka"
                },
                "hourlySalary": {
                    "amountLabel": "Tunteja",
                    "description": "Palkanmaksu tehtyjen tuntien perusteella.",
                    "iconText": "h",
                    "label": "Tuntipalkka",
                    "moreInfo": "",
                    "priceLabel": "Tuntipalkka"
                },
                "irIncomeType": {
                    "amountLabel": "Määrä",
                    "description": "Erikseen syötetty tulorekisterin tulolaji, mikä ei sisälly muihin laskelman riveihin.",
                    "iconText": "katre",
                    "label": "Muu tulorekisterin tulolaji",
                    "moreInfo": "Laskelma luo automaattisesti tulorekisterin tulolajit kullekin riville rivin tyypin perusteella. Tällä rivityyppillä voi erikseen syöttää tulorekisterin tulolajin, mikä ei sisälly muihin laskelman riveihin.",
                    "priceLabel": "Hinta"
                },
                "mealCompensation": {
                    "amountLabel": "Päiviä",
                    "description": "Ateriakorvauksen voi maksaa työmatkoilta, joilta ei makseta päivärahaa.",
                    "iconText": "ater",
                    "label": "Ateriakorvaus",
                    "moreInfo": "",
                    "priceLabel": "Korvaus / päivä"
                },
                "milageDaily": {
                    "amountLabel": "Päiviä",
                    "description": "Kilometrikorvaus määritetään monissa TES:ssa päiväkohtaisina summina.",
                    "iconText": "km",
                    "label": "Kilometrikorvaus, päiväkohtainen",
                    "moreInfo": "Esim. Rakennusalan työehtosopimuksissa on päiväkohtaiset taulukot, joiden perusteella maksetaan kilometrikorvauksia.",
                    "priceLabel": "Korvaus / päivä"
                },
                "milageOther": {
                    "amountLabel": "Päiviä",
                    "description": "Kilometrikorvaus jollain muulla perusteella.",
                    "iconText": "km",
                    "label": "Kilometrikorvaus, muu peruste",
                    "moreInfo": "",
                    "priceLabel": "Korvaus / päivä"
                },
                "milageOwnCar": {
                    "amountLabel": "Kilometriä",
                    "description": "Kilometrikorvaus oman auton käytöstä.",
                    "iconText": "0,43€",
                    "label": "Kilometrikorvaus, oma auto",
                    "moreInfo": "",
                    "priceLabel": "Korvaus / km"
                },
                "monthlySalary": {
                    "amountLabel": "Kuukausia",
                    "description": "Kiinteä kuukausipalkka.",
                    "iconText": "kk",
                    "label": "Kuukausipalkka",
                    "moreInfo": "",
                    "priceLabel": "Kuukausipalkka"
                },
                "nightimeAddition": {
                    "amountLabel": "Tuntia",
                    "description": "Korvaus yötyöstä työsopimuksen tai työehtosopimuksen mukaan.",
                    "iconText": "YÖ",
                    "label": "Yövuorolisä",
                    "moreInfo": "",
                    "priceLabel": "Lisä (per tunti)"
                },
                "otherAdditions": {
                    "amountLabel": "Määrä",
                    "description": "Muut sovitut aikaperusteiset lisät.",
                    "iconText": "lis",
                    "label": "Muut lisät",
                    "moreInfo": "",
                    "priceLabel": "Euroa"
                },
                "otherBenefit": {
                    "amountLabel": "Kuukausia",
                    "description": "Muu työnantajan maksama verotettava etu.",
                    "iconText": "etu",
                    "label": "Muu etu",
                    "moreInfo": "",
                    "priceLabel": "Muu etu € / kk"
                },
                "otherCompensation": {
                    "amountLabel": "Määrä",
                    "description": "Tulorekisterin tulolajeissa oleva muu korvaus tai palkkio",
                    "iconText": "muu",
                    "label": "Muu palkkio tai korvaus",
                    "moreInfo": "",
                    "priceLabel": "Hinta"
                },
                "otherDeductions": {
                    "amountLabel": "Määrä",
                    "description": "Muu vähennys, joka pienentää työntekijälle maksettavan nettopalkan määrää.",
                    "iconText": "muu",
                    "label": "Muu vähennys",
                    "moreInfo": "",
                    "priceLabel": "Vähennys"
                },
                "overtime": {
                    "amountLabel": "Prosentti",
                    "description": "Ylityökorvaukset",
                    "iconText": "yli",
                    "label": "Ylityöt",
                    "moreInfo": "",
                    "priceLabel": "Palkkasumma"
                },
                "phoneBenefit": {
                    "amountLabel": "Kuukausia",
                    "description": "Puhelimen verotusarvo, jonka verottaja määrittää vuosittain.",
                    "iconText": 20,
                    "label": "Puhelinetu",
                    "moreInfo": "",
                    "priceLabel": "Puhelinetu / kk"
                },
                "prepaidExpenses": {
                    "amountLabel": "Määrä",
                    "description": "Kulukorvaus, mikä on jo maksettu ennakkoon työntekijälle. Vähentää työntekijälle maksettavien kulukorvausten määrää.",
                    "iconText": "ek",
                    "label": "Ennakkoon maksettu kulukorvaus",
                    "moreInfo": "",
                    "priceLabel": "Maksettu ennakko"
                },
                "remuneration": {
                    "amountLabel": "Määrä",
                    "description": "Tulorekisterin tulolajeissa oleva kertaluonteinen palkkio",
                    "iconText": "ker",
                    "label": "Kertaluonteinen palkkio",
                    "moreInfo": "",
                    "priceLabel": "Hinta"
                },
                "salary": {
                    "amountLabel": "",
                    "description": "Kertakorvaus työstä.",
                    "iconText": "P",
                    "label": "Palkka tai palkkio",
                    "moreInfo": "",
                    "priceLabel": "Palkka tai palkkio"
                },
                "saturdayAddition": {
                    "amountLabel": "Prosentti",
                    "description": "Lisä lauantaina tehdystä työstä työ- tai työehtosopimuksen mukaan.",
                    "iconText": "LA",
                    "label": "Lauantailisä",
                    "moreInfo": "",
                    "priceLabel": "Palkkasumma"
                },
                "sundayWork": {
                    "amountLabel": "Määrä",
                    "description": "Lain määrittämä 100% korotus sunnuntailta ja pyhäpäiviltä.",
                    "iconText": "SU",
                    "label": "Sunnuntai- / pyhätyö",
                    "moreInfo": "",
                    "priceLabel": "Palkkasumma"
                },
                "tesWorktimeShortening": {
                    "amountLabel": "Prosentti",
                    "description": "Erillinen palkanosa on määritetty rakennusalan työehtosopimuksissa.",
                    "iconText": "TES",
                    "label": "Erillinen palkan osa (Raksa)",
                    "moreInfo": "Ne ovat pääosin yleissitovia ja koskevat myös yksityishenkilöä. Entinen työajan lyhennysraha / \"pekkaset\".",
                    "priceLabel": "Palkkasumma"
                },
                "toolCompensation": {
                    "amountLabel": "Päiviä",
                    "description": "Työvälinekorvaus on määritetty joissakin työehtosopimuksissa (esim. Raksa TES).",
                    "iconText": "tool",
                    "label": "Työvälinekorvaus",
                    "moreInfo": "",
                    "priceLabel": "Korvaus / päivä"
                },
                "totalEmployerPayment": {
                    "amountLabel": "",
                    "description": "Laskee palkan kokonaiskustannuksena: Mitä palkanmaksu maksaa sivukuluineen työnantajalle. Lopputulos on kertakorvaus.",
                    "iconText": "sum",
                    "label": "Kokonaiskustannus",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "totals": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "Yhteensä",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "totalWorkerPayment": {
                    "amountLabel": "",
                    "description": "Laskee palkan nettopalkkana: Mitä työntekijälle jää käteen sivukulujen ja verojen jälkeen. Lopputulos on kertakorvaus.",
                    "iconText": "net",
                    "label": "Nettopalkka",
                    "moreInfo": "Laskee palkan nettopalkkana: Mitä työntekijälle jää käteen sivukulujen ja verojen jälkeen. Lopputulos on kertakorvaus.",
                    "priceLabel": ""
                },
                "unknown": {
                    "amountLabel": "Kuukausia",
                    "description": "Rivin tyyppiä ei ole vielä määritetty.",
                    "iconText": "",
                    "label": "Valitse...",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "workingTimeCompensation": {
                    "amountLabel": "Määrä",
                    "description": "Tulorekisterin tulolajeissa oleva aikaperusteinen lisä ",
                    "iconText": "lisä",
                    "label": "Aikaperusteinen lisä",
                    "moreInfo": "",
                    "priceLabel": "Hinta"
                },
                "carBenefit": {
                    "label": "Autoetu",
                    "description": "Autoetu lisätietoineen ja vähennyksineen",
                    "iconText": "auto",
                    "moreInfo": "Autoedulla tarkoitetaan verotettavaa etua, jonka työntekijä saa, jos saa käyttää työnantajan omistamaa tai hallinnoimaa (esim. leasing-auto) autoa työajojen lisäksi yksityisajoihin.\r\n\r\nAutoetu on palkanlisänä tiukasti säännelty. Sen arvo lasketaan verottajan laskentakaavalla ja sekä arvo että laskennan perusteet tulee ilmoittaa tulorekisteriin. Ilmoitus pitää tehdä myös silloin, jos työntekijä maksaa verotusarvosta korvauksen, jolloin verotettavaa tuloa ei synny. Ilmoitus tehdään lähtökohtaisesti palkkakausittain tai vähintään kuukausittain, jos muuta palkkaa ei makseta. Kilometrikohtaisessa laskennassa ilmoituksen saa vaihtoehtoisesti tehdä vain vuoden lopussa.\r\n\r\nLaskentakaava perustuu kahteen luokkaan: vapaa autoetu ja käyttöetu:\r\n\r\n- Vapaassa autoedussa työnantaja huolehtii kaikista auton käyttöön liittyvistä kustannuksista, kuten polttonesteistä, vakuutuksista, veroista, huolloista ja korjauksista.\r\n- Käyttöedussa auton käyttäjä maksaa yksityisajojensa polttoainekustannukset, sopimuksen mukaan mahd. myös muita kustannuksia.\r\n\r\nLisäksi laskentakaavaan tarvitaan auton hinta, lisävarusteiden hinta sekä ikäryhmä A, B tai C. Tyypillisesti arvo lasketaan kiinteällä 18 000 kilometrin vuosittaisella yksityisajolla. Jos yksityisajot ovat ilmiselvästi suuremmat, tulisi käyttää kilometreihin perustuvaa menetelmää. \r\n\r\nAutoedun verotusarvon laskuri löytyy osoitteesta: https://www.vero.fi/autoetulaskuri\r\n\r\nVaihtoehtoisesti verotusarvon voi laskea kilometripohjaisesti. Tämä on edullisempaa, jos yksityisajon kilometrit ovat vähäiset, mutta erittäin työlästä, koska silloin yksityisajoista tulee pitää ajopäiväkirjaa ja nämä kilometrit pitää raportoida verottajalle. Jos käytetään kilometrikohtaista laskentaa, autoedun voi ilmoittaa vain kerran vuodessa: tyypillisesti vuoden viimeisellä palkkalaskelmalla.",
                    "priceLabel": "Autoedun verotusarvo"
                },
                "unionPayment": {
                    "amountLabel": "Prosenttia palkasta",
                    "description": "Työnantajan tulee maksaa AY-jäsenmaksu suoraan liitolle, jos työntekijä näin toivoo.",
                    "iconText": "AY",
                    "label": "Ay-jäsenmaksu",
                    "moreInfo": "Työnantaja voi vähentää AY-jäsenmaksun suoraan työntekijän palkasta ja tilittää sen ammattiliitolle. Vähentäminen tapahtuu työntekijän pyynnöstä / suostumuksella. AY jäsenmaksu vähennetään työntekijän nettopalkasta.\n\nMenettelystä on saatettu sopia työehtosopimuksessa, jolloin AY-jäsenmaksun tilittäminen saattaa olla työnantajan velvollisuus. Siitä, koskeeko velvollisuus vain järjestäytyneitä työnantajia, ei tätä kirjoitettaessa ole täyttä varmuutta: Asiasta on eri mielipiteitä ja siitä ei ole oikeustapausta.\n\nTyypillisesti tilanne on Palkkaus.fi-asiakkailla (pienillä yrityksillä) harvinainen ja siksi AY-jäsenmaksuja ei toistaiseksi hoideta Palkkaus.fi-palvelun kautta: Työnantajan tulee itse hoitaa jäsenmaksun tilitys suoraan liittoon. Näin vähennettävä summa vähennetään Palkkaus.fi-palvelun asiakasvaratilille maksettavasta summasta. Lisätietoja ilmoittamisesta ja maksamisesta saat kyseisestä liitosta.",
                    "priceLabel": "Ennakonpidätyksen alainen palkka"
                },
                "dailyAllowance": {
                    "amountLabel": "Päiviä",
                    "description": "Päiväraha: kokopäiväraha (oletus) sekä muut päivärahat",
                    "iconText": "pv",
                    "label": "Päiväraha",
                    "moreInfo": "Päiväraha on korvaus kohtuullisesta ruokailu- ja muiden elinkustannusten lisäyksestä, jotka palkansaajalle aiheutuu työmatkasta. Kuitenkaan näihin kustannuksiin ei kuulu matkustamisesta (liput, kilometrit) eikä majoittumisesta aiheutuvia kustannuksia: Ne maksetaan tyypillisesti erikseen kuittien perusteella tai kilometrikorvauksina.\r\n\r\nVerohallinto määrittää päivärahan enimmäismäärät vuosittain. Usein käytetään näitä enimmäismääriä, mutta tämä ei ole mikään yleispätevä sääntö. Verottoman enimmäismäärän yrittävät summat tulee maksaa verotettavana palkkana tai työkorvauksena.\r\n\r\nPäivärahan saaminen edellyttää työ- tai virkamatkaa, joka suuntautuu yli 15 kilometriä työpaikalta tai kotoa riippuen siitä, kummasta alkaen matka tehdään. Osapäivärahaa maksetaan kotimaassa yli kuusi tuntia ja kokopäivärahaa yli 10 tuntia kestävältä työmatkalta. Päivärahan sijaan on myös mahdollista maksaa ateriakorvausta. Ateriakorvauksen saamisen edellytyksenä on, ettei matka oikeuta päivärahaan tai sitä ei muutoin makseta.",
                    "priceLabel": "Euroa / päivä"
                },
                "mealBenefit": {
                    "amountLabel": "Aterioita",
                    "description": "Työnantaja työntekijälleen tarjoama ateria. Myös lounassetelit.",
                    "iconText": "rav",
                    "label": "Ravintoetu",
                    "moreInfo": "Ravintoetu on luontoisetu, joka syntyy, kun työnantaja tarjoaa työntekijälleen aterian. Työnantaja voi tukea ruokailukustannuksia ruokailulipukkeella (Lounasseteli) tai muulla kohdennetulla maksuvälineellä taikka järjestämällä työpaikkaruokailun (sopimusruokailu).\r\n\r\nRavintoedun verotusarvo määräytyy Verohallinnon päätöksen mukaisena vuosittain vahvistettavana arvona.\r\n\r\nVaihtoehtona ravintoedulle on ateriakorvaus, joka maksetaan työmatkalla. Sen maksaminen edellyttää, että työmatkasta ei suoriteta päivärahaa ja että palkansaajalla ei työn vuoksi ole mahdollisuutta ruokailutauon aikana aterioida tavanomaisella ruokailupaikallaan. Ateriakorvaus on veroton etu (maksetaan työntekijälle), kun erilaiset ravintoedut ovat luontoisetuja (yritys maksaa kulun ja siitä osa on työntekijältä verotettavaa tuloa).\r\n\r\nJos työntekijän palkanmaksupäivä on esimerkiksi kuukauden puolivälissä, tieto ravintoedun määrästä annetaan tulorekisteriin ennen kuin on varmuutta ravintoedun kokonaismäärästä kyseisenä kuukautena (esimerkiksi mahdolliset poissaolot eivät ole työnantajan tiedossa). Tämän vuoksi on katsottu riittäväksi, että ravintoetu täsmäytetään oikean suuruiseksi viimeistään seuraavalla palkkatietoilmoituksella. \r\n\r\nJoulukuun ravintoedun määrä on korjattava antamalla joulukuulle korvaava ilmoitus, jotta ravintoedun määrä korjaantuu oikealle verovuodelle. Tästä täsmäyksestä Palkkaus.fi antaa erillinen ohjeistuksen ennen vuodenvaihdetta.\r\n\r\nJos ravintoetu toteutetaan saldoon perustuvaa maksuvälinettä käyttäen (esimerkiksi maksukortti), täsmäytys on tehtävä vähintään vuoden viimeisellä palkkatietoilmoituksella.",
                    "priceLabel": "Nimellisarvo / kustannus"
                },
                "nonProfitOrg": {
                    "amountLabel": "Määrä",
                    "description": "Yleishyödylliset yhteisön vapaaehtoistyöhön osallistuvalle maksama päiväraha tai kilometrikorvaus.",
                    "iconText": "NPO",
                    "label": "Yleishyödyllisen yhteisön päiväraha ja km-korvaus",
                    "moreInfo": "Yleishyödylliset yhteisöt voivat maksaa korvauksettomaan vapaaehtoistyöhön osallistuvalle päivärahaa tai kilometrikorvausta.\r\n\r\nHUOM: Tällä käyttöliittymällä ilmoitetaan vain vapaaehtoistyöhön liittyvät korvaukset. Jos korvaukset liittyvät työsuhteeseen / palkkaan, korvaukset tulee ilmoittaa erikseen kohdissa Kilometrikorvaus ja Päiväraha (kokopäiväraha tai osapäiväraha). Jos yhdistys ei ole verottajan määrittelemällä tavalla yleishyödyllinen, työsuhteen ulkopuoliset korvaukset, myös vapaaehtoistyöstä, tulee tilittää ennakonpidätyksen alaisena työkorvauksena. Vastaanottaja voi sitten vähentää ne omassa verotuksessaan.\r\n\r\nIlmoitettava tulo on määritetty tuloverolain 71 § 3 momentissa: \r\n\r\nPäivärahan voi maksaa enintään 20 päivältä per kalenterivuosi ja lisäksi majoittumiskorvaus (tositteen perusteella).\r\n\r\nKilometrikorvausten osalta voidaan maksaa matkustamiskustannusten korvaus. Toisin kuin tavallisessa kilometrikorvauksessa, tämä voidaan maksaa myös verovelvollisen asunnolta tehdystä matkasta. Muulla kuin julkisella kulkuneuvolla tehdystä matkasta on verovapaata enintään 3 000 euroa kalenterivuodelta.\r\n\r\nTässä kohdassa ilmoitetaan vain verovapaat määrät. Jos yleishyödyllinen yhteisö maksaan päivärahaa enemmän kuin yllä, ylimenevä osa ilmoitetaan työkorvauksena. Palkkaus.fi ei tarkkaile näitä rajoja, vaan työnantajan tulee huolehtia tästä itse.",
                    "priceLabel": "Hinta"
                },
                "subsidisedCommute": {
                    "description": "Työnantajan työntekijälle kustantaman ja hankkima julkisen liikenteen henkilökohtainen joukkoliikennelippu, josta osa on verovapaata.",
                    "iconText": "bus",
                    "label": "Työsuhdematkalippu",
                    "moreInfo": "Työsuhdematkalippu on työnantajan työntekijälle kustantaman ja hankkima julkisen liikenteen henkilökohtainen joukkoliikennelippu. Osa työsuhdematkalipun arvosta on verovapaata ja osa veronalaista: Verovapaata on 0 - 300€ ja 750 – 3 400€ vuonna 2019. Palkkaus.fi-palvelu laskee verovapaan ja veronalaisen palkan lipun hinnan perusteella. Lisäksi otetaan huomioon työntekijän mahdollisesti työnantajalle maksama korvaus. Kaikki nämä tiedot täytyy ilmoittaa erikseen verottajalle / tulorekisteriin. \r\n\r\nJos palkansaaja ostaa matkalipun itse ja työnantaja maksaa työntekijälle matkalipun hinnan tai osan siitä, työnantajan maksama korvaus katsotaan kokonaisuudessaan työntekijän palkaksi. Tällöin työntekijälle maksettu lipun hinta ilmoitetaan vain palkkana.\r\n\r\nMatkalippu on yleensä voimassa vuoden ja siksi työsuhdematkalipussa veronalaisen ja verovapaan edun määriä arvioidaan vuositasolla (toisin kuin muissa luontoiseduissa kuukausitasolla). \r\n\r\nJos kuitenkin korvausta peritään työntekijän palkasta säännöllisesti koko vuosi (esim. kerran kuussa) voi maksaja jo etukäteen ennakoida tilanteen ja jakaa verovapaan osuuden koko vuodelle ja ilmoittaa sen kuukausittain tulorekisteriin samassa yhteydessä perimänsä korvauksen kanssa. Tämä siitä huolimatta, että työsuhdematkalippu annettaisiin kerran vuodessa.\r\n\r\nJos haluat toteuttaa tämän jaon, sinun tulee asettaa kohta ”Jaetaanko korvaus palkkajaksoihin?” arvoksi Kyllä ja määrittää jaksojen määrä (oletus 12 kuukautta). Palkkaus.fi-palvelu ei tässä versiossa tarkkaile, että vuodessa kaikki jaksot tulee ilmoitettua oikein, joten sinun tulee vuoden lopussa tarkistaa, että kaikki työsuhdematkalipun osat on ilmoitettu. Erityisen huolellisesti pitää tarkistaa, jos vaihdat jaksojen määrää kesken vuotta (ei suositeltavaa). Ota tarvittaessa yhteyttä Palkanlaskijaasi tai Palkkaus.fi-asiakaspalveluun.",
                    "priceLabel": "Lipun hinta"
                }
            },
            "CalculationRowUnit": {
                "count": {
                    "description": "",
                    "label": "kpl"
                },
                "days": {
                    "description": "",
                    "label": "päivää"
                },
                "kilometers": {
                    "description": "",
                    "label": "km"
                },
                "percent": {
                    "description": "",
                    "label": "%"
                },
                "undefined": {
                    "description": "",
                    "label": ""
                }
            },
            "CalculationStatus": {
                "draft": {
                    "description": "",
                    "label": "Luonnos"
                },
                "externalPaymentCanceled": {
                    "description": "",
                    "label": "Maksu peruttu salaxy-palvelun ulkopuolella"
                },
                "externalPaymentError": {
                    "description": "",
                    "label": "Virheitä (salaxy-palvelun ulkopuolella)"
                },
                "externalPaymentStarted": {
                    "description": "",
                    "label": "Maksu aloitettu salaxy-palvelun ulkopuolella"
                },
                "externalPaymentSucceeded": {
                    "description": "",
                    "label": "Maksettu salaxy-palvelun ulkopuolella"
                },
                "paymentCanceled": {
                    "description": "",
                    "label": "Maksu peruttu"
                },
                "paymentError": {
                    "description": "",
                    "label": "Virheitä"
                },
                "paymentRefunded": {
                    "description": "",
                    "label": "Maksu peruttu ja rahat palautettu"
                },
                "paymentStarted": {
                    "description": "",
                    "label": "Maksu aloitettu"
                },
                "paymentSucceeded": {
                    "description": "",
                    "label": "Maksettu"
                },
                "paymentWorkerCopy": {
                    "description": "",
                    "label": "Työntekijän kopio"
                },
                "template": {
                    "description": "",
                    "label": "Laskelmapohja (template)"
                },
                "workerRequestAccepted": {
                    "description": "",
                    "label": "Työntekijän tekemä palkkalaskelma hyväksytty"
                },
                "workerRequestDeclined": {
                    "description": "",
                    "label": "Työntekijän tekemä palkkalaskelma hylätty"
                },
                "workerRequested": {
                    "description": "",
                    "label": "Työntekijän tekemä palkkalaskelma"
                },
                "payrollDraft": {
                    "description": "",
                    "label": "Palkkalistan laskelma"
                },
                "proDraft": {
                    "label": ""
                }
            },
            "CompanyType": {
                "fiOy": {
                    "description": "",
                    "label": "Osakeyhtiö, myös asunto-osakeyhtiö ja Oyj"
                },
                "fiRy": {
                    "description": "",
                    "label": "Yhdistys"
                },
                "fiTm": {
                    "description": "",
                    "label": "Yksityinen elinkeinonharjoittaja tai Maatalousyrittäjä"
                },
                "fiYy": {
                    "description": "",
                    "label": "Muu, esim. Kommandiittiyhtiö, Avoin yhtiö,"
                },
                "unknown": {
                    "description": "",
                    "label": ""
                }
            },
            "ContractPartyType": {
                "customContact": {
                    "description": "",
                    "label": "Custom Contact"
                },
                "person": {
                    "description": "",
                    "label": "Person"
                }
            },
            "DateOfBirthAccuracy": {
                "ageBased": {
                    "description": "",
                    "label": "Iän perusteella"
                },
                "ageGroupBased": {
                    "description": "",
                    "label": "Ikäluokan perusteella"
                },
                "assumption": {
                    "description": "",
                    "label": "Oletus"
                },
                "exact": {
                    "description": "",
                    "label": "Täsmällinen päivämäärä"
                },
                "monthCorrect": {
                    "description": "",
                    "label": "Kuukausi oikea"
                },
                "verified": {
                    "description": "",
                    "label": "Vahvistettu"
                }
            },
            "EmployerType": {
                "fullTimeEmployer": {
                    "description": "",
                    "label": "Jatkuva sopimus tai yli 8178€ / 6kk"
                },
                "miniEmployer": {
                    "description": "",
                    "label": "Alle 1300€ / vuosi"
                },
                "smallEmployer": {
                    "description": "",
                    "label": "Väh. 1300€ / vuosi"
                },
                "tyelOwnContractEmployer": {
                    "description": "",
                    "label": "TyEL-vuosisopimus tai hoitaa itse."
                },
                "unknown": {
                    "description": "",
                    "label": "Ei tiedossa"
                }
            },
            "EmploymentContract": {
                "annualLeave": {
                    "label": "Vuosiloma"
                },
                "benefitsException": {
                    "label": "Benefits"
                },
                "noticeException": {
                    "label": "Irtisanomisaika"
                },
                "otherTerms": {
                    "label": "Muut sopimusehdot"
                }
            },
            "EmploymentRelationType": {
                "undefined": {
                    "label": "Muu",
                    "description": ""
                },
                "salary": {
                    "label": "Keikkatyöntekijä (kertaluonteinen työ)",
                    "description": ""
                },
                "hourlySalary": {
                    "label": "Tuntipalkkainen työntekijä",
                    "description": ""
                },
                "monthlySalary": {
                    "label": "Kuukausipalkkainen työntekijä",
                    "description": ""
                },
                "compensation": {
                    "label": "Suoritus työkorvauksena",
                    "description": ""
                },
                "boardMember": {
                    "label": "Hallituksen jäsen",
                    "description": ""
                },
                "entrepreneur": {
                    "label": "Yrittäjä tai yrittäjän perheenjäsen",
                    "description": ""
                },
                "entrepreneurNew": {
                    "label": "Yrittäjä, osaomistaja tai yrittäjän perheenjäsen",
                    "description": ""
                },
                "farmer": {
                    "label": "Maatalousyrittäjä tai perheenjäsen",
                    "description": ""
                },
                "athlete": {
                    "label": "Urheilija",
                    "description": ""
                },
                "employedByStateEmploymentFund": {
                    "label": "Valtion työllisyysmäärärahoilla työllistetty (palkkatuki)",
                    "description": ""
                },
                "keyEmployee": {
                    "label": "Avainhenkilö. Ulkomaalainen asiantuntija, jolle maksetaan avainhenkilön lähdeveron alainen palkka.",
                    "description": ""
                },
                "performingArtist": {
                    "label": "Esiintyvä taitelija",
                    "description": ""
                }
            },
            "EmploymentSalaryType": {
                "hourlyPay": {
                    "description": "",
                    "label": "tuntipalkka",
                    "metricAbbrev": "/h"
                },
                "montlyPay": {
                    "description": "",
                    "label": "kuukausipalkka",
                    "metricAbbrev": "/kk"
                },
                "otherPay": {
                    "description": "",
                    "label": "muu"
                },
                "unknown": {
                    "description": "",
                    "label": "Valitse..."
                }
            },
            "EmploymentType": {
                "fullTime": {
                    "description": "",
                    "label": "Toistaiseksi voimassaoleva"
                },
                "job": {
                    "description": "",
                    "label": "Kertaluonteinen työ"
                },
                "partTime": {
                    "description": "",
                    "label": "Määräaikainen"
                },
                "unknown": {
                    "description": "",
                    "label": "Valitse..."
                }
            },
            "EmploymentWorkHoursType": {
                "hourPerThreeWeeks": {
                    "description": "",
                    "label": "3 viikon jaksossa"
                },
                "hourPerTwoWeeks": {
                    "description": "",
                    "label": "2 viikon jaksossa"
                },
                "hoursPerDay": {
                    "description": "",
                    "label": "tuntia/vuorokaudessa"
                },
                "hoursPerWeek": {
                    "description": "",
                    "label": "tuntia/viikkossa"
                }
            },
            "FrameworkAgreement": {
                "childCare": {
                    "description": "Jatkuva lastenhoitaja ja siihen liittyvät tuet",
                    "label": "Muu lastenhoito"
                },
                "cleaning": {
                    "description": "Siivous- ja kiinteistöalan työ",
                    "label": "Siivous- ja kiinteistöala"
                },
                "construction": {
                    "description": "Työtä rakennusalan työehtosopimuksen mukaan",
                    "label": "Rakennus- ja remonttityö"
                },
                "entrepreneur": {
                    "description": "Yrittäjän oma palkka",
                    "label": "Yrittäjä"
                },
                "mll": {
                    "description": "MLL:n lastenhoitajan palkka",
                    "label": "MLL suositukset"
                },
                "notDefined": {
                    "description": "Työehtosopimusta tai suositusta ei ole määritetty",
                    "label": "Ei määritetty"
                },
                "other": {
                    "description": "Muu työ - ei työehtosopimusta",
                    "label": "Muu työ"
                },
                "santaClaus": {
                    "description": "Joulupukin kotikäynti jouluaattona",
                    "label": "Joulupukki kotiin"
                }
            },
            "Gender": {
                "female": {
                    "description": "",
                    "label": "Nainen"
                },
                "male": {
                    "description": "",
                    "label": "Mies"
                },
                "unknown": {
                    "description": "",
                    "label": "-"
                }
            },
            "HelttiIndustry": {
                "i": {
                    "description": "",
                    "label": "Majoitus- ja ravitsemistoiminta"
                },
                "j": {
                    "description": "",
                    "label": "Informaatio ja viestintä"
                },
                "k": {
                    "description": "",
                    "label": "Rahoitus- ja vakuutustoiminta"
                },
                "m": {
                    "description": "",
                    "label": "Ammatillinen, tieteellinen ja tekninen toiminta"
                },
                "n": {
                    "description": "",
                    "label": "Hallinto- ja tukipalvelutoiminta"
                },
                "notDefined": {
                    "description": "",
                    "label": "Ei valintaa"
                },
                "o": {
                    "description": "",
                    "label": "Julkinen hallinto ja maanpuolustus"
                },
                "other": {
                    "description": "",
                    "label": "Muu toimiala"
                },
                "q": {
                    "description": "",
                    "label": "Terveys- ja sosiaalipalvelut"
                },
                "r": {
                    "description": "",
                    "label": "Taiteet, viihde ja virkistys"
                },
                "s": {
                    "description": "",
                    "label": "Muu palvelutoiminta"
                }
            },
            "HelttiProductPackage": {
                "large": {
                    "description": "",
                    "label": "Tuloskunto"
                },
                "medium": {
                    "description": "",
                    "label": "Kasvuyritys"
                },
                "notDefined": {
                    "description": "",
                    "label": "Ei sopimusta"
                },
                "small": {
                    "description": "",
                    "label": "Start-up"
                }
            },
            "HouseHoldUseCaseTree": {
                "childCare": {
                    "description": "Tilapäinen tai jatkuva",
                    "kela": {
                        "description": "Lastenhoitaja kotona.",
                        "label": "Yksityisen hoidon tuki"
                    },
                    "label": "Lastenhoito",
                    "mll": {
                        "description": "Palkka MLL:n suosituksen mukaan.",
                        "label": "Tilapäinen lastenhoito"
                    },
                    "other": {
                        "description": "Muu jatkuva tai tilapäinen lastenhoito",
                        "label": "Muu lastenhoito"
                    }
                },
                "cleaning": {
                    "51530": {
                        "description": "Kiinteistöhuollon työntekijät",
                        "label": "Kiinteistöhuolto"
                    },
                    "53221": {
                        "description": "Kotityöpalvelutyöntekijän työ",
                        "label": "Kotityöpalvelu"
                    },
                    "61132": {
                        "description": "Puutarha- ja kasvihuonetyöntekijät",
                        "label": "Puutarhanhoito"
                    },
                    "91110": {
                        "description": "Siivoustyö tai kotiapulainen",
                        "label": "Kotisiivous tai kotiapulainen"
                    },
                    "description": "Kodin siivous ja kunnossapito",
                    "label": "Kotisiivous",
                    "other": {
                        "description": "Kodin muut työt",
                        "label": "Muut"
                    }
                },
                "construction": {
                    "carpenter": {
                        "description": "Kirvesmiehet ja rakennuspuusepät",
                        "label": "Kirvesmies"
                    },
                    "description": "Rakennusalan työehtosopimus.",
                    "floor": {
                        "description": "Lattianpäällystys",
                        "label": "Lattiatyöt"
                    },
                    "label": "Rakennus- ja remonttityö",
                    "new": {
                        "description": "Uudisrakennukset",
                        "label": "Muu uudisrakentaminen"
                    },
                    "painter": {
                        "description": "Rakennusmaalarit ym.",
                        "label": "Maalaaminen"
                    },
                    "renovation": {
                        "description": "Asunnon tai vapaa-ajan asunnon remontointi",
                        "label": "Muu remontointi"
                    },
                    "roof": {
                        "description": "Kattoasentajat ja -korjaajat",
                        "label": "Kattotyöt"
                    }
                },
                "other": {
                    "51530": {
                        "description": "",
                        "label": "Kiinteistöhuollon työntekijät"
                    },
                    "53112": {
                        "description": "",
                        "label": "Perhepäivähoitajat (sis. kotitalousten lastenhoitajat)"
                    },
                    "53212": {
                        "description": "",
                        "label": "Kehitysvammaisten hoitajat"
                    },
                    "53213": {
                        "description": "",
                        "label": "Sosiaalialan hoitajat"
                    },
                    "53221": {
                        "description": "",
                        "label": "Kotityöpalvelutyöntekijät"
                    },
                    "53222": {
                        "description": "",
                        "label": "Henkilökohtaiset avustajat, omaishoitajat ym."
                    },
                    "61112": {
                        "description": "",
                        "label": "Peltoviljelytyönjohtajat ja -työntekijät"
                    },
                    "61132": {
                        "description": "",
                        "label": "Puutarha- ja kasvihuonetyönjohtajat ja - työntekijät"
                    },
                    "62100": {
                        "description": "",
                        "label": "Metsurit ja metsätyöntekijät"
                    },
                    "71110": {
                        "description": "",
                        "label": "Talonrakentajat (sis. remonttimiehet)"
                    },
                    "71150": {
                        "description": "",
                        "label": "Kirvesmiehet ja rakennuspuusepät"
                    },
                    "71210": {
                        "description": "",
                        "label": "Kattoasentajat ja -korjaajat"
                    },
                    "71310": {
                        "description": "",
                        "label": "Rakennusmaalarit ym."
                    },
                    "91110": {
                        "description": "",
                        "label": "Kotiapulaiset ja -siivoojat"
                    },
                    "description": "Yleinen palkkalaskuri",
                    "label": "Muu työ",
                    "undefined": {
                        "description": "",
                        "label": "Muu työ"
                    }
                }
            },
            "InsuranceCompany": {
                "aktia": {
                    "description": "",
                    "label": "Aktia"
                },
                "alandia": {
                    "description": "",
                    "label": "Alandia"
                },
                "ålands": {
                    "description": "",
                    "label": "Ålands"
                },
                "aVakuutus": {
                    "description": "",
                    "label": "A-Vakuutus"
                },
                "fennia": {
                    "description": "",
                    "label": "Fennia"
                },
                "folksam": {
                    "description": "",
                    "label": "Folksam"
                },
                "if": {
                    "description": "",
                    "label": "If"
                },
                "lähiTapiola": {
                    "description": "",
                    "label": "LähiTapiola"
                },
                "none": {
                    "description": "",
                    "label": "(Ei valittu vielä)"
                },
                "other": {
                    "description": "",
                    "label": "Muu vakuutusyhtiö"
                },
                "pohjantähti": {
                    "description": "",
                    "label": "Pohjantähti"
                },
                "pohjola": {
                    "description": "",
                    "label": "OP Vakuutus"
                },
                "redarnas": {
                    "description": "",
                    "label": "Redarnas"
                },
                "tryg": {
                    "description": "",
                    "label": "Tryg"
                },
                "turva": {
                    "description": "",
                    "label": "Turva"
                }
            },
            "LegalEntityType": {
                "company": {
                    "description": "",
                    "label": "Y-tunnus"
                },
                "partner": {
                    "description": "",
                    "label": "Kumppani"
                },
                "person": {
                    "description": "",
                    "label": "Henkilö"
                },
                "personCreatedByEmployer": {
                    "description": "",
                    "label": "Työntekijä (TA:n)"
                },
                "undefined": {
                    "description": "",
                    "label": "Tuntematon"
                }
            },
            "MessageType": {
                "email": {
                    "description": "",
                    "label": "Sähköposti"
                },
                "sms": {
                    "description": "",
                    "label": "Tekstiviesti"
                }
            },
            "OnboardingStatus": {
                "created": {
                    "description": "",
                    "label": "Luotu"
                },
                "done": {
                    "description": "",
                    "label": "Valmis"
                },
                "opdescription": "",
                "oplabel": "Käynnissä"
            },
            "PalkkausCampaignPricing": {
                "campaignAfterFirstUse": {
                    "description": "",
                    "label": "Campaign After First Use"
                },
                "campaignFirstUse": {
                    "description": "",
                    "label": "Campaign First Use"
                },
                "companyFreeTrial": {
                    "description": "",
                    "label": "Company Free Trial"
                },
                "none": {
                    "description": "",
                    "label": "None"
                }
            },
            "PartnerSite": {
                "careDotCom": {
                    "description": "",
                    "label": "Care Dot Com"
                },
                "dev": {
                    "description": "",
                    "label": "Dev"
                },
                "duunitori": {
                    "description": "",
                    "label": "Duunitori"
                },
                "example": {
                    "description": "",
                    "label": "Example"
                },
                "mol": {
                    "description": "",
                    "label": "Mol"
                },
                "palkkaapakolaindescription": "",
                "palkkaapakolainlabel": "Palkkaapakolainen",
                "palkkaus": {
                    "description": "",
                    "label": "Palkkaus"
                },
                "palkkausEmployerFillIn": {
                    "description": "",
                    "label": "Palkkaus Employer Fill In"
                },
                "palkkausIdentified": {
                    "description": "",
                    "label": "Palkkaus Identified"
                },
                "raksa": {
                    "description": "",
                    "label": "Raksa"
                },
                "refugeeJobs": {
                    "description": "",
                    "label": "Refugee Jobs"
                },
                "talkkarit": {
                    "description": "",
                    "label": "Talkkarit"
                },
                "unknown": {
                    "description": "",
                    "label": "Unknown"
                }
            },
            "PaymentStatus": {
                "bankDelivered": {
                    "description": "",
                    "label": "Pankki hyväksynyt"
                },
                "bankError": {
                    "description": "",
                    "label": "Virhe pankissa"
                },
                "bankPartialError": {
                    "description": "",
                    "label": "Virhe pankissa"
                },
                "bankTechApproval": {
                    "description": "",
                    "label": "Pankki vastaanottanut"
                },
                "cancelled": {
                    "description": "",
                    "label": "Peruttu"
                },
                "new": {
                    "description": "",
                    "label": "Uusi"
                },
                "paid": {
                    "description": "",
                    "label": "Maksettu"
                },
                "sentToBank": {
                    "description": "",
                    "label": "Lähetetty pankkiin"
                },
                "unknown": {
                    "description": "",
                    "label": "Tuntematon"
                }
            },
            "PayrollStatus": {
                "draft": {
                    "label": "Luonnos"
                },
                "paymentStarted": {
                    "label": "Maksu aloitettu"
                },
                "paymentSucceeded": {
                    "label": "Maksettu"
                },
                "paymentCanceled": {
                    "label": "Maksu peruttu"
                },
                "paymentError": {
                    "label": "Virheitä"
                },
                "template": {
                    "label": "Palkkalistapohja (template)"
                }
            },
            "PensionCompany": {
                "elo": {
                    "description": "",
                    "label": "Elo"
                },
                "etera": {
                    "description": "",
                    "label": "Etera"
                },
                "ilmarindescription": "",
                "ilmarinen": {
                    "label": "Ilmarinen"
                },
                "none": {
                    "description": "",
                    "label": "(Ei valittu vielä)"
                },
                "other": {
                    "description": "",
                    "label": "Muu yhtiö"
                },
                "pensionsAlandia": {
                    "description": "",
                    "label": "Alandia"
                },
                "varma": {
                    "description": "",
                    "label": "Varma"
                },
                "veritas": {
                    "description": "",
                    "label": "Veritas"
                },
                "apteekkien": {
                    "description": "",
                    "label": "Apteekkien Eläkekassa"
                },
                "verso": {
                    "description": "",
                    "label": "Verso"
                }
            },
            "PensionCalculation": {
                "undefined": {
                    "label": "(Ei valittu vielä)",
                    "description": ""
                },
                "employee": {
                    "label": "TyEL",
                    "description": ""
                },
                "entrepreneur": {
                    "label": "YEL",
                    "description": ""
                },
                "smallEntrepreneur": {
                    "label": "YEL, ei vakuuttamisvelvollisuutta",
                    "description": "Tulonsaaja täyttää yrittäjän eläkelain 3 §:ssä säädetyt edellytykset, mutta jolla ei ole vakuuttamisvelvollisuutta yrittäjän eläkelain 4 §:n nojalla.\nVakuuttamisvelvollisuus ei koske:\n1) yrittäjän toimintaa ennen 18 vuoden iän täyttämistä seuraavan kalenterikuukauden alkua, eikä työskentelyä, joka jatkuu sen kalenterikuukauden jälkeen, jolloin vuonna 1957 tai sitä ennen syntynyt yrittäjä täyttää 68 vuotta, vuosina 1958–1961 syntynyt yrittäjä täyttää 69 vuotta ja vuonna 1962 ja sen jälkeen syntynyt yrittäjä täyttää 70 vuotta (vakuuttamisvelvollisuuden yläikäraja); (29.1.2016/72)\n2) yrittäjän toimintaa, joka ei ole jatkunut yhdenjaksoisesti vähintään neljää kuukautta;\n3) yrittäjän toimintaa, joka on alkanut tai jatkunut sen jälkeen, kun hän on siirtynyt työeläkelakien mukaiselle vanhuuseläkkeelle;\n4) yrittäjää, jonka työtulo tässä laissa tarkoitetusta yrittäjätoiminnasta on arvioitava pienemmäksi kuin 5 504,14 euroa vuodessa;\n5) ansiotyötä, jonka perusteella yrittäjällä on oikeus eläkkeeseen muun työeläkelain mukaan; eikä\n6) yrittäjää, johon ei sovelleta Suomen lainsäädäntöä EU:n sosiaaliturvan perusasetuksen tai sosiaaliturvasopimuksen sovellettavaa lainsäädäntöä koskevien määräysten perusteella. (14.5.2010/355)"
                },
                "partialOwner": {
                    "label": "TyEL, osaomistaja",
                    "description": "Osaomistajan palkka\r\nYrityksen osaomistajat maksavat pienempää palkansaajan työttömyysvakuutusmaksua kuin työntekijät.\r\n•\tOsaomistajan työnantajan työttömyysvakuutusmaksu on 0,5 % palkkasummasta.\r\n•\tPalkansaajan, joka on myös osaomistaja, työttömyysvakuutusmaksuprosentti on 0,78 %. Työnantaja pidättää sen palkasta palkanmaksun yhteydessä.\r\nJos et ole ole yrityksessä johtavassa asemassa, mutta työskentelet yrityksessä tai yhteisössä, olet osaomistaja, jos jokin seuraavista ehdoista täyttyy: \r\n•\tsinulla itselläsi on vähintään 50 % kyseisen yrityksen tai yhteisön osakepääomasta, äänivallasta tai muusta määräämisvallasta \r\n•\tperheenjäsenelläsi on vähintään 50 % kyseisen yrityksen tai yhteisön osakepääomasta, äänivallasta tai muusta määräämisvallasta\r\n•\tsinulla on yhdessä perheenjäsentesi kanssa vähintään 50 % osakepääomasta, äänivallasta tai muusta määräämisvallasta. \r\nJos olet johtavassa asemassa mutta et ole yrittäjä, voit olla työttömyysturvalain mukaan osaomistaja, jos työskentelet yrityksessä ja jompikumpi seuraavista ehdoista täyttyy:\r\n•\tsinulla on vähintään 15 % osakepääomasta, äänivallasta tai muusta määräämisvallasta\r\n•\tperheenjäsenilläsi tai teillä yhdessä on vähintään 30 % osakepääomasta, äänivallasta tai muusta määräämisvallasta\r\nTyöllisyysrahaston sivulla voi testata onko osaomistaja vai palkansaaja\r\nhttps://www.tyollisyysrahasto.fi/tyottomyysvakuusmaksut/tyottomyysvakuutusmaksuvelvollisuus/#osaomistaja\r\nOsaomistajan käsite on määritelty työttömyysturvalaissa (1290/2002). \r\n"
                },
                "farmer": {
                    "label": "MYEL",
                    "description": ""
                },
                "smallFarmer": {
                    "label": "MYEL, ei vakuuttamisvelvollisuutta",
                    "description": "Tulonsaaja täyttää maatalousyrittäjän eläkelain 3 §:ssä säädetyt edellytykset, mutta jolla ei ole mainitun lain perusteella vakuuttamisvelvollisuutta.\n\nVakuuttamisvelvollisuus ei koske:\n1) maatalousyrittäjän toimintaa ennen 18 vuoden iän täyttämistä seuraavan kalenterikuukauden alkua eikä toimintaa, joka jatkuu sen kalenterikuukauden jälkeen, jolloin vuonna 1957 tai sitä ennen syntynyt maatalousyrittäjä täyttää 68 vuotta, vuosina 1958–1961 syntynyt maatalousyrittäjä täyttää 69 vuotta ja vuonna 1962 ja sen jälkeen syntynyt maatalousyrittäjä täyttää 70 vuotta (vakuuttamisvelvollisuuden yläikäraja); (29.1.2016/75)\n2) maatalousyrittäjän toimintaa, joka ei ole jatkunut 18 vuoden iän täyttämistä seuraavan kalenterikuukauden alun jälkeen yhdenjaksoisesti vähintään neljää kuukautta;\n3) maatalousyrittäjän toimintaa, joka on alkanut tai jatkunut sen jälkeen, kun hän on siirtynyt työeläkelakien mukaiselle vanhuuseläkkeelle;\n4) maatalousyrittäjää, jonka työtulo tässä laissa tarkoitetusta maatalousyrittäjätoiminnasta on arvioitava pienemmäksi kuin 2 752,07 euroa vuodessa;\n5) maatilatalouden, kalastuksen tai poronhoidon yhteydessä harjoitettua toimintaa, jota on pidettävä eri yrityksenä;\n6) ansiotyötä, jonka perusteella maatalousyrittäjällä on oikeus eläkkeeseen muun työeläkelain mukaan; eikä\n7) maatalousyrittäjää, johon ei sovelleta Suomen lainsäädäntöä EU:n sosiaaliturvan perusasetuksen tai sosiaaliturvasopimuksen sovellettavaa lainsäädäntöä koskevien määräysten perusteella. (14.5.2010/357)\n\nVakuuttamisvelvollisuus ei koske apurahansaajan työtä:\n1) ennen 18 vuoden iän täyttämistä seuraavan kalenterikuukauden alkua, eikä työtä, joka jatkuu sen kalenterikuukauden jälkeen, jolloin vuonna 1957 tai sitä ennen syntynyt apurahansaaja täyttää 68 vuotta, vuosina 1958–1961 syntynyt apurahansaaja täyttää 69 vuotta ja vuonna 1962 ja sen jälkeen syntynyt apurahansaaja täyttää 70 vuotta (vakuuttamisvelvollisuuden yläikäraja); (29.1.2016/75)\n2) joka ei ole jatkunut 18 vuoden iän täyttämistä seuraavan kalenterikuukauden alun jälkeen yhdenjaksoisesti vähintään neljä kuukautta;\n3) joka on alkanut tai jatkunut sen jälkeen, kun hän on siirtynyt työeläkelakien mukaiselle vanhuuseläkkeelle;\n4) ajalta, jona apurahansaajalle arvioitava vuotuinen työtulo on pienempi kuin 2 752,07 euroa;\n5) jos apurahansaajaan ei sovelleta Suomen sosiaaliturvalainsäädäntöä EU:n sosiaaliturvan perusasetuksen tai sosiaaliturvasopimuksen sovellettavaa lainsäädäntöä koskevien määräysten perusteella. (14.5.2010/357)"
                },
                "athlete": {
                    "label": "Urheilijan eläke",
                    "description": ""
                },
                "compensation": {
                    "label": "Työkorvaus",
                    "description": ""
                },
                "boardRemuneration": {
                    "label": "Hallituspalkkio",
                    "description": ""
                }
            },
            "Product": {
                "accounting": {
                    "description": "Palkkalaskelmien tiedot helposti kirjanpitäjälle",
                    "label": "Kirjanpitoraportit",
                    "status": "Ei käytössä"
                },
                "baseService": {
                    "description": "Digiajan palkanmaksupalvelu",
                    "label": "Palkkaus.fi-tili",
                    "status": "Palkkaamisen peruspalvelut"
                },
                "healthCareHeltti": {
                    "description": "Tuottavammat ja terveemmät työntekijät",
                    "label": "Työterveyshuolto",
                    "status": "Ei sopimusta"
                },
                "insurance": {
                    "description": "Tapaturmavakuutus vakuuttaa työntekijäsi",
                    "label": "Työtapaturmavakuutus",
                    "status": "Ei sopimusta. HUOM: työnantajan 1300 € :n vuosisääntö!"
                },
                "pension": {
                    "description": "TyEL-vakuutus on työntekijän eläketurva",
                    "label": "TyEL-eläkevakuutus",
                    "status": "Ei sopimusta: TyEL maksetaan tilapäisenä työnantajana"
                },
                "pensionEntrepreneur": {
                    "description": "YEL-vakuutus on yrittäjän eläketurva",
                    "label": "Yrittäjän eläke",
                    "status": "Ei YEL-sopimusta"
                },
                "tax": {
                    "description": "Ennakonpidätykset ja sava-maksu",
                    "label": "Yhteydet verottajaan",
                    "status": "Ennakonpidätys ja ilmoitukset"
                },
                "taxCard": {
                    "description": "Työntekijän verokortti ja sen käsittely",
                    "label": "Verokortti (TT)",
                    "status": "Ei verokorttia"
                },
                "unemployment": {
                    "description": "Työttömyysturva rahoitetaan TVR-maksuilla",
                    "label": "Työttömyysvakuutus (TVR)",
                    "status": "Ilmoitukset TVR:lle",
                    "statusTVR": "Ilmoitukset TVR:lle"
                }
            },
            "ProductListFilter": {
                "all": {
                    "description": "",
                    "label": "All products, even the currently non-available."
                },
                "available": {
                    "description": "",
                    "label": "Available products for this user"
                }
            },
            "Profession": {
                "0": {
                    "label": "Sotilaat"
                },
                "1": {
                    "label": "Johtajat"
                },
                "2": {
                    "label": "Erityisasiantuntijat"
                },
                "3": {
                    "label": "Asiantuntijat"
                },
                "4": {
                    "label": "Toimisto- ja asiakaspalvelutyöntekijät"
                },
                "5": {
                    "label": "Palvelu- ja myyntityöntekijät"
                },
                "6": {
                    "label": "Maanviljelijät, metsätyöntekijät ym."
                },
                "7": {
                    "label": "Rakennus-, korjaus- ja valmistustyöntekijät"
                },
                "8": {
                    "label": "Prosessi- ja kuljetustyöntekijät"
                },
                "9": {
                    "label": "Muut työntekijät"
                },
                "11": {
                    "label": "Johtajat, ylimmät virkamiehet ja järjestöjen johtajat"
                },
                "12": {
                    "label": "Hallintojohtajat ja kaupalliset johtajat"
                },
                "13": {
                    "label": "Tuotantotoiminnan ja yhteiskunnan peruspalvelujen johtajat"
                },
                "14": {
                    "label": "Hotelli- ja ravintola-alan, vähittäiskaupan ja muiden palvelualojen johtajat"
                },
                "21": {
                    "label": "Luonnontieteiden ja tekniikan erityisasiantuntijat"
                },
                "22": {
                    "label": "Terveydenhuollon erityisasiantuntijat"
                },
                "23": {
                    "label": "Opettajat ja muut opetusalan erityisasiantuntijat"
                },
                "24": {
                    "label": "Liike-elämän ja hallinnon erityisasiantuntijat"
                },
                "25": {
                    "label": "Tieto- ja viestintäteknologian erityisasiantuntijat"
                },
                "26": {
                    "label": "Lainopilliset, sosiaalialan ja kulttuurialan erityisasiantuntijat"
                },
                "31": {
                    "label": "Luonnontieteiden ja tekniikan asiantuntijat"
                },
                "32": {
                    "label": "Terveydenhuollon asiantuntijat"
                },
                "33": {
                    "label": "Liike-elämän ja hallinnon asiantuntijat"
                },
                "34": {
                    "label": "Lainopilliset avustajat sekä sosiaali- ja kulttuurialan asiantuntijat"
                },
                "35": {
                    "label": "Informaatio- ja tietoliikenneteknologian asiantuntijat"
                },
                "41": {
                    "label": "Toimistotyöntekijät"
                },
                "42": {
                    "label": "Asiakaspalvelutyöntekijät"
                },
                "43": {
                    "label": "Laskennan ja varastoinnin toimistotyöntekijät"
                },
                "44": {
                    "label": "Muut toimisto- ja asiakaspalvelutyöntekijät"
                },
                "51": {
                    "label": "Palvelutyöntekijät"
                },
                "52": {
                    "label": "Myyjät, kauppiaat ym."
                },
                "53": {
                    "label": "Hoivapalvelun ja terveydenhuollon työntekijät"
                },
                "54": {
                    "label": "Suojelu- ja vartiointityöntekijät"
                },
                "61": {
                    "label": "Maanviljelijät ja eläintenkasvattajat ym."
                },
                "62": {
                    "label": "Metsä- ja kalatalouden työntekijät"
                },
                "63": {
                    "label": "Kotitarveviljelijät, -kalastajat ja -metsästäjät"
                },
                "71": {
                    "label": "Rakennustyöntekijät ym. (pl. sähköasentajat)"
                },
                "72": {
                    "label": "Konepaja- ja valimotyöntekijät sekä asentajat ja korjaajat"
                },
                "73": {
                    "label": "Käsityötuotteiden valmistajat, hienomekaanikot sekä painoalan työntekijät"
                },
                "74": {
                    "label": "Sähkö- ja elektroniikka-alan työntekijät"
                },
                "75": {
                    "label": "Elintarvike-, puutyö- ja vaatetus- ja jalkinealan valmistustyöntekijät ym."
                },
                "81": {
                    "label": "Prosessityöntekijät"
                },
                "82": {
                    "label": "Teollisuustuotteiden kokoonpanijat"
                },
                "83": {
                    "label": "Kuljetustyöntekijät"
                },
                "91": {
                    "label": "Siivoojat, kotiapulaiset ja muut puhdistustyöntekijät"
                },
                "92": {
                    "label": "Maa-, metsä- ja kalatalouden avustavat työntekijät"
                },
                "93": {
                    "label": "Teollisuuden ja rakentamisen avustavat työntekijät"
                },
                "94": {
                    "label": "Avustavat keittiö- ja ruokatyöntekijät"
                },
                "95": {
                    "label": "Katumyyjät, kengänkiillottajat ym."
                },
                "96": {
                    "label": "Katujen puhtaanapidon ja jätehuollon työntekijät ym."
                },
                "111": {
                    "label": "Ylimmät virkamiehet ja järjestöjen johtajat"
                },
                "112": {
                    "label": "Toimitusjohtajat ja pääjohtajat"
                },
                "121": {
                    "label": "Liiketoiminta- ja hallintojohtajat"
                },
                "122": {
                    "label": "Myynti-, markkinointi- ja kehitysjohtajat"
                },
                "131": {
                    "label": "Maa-, metsä- ja kalatalouden johtajat"
                },
                "132": {
                    "label": "Teollisuuden tuotantojohtajat sekä kaivos-, rakennus- ja jakelujohtajat"
                },
                "133": {
                    "label": "Tieto- ja viestintäteknologiajohtajat"
                },
                "134": {
                    "label": "Yhteiskunnan peruspalvelujen sekä rahoitus- ja vakuutuspalvelujen johtajat"
                },
                "141": {
                    "label": "Hotellin- ja ravintolanjohtajat"
                },
                "142": {
                    "label": "Vähittäis- ja tukkukaupan johtajat"
                },
                "143": {
                    "label": "Muiden palvelualojen johtajat"
                },
                "211": {
                    "label": "Luonnon- ja geotieteen erityisasiantuntijat"
                },
                "212": {
                    "label": "Matematiikan ja tilastotieteen erityisasiantuntijat"
                },
                "213": {
                    "label": "Biotieteiden erityisasiantuntijat"
                },
                "214": {
                    "label": "Tekniikan erityisasiantuntijat (pl. sähköteknologia)"
                },
                "215": {
                    "label": "Sähköteknologian erityisasiantuntijat"
                },
                "216": {
                    "label": "Arkkitehdit, suunnittelijat ja maanmittaajat"
                },
                "221": {
                    "label": "Lääkärit"
                },
                "222": {
                    "label": "Hoitotyön erityisasiantuntijat"
                },
                "223": {
                    "label": "Perinteisen ja vaihtoehtohoidon erityisasiantuntijat"
                },
                "224": {
                    "label": "Muiden terveyspalvelujen tuottajat"
                },
                "225": {
                    "label": "Eläinlääkärit"
                },
                "226": {
                    "label": "Muut terveydenhuollon erityisasiantuntijat"
                },
                "231": {
                    "label": "Yliopisto- ja korkeakouluopettajat"
                },
                "232": {
                    "label": "Ammatillisen koulutuksen opettajat"
                },
                "233": {
                    "label": "Lukion ja peruskoulun yläluokkien opettajat"
                },
                "234": {
                    "label": "Peruskoulun alaluokkien opettajat ja lastentarhanopettajat"
                },
                "235": {
                    "label": "Muut opetusalan erityisasiantuntijat"
                },
                "241": {
                    "label": "Rahoitusalan erityisasiantuntijat"
                },
                "242": {
                    "label": "Hallinnon erityisasiantuntijat"
                },
                "243": {
                    "label": "Myynnin, markkinoinnin ja tiedotuksen erityisasiantuntijat"
                },
                "251": {
                    "label": "Systeemityön erityisasiantuntijat"
                },
                "252": {
                    "label": "Tietokantojen,- verkkojen ja järjestelmäohjelmistojen erityisasiantuntijat"
                },
                "261": {
                    "label": "Lainopilliset erityisasiantuntijat"
                },
                "262": {
                    "label": "Kirjaston- ja arkistonhoitajat sekä museoalan erityisasiantuntijat"
                },
                "263": {
                    "label": "Yhteiskunta- ja sosiaalialan sekä uskonnollisen elämän erityisasiantuntijat"
                },
                "264": {
                    "label": "Toimittajat, kirjailijat ja kielitieteilijät"
                },
                "265": {
                    "label": "Taiteilijat"
                },
                "311": {
                    "label": "Fysiikan, kemian ja teknisten alojen asiantuntijat"
                },
                "312": {
                    "label": "Työnjohtajat kaivos-, teollisuus- ja rakennustoiminnassa"
                },
                "313": {
                    "label": "Prosessinvalvonnan asiantuntijat"
                },
                "314": {
                    "label": "Biotieteiden asiantuntijat"
                },
                "315": {
                    "label": "Laiva-, lento- ja satamaliikenteen päälliköt ja ohjaajat"
                },
                "321": {
                    "label": "Terveydenhuollon tekniset asiantuntijat"
                },
                "322": {
                    "label": "Sairaanhoitajat, kätilöt ym."
                },
                "323": {
                    "label": "Luontais- ja vaihtoehtohoitajat"
                },
                "324": {
                    "label": "Seminologit ym."
                },
                "325": {
                    "label": "Muut terveydenhuollon asiantuntijat"
                },
                "331": {
                    "label": "Rahoitus-, vakuutus- ja laskentatoimen asiantuntijat"
                },
                "332": {
                    "label": "Myynti- ja ostoagentit"
                },
                "333": {
                    "label": "Yrityspalveluiden välittäjät"
                },
                "334": {
                    "label": "Hallinnolliset ja erikoistuneet sihteerit"
                },
                "335": {
                    "label": "Julkishallinnon valmistelu- ja valvontavirkamiehet"
                },
                "341": {
                    "label": "Lainopilliset asiantuntijat sekä sosiaalialan ja seurakunnan työntekijät"
                },
                "342": {
                    "label": "Urheilijat, urheiluvalmentajat, liikunnanohjaajat ym."
                },
                "343": {
                    "label": "Taide- ja kulttuurialan asiantuntijat sekä keittiöpäälliköt"
                },
                "351": {
                    "label": "Informaatio- ja tietoliikenneteknologian teknikot sekä käyttäjätukihenkilöt"
                },
                "352": {
                    "label": "Teleliikenne- sekä radio- ja tv-teknikot"
                },
                "411": {
                    "label": "Toimistoavustajat"
                },
                "412": {
                    "label": "Yleissihteerit"
                },
                "413": {
                    "label": "Tekstinkäsittelijät ja tallentajat"
                },
                "421": {
                    "label": "Rahaliikenteen asiakaspalvelutyöntekijät"
                },
                "422": {
                    "label": "Muut asiakaspalvelutyöntekijät"
                },
                "431": {
                    "label": "Palkanlaskijat, vakuutuskäsittelijät ym."
                },
                "432": {
                    "label": "Kuljetuksen ja varastoinnin toimistotyöntekijät"
                },
                "441": {
                    "label": "Muut toimisto- ja asiakaspalvelutyöntekijät"
                },
                "511": {
                    "label": "Matkustuspalvelutyöntekijät, konduktöörit ja oppaat"
                },
                "512": {
                    "label": "Ravintola- ja suurtaloustyöntekijät"
                },
                "513": {
                    "label": "Tarjoilutyöntekijät"
                },
                "514": {
                    "label": "Kampaajat, parturit, kosmetologit ym."
                },
                "515": {
                    "label": "Kiinteistöhuollon ja siivoustyön esimiehet"
                },
                "516": {
                    "label": "Muut henkilökohtaisen palvelun työntekijät"
                },
                "521": {
                    "label": "Katu- ja torikauppiaat"
                },
                "522": {
                    "label": "Myyjät ja kauppiaat"
                },
                "523": {
                    "label": "Kassanhoitajat ja lipunmyyjät"
                },
                "524": {
                    "label": "Muut myyntityöntekijät"
                },
                "531": {
                    "label": "Lastenhoitajat ja koulunkäyntiavustajat"
                },
                "532": {
                    "label": "Lähihoitajat, muut terveydenhuollon työntekijät ja kodinhoitajat"
                },
                "541": {
                    "label": "Suojelu- ja vartiointityöntekijät"
                },
                "611": {
                    "label": "Pelto- ja puutarhaviljelijät"
                },
                "612": {
                    "label": "Eläintenkasvattajat"
                },
                "613": {
                    "label": "Yhdistetyn maanviljelyn ja eläintenkasvatuksen harjoittajat"
                },
                "621": {
                    "label": "Metsurit ja metsätyöntekijät"
                },
                "622": {
                    "label": "Kalanviljelijät, kalastajat ja metsästäjät"
                },
                "631": {
                    "label": "Kotitarveviljelijät"
                },
                "632": {
                    "label": "Kotitarvekarjankasvattajat"
                },
                "633": {
                    "label": "Kotitarveviljelijät ja -karjankasvattajat"
                },
                "634": {
                    "label": "Kotitarvekalastajat ja -metsästäjät"
                },
                "711": {
                    "label": "Rakennustyöntekijät ym."
                },
                "712": {
                    "label": "Rakennusten viimeistelytyöntekijät"
                },
                "713": {
                    "label": "Maalarit ja rakennuspuhdistajat"
                },
                "721": {
                    "label": "Valimotyöntekijät, hitsaajat, levysepät ym."
                },
                "722": {
                    "label": "Sepät, työkaluntekijät ja koneenasettajat"
                },
                "723": {
                    "label": "Koneasentajat ja -korjaajat"
                },
                "731": {
                    "label": "Käsityötuotteiden valmistajat ja hienomekaanikot"
                },
                "732": {
                    "label": "Painoalan työntekijät"
                },
                "741": {
                    "label": "Sähkölaitteiden asentajat ja korjaajat"
                },
                "742": {
                    "label": "Elektroniikka- ja tietoliikenneasentajat ja -korjaajat"
                },
                "751": {
                    "label": "Lihanleikkaajat, leipurit, meijeristit ym."
                },
                "752": {
                    "label": "Puutavaran käsittelijät, puusepät ym."
                },
                "753": {
                    "label": "Vaatetusalan työntekijät ym."
                },
                "754": {
                    "label": "Muut pääluokkaan 7 luokiteltavat työntekijät"
                },
                "811": {
                    "label": "Kaivos- ja louhintatyön koneenkäyttäjät"
                },
                "812": {
                    "label": "Metalliteollisuuden prosessityöntekijät ja viimeistelijät"
                },
                "813": {
                    "label": "Kemianteollisuuden ja valokuvatuotteiden valmistuksen prosessityöntekijät"
                },
                "814": {
                    "label": "Kumi-, muovi- ja paperituotteiden valmistuksen prosessityöntekijät"
                },
                "815": {
                    "label": "Tekstiili-, turkis- ja nahkatuoteteollisuuden prosessityöntekijät"
                },
                "816": {
                    "label": "Elintarviketeollisuuden prosessityöntekijät"
                },
                "817": {
                    "label": "Sahatavaran sekä paperin ja kartongin valmistuksen prosessityöntekijät"
                },
                "818": {
                    "label": "Muut prosessityöntekijät"
                },
                "821": {
                    "label": "Teollisuustuotteiden kokoonpanijat"
                },
                "831": {
                    "label": "Raideliikenteen kuljettajat ja työntekijät"
                },
                "832": {
                    "label": "Henkilö- ja pakettiauton- sekä moottoripyöränkuljettajat"
                },
                "833": {
                    "label": "Raskaiden moottoriajoneuvojen kuljettajat"
                },
                "834": {
                    "label": "Työkoneiden kuljettajat"
                },
                "835": {
                    "label": "Kansimiehistö ym. vesiliikenteen työntekijät"
                },
                "911": {
                    "label": "Koti-, hotelli- ja toimistosiivoojat ym."
                },
                "912": {
                    "label": "Ajoneuvojen puhdistajat, ikkunanpesijät ym."
                },
                "921": {
                    "label": "Maa-, metsä- ja kalatalouden avustavat työntekijät"
                },
                "931": {
                    "label": "Avustavat kaivos- ja rakennustyöntekijät"
                },
                "932": {
                    "label": "Valmistusalan avustavat työntekijät"
                },
                "933": {
                    "label": "Rahdinkäsittelijät ja varastotyöntekijät ym."
                },
                "941": {
                    "label": "Avustavat keittiö- ja ruokatyöntekijät"
                },
                "951": {
                    "label": "Mainosten jakajat, kengänkiillottajat ym."
                },
                "952": {
                    "label": "Katumyyjät (pl. elintarvikkeet)"
                },
                "961": {
                    "label": "Jätehuoltotyöntekijät"
                },
                "962": {
                    "label": "Sanomalehtien jakajat, lähetit ym."
                },
                "1111": {
                    "label": "Lainsäätäjät"
                },
                "1112": {
                    "label": "Julkishallinnon ylimmät virkamiehet"
                },
                "1113": {
                    "label": "Heimo- ja kyläpäälliköt"
                },
                "1114": {
                    "label": "Järjestöjen johtajat"
                },
                "1120": {
                    "label": "Toimitusjohtajat ja pääjohtajat"
                },
                "1211": {
                    "label": "Talousjohtajat"
                },
                "1212": {
                    "label": "Henkilöstöjohtajat"
                },
                "1213": {
                    "label": "Politiikka- ja suunnittelujohtajat"
                },
                "1219": {
                    "label": "Muut hallintojohtajat ja kaupalliset johtajat"
                },
                "1221": {
                    "label": "Myynti- ja markkinointijohtajat"
                },
                "1222": {
                    "label": "Mainos- ja tiedotusjohtajat"
                },
                "1223": {
                    "label": "Tutkimus- ja kehitysjohtajat"
                },
                "1311": {
                    "label": "Maa- ja metsätalouden johtajat"
                },
                "1312": {
                    "label": "Vesiviljely- ja kalatalouden johtajat"
                },
                "1321": {
                    "label": "Teollisuuden tuotantojohtajat"
                },
                "1322": {
                    "label": "Kaivostoiminnan tuotantojohtajat"
                },
                "1323": {
                    "label": "Rakennustoiminnan tuotantojohtajat"
                },
                "1324": {
                    "label": "Hankinta- ja jakelujohtajat"
                },
                "1330": {
                    "label": "Tieto- ja viestintäteknologiajohtajat"
                },
                "1341": {
                    "label": "Lastenhoidon johtajat"
                },
                "1342": {
                    "label": "Terveydenhuollon johtajat"
                },
                "1343": {
                    "label": "Vanhustenhuollon johtajat"
                },
                "1344": {
                    "label": "Sosiaalihuollon johtajat"
                },
                "1345": {
                    "label": "Opetusalan johtajat"
                },
                "1346": {
                    "label": "Rahoitus- ja vakuutuspalvelujen johtajat"
                },
                "1349": {
                    "label": "Muut yhteiskunnan palvelujen johtajat"
                },
                "1411": {
                    "label": "Hotellinjohtajat"
                },
                "1412": {
                    "label": "Ravintolanjohtajat"
                },
                "1420": {
                    "label": "Vähittäis- ja tukkukaupan johtajat"
                },
                "1431": {
                    "label": "Urheilu-, vapaa-aika- ja kulttuurikeskusten johtajat"
                },
                "1439": {
                    "label": "Muut palvelualojen johtajat"
                },
                "2111": {
                    "label": "Fyysikot ja astronomit"
                },
                "2112": {
                    "label": "Meteorologit"
                },
                "2113": {
                    "label": "Kemistit"
                },
                "2114": {
                    "label": "Geologit ja geofyysikot"
                },
                "2120": {
                    "label": "Matemaatikot, aktuaarit ja tilastotieteilijät"
                },
                "2131": {
                    "label": "Biologit, kasvi- ja eläintieteilijät ym. erityisasiantuntijat"
                },
                "2132": {
                    "label": "Maa-, metsä- ja kalatalouden erityisasiantuntijat"
                },
                "2133": {
                    "label": "Ympäristön- ja luonnonsuojelun erityisasiantuntijat"
                },
                "2141": {
                    "label": "Teollisen valmistuksen ja tuotantotekniikan erityisasiantuntijat"
                },
                "2142": {
                    "label": "Maa- ja vesirakentamisen erityisasiantuntijat"
                },
                "2143": {
                    "label": "Ympäristötekniikan erityisasiantuntijat"
                },
                "2144": {
                    "label": "Konetekniikan erityisasiantuntijat"
                },
                "2145": {
                    "label": "Puunjalostuksen ja kemian prosessitekniikan erityisasiantuntijat"
                },
                "2146": {
                    "label": "Kaivosteollisuuden, metallurgian ym. erityisasiantuntijat"
                },
                "2149": {
                    "label": "Muut tekniikan erityisasiantuntijat"
                },
                "2151": {
                    "label": "Sähkötekniikan erityisasiantuntijat"
                },
                "2152": {
                    "label": "Elektroniikan erityisasiantuntijat"
                },
                "2153": {
                    "label": "ICT-alan erityisasiantuntijat"
                },
                "2161": {
                    "label": "Talonrakennuksen arkkitehdit"
                },
                "2162": {
                    "label": "Maisema-arkkitehdit"
                },
                "2163": {
                    "label": "Tuote- ja vaatesuunnittelijat"
                },
                "2164": {
                    "label": "Yhdyskunta- ja liikennesuunnittelijat"
                },
                "2165": {
                    "label": "Kartoituksen ja maanmittauksen erityisasiantuntijat"
                },
                "2166": {
                    "label": "Graafiset ja multimediasuunnittelijat"
                },
                "2211": {
                    "label": "Yleislääkärit"
                },
                "2212": {
                    "label": "Ylilääkärit ja erikoislääkärit"
                },
                "2221": {
                    "label": "Ylihoitajat ja osastonhoitajat"
                },
                "2222": {
                    "label": "Johtavat kätilöt"
                },
                "2230": {
                    "label": "Perinteisen ja vaihtoehtohoidon erityisasiantuntijat"
                },
                "2240": {
                    "label": "Muiden terveyspalvelujen tuottajat"
                },
                "2250": {
                    "label": "Eläinlääkärit"
                },
                "2261": {
                    "label": "Hammaslääkärit"
                },
                "2262": {
                    "label": "Proviisorit"
                },
                "2263": {
                    "label": "Ympäristöterveyden ja työsuojelun erityisasiantuntijat"
                },
                "2264": {
                    "label": "Fysioterapian erityisasiantuntijat"
                },
                "2265": {
                    "label": "Ravitsemusalan erityisasiantuntijat"
                },
                "2266": {
                    "label": "Kuulontutkijat ja puheterapeutit"
                },
                "2267": {
                    "label": "Optometrian erityisasiantuntijat"
                },
                "2269": {
                    "label": "Muut muualla luokittelemattomat terveydenhuollon erityisasiantuntijat"
                },
                "2310": {
                    "label": "Yliopistojen ja ammattikorkeakoulujen opettajat"
                },
                "2320": {
                    "label": "Ammatillisen koulutuksen opettajat"
                },
                "2330": {
                    "label": "Lukion ja peruskoulun yläluokkien opettajat"
                },
                "2341": {
                    "label": "Peruskoulun alaluokkien opettajat"
                },
                "2342": {
                    "label": "Lastentarhanopettajat"
                },
                "2351": {
                    "label": "Opetusmenetelmien erityisasiantuntijat"
                },
                "2352": {
                    "label": "Erityisopettajat"
                },
                "2353": {
                    "label": "Muut kieltenopettajat"
                },
                "2354": {
                    "label": "Muut musiikin opettajat"
                },
                "2355": {
                    "label": "Muut taideaineiden opettajat"
                },
                "2356": {
                    "label": "Muut tietotekniikan opettajat ja kouluttajat"
                },
                "2359": {
                    "label": "Opinto-ohjaajat ja muut opetuksen erityisasiantuntijat"
                },
                "2411": {
                    "label": "Laskentatoimen erityisasiantuntijat ja tilintarkastajat"
                },
                "2412": {
                    "label": "Rahoitus- ja sijoitusneuvojat"
                },
                "2413": {
                    "label": "Rahoitusanalyytikot"
                },
                "2421": {
                    "label": "Johtamisen ja organisaatioiden erityisasiantuntijat"
                },
                "2422": {
                    "label": "Hallinnon ja elinkeinojen kehittämisen erityisasiantuntijat"
                },
                "2423": {
                    "label": "Henkilöstöhallinnon erityisasiantuntijat ja urasuunnittelijat"
                },
                "2424": {
                    "label": "Henkilöstön kehittämisen erityisasiantuntijat ja kouluttajat"
                },
                "2431": {
                    "label": "Mainonnan ja markkinoinnin erityisasiantuntijat"
                },
                "2432": {
                    "label": "Tiedottajat"
                },
                "2433": {
                    "label": "Myynti-insinöörit ja lääke-esittelijät (pl. tieto- ja viestintätekniikka)"
                },
                "2434": {
                    "label": "Tieto- ja viestintätekniikan myynnin erityisasiantuntijat"
                },
                "2511": {
                    "label": "Sovellusarkkitehdit"
                },
                "2512": {
                    "label": "Sovellussuunnittelijat"
                },
                "2513": {
                    "label": "Web- ja multimediakehittäjät"
                },
                "2514": {
                    "label": "Sovellusohjelmoijat"
                },
                "2519": {
                    "label": "Muut ohjelmisto- ja sovelluskehittäjät"
                },
                "2521": {
                    "label": "Tietokantasuunnittelijat ja -vastaavat"
                },
                "2522": {
                    "label": "Tietojärjestelmien ylläpitäjät"
                },
                "2523": {
                    "label": "Tietoverkkojen erityisasiantuntijat"
                },
                "2529": {
                    "label": "Muut tietokanta- ja tietoverkkojen erityisasiantuntijat"
                },
                "2611": {
                    "label": "Asianajajat"
                },
                "2612": {
                    "label": "Tuomioistuinlakimiehet"
                },
                "2619": {
                    "label": "Muut lainopilliset erityisasiantuntijat"
                },
                "2621": {
                    "label": "Arkistonhoitajat ja museoalan erityisasiantuntijat"
                },
                "2622": {
                    "label": "Kirjastonhoitajat, informaatikot ym."
                },
                "2631": {
                    "label": "Ekonomistit"
                },
                "2632": {
                    "label": "Yhteiskunta- ja kulttuuritutkijat"
                },
                "2633": {
                    "label": "Historioitsijat, politiikan tutkijat ja filosofit"
                },
                "2634": {
                    "label": "Psykologit"
                },
                "2635": {
                    "label": "Sosiaalityön erityisasiantuntijat"
                },
                "2636": {
                    "label": "Papit ym. uskonnollisen elämän erityisasiantuntijat"
                },
                "2641": {
                    "label": "Kirjailijat ym."
                },
                "2642": {
                    "label": "Toimittajat"
                },
                "2643": {
                    "label": "Kääntäjät, tulkit ja muut kielitieteilijät"
                },
                "2651": {
                    "label": "Kuvataiteilijat"
                },
                "2652": {
                    "label": "Muusikot, laulajat ja säveltäjät"
                },
                "2653": {
                    "label": "Tanssitaiteilijat ja koreografit"
                },
                "2654": {
                    "label": "Ohjaajat ja tuottajat"
                },
                "2655": {
                    "label": "Näyttelijät"
                },
                "2656": {
                    "label": "Juontajat, kuuluttajat ym."
                },
                "2659": {
                    "label": "Muut taiteilijat"
                },
                "3111": {
                    "label": "Luonnontieteen tekniset asiantuntijat"
                },
                "3112": {
                    "label": "Rakentamisen asiantuntijat"
                },
                "3113": {
                    "label": "Sähkötekniikan asiantuntijat"
                },
                "3114": {
                    "label": "Elektroniikan asiantuntijat"
                },
                "3115": {
                    "label": "Konetekniikan asiantuntijat"
                },
                "3116": {
                    "label": "Kemian prosessitekniikan asiantuntijat"
                },
                "3117": {
                    "label": "Kaivosteollisuuden ja metallurgian asiantuntijat"
                },
                "3118": {
                    "label": "Tekniset piirtäjät"
                },
                "3119": {
                    "label": "Muut fysiikan, kemian ja teknisten alojen asiantuntijat"
                },
                "3121": {
                    "label": "Kaivostyönjohtajat"
                },
                "3122": {
                    "label": "Teollisuuden työnjohtajat"
                },
                "3123": {
                    "label": "Rakennusalan työnjohtajat"
                },
                "3131": {
                    "label": "Voimalaitosten prosessinhoitajat"
                },
                "3132": {
                    "label": "Jätteenpoltto- ja vedenpuhdistuslaitosten prosessinhoitajat"
                },
                "3133": {
                    "label": "Kemianteollisuuden prosessinhoitajat"
                },
                "3134": {
                    "label": "Öljy- ja maakaasujalostamon prosessinhoitajat"
                },
                "3135": {
                    "label": "Metallien jalostuksen prosessinhoitajat"
                },
                "3139": {
                    "label": "Muut prosessinvalvonnan asiantuntijat"
                },
                "3141": {
                    "label": "Laborantit ym."
                },
                "3142": {
                    "label": "Maa- ja kalatalousteknikot"
                },
                "3143": {
                    "label": "Metsätalousteknikot"
                },
                "3151": {
                    "label": "Laivojen konepäälliköt ja -mestarit"
                },
                "3152": {
                    "label": "Vesiliikenteen perämiehet ja päälliköt"
                },
                "3153": {
                    "label": "Lentokapteenit ja -perämiehet"
                },
                "3154": {
                    "label": "Lennonjohtajat"
                },
                "3155": {
                    "label": "Lennonvalvonnan tekniset asiantuntijat"
                },
                "3211": {
                    "label": "Lääketieteellisen kuvantamis- ja laitetekniikan asiantuntijat"
                },
                "3212": {
                    "label": "Bioanalyytikot (terveydenhuolto)"
                },
                "3213": {
                    "label": "Farmaseutit"
                },
                "3214": {
                    "label": "Hammas- ja apuvälineteknikot"
                },
                "3221": {
                    "label": "Sairaanhoitajat ym."
                },
                "3222": {
                    "label": "Kätilöt"
                },
                "3230": {
                    "label": "Luontais- ja vaihtoehtohoitajat"
                },
                "3240": {
                    "label": "Seminologit ym."
                },
                "3251": {
                    "label": "Suuhygienistit"
                },
                "3252": {
                    "label": "Potilas- ja terveystietojen käsittelijät"
                },
                "3253": {
                    "label": "Terveysneuvojat"
                },
                "3254": {
                    "label": "Optikot"
                },
                "3255": {
                    "label": "Fysioterapeutit ym."
                },
                "3256": {
                    "label": "Avustavat hoitotyöntekijät"
                },
                "3257": {
                    "label": "Terveys- ja työsuojelutarkastajat"
                },
                "3258": {
                    "label": "Sairaankuljetuksen ensihoitajat"
                },
                "3259": {
                    "label": "Muut muualla luokittelemattomat terveydenhuollon asiantuntijat"
                },
                "3311": {
                    "label": "Arvopaperi- ja valuuttakauppiaat"
                },
                "3312": {
                    "label": "Luotto- ja laina-asiantuntijat"
                },
                "3313": {
                    "label": "Kirjanpidon ja laskentatoimen asiantuntijat"
                },
                "3314": {
                    "label": "Tilastointi- ja matematiikka-asiantuntijat"
                },
                "3315": {
                    "label": "Arvioitsijat ja vahinkotarkastajat"
                },
                "3321": {
                    "label": "Vakuutusalan palvelumyyjät"
                },
                "3322": {
                    "label": "Myyntiedustajat"
                },
                "3323": {
                    "label": "Sisäänostajat"
                },
                "3324": {
                    "label": "Kaupanvälittäjät"
                },
                "3331": {
                    "label": "Huolitsijat, tulli- ja laivanselvittäjät"
                },
                "3332": {
                    "label": "Konferenssi- ja tapahtumajärjestäjät"
                },
                "3333": {
                    "label": "Työnvälittäjät"
                },
                "3334": {
                    "label": "Kiinteistönvälittäjät ja isännöitsijät"
                },
                "3339": {
                    "label": "Muut liike-elämän asiantuntijat"
                },
                "3341": {
                    "label": "Toimistotyön esimiehet"
                },
                "3342": {
                    "label": "Asianajosihteerit"
                },
                "3343": {
                    "label": "Johdon sihteerit ja osastosihteerit"
                },
                "3344": {
                    "label": "Toimistosihteerit (terveydenhuolto)"
                },
                "3351": {
                    "label": "Tulli- ja rajavirkamiehet"
                },
                "3352": {
                    "label": "Verovalmistelijat ja -tarkastajat"
                },
                "3353": {
                    "label": "Sosiaaliturvaetuuksien käsittelijät"
                },
                "3354": {
                    "label": "Lupavirkamiehet"
                },
                "3355": {
                    "label": "Komisariot ja ylikonstaapelit"
                },
                "3359": {
                    "label": "Muut julkishallinnon valmistelu- ja valvontavirkamiehet"
                },
                "3411": {
                    "label": "Lainopilliset avustajat ja järjestöalan asiantuntijat"
                },
                "3412": {
                    "label": "Sosiaalialan ohjaajat ja neuvojat ym."
                },
                "3413": {
                    "label": "Seurakuntatyöntekijät"
                },
                "3421": {
                    "label": "Urheilijat"
                },
                "3422": {
                    "label": "Urheiluvalmentajat ja toimitsijat"
                },
                "3423": {
                    "label": "Liikunnan ja vapaa-ajan ohjaajat"
                },
                "3431": {
                    "label": "Valokuvaajat"
                },
                "3432": {
                    "label": "Sisustussuunnittelijat ym."
                },
                "3433": {
                    "label": "Gallerioiden, museoiden ja kirjastojen tekniset työntekijät"
                },
                "3434": {
                    "label": "Keittiöpäälliköt"
                },
                "3435": {
                    "label": "Muut taide- ja kulttuurialan asiantuntijat"
                },
                "3511": {
                    "label": "Käytön operaattorit"
                },
                "3512": {
                    "label": "Käytön tukihenkilöt"
                },
                "3513": {
                    "label": "Tietoverkkoteknikot"
                },
                "3514": {
                    "label": "Webmasterit ja -teknikot"
                },
                "3521": {
                    "label": "Lähetys- ja audiovisuaaliteknikot"
                },
                "3522": {
                    "label": "Televiestinnän tekniset asiantuntijat"
                },
                "4110": {
                    "label": "Toimistoavustajat"
                },
                "4120": {
                    "label": "Yleissihteerit"
                },
                "4131": {
                    "label": "Tekstinkäsittelijät"
                },
                "4132": {
                    "label": "Tallentajat"
                },
                "4211": {
                    "label": "Pankki- ym. toimihenkilöt"
                },
                "4212": {
                    "label": "Vedonvälittäjät, bingo- ja kasinopelin hoitajat ym."
                },
                "4213": {
                    "label": "Panttilainaajat"
                },
                "4214": {
                    "label": "Maksujenperijät"
                },
                "4221": {
                    "label": "Matkatoimistovirkailijat"
                },
                "4222": {
                    "label": "Puhelinpalveluneuvojat"
                },
                "4223": {
                    "label": "Puhelinvaihteenhoitajat"
                },
                "4224": {
                    "label": "Hotellin vastaanottovirkailijat"
                },
                "4225": {
                    "label": "Informaatiopisteen asiakasneuvojat"
                },
                "4226": {
                    "label": "Vastaanoton ja neuvonnan hoitajat"
                },
                "4227": {
                    "label": "Tutkimus- ja markkinatutkimushaastattelijat"
                },
                "4229": {
                    "label": "Muualla luokittelemattomat asiakaspalvelutyöntekijät"
                },
                "4311": {
                    "label": "Taloushallinnon toimistotyöntekijät"
                },
                "4312": {
                    "label": "Tilasto-, rahoitus- ja vakuutusalan toimistotyöntekijät"
                },
                "4313": {
                    "label": "Palkanlaskijat"
                },
                "4321": {
                    "label": "Varastonhoitajat ym."
                },
                "4322": {
                    "label": "Tuotannon valmistelijat"
                },
                "4323": {
                    "label": "Kuljetuksen toimistotyöntekijät"
                },
                "4411": {
                    "label": "Kirjastotyöntekijät"
                },
                "4412": {
                    "label": "Postinkantajat ja -lajittelijat"
                },
                "4413": {
                    "label": "Koodaajat, oikolukijat ym."
                },
                "4414": {
                    "label": "Kirjurit ym."
                },
                "4415": {
                    "label": "Arkistotyöntekijät"
                },
                "4416": {
                    "label": "Henkilöstöhallinnon avustavat toimistotyöntekijät"
                },
                "4419": {
                    "label": "Muut muualla luokittelemattomat toimisto- ja asiakaspalvelutyöntekijät"
                },
                "5111": {
                    "label": "Lentoemännät, purserit ym."
                },
                "5112": {
                    "label": "Konduktöörit, lipuntarkastajat ym."
                },
                "5113": {
                    "label": "Matkaoppaat"
                },
                "5120": {
                    "label": "Ravintola- ja suurtaloustyöntekijät"
                },
                "5131": {
                    "label": "Tarjoilijat"
                },
                "5132": {
                    "label": "Baarimestarit"
                },
                "5141": {
                    "label": "Kampaajat ja parturit"
                },
                "5142": {
                    "label": "Kosmetologit ym."
                },
                "5151": {
                    "label": "Siivoustyön esimiehet toimistoissa, hotelleissa ja muissa laitoksissa"
                },
                "5152": {
                    "label": "Yksityiskotien taloudenhoitajat"
                },
                "5153": {
                    "label": "Kiinteistöhuollon työntekijät"
                },
                "5161": {
                    "label": "Astrologit, ennustajat ym."
                },
                "5162": {
                    "label": "Henkilökohtaiset palvelijat"
                },
                "5163": {
                    "label": "Hautauspalvelutyöntekijät"
                },
                "5164": {
                    "label": "Eläintenhoitajat ja lemmikkieläinten trimmaajat"
                },
                "5165": {
                    "label": "Ajo-opettajat"
                },
                "5169": {
                    "label": "Muualla luokittelemattomat henkilökohtaisen palvelun työntekijät"
                },
                "5211": {
                    "label": "Kioski- ja torimyyjät"
                },
                "5212": {
                    "label": "Katumyyjät (elintarvikkeet)"
                },
                "5221": {
                    "label": "Kauppiaat (pienyrittäjät)"
                },
                "5222": {
                    "label": "Myymäläesimiehet"
                },
                "5223": {
                    "label": "Myyjät"
                },
                "5230": {
                    "label": "Kassanhoitajat ja lipunmyyjät"
                },
                "5241": {
                    "label": "Mallit"
                },
                "5242": {
                    "label": "Tuote-esittelijät"
                },
                "5243": {
                    "label": "Suoramyyjät"
                },
                "5244": {
                    "label": "Puhelin- ja asiakaspalvelukeskusten myyjät"
                },
                "5245": {
                    "label": "Huoltamotyöntekijät"
                },
                "5246": {
                    "label": "Kahvila- ja baarimyyjät"
                },
                "5249": {
                    "label": "Muut muualla luokittelemattomat myyntityöntekijät"
                },
                "5311": {
                    "label": "Lastenhoitotyöntekijät"
                },
                "5312": {
                    "label": "Koulunkäyntiavustajat"
                },
                "5321": {
                    "label": "Lähihoitajat"
                },
                "5322": {
                    "label": "Kodinhoitajat (kotipalvelutoiminta)"
                },
                "5329": {
                    "label": "Muut terveydenhuoltoalan työntekijät"
                },
                "5411": {
                    "label": "Palomiehet"
                },
                "5412": {
                    "label": "Poliisit"
                },
                "5413": {
                    "label": "Vanginvartijat"
                },
                "5414": {
                    "label": "Vartijat"
                },
                "5419": {
                    "label": "Muut suojelu- ja vartiointityöntekijät"
                },
                "6111": {
                    "label": "Pelto- ja avomaaviljelijät"
                },
                "6112": {
                    "label": "Hedelmäpuiden ja pensaiden yms. kasvattajat"
                },
                "6113": {
                    "label": "Puutarhurit, kasvihuoneviljelijät ja -työntekijät"
                },
                "6114": {
                    "label": "Yhdistetyn maan- ja vihannesviljelyn tai puutarhanhoidon ym. harjoittajat"
                },
                "6121": {
                    "label": "Liha- ja lypsykarjan kasvattajat sekä muiden kotieläinten kasvattajat"
                },
                "6122": {
                    "label": "Siipikarjankasvattajat"
                },
                "6123": {
                    "label": "Mehiläistenhoitajat ym."
                },
                "6129": {
                    "label": "Muut eläinten kasvattajat ja hoitajat"
                },
                "6130": {
                    "label": "Yhdistetyn maanviljelyn ja eläintenkasvatuksen harjoittajat"
                },
                "6210": {
                    "label": "Metsurit ja metsätyöntekijät"
                },
                "6221": {
                    "label": "Kalanviljelijät ja -viljelytyöntekijät"
                },
                "6222": {
                    "label": "Kalastajat"
                },
                "6223": {
                    "label": "Syvänmerenkalastajat"
                },
                "6224": {
                    "label": "Riistanhoitajat ja metsästäjät"
                },
                "6310": {
                    "label": "Kotitarveviljelijät"
                },
                "6320": {
                    "label": "Kotitarvekarjankasvattajat"
                },
                "6330": {
                    "label": "Kotitarveviljelijät ja -karjankasvattajat"
                },
                "6340": {
                    "label": "Kotitarvekalastajat ja -metsästäjät"
                },
                "7111": {
                    "label": "Talonrakentajat"
                },
                "7112": {
                    "label": "Muurarit ym."
                },
                "7113": {
                    "label": "Kivenhakkaajat ja -leikkaajat ym."
                },
                "7114": {
                    "label": "Betonirakentajat ja raudoittajat"
                },
                "7115": {
                    "label": "Kirvesmiehet ja rakennuspuusepät"
                },
                "7119": {
                    "label": "Muut rakennustyöntekijät"
                },
                "7121": {
                    "label": "Kattoasentajat ja -korjaajat"
                },
                "7122": {
                    "label": "Lattianpäällystystyöntekijät"
                },
                "7123": {
                    "label": "Rappaajat"
                },
                "7124": {
                    "label": "Eristäjät"
                },
                "7125": {
                    "label": "Lasinasentajat"
                },
                "7126": {
                    "label": "Putkiasentajat"
                },
                "7127": {
                    "label": "Ilmastointi- ja jäähdytyslaiteasentajat"
                },
                "7131": {
                    "label": "Rakennusmaalarit ym."
                },
                "7132": {
                    "label": "Ruiskumaalaajat ja -lakkaajat"
                },
                "7133": {
                    "label": "Rakennuspuhdistajat ja nuohoojat"
                },
                "7211": {
                    "label": "Muotin- ja keernantekijät"
                },
                "7212": {
                    "label": "Hitsaajat ja kaasuleikkaajat"
                },
                "7213": {
                    "label": "Ohutlevysepät"
                },
                "7214": {
                    "label": "Paksulevysepät ja rautarakennetyöntekijät"
                },
                "7215": {
                    "label": "Kaapelin- ja köysienasentajat"
                },
                "7221": {
                    "label": "Sepät"
                },
                "7222": {
                    "label": "Työkaluntekijät ja lukkosepät"
                },
                "7223": {
                    "label": "Koneenasettajat ja koneistajat"
                },
                "7224": {
                    "label": "Konehiojat, kiillottajat ja teroittajat"
                },
                "7231": {
                    "label": "Moottoriajoneuvojen asentajat ja korjaajat"
                },
                "7232": {
                    "label": "Lentokoneasentajat ja -korjaajat"
                },
                "7233": {
                    "label": "Maatalous- ja teollisuuskoneasentajat ja -korjaajat"
                },
                "7234": {
                    "label": "Polkupyöränkorjaajat ym."
                },
                "7311": {
                    "label": "Kellosepät ja muut hienomekaanisten instrumenttien tekijät ja korjaajat"
                },
                "7312": {
                    "label": "Soittimien tekijät ja virittäjät"
                },
                "7313": {
                    "label": "Koru-, kulta- ja hopeasepät"
                },
                "7314": {
                    "label": "Saven- ja tiilenvalajat ja dreijaajat"
                },
                "7315": {
                    "label": "Lasinpuhaltajat, -leikkaajat, -hiojat ja -viimeistelijät"
                },
                "7316": {
                    "label": "Kaivertajat, etsaajat ja koristemaalarit"
                },
                "7317": {
                    "label": "Puu-, kori- yms. käsityötuotteiden tekijät"
                },
                "7318": {
                    "label": "Tekstiili-, nahka- yms. käsityötuotteiden tekijät"
                },
                "7319": {
                    "label": "Muut käsityöntekijät"
                },
                "7321": {
                    "label": "Painopinnanvalmistajat"
                },
                "7322": {
                    "label": "Painajat"
                },
                "7323": {
                    "label": "Jälkikäsittelijät ja sitomotyöntekijät"
                },
                "7411": {
                    "label": "Rakennussähköasentajat"
                },
                "7412": {
                    "label": "Muut sähköasentajat"
                },
                "7413": {
                    "label": "Linja-asentajat ja -korjaajat"
                },
                "7421": {
                    "label": "Elektroniikka- ja automaatiolaitteiden asentajat ja korjaajat"
                },
                "7422": {
                    "label": "Tieto- ja viestintäteknologian asentajat ja korjaajat"
                },
                "7511": {
                    "label": "Lihanleikkaajat, kalankäsittelijät ym."
                },
                "7512": {
                    "label": "Leipurit ja kondiittorit"
                },
                "7513": {
                    "label": "Meijeristit, juustomestarit ym."
                },
                "7514": {
                    "label": "Hedelmä- ja vihannestuotteiden valmistajat"
                },
                "7515": {
                    "label": "Ruokien ja juomien laaduntarkkailijat"
                },
                "7516": {
                    "label": "Tupakkatuotteiden valmistajat"
                },
                "7521": {
                    "label": "Raakapuun käsittelijät"
                },
                "7522": {
                    "label": "Huonekalupuusepät ym."
                },
                "7523": {
                    "label": "Konepuusepät"
                },
                "7531": {
                    "label": "Vaatturit, pukuompelijat, turkkurit ja hatuntekijät"
                },
                "7532": {
                    "label": "Leikkaajat ja mallimestarit"
                },
                "7533": {
                    "label": "Koru- ja muut tekstiiliompelijat"
                },
                "7534": {
                    "label": "Verhoilijat"
                },
                "7535": {
                    "label": "Turkisten muokkaajat ja nahkurit"
                },
                "7536": {
                    "label": "Suutarit ym."
                },
                "7541": {
                    "label": "Vedenalaistyöntekijät"
                },
                "7542": {
                    "label": "Panostajat ja räjäyttäjät"
                },
                "7543": {
                    "label": "Luokittelijat ja laaduntarkkailijat (pl. ruoat ja juomat)"
                },
                "7544": {
                    "label": "Savupuhdistajat, tuholais- ja rikkakasvintorjujat"
                },
                "7549": {
                    "label": "Muut pääluokkaan 7 muualla luokittelemattomat työntekijät"
                },
                "8111": {
                    "label": "Kaivos- ja louhostyöntekijät"
                },
                "8112": {
                    "label": "Rikastustyöntekijät"
                },
                "8113": {
                    "label": "Iskuporaajat ja syväkairaajat"
                },
                "8114": {
                    "label": "Betonituote- ym. teollisuuden prosessityöntekijät"
                },
                "8121": {
                    "label": "Metalliteollisuuden prosessityöntekijät"
                },
                "8122": {
                    "label": "Metallien teolliset päällystäjät ja viimeistelijät"
                },
                "8131": {
                    "label": "Kemianteollisuuden prosessityöntekijät ym."
                },
                "8132": {
                    "label": "Valokuvatuotteiden valmistuksen prosessityöntekijät"
                },
                "8141": {
                    "label": "Kumituoteteollisuuden prosessityöntekijät"
                },
                "8142": {
                    "label": "Muovituoteteollisuuden prosessityöntekijät"
                },
                "8143": {
                    "label": "Paperituoteteollisuuden prosessityöntekijät"
                },
                "8151": {
                    "label": "Kuitujenkäsittely-, kehruu- ja puolauskoneiden hoitajat"
                },
                "8152": {
                    "label": "Kutoma- ja neulekoneiden hoitajat"
                },
                "8153": {
                    "label": "Teollisuusompelijat"
                },
                "8154": {
                    "label": "Valkaisu-, värjäys- ja puhdistuskoneiden hoitajat"
                },
                "8155": {
                    "label": "Turkisten ja nahkojen teolliset käsittelijät, värjääjät ym."
                },
                "8156": {
                    "label": "Jalkine- ja laukkuteollisuuden prosessityöntekijät"
                },
                "8157": {
                    "label": "Pesulatyöntekijät"
                },
                "8159": {
                    "label": "Muut tekstiili-, turkis- ja nahkatuoteteollisuuden prosessityöntekijät"
                },
                "8160": {
                    "label": "Elintarviketeollisuuden prosessityöntekijät"
                },
                "8171": {
                    "label": "Paperimassan sekä paperin ja kartongin valmistuksen prosessityöntekijät"
                },
                "8172": {
                    "label": "Puu- ja sahatavaran prosessityöntekijät"
                },
                "8181": {
                    "label": "Lasi- ja keramiikkateollisuuden uunienhoitajat"
                },
                "8182": {
                    "label": "Höyrykoneiden ja lämmityskattiloiden hoitajat, lämmittäjät ym."
                },
                "8183": {
                    "label": "Pakkaus-, pullotus- ja etiköintikoneiden hoitajat"
                },
                "8189": {
                    "label": "Muut muualla luokittelemattomat prosessityöntekijät"
                },
                "8211": {
                    "label": "Konepaja- ja metallituotteiden kokoonpanijat"
                },
                "8212": {
                    "label": "Sähkö- ja elektroniikkalaitteiden kokoonpanijat"
                },
                "8219": {
                    "label": "Muut teollisuustuotteiden kokoonpanijat"
                },
                "8311": {
                    "label": "Veturinkuljettajat"
                },
                "8312": {
                    "label": "Jarru-, turvalaite- ja vaihdetyöntekijät"
                },
                "8321": {
                    "label": "Moottoripyörälähetit yms."
                },
                "8322": {
                    "label": "Henkilö-, taksi- ja pakettiautonkuljettajat"
                },
                "8331": {
                    "label": "Linja-auton- ja raitiovaununkuljettajat"
                },
                "8332": {
                    "label": "Kuorma-auton ja erikoisajoneuvojen kuljettajat"
                },
                "8341": {
                    "label": "Maa- ja metsätaloustyökoneiden kuljettajat"
                },
                "8342": {
                    "label": "Maansiirtokoneiden ym. kuljettajat"
                },
                "8343": {
                    "label": "Nosturinkuljettajat"
                },
                "8344": {
                    "label": "Ahtaajat ja trukinkuljettajat ym."
                },
                "8350": {
                    "label": "Kansimiehistö ym. vesiliikenteen työntekijät"
                },
                "9111": {
                    "label": "Kotiapulaiset ja -siivoojat"
                },
                "9112": {
                    "label": "Toimisto- ja laitossiivoojat ym."
                },
                "9121": {
                    "label": "Puhdistajat ja prässääjät"
                },
                "9122": {
                    "label": "Ajoneuvojen pesijät"
                },
                "9123": {
                    "label": "Ikkunanpesijät"
                },
                "9129": {
                    "label": "Muut puhdistustyöntekijät"
                },
                "9211": {
                    "label": "Maanviljelyn avustavat työntekijät"
                },
                "9212": {
                    "label": "Karjankasvatuksen avustavat työntekijät"
                },
                "9213": {
                    "label": "Yhdistetyn maanviljelyn ja karjankasvatuksen avustavat työntekijät"
                },
                "9214": {
                    "label": "Avustavat puutarhatyöntekijät"
                },
                "9215": {
                    "label": "Metsätalouden avustavat työntekijät"
                },
                "9216": {
                    "label": "Kalatalouden ja vesiviljelyn avustavat työntekijät"
                },
                "9311": {
                    "label": "Kaivosten avustavat työntekijät"
                },
                "9312": {
                    "label": "Maa- ja vesirakentamisen avustavat työntekijät"
                },
                "9313": {
                    "label": "Rakennusalan avustavat työntekijät"
                },
                "9321": {
                    "label": "Käsinpakkaajat"
                },
                "9329": {
                    "label": "Muut valmistusalan avustavat työntekijät"
                },
                "9331": {
                    "label": "Käsivetoisten- ja poljinkulkuneuvojen kuljettajat"
                },
                "9332": {
                    "label": "Eläinvetoisten kulkuneuvojen kuljettajat"
                },
                "9333": {
                    "label": "Rahdinkäsittelijät, varastotyöntekijät ym."
                },
                "9334": {
                    "label": "Hyllyjen täyttäjät"
                },
                "9411": {
                    "label": "Pikaruokatyöntekijät"
                },
                "9412": {
                    "label": "Avustavat keittiötyöntekijät"
                },
                "9510": {
                    "label": "Mainosten jakajat, kengänkiillottajat ym."
                },
                "9520": {
                    "label": "Katumyyjät (pl. elintarvikkeet)"
                },
                "9611": {
                    "label": "Jätteiden kerääjät"
                },
                "9612": {
                    "label": "Jätteiden lajittelijat"
                },
                "9613": {
                    "label": "Kadunlakaisijat ym."
                },
                "9621": {
                    "label": "Sanomalehtien jakajat, lähetit ja kantajat"
                },
                "9622": {
                    "label": "Satunnaistöiden tekijät"
                },
                "9623": {
                    "label": "Mittareiden lukijat ym."
                },
                "9624": {
                    "label": "Vedenhakijat ja polttopuun kerääjät"
                },
                "9629": {
                    "label": "Muut muualla luokittelemattomat työntekijät"
                },
                "11121": {
                    "label": "Valtion keskushallinnon johtajat"
                },
                "11122": {
                    "label": "Alue- ja paikallishallinnon johtajat ja ylimmät virkamiehet"
                },
                "11141": {
                    "label": "Työmarkkina- ja elinkeinoelämän järjestöjen johtajat"
                },
                "11142": {
                    "label": "Muiden järjestöjen johtajat"
                },
                "21321": {
                    "label": "Maa- ja kalatalouden erityisasiantuntijat"
                },
                "21322": {
                    "label": "Metsätalouden erityisasiantuntijat"
                },
                "21531": {
                    "label": "Tietoliikenneteknologian tutkijat"
                },
                "21532": {
                    "label": "Tietotekniikka-alan tutkijat"
                },
                "22121": {
                    "label": "Ylilääkärit"
                },
                "22122": {
                    "label": "Erikoislääkärit"
                },
                "22211": {
                    "label": "Ylihoitajat"
                },
                "22212": {
                    "label": "Osastonhoitajat"
                },
                "23101": {
                    "label": "Professorit"
                },
                "23102": {
                    "label": "Lehtorit ja yliassistentit (yliopisto)"
                },
                "23103": {
                    "label": "Assistentit ja tuntiopettajat (yliopisto)"
                },
                "23104": {
                    "label": "Yliopettajat (AMK)"
                },
                "23105": {
                    "label": "Lehtorit (AMK)"
                },
                "23106": {
                    "label": "Tuntiopettajat ym. (AMK)"
                },
                "23301": {
                    "label": "Matemaattisten aineiden opettajat"
                },
                "23302": {
                    "label": "Äidinkielen ja kirjallisuuden opettajat"
                },
                "23303": {
                    "label": "Taito- ja taideaineiden opettajat"
                },
                "23304": {
                    "label": "Muut peruskoulun yläluokkien ja lukion opettajat"
                },
                "23411": {
                    "label": "Luokanopettajat"
                },
                "23412": {
                    "label": "Aineenopettajat (peruskoulun alaluokat)"
                },
                "23591": {
                    "label": "Opinto-ohjaajat"
                },
                "23592": {
                    "label": "Muut opetuksen erityisasiantuntijat"
                },
                "26211": {
                    "label": "Arkistonhoitajat"
                },
                "26212": {
                    "label": "Museoalan erityisasiantuntijat"
                },
                "26351": {
                    "label": "Sosiaalityöntekijät ym."
                },
                "26352": {
                    "label": "Sosiaalialan suunnittelijat ym."
                },
                "26421": {
                    "label": "Toimituspäälliköt ja -sihteerit, ohjelmapäälliköt"
                },
                "26422": {
                    "label": "Lehtien yms. toimittajat"
                },
                "26423": {
                    "label": "Radio- ja tv-toimittajat"
                },
                "31121": {
                    "label": "Talonrakentamisen asiantuntijat"
                },
                "31122": {
                    "label": "Maa- ja vesirakentamisen asiantuntijat"
                },
                "31123": {
                    "label": "Kartoituksen ja maanmittauksen asiantuntijat"
                },
                "31521": {
                    "label": "Isojen alusten päälliköt ja perämiehet"
                },
                "31522": {
                    "label": "Pienten alusten päälliköt"
                },
                "31523": {
                    "label": "Satamaliikenteen ohjaajat ja satamakapteenit"
                },
                "32141": {
                    "label": "Hammasteknikot"
                },
                "32142": {
                    "label": "Apuvälineteknikot"
                },
                "32211": {
                    "label": "Sairaanhoitajat"
                },
                "32212": {
                    "label": "Terveydenhoitajat"
                },
                "32591": {
                    "label": "Toimintaterapeutit"
                },
                "32592": {
                    "label": "Muut terapeutit"
                },
                "33341": {
                    "label": "Kiinteistönvälittäjät"
                },
                "33342": {
                    "label": "Isännöitsijät"
                },
                "34111": {
                    "label": "Oikeudenkäyntiasiamiehet ja ulosottomiehet"
                },
                "34112": {
                    "label": "Asiamiehet, toimitsijat ym. järjestöalan asiantuntijat"
                },
                "34113": {
                    "label": "Kuluttajaneuvojat ym."
                },
                "34121": {
                    "label": "Sosiaalialan ohjaajat"
                },
                "34122": {
                    "label": "Nuorisotyön ohjaajat (ei srk.)"
                },
                "34123": {
                    "label": "Työn- ja askarteluohjaajat"
                },
                "34131": {
                    "label": "Diakonit ja diakonissat"
                },
                "34139": {
                    "label": "Muut seurakuntatyöntekijät"
                },
                "34351": {
                    "label": "Kuvaussihteerit ja muut näyttämötekniset asiantuntijat"
                },
                "34359": {
                    "label": "Muut taide- ja kulttuurialan tekniset asiantuntijat"
                },
                "42291": {
                    "label": "Hälytyspäivystäjät"
                },
                "42299": {
                    "label": "Muut muualla luokittelemattomat asiakaspalvelutyöntekijät"
                },
                "43231": {
                    "label": "Raideliikenteen ohjaajat, ajojärjestelijät ym."
                },
                "43239": {
                    "label": "Muut kuljetuksen ja huolinnan toimistotyöntekijät"
                },
                "44121": {
                    "label": "Postinkantajat"
                },
                "44122": {
                    "label": "Toimistovahtimestarit"
                },
                "51201": {
                    "label": "Kokit, keittäjät ja kylmäköt"
                },
                "51202": {
                    "label": "Ravintolaesimiehet ja vuoropäälliköt"
                },
                "51631": {
                    "label": "Hautaustoimistonhoitajat ym."
                },
                "51632": {
                    "label": "Muut hautaustyöntekijät"
                },
                "53111": {
                    "label": "Päiväkotien ja muiden laitosten lastenhoitajat ym."
                },
                "53112": {
                    "label": "Perhepäivähoitajat"
                },
                "53113": {
                    "label": "Lastenkerhojen ohjaajat ym."
                },
                "53211": {
                    "label": "Mielenterveyshoitajat"
                },
                "53212": {
                    "label": "Kehitysvammaisten hoitajat"
                },
                "53213": {
                    "label": "Sosiaalialan hoitajat"
                },
                "53219": {
                    "label": "Muut lähihoitajat"
                },
                "53221": {
                    "label": "Kotityöpalvelutyöntekijät"
                },
                "53222": {
                    "label": "Henkilökohtaiset avustajat, omaishoitajat ym."
                },
                "53291": {
                    "label": "Hammashoitajat"
                },
                "53292": {
                    "label": "Välinehuoltajat"
                },
                "53293": {
                    "label": "Apteekkien lääketyöntekijät"
                },
                "53294": {
                    "label": "Hierojat ja kuntohoitajat"
                },
                "61111": {
                    "label": "Peltoviljelijät"
                },
                "61112": {
                    "label": "Peltoviljelytyönjohtajat ja -työntekijät"
                },
                "61131": {
                    "label": "Puutarhurit ja kasvihuoneviljelijät"
                },
                "61132": {
                    "label": "Puutarha- ja kasvihuonetyönjohtajat ja - työntekijät"
                },
                "61211": {
                    "label": "Karjankasvattajat ym."
                },
                "61212": {
                    "label": "Karjanhoitajat ym."
                },
                "61213": {
                    "label": "Lemmikkieläinten kasvattajat"
                },
                "61214": {
                    "label": "Maatalouslomittajat"
                },
                "61291": {
                    "label": "Turkiseläinten ja porojen kasvattajat"
                },
                "61299": {
                    "label": "Muualla luokittelemattomat eläintenhoitajat"
                },
                "62211": {
                    "label": "Kalanviljely-yrittäjät"
                },
                "62212": {
                    "label": "Kalanviljelytyönjohtajat ja -työntekijät"
                },
                "74211": {
                    "label": "Elektroniikka-asentajat ja -korjaajat"
                },
                "74212": {
                    "label": "Automaatioasentajat ja -korjaajat"
                },
                "81821": {
                    "label": "Voima- ja jätteenkäsittelylaitosten laitosmiehet"
                },
                "81822": {
                    "label": "Muut laitosmiehet ym."
                },
                "83441": {
                    "label": "Ahtaajat"
                },
                "83442": {
                    "label": "Trukinkuljettajat ym."
                },
                "91121": {
                    "label": "Toimistosiivoojat ym."
                },
                "91122": {
                    "label": "Hotellisiivoojat"
                },
                "91123": {
                    "label": "Sairaala- ja laitosapulaiset"
                },
                "91124": {
                    "label": "Päiväkotiapulaiset"
                },
                "91129": {
                    "label": "Muut muualla luokittelemattomat siivoojat"
                },
                "01": {
                    "label": "Upseerit"
                },
                "011": {
                    "label": "Upseerit"
                },
                "0110": {
                    "label": "Upseerit"
                },
                "02": {
                    "label": "Aliupseerit"
                },
                "021": {
                    "label": "Aliupseerit"
                },
                "0210": {
                    "label": "Aliupseerit"
                },
                "03": {
                    "label": "Sotilasammattihenkilöstö"
                },
                "031": {
                    "label": "Sotilasammattihenkilöstö"
                },
                "0310": {
                    "label": "Sotilasammattihenkilöstö"
                },
                "#X": {
                    "label": "Tuntematon"
                },
                "#XX": {
                    "label": "Tuntematon"
                },
                "#XXX": {
                    "label": "Tuntematon"
                },
                "#XXXX": {
                    "label": "Tuntematon"
                },
                "#XXXXX": {
                    "label": "Tuntematon"
                }
            },
            "ReportCategory": {
                "all": {
                    "description": "",
                    "label": "All"
                },
                "monthly": {
                    "description": "",
                    "label": "Monthly"
                },
                "yearly": {
                    "description": "",
                    "label": "Yearly"
                }
            },
            "ReportType": {
                "employerReport": {
                    "description": "",
                    "label": "Työntekijäraportti"
                },
                "employmentContract": {
                    "description": "",
                    "label": "Työsopimus"
                },
                "example": {
                    "description": "",
                    "label": "Esimerkki"
                },
                "householdDeduction": {
                    "description": "",
                    "label": "Kotitalousvähennys"
                },
                "insurance": {
                    "description": "",
                    "label": "Vakuutus"
                },
                "monthlyDetails": {
                    "description": "",
                    "label": "Kuukausittaisia tietoja"
                },
                "monthlyLiikekirjuri": {
                    "description": "",
                    "label": ""
                },
                "monthlyPension": {
                    "description": "",
                    "label": "Kuukausittainen eläke"
                },
                "monthlyRapko": {
                    "description": "",
                    "label": ""
                },
                "paymentReport": {
                    "description": "",
                    "label": "Maksuraportti"
                },
                "salarySlip": {
                    "description": "",
                    "label": "Palkkakuitti"
                },
                "salarySlipPaid": {
                    "description": "",
                    "label": "Palkkakuitti maksettu"
                },
                "taxHouseholdDeduction14B": {
                    "description": "",
                    "label": ""
                },
                "taxHouseholdDeduction14BSpouseA": {
                    "description": "",
                    "label": ""
                },
                "taxHouseholdDeduction14BSpouseB": {
                    "description": "",
                    "label": ""
                },
                "taxMonthly4001": {
                    "description": "",
                    "label": "Kuukausittainen vero"
                },
                "taxYearly7801": {
                    "description": "",
                    "label": "Vuosittainen vero"
                },
                "undefined": {
                    "description": "",
                    "label": "Ei määritelty"
                },
                "unemployment": {
                    "description": "",
                    "label": "Työttömyys"
                },
                "yearEndReport": {
                    "description": "",
                    "label": "Loppuvuoden raportti"
                },
                "yearlyDetails": {
                    "description": "",
                    "label": "Vuosittaisia tietoja"
                },
                "yearlyWorkerSummary": {
                    "description": "",
                    "label": ""
                }
            },
            "SalaryKind": {
                "compensation": {
                    "description": "",
                    "label": "Korvaus"
                },
                "fixedSalary": {
                    "description": "",
                    "label": "Kiinteä palkka"
                },
                "hourlySalary": {
                    "description": "",
                    "label": "Tuntipalkka"
                },
                "monthlySalary": {
                    "description": "",
                    "label": "Kuukausipalkka"
                },
                "totalEmployerPayment": {
                    "description": "",
                    "label": ""
                },
                "totalWorkerPayment": {
                    "description": "",
                    "label": ""
                },
                "undefined": {
                    "description": "",
                    "label": "Ei määritelty"
                }
            },
            "SalaryPeriod": {
                "fixed": {
                    "description": "",
                    "label": "Fixed"
                },
                "hourly": {
                    "description": "",
                    "label": "Hourly"
                },
                "monthly": {
                    "description": "",
                    "label": "Monthly"
                },
                "notDefined": {
                    "description": "",
                    "label": "Not Defined"
                }
            },
            "SalaryPerMonthRange": {
                "noPensionRequired": {
                    "description": "",
                    "label": "Alle 57,10 €"
                },
                "normal": {
                    "description": "",
                    "label": "57,10 € tai yli"
                },
                "unknown": {
                    "description": "",
                    "label": "Ei tiedossa"
                }
            },
            "SalaryPerYearRange": {
                "noMonthlyReporting": {
                    "description": "",
                    "label": "201 - 1500 €"
                },
                "noReportingNecessary": {
                    "description": "",
                    "label": "1 - 200 €"
                },
                "normal": {
                    "description": "",
                    "label": "Yli 1500 €"
                },
                "zeroSalary": {
                    "description": "",
                    "label": 0
                }
            },
            "TaxCardIncomeType": {
                "externalSalaries": {
                    "description": "",
                    "label": "Ulkopuoliset palkat"
                },
                "previousEmployerSalaries": {
                    "description": "Merkitse tähän työntekijän edellisten työnantajien kuluvana verovuonna maksamat palkat yhteensä euroina.",
                    "label": "Edellisten työnantajien maksamat palkat"
                },
                "salaxyCalculation": {
                    "description": "",
                    "label": "Salaxy laskelma"
                },
                "unknown": {
                    "description": "",
                    "label": "Tuntematon"
                }
            },
            "TaxCardState": {
                "approved": {
                    "description": "",
                    "label": "Hyväksytty"
                },
                "new": {
                    "description": "",
                    "label": "Uusi"
                },
                "rejected": {
                    "description": "",
                    "label": "Hylätty"
                },
                "waiting": {
                    "description": "",
                    "label": "Odottaa"
                }
            },
            "TaxCardType": {
                "example": {
                    "description": "",
                    "label": "Esimerkkiverokortti"
                },
                "freelancer": {
                    "description": "",
                    "label": "Freelanceverokortti"
                },
                "noTaxCard": {
                    "description": "",
                    "label": "Ei verokorttia (ennakonpidätys 60%)"
                },
                "noTaxPrepayment": {
                    "description": "",
                    "label": "Ei ennakonpidätystä"
                },
                "others": {
                    "description": "",
                    "label": "Muu"
                },
                "sideIncome": {
                    "description": "",
                    "label": "Sivuntulon verokortti"
                },
                "steps": {
                    "description": "",
                    "label": "Portaikkoverokortti"
                },
                "taxCardA": {
                    "description": "",
                    "label": "A-verokortti (kausikohtaiset tulorajat)"
                },
                "taxCardB": {
                    "description": "",
                    "label": "B-verokortti (yksi tuloraja koko vuodelle)"
                }
            },
            "TaxDeductionWorkCategories": {
                "carework": {
                    "description": "",
                    "label": "Hoiva- tai hoitotyö"
                },
                "homeImprovement": {
                    "description": "",
                    "label": "Asunnon kunnossapito- tai perusparannustyö"
                },
                "householdwork": {
                    "description": "",
                    "label": "Kotitaloustyö"
                },
                "none": {
                    "description": "",
                    "label": "Ei valintaa"
                },
                "ownPropety": {
                    "description": "",
                    "label": "Omassa käytössä oleva asunto tai vapaa-ajan asunto"
                },
                "relativesProperty": {
                    "description": "",
                    "label": "Vanhempien, isovanhempien yms. käytössä oleva asunto tai vapaa-ajan asunto."
                }
            },
            "TesSubtype": {
                "constructionCarpenter": {
                    "description": "",
                    "label": "Construction Carpenter"
                },
                "constructionFloor": {
                    "description": "",
                    "label": "Construction Floor"
                },
                "constructionFreeContract": {
                    "description": "",
                    "label": "Construction Free Contract"
                },
                "constructionOther": {
                    "description": "",
                    "label": "Construction Other"
                },
                "notSelected": {
                    "description": "",
                    "label": "Not Selected"
                }
            },
            "TestEnum": {
                "valueEight": {
                    "description": "",
                    "label": "Value Eight"
                },
                "valueFive": {
                    "description": "",
                    "label": "Value Five"
                },
                "valueFour": {
                    "description": "",
                    "label": "Value Four"
                },
                "valueNine": {
                    "description": "",
                    "label": "Value Nine"
                },
                "valueOne": {
                    "description": "",
                    "label": "Value One"
                },
                "valueSevdescription": "",
                "valueSevlabel": "Value Seven",
                "valueSix": {
                    "description": "",
                    "label": "Value Six"
                },
                "valueTdescription": "",
                "valueThree": {
                    "description": "",
                    "label": "Value Three"
                },
                "valueTlabel": "Value Ten",
                "valueTwo": {
                    "description": "",
                    "label": "Value Two"
                },
                "valueZero": {
                    "description": "",
                    "label": "Value Zero"
                }
            },
            "UnionPaymentType": {
                "notSelected": {
                    "description": "",
                    "label": "Ei jäsenyyttä"
                },
                "other": {
                    "description": "",
                    "label": "Muu liitto..."
                },
                "raksaNormal": {
                    "description": "",
                    "label": "Rakennusliitto, A-jäsen"
                },
                "raksaUnemploymentOnly": {
                    "description": "",
                    "label": "Rakennusliitto, OA- tai TA-jäsen"
                }
            },
            "WebSiteUserRole": {
                "company": {
                    "description": "",
                    "label": "Yrittäjä"
                },
                "household": {
                    "description": "",
                    "label": "Työnantaja (kotitalous)"
                },
                "none": {
                    "description": "",
                    "label": "Valitse rooli..."
                },
                "worker": {
                    "description": "",
                    "label": "Työntekijä"
                }
            },
            "YtjCompanyType": {
                "alandFederation": {
                    "description": "",
                    "label": "Ahvenanmaan liikelaitos"
                },
                "asoAssociation": {
                    "description": "",
                    "label": "Asumisoikeusyhdistys"
                },
                "association": {
                    "description": "",
                    "label": "Aatteellinen yhdistys"
                },
                "condominium": {
                    "description": "",
                    "label": "Asunto-osakeyhtiö"
                },
                "cooperativeBank": {
                    "description": "",
                    "label": "Osuuspankki"
                },
                "europeanCooperative": {
                    "description": "",
                    "label": "Eurooppaosuuskunta"
                },
                "europeanCooperativeBank": {
                    "description": "",
                    "label": "Eurooppaosuuspankki"
                },
                "federationOfMunicipalitiesEstablishment": {
                    "description": "",
                    "label": "Kuntainliiton liikelaitos"
                },
                "financialAssociation": {
                    "description": "",
                    "label": "Taloudellinen yhdistys"
                },
                "forestCareAssociation": {
                    "description": "",
                    "label": "Metsänhoitoyhdistys"
                },
                "foundation": {
                    "description": "",
                    "label": "Säätiö"
                },
                "housingCooperative": {
                    "description": "",
                    "label": "Asunto-osuuskunta"
                },
                "hypoAssociation": {
                    "description": "",
                    "label": "Hypoteekkiyhdistys"
                },
                "insuranceAssociation": {
                    "description": "",
                    "label": "Vakuutusyhdistys"
                },
                "ky": {
                    "description": "",
                    "label": "Kommandiittiyhtiö"
                },
                "municipalEstablishment": {
                    "description": "",
                    "label": "Kunnallinen liikelaitos"
                },
                "mutualInsuranceAssociation": {
                    "description": "",
                    "label": "Keskinäinen vahinkovak.yhdistys"
                },
                "noCompanyType": {
                    "description": "",
                    "label": "Ei yritysmuotoa"
                },
                "openCompany": {
                    "description": "",
                    "label": "Avoin yhtiö"
                },
                "osuuskunta": {
                    "description": "",
                    "label": "Osuuskunta"
                },
                "otherAssociation": {
                    "description": "",
                    "label": "Muu yhdistys"
                },
                "otherFinancialAssociation": {
                    "description": "",
                    "label": "Muu taloudellinen yhdistys"
                },
                "oy": {
                    "description": "",
                    "label": "Osakeyhtiö"
                },
                "privateEntrepreneur": {
                    "description": "",
                    "label": "Yksityinen elinkeinonharjoittaja l. toiminimi"
                },
                "reindeerHerdingCooperative": {
                    "description": "",
                    "label": "Paliskunta"
                },
                "savingsBank": {
                    "description": "",
                    "label": "Säästöpankki"
                },
                "specialPurposeAssociation": {
                    "description": "",
                    "label": "Erityislainsäädäntöön perustuva yhdistys"
                },
                "stateEstablishment": {
                    "description": "",
                    "label": "Valtion liikelaitos"
                },
                "unknown": {
                    "description": "",
                    "label": "Tuntematon yritysmuoto"
                }
            },
            "TaxcardKind": {
                "undefined": {
                    "label": "Verokorttia ei ole määritetty"
                },
                "noTaxCard": {
                    "label": "Ei verokorttia (60%)"
                },
                "defaultYearly": {
                    "label": "Alkuperäinen verokortti"
                },
                "replacement": {
                    "label": "Muutosverokortti"
                },
                "others": {
                    "label": "Muu verokortti"
                },
                "historical": {
                    "label": "Vanha verokortti"
                }
            },
            "CarBenefitCode": {
                "limitedCarBenefit": {
                    "label": "Käyttöetu"
                },
                "fullCarBenefit": {
                    "label": "Vapaa autoetu"
                }
            },
            "AgeGroupCode": {
                "a": {
                    "label": "Ikäryhmä A"
                },
                "b": {
                    "label": "Ikäryhmä B"
                },
                "c": {
                    "label": "Ikäryhmä C"
                },
                "u": {
                    "label": "Ikäryhmä U"
                }
            },
            "AllowanceCode": {
                "mealAllowance": {
                    "label": "Ateriakorvaus"
                },
                "partialDailyAllowance": {
                    "label": "Osapäiväraha"
                },
                "fullDailyAllowance": {
                    "label": "Kokopäiväraha"
                },
                "internationalDailyAllowance": {
                    "label": "Ulkomaan päiväraha"
                },
                "expensesWorkingAbroad": {
                    "label": "Ulkomaan työskentelyyn liittyvät verovapaat korvaukset"
                }
            },
            "BoardKind": {
                "undefined": {
                    "label": "Oletusarvo",
                    "description": "Oletusarvo"
                }
            },
            "IrFlags": {
                "noMoney": {
                    "label": "Maksettu muuna kuin rahana (NoMoney)"
                },
                "oneOff": {
                    "label": "Kertakorvaus (OneOff)"
                },
                "unjustEnrichment": {
                    "label": "Perusteeton etu (UnjustEnrichment)"
                }
            },
            "CalculationFlag": {
                "exclude": {
                    "label": "Ei käytetä laskelmalla"
                },
                "pensionInsurance": {
                    "label": "Työeläkevakuutusmaksun alainen"
                },
                "accidentInsurance": {
                    "label": "Työtapaturma- ja ammattitautivakuutusmaksun alainen"
                },
                "unemploymentInsurance": {
                    "label": "Työttömyysvakuutusmaksun alainen"
                },
                "healthInsurance": {
                    "label": "Sairausvakuutusmaksun alainen"
                },
                "noTax": {
                    "label": "Ei vaikuta ennakonpidätykseen"
                },
                "tax": {
                    "label": "Lasketaan ennakonpidätykseen"
                },
                "taxDeduction": {
                    "label": "Vähentää ennakonpidätrystä"
                },
                "cfNoPayment": {
                    "label": "Ei makseta asiakasvaratilin kautta"
                },
                "cfPayment": {
                    "label": "Maksetaan asiakasvaratilin kautta"
                },
                "cfDeduction": {
                    "label": "Vähennetään maksusta asiakasvaratililla"
                },
                "cfDeductionAtSalaxy": {
                    "label": "Vähennetään nettomaksusta asiakasvaratililtä työntekijälle"
                }
            },
            "IrInsuranceExceptions": {
                "includeAll": {
                    "label": "Lisää kaikkien sosiaalivakuutusmaksujen alaisuus"
                },
                "includePension": {
                    "label": "Lisää työeläkevakuutusmaksun alaisuus"
                },
                "includeHealthInsurance": {
                    "label": "Lisää sairausvakuutusmaksun alaisuus"
                },
                "includeUnemployment": {
                    "label": "Lisää työttömyysvakuutusmaksun alaisuus"
                },
                "includeAccidentInsurance": {
                    "label": "Lisää työtapaturma- ja ammattitautivakuutusmaksun alaisuus"
                },
                "excludeAll": {
                    "label": "Poista kaikkien sosiaalivakuutusmaksujen alaisuus"
                },
                "excludePension": {
                    "label": "Poista työeläkevakuutusmaksun alaisuus"
                },
                "excludeHealthInsurance": {
                    "label": "Poista sairausvakuutusmaksun alaisuus"
                },
                "excludeUnemployment": {
                    "label": "Poista työttömyysvakuutusmaksun alaisuus"
                },
                "excludeAccidentInsurance": {
                    "label": "Poista työtapaturma- ja ammattitautivakuutusmaksun alaisuus"
                }
            },
            "UnionPaymentKind": {
                "undefined": {
                    "label": "Ei jäsenyyttä",
                    "description": "AY-jäsenmaksun tyyppiä ei valittu, rivi poistetaan"
                },
                "raksaNormal": {
                    "label": "Muu liitto...",
                    "description": "Rakennusliiton normaalijäsenyys. Palkkaus.fi hoitaa maksun suoraan."
                },
                "raksaUnemploymentOnly": {
                    "label": "Rakennusliitto, A-jäsen",
                    "description": "Rakennusliiton jäsenyys vain työttömyyskassassa. Palkkaus.fi hoitaa maksun suoraan."
                },
                "other": {
                    "label": "Rakennusliitto, OA- tai TA-jäsen",
                    "description": "Muu liitto: Työnantaja hoitaa maksun ja ilmoituksen itse."
                }
            },
            "SubsidisedCommuteKind": {
                "undefined": {
                    "label": "Ei valintaa",
                    "description": "Ei valintaa, oletus \"Ei vähennystä\""
                },
                "noDeduction": {
                    "label": "Ei vähennystä",
                    "description": "Ei vähennystä työntekijän palkasta"
                },
                "singleDeduction": {
                    "label": "Vähennys palkasta kerralla",
                    "description": "Vähennys työntekijän palkasta otetaan kerralla (tästä palkkalaskelmasta)"
                },
                "periodicalDeduction": {
                    "label": "Vähennys jaetaan palkkakausille",
                    "description": "Vähennys työntekijän palkasta jaetaan palkkakausiin (oletus 12 kuukautta)."
                }
            },
            "NonProfitOrgKind": {
                "undefined": {
                    "label": "Tyyppiä ei määritetty",
                    "description": "Tyyppiä ei määritetty, oletus kilometrikorvaus"
                },
                "kilometreAllowance": {
                    "label": "Kilometrikorvaus",
                    "description": "Matkakustannusten korvaus. Muulla kuin julkisella kulkuneuvolla tehdystä matkasta on verovapaata enintään 3 000 euroa kalenterivuodelta."
                },
                "dailyAllowance": {
                    "label": "Päiväraha",
                    "description": "Päivärahan voi maksaa enintään 20 päivältä per kalenterivuosi ja lisäksi majoittumiskorvaus (kts alla)."
                },
                "accomodationAllowance": {
                    "label": "Majoittumiskorvaus",
                    "description": "Majoittumiskorvaus (tositteen perusteella). "
                }
            },
            "MealBenefitKind": {
                "undefined": {
                    "label": "Ei valintaa",
                    "description": "Ei valintaa, oletus \"Verotusarvo\"."
                },
                "cateringContract": {
                    "label": "Sopimusruokailu",
                    "description": "Työnantajan järjestämä sopimusruokailu, jonka kustannus työnantajalle on verottajan vuosittain määrittämissä rajoissa (vuonna 2020 6,80€ - 10,70€). Arvostetaan verotuksessa 6,80€ per ruokailu."
                },
                "mealTicket": {
                    "label": "Ruokailulipuke",
                    "description": "Ruokailulipuke (Lounasseteli tai vast.) tai maksukortille ladattava tapahtuma, jonka kustannus työnantajalle on verottajan vuosittain määrittämissä rajoissa (vuonna 2020 6,80€ - 10,70€). Arvostetaan verotuksessa 75 % nimellisarvosta."
                },
                "taxableAmount": {
                    "label": "Ravintoetu, verotusarvo",
                    "description": "Jos ravintoedun hankkimisesta työnantajalle aiheutuneiden kustannusten määrä on yli tai alle verottajan vuosittain määrittämien rajojen (vuonna 2020 6,80€ - 10,70€) tai jos etu muuten ylittää rajata (esim. enemmän ruokailuja kuin työpäiviä), edun arvona pidetään suoria kustannuksia / nimellisarvoa.\nKäytä tätä valintaa myös, jos et halua käyttää automaattista verotusarvon laskentaa muissa kohdissa."
                },
                "mealAllowance": {
                    "label": "Ateriakorvaus",
                    "description": "Ateriakorvauksen on veroton korvaus (muut tämän sivun valinnat ovat ravintoetuja / luontoisetuja). Sen maksaminen edellyttää, että työmatkasta ei suoriteta päivärahaa ja että palkansaajalla ei työn vuoksi ole mahdollisuutta ruokailutauon aikana aterioida tavanomaisella ruokailupaikallaan. \nLuonnollisesti näiltä päiviltä ei voi käyttää muuta ravintoetua. Ateriakorvauksen enimmäismäärä on 10,75€ per ateria, 2 ateriaa per päivä (21,50 € per päivä)."
                },
                "institute": {
                    "label": "Sairaalan, koulun, päiväkodin tms. ruokailu",
                    "description": "Sairaalan, koulun, päiväkodin tai muun vastaavan laitoksen henkilökuntaan kuuluvan laitosruokailun yhteydessä saaman ravintoedun raha-arvona pidetään 5,10 € ateriaa kohden (vuonna 2020)."
                },
                "teacher": {
                    "label": "Ruokailu valvonnan yhteydessä",
                    "description": "Koulun, päiväkodin tai vastaavan laitoksen henkilökunnan oppilaiden tai hoidettavien ruokailun valvonnan yhteydessä saaman ravintoedun arvo on 4,08 € ateriaa kohden (vuonna 2020)."
                },
                "restaurantWorker": {
                    "label": "Hotelli- ja ravintola-alan ravintoetu",
                    "description": "Hotelli- ja ravintola-alan henkilökunnan ja lentohenkilöstön lennon aikana saaman ravintoedun raha-arvona pidetään 5,78 € ateriaa kohden (vuonna 2020)."
                }
            },
            "DailyAllowanceKind": {
                "undefined": {
                    "label": "Ei valintaa",
                    "description": "Ei valintaa, oletus kokopäiväraha"
                },
                "fullDailyAllowance": {
                    "label": "Kokopäiväraha",
                    "description": "Päiväraha, kun työmatka on yli 10 tuntia."
                },
                "partialDailyAllowance": {
                    "label": "Osapäiväraha",
                    "description": "Päiväraha, kun työmatka on 6-10 tuntia."
                },
                "internationalDailyAllowance": {
                    "label": "Ulkomaan päiväraha",
                    "description": "Päiväraha ulkomaanmatkoilla"
                },
                "mealAllowance": {
                    "label": "Ateriakorvaus",
                    "description": "Ateriakorvauksen voi maksaa työmatkoilta, joilta ei makseta päivärahaa. Ateriakorvauksen enimmäismäärä on 10,75€ per ateria, 2 ateriaa per päivä (21,50 € per päivä)."
                }
            },
            "CarBenefitKind": {
                "undefined": {
                    "label": "Ei valintaa",
                    "description": "Autoedun tyypin valinta on pakollinen"
                },
                "limitedCarBenefit": {
                    "label": "Käyttöetu",
                    "description": "Auton käyttäjä maksaa yksityisajojensa polttoainekustannukset"
                },
                "fullCarBenefit": {
                    "label": "Vapaa autoetu",
                    "description": "Työnantaja huolehtii kaikista auton käyttöön liittyvistä kustannuksista"
                }
            },
            "EmploymentTerminationKind": {
                "undefined": {
                    "label": "Ei valintaa",
                    "description": "Ei valintaa"
                },
                "noticePeriodCompensation": {
                    "label": "Irtisanomisajan korvaus",
                    "description": "Korvaus, jonka työnantaja maksaa työntekijälle palvelussuhteen päättyessä ilman irtisanomisaikaa eli tilanteessa, jossa jätetään irtisanomisaika noudattamatta ja työsuhde päättyy heti (TSL 6:4). Tulolajilla ilmoitetaan myös korvaus, jonka työnantaja maksaa, kun työntekijä irtisanoutuu yli 200 päivää kestäneen lomautuksen johdosta sekä, kun työnantaja irtisanoo lomautettuna olevan työntekijän."
                },
                "monetaryWorkingTimeBankCompensation": {
                    "label": "Työaikapankin rahakorvaus",
                    "description": "Palkka, joka maksetaan työaikapankkiin säästetyn ajan perusteella."
                },
                "terminationAndLayOffDamages": {
                    "label": "Vahingonkorvaus päättämis- ja lomautustilanteissa",
                    "description": "Korvaus, jota työnantaja on velvollinen maksamaan, kun työnantaja on päättänyt palvelussuhteen henkilön työsopimuslain, kunnallisesta viranhaltijasta annetun lain tai valtion virkamieslain vastaisesti. Kohdassa ilmoitetaan myös korvaus työsuhteen purkamisesta (TSL 8:1, 55/2001) sekä korvaus perusteettomasta lomauttamisesta."
                },
                "voluntaryTerminationCompensation": {
                    "label": "Vapaaehtoinen korvaus päättämistilanteessa",
                    "description": "Korvaus, jonka työnantaja maksaa vapaaehtoisesti irtisanomis- tai purkamistilanteessa tai silloin, kun palvelussuhde päätetään sopimalla."
                },
                "pensionPaidByEmployer": {
                    "label": "Työnantajan maksama eläke",
                    "description": "Eläke, jonka työnantaja maksaa entiselle työntekijälleen tai tämän edunsaajalle aiemman palvelussuhteen perusteella."
                }
            },
            "IrIncomeTypeKind": {
                "undefined": {
                    "label": "Oletusarvo",
                    "description": "Oletusarvo"
                }
            },
            "OtherCompensationKind": {
                "undefined": {
                    "label": "Ei valintaa",
                    "description": "Ei valintaa"
                },
                "meetingFee": {
                    "label": "Kokouspalkkio",
                    "description": "Palkkio, joka maksetaan kokoukseen osallistumisesta."
                },
                "lectureFee": {
                    "label": "Luentopalkkio",
                    "description": "Palkkio, joka maksetaan luennon pitämisestä."
                },
                "positionOfTrustCompensation": {
                    "label": "Luottamustoimipalkkio",
                    "description": "Palkkio, joka maksetaan muusta luottamustoimen hoitamisesta kuin kokouksiin osallistumisesta."
                },
                "accruedTimeOffCompensation": {
                    "label": "Työajantasauskorvaus",
                    "description": "Työaikakorvaus, joka maksetaan ansionvähentymisestä, joka aiheutuu työajan tasaamisesta keskimääräiseen viikkotyöaikaan."
                },
                "membershipOfGoverningBodyCompensation": {
                    "label": "Hallintoelimen jäsenyydestä maksettu palkkio",
                    "description": "Luottamustoimipalkkio, joka maksetaan yhteisön hallituksen tai vastaavan hallintoelimen jäsenyyden perusteella."
                },
                "monetaryGiftForEmployees": {
                    "label": "Henkilöstölle annettu rahalahja",
                    "description": "Työnantajalta rahana tai siihen verrattavana suorituksena saatu lahja."
                },
                "useCompensationAsEarnedIncome": {
                    "label": "Käyttökorvaus ansiotuloa",
                    "description": "Korvaus, joka suoritetaan tekijänoikeuden, teollisoikeuden tai teollisia, kaupallisia tai tieteellisiä kokemuksia koskevien tietojen luovuttamisesta tai käyttöoikeudesta."
                },
                "useCompensationAsCapitalIncome": {
                    "label": "Käyttökorvaus pääomatuloa",
                    "description": "Korvaus, joka suoritetaan tekijänoikeuden, teollisoikeuden tai teollisia, kaupallisia tai tieteellisiä kokemuksia koskevien tietojen luovuttamisesta tai käyttöoikeudesta."
                },
                "otherTaxableIncomeAsEarnedIncome": {
                    "label": "Muu veronalainen ansiotulo",
                    "description": "Tulolajilla ilmoitetaan muiden veronalaisten ansiotuloa olevien suoritusten yhteissumma."
                },
                "stockOptionsAndGrants": {
                    "label": "Osakepalkkio",
                    "description": "Palkkio, joka annetaan työnantajayrityksen osakkeina tai sovitun palkkion sijaan rahasummana, joka vastaa osakkeiden arvoa."
                },
                "employeeInventionCompensation": {
                    "label": "Palkkio työsuhdekeksinnöstä",
                    "description": "Palkkio, joka maksetaan työsuhdekeksinnöstä."
                },
                "capitalIncomePayment": {
                    "label": "Pääomatuloa oleva suoritus",
                    "description": "Suoritus, joka on saajalleen pääomatuloa. Tällainen on esimerkiksi työntekijälle tai osakkaalle maksettu korko, kuten palkkasaatavan korko tai pääomatuloa oleva takausprovisio."
                },
                "workEffortBasedDividendsAsWage": {
                    "label": "Työpanokseen perustuva osinko tai ylijäämä (palkka)",
                    "description": "Osakkaalle palkkana maksettava osinko, jonka jakoperusteena on osingonsaajan tai tämän intressipiiriin kuuluvan henkilön työpanos."
                },
                "workEffortBasedDividendsAsNonWage": {
                    "label": "Työpanokseen perustuva osinko tai ylijäämä (työkorvaus)",
                    "description": "Osakkaalle työkorvauksena maksettava osinko, jonka jakoperusteena on osingonsaajan tai tämän intressipiiriin kuuluvan henkilön työpanos."
                },
                "employeeStockOption": {
                    "label": "Työsuhdeoptio",
                    "description": "Palkkio, joka annetaan työnantajayrityksen option muodossa."
                },
                "employeeStockOptionWithLowerPrice": {
                    "label": "Työsuhdeoptio, jonka merkintähinta on luovutusajankohtana alhaisempi kuin markkinahinta",
                    "description": "Palkkio, joka annetaan työnantajayrityksen option muodossa ja jossa työntekijältä peritty option merkintähinta option luovutusajankohtana on selvästi alhaisempi kuin osakkeen markkinahinta."
                }
            },
            "RemunerationKind": {
                "undefined": {
                    "label": "Ei valintaa",
                    "description": "Ei valintaa"
                },
                "initiativeFee": {
                    "label": "Aloitepalkkio",
                    "description": "Kertapalkkio, joka maksetaan aloitteen tekijälle esimerkiksi toiminnan tai tuotteen kehittämiseen liittyvästä aloitteesta."
                },
                "bonusPay": {
                    "label": "Bonuspalkka",
                    "description": "Kertaluonteinen palkkiopalkka, jonka suuruus määräytyy kokonaan tai osittain sen mukaan, kuinka hyvin tavoitteeksi asetettu työtulos saavutetaan. Työtuloksen mittana voi olla määrä, laatu tai jokin muu tulostekijä."
                },
                "commission": {
                    "label": "Provisiopalkka",
                    "description": "Pysyvän palkan osan muodostava jatkuvaluonteinen palkkiopalkka, jonka määrästä on sovittu työsopimuksessa."
                },
                "performanceBonus": {
                    "label": "Tulospalkkio",
                    "description": "Palkka, joka maksetaan organisaation ennalta sovitun tulostavoitteen täyttymisen tai ylittymisen perusteella."
                },
                "shareIssueForEmployees": {
                    "label": "Työsuhteeseen perustuva osakeanti",
                    "description": "Yhtiön omalle henkilökunnalle suunnattu osakeanti. Etu työsuhteeseen perustuvasta oikeudesta merkitä työnantajayrityksen osakkeita on veronalaista ansiotuloa."
                },
                "profitSharingBonus": {
                    "label": "Voittopalkkio",
                    "description": "Työntekijöille ilman ennalta sovittua suunnitelmaa yhtiökokouksen päätöksellä jaettava palkkio, joka muodostuu yrityksen voiton perusteella."
                }
            },
            "WorkingTimeCompensationKind": {
                "undefined": {
                    "label": "Ei valintaa",
                    "description": "Ei valintaa"
                },
                "emergencyWorkCompensation": {
                    "label": "Hätätyökorvaus",
                    "description": "Työaikakorvaus, joka maksetaan hätätyöstä. Hätätyöllä tarkoitetaan hätätilanteessa säännöllisen työajan ylittävänä aikana teetettävää työtä."
                },
                "eveningWorkCompensation": {
                    "label": "Iltatyökorvaus",
                    "description": "Työaikakorvaus, joka maksetaan iltatyöstä. Iltatyökorvausta voidaan maksaa säännölliseltä työajalta tai säännöllisen työajan ylittävältä ajalta."
                },
                "eveningShiftAllowance": {
                    "label": "Iltavuorolisä",
                    "description": "Vuorotyökorvaus, joka maksetaan iltavuorosta."
                },
                "saturdayPay": {
                    "label": "Lauantaityökorvaus",
                    "description": "Työaikakorvaus, joka maksetaan lauantaityöstä.\n Lauantaityökorvausta voidaan maksaa säännölliseltä työajalta tai säännöllisen työajan ylittävältä ajalta."
                },
                "extraWorkPremium": {
                    "label": "Lisätyökorvaus",
                    "description": "Työaikakorvaus, joka maksetaan lisätyöstä."
                },
                "otherCompensation": {
                    "label": "Muu maksettu lisä",
                    "description": "Muiden maksettujen työaika- ja poikkeustilakorvausten yhteissumma. Näitä ovat mm. aattotyökorvaukset, arkipyhäkorvaukset ja muut mahdolliset työehtosopimusten tai työsopimusten perusteella\n maksettavat korvaukset ja lisät."
                },
                "waitingTimeCompensation": {
                    "label": "Odotusajan korvaus",
                    "description": "Korvaus, johon työntekijällä on oikeus, jos palkanmaksu viivästyy työsuhteen päätyttyä. Ellei toisin sovita, palkka tulee maksaa palkanmaksukauden\n viimeisenä päivänä. Odotusajan korvausta voidaan\n maksaa enintään kuudelta päivältä."
                },
                "sundayWorkCompensation": {
                    "label": "Sunnuntaityökorvaus",
                    "description": "Sunnuntaityöstä maksettava työaikakorvaus. Sunnuntaityökorvausta voidaan maksaa säännölliseltä työajalta tai säännöllisen työajan ylittävältä ajalta."
                },
                "standByCompensation": {
                    "label": "Varallaolokorvaus",
                    "description": "Palkka, joka maksetaan siitä, että työntekijä on tavoitettavissa ja työnantaja voi tarvittaessa kutsua hänet hoitamaan palvelussuhteeseen kuuluvia tehtäviä."
                },
                "weeklyRestCompensation": {
                    "label": "Viikkolepokorvaus",
                    "description": "Työaikakorvaus, jota maksetaan viikkolevon aikana tehdystä työstä."
                },
                "overtimeCompensation": {
                    "label": "Ylityökorvaus",
                    "description": "Ylityöstä maksettava työaikakorvaus. Ylityönä pidetään työtä, joka tehdään työnantajan aloitteesta sovitun ylityöaikarajan ylittävänä aikana."
                },
                "nightWorkAllowance": {
                    "label": "Yötyökorvaus",
                    "description": "Työaikakorvaus, jota maksetaan yötyöstä."
                },
                "nightShiftCompensation": {
                    "label": "Yövuorolisä",
                    "description": "Vuorotyökorvaus, joka maksetaan yövuorosta."
                }
            },
            "HolidayYearInitType": {
                "ignore": {
                    "label": "Älä lisää tai poista lomavuotta"
                },
                "createEmpty": {
                    "label": "Luo uusi tyhjä lomavuosi"
                },
                "createMonths": {
                    "label": "Luo lomavuosi ja lisää kaikki kuukaudet"
                },
                "createFromCalcs": {
                    "label": "Luo lomavuosi ja lisää lomapäivät maksettujen laskelmien perusteella"
                }
            },
            "HolidayCode": {
                "undefined": {
                    "label": "Lisää lomakirjanpito",
                    "description": "Loma-ajan kertymistä ei ole määritetty"
                },
                "permanent14Days": {
                    "label": "14 päivän sääntö",
                    "description": "Työntekijä työskentelee työsopimuksen mukaan kaikkina kuukausina vähintään 14 päivää / kk"
                },
                "permanent35Hours": {
                    "label": "35 tunnin sääntö",
                    "description": "Työntekijä työskentelee vähintään yhtenä kuukautena vuodessa 35 tuntia / kk, mutta ei kuulu 14 päivän säännön piiriin."
                },
                "temporaryTimeOff": {
                    "label": "Vapaan ansaintasääntö",
                    "description": "Työntekijä ei kuulu 14 päivän tai 35 tunnin säännön piiriin."
                },
                "holidayCompensation": {
                    "label": "Lomakorvaus palkanmaksun yhteydessä",
                    "description": "Lomia ei kerrytetä, vaan lomakorvaus (+mahd. lomaraha) maksetaan heti palkan yhteydessä. Tyypillistä rakennusalalla ja muissa keikkatöissä."
                },
                "holidayCompensationIncluded": {
                    "label": "Lomakorvaus osa kokonaispalkkaa",
                    "description": "Lomia ei kerrytetä, vaan lomakorvaus on sovittu osaksi kokonaispalkkaa. Tämä on mahdollista vain poikkeustilanteissa, lähinnä kotitalouksilla."
                },
                "noHolidays": {
                    "label": "Ei lomaoikeutta",
                    "description": "Maksun saajalla ei ole lomaoikeutta. Esim. hallituksen jäsen, työkorvauksella työskentelevät, joskus toimitusjohtaja."
                }
            },
            "HolidayAccrualKind": {
                "manual": {
                    "label": "Käsin syötetty kuukausikertymä"
                },
                "saldo": {
                    "label": "Lomavuoden alku- tai loppusaldo"
                },
                "calculation": {
                    "label": "Palkkalaskelma"
                },
                "holiday": {
                    "label": "Pidetty loma"
                },
                "holidayCompensated": {
                    "label": "Lomakorvaus"
                }
            },
            "AbsenceCauseCode": {
                "unpaidLeave": {
                    "label": "Palkaton loma / vapaa"
                },
                "personalReason": {
                    "label": "Henkilökohtainen muu syy"
                },
                "illness": {
                    "label": "Sairaus"
                },
                "partTimeSickLeave": {
                    "label": "Osa-aikainen sairauspoissaolo"
                },
                "parentalLeave": {
                    "label": "Äitiys-, isyys- ja vanhempainvapaa"
                },
                "specialMaternityLeave": {
                    "label": "Erityisäitiysvapaa"
                },
                "rehabilitation": {
                    "label": "Kuntoutus"
                },
                "childIllness": {
                    "label": "Lapsen sairaus tai pakottava perhesyy"
                },
                "partTimeChildCareLeave": {
                    "label": "Osittainen hoitovapaa"
                },
                "training": {
                    "label": "Koulutus"
                },
                "jobAlternationLeave": {
                    "label": "Vuorotteluvapaa"
                },
                "studyLeave": {
                    "label": "Opintovapaa"
                },
                "industrialAction": {
                    "label": "Lakko tai työsulku"
                },
                "interruptionInWorkProvision": {
                    "label": "Työtarjonnan keskeytyminen"
                },
                "leaveOfAbsence": {
                    "label": "Virkavapaa"
                },
                "militaryRefresherTraining": {
                    "label": "Kertausharjoitus"
                },
                "militaryService": {
                    "label": "Varusmiespalvelus tai siviilipalvelus"
                },
                "layOff": {
                    "label": "Lomautus"
                },
                "childCareLeave": {
                    "label": "Hoitovapaa"
                },
                "midWeekHoliday": {
                    "label": "Arkipyhä"
                },
                "accruedHoliday": {
                    "label": "Pekkasvapaa"
                },
                "occupationalAccident": {
                    "label": "Työtapaturma"
                },
                "annualLeave": {
                    "label": "Vuosiloma"
                },
                "partTimeAbsenceDueToRehabilitation": {
                    "label": "Osittainen poissaolo kuntoutuksen vuoksi"
                },
                "other": {
                    "label": "Muu syy"
                }
            },
            "AnnualLeavePaymentKind": {
                "undefined": {
                    "label": "Valitse...",
                    "description": "Rivin tyyppiä ei ole valittu"
                },
                "manualSalary": {
                    "label": "Loma-ajan palkka",
                    "description": "Pidetyt lomapäivät ja niiden palkka sekä lomaraha manuaalisena korjauksena"
                },
                "manualCompensation": {
                    "label": "Lomakorvaus",
                    "description": "Korvattavat lomapäivät ja niiden korvaus sekä lomaraha manuaalisena korjauksena"
                },
                "manualBonus": {
                    "label": "Lomaraha",
                    "description": "Lomaraha maksettuna erikseen maksettuna erillisenä korjauksena"
                },
                "paidCalc": {
                    "label": "Maksettu palkkalaskelma",
                    "description": "Palkkaus.fi-palvelussa maksettu palkka, jossa lomaan liittyviä maksuja"
                },
                "draftCalc": {
                    "label": "Palkkalaskelman luonnos",
                    "description": "Palkkalaskelman luonnos, jossa lomaan liittyviä maksuja"
                },
                "info": {
                    "label": "Ei rivejä",
                    "description": "Lomavuodella ei ole maksuja"
                },
                "startSaldo": {
                    "label": "Käytettävissä olevat",
                    "description": "Edellisenä vuonna kertyneet lomat"
                },
                "endSaldo": {
                    "label": "Maksettavaa tai siirrettävää",
                    "description": "Seuraavalle lomavuodelle tai maksettavaa"
                },
                "total": {
                    "label": "Yhteensä",
                    "description": "Käytetyt/maksetut lomapäivät, -rahat ja korvaukset"
                }
            },
            "HolidayBonusPaymentMethod": {
                "none": {
                    "label": "Ei lomarahaa"
                },
                "payForHolidaySalary": {
                    "label": "Maksetun loma-ajan palkan mukaan (oletus)"
                },
                "paySummerBonus": {
                    "label": "Suunnitellut kesälomat (max 24pv)"
                },
                "pay24Days": {
                    "label": "Kesäloma 24 päivää (ei huomioi lomasuunnitelmia)"
                },
                "payAllBonus": {
                    "label": "Kaikki kerralla (kesäloman yhteydessä)"
                }
            },
            "PeriodType": {
                "month": {
                    "label": "Kuukausi"
                },
                "quarter": {
                    "label": "Neljännesvuosi"
                },
                "year": {
                    "label": "Kalenterivuosi"
                },
                "custom": {
                    "label": "Muu periodi"
                }
            },
            "PricingModel": {
                "palkkausFee": {
                    "label": "Palkkaus.fi-palkkio (1%)"
                },
                "noFee": {
                    "label": "Ei palkkiota"
                },
                "fixedFee": {
                    "label": "Kiinteä palkkio"
                }
            },
            "ServiceModel": {
                "shared": {
                    "label": "Yhteiskäyttö"
                },
                "partnerOnly": {
                    "label": "Tilitoimistokäyttö"
                }
            },
            "WageBasis": {
                "undefined": {
                    "label": "Valitse..."
                },
                "monthly": {
                    "label": "Kuukausipalkka"
                },
                "hourly": {
                    "label": "Tuntipalkka"
                },
                "performanceBased": {
                    "label": "Suorituspalkka"
                },
                "other": {
                    "label": "Palkanmaksu ilman lomalaskentaa"
                }
            }
        },
        "UI_TERMS": {
            "add": "Lisää",
            "addNew": "Lisää uusi",
            "addRow": "Lisää rivi",
            "areYouSure": "Oletko varma?",
            "back": "Takaisin",
            "calculate": "Laske",
            "calculations": "Laskelmat",
            "cancel": "Peruuta",
            "cancelEditing": "Peru muokkaaminen",
            "choose": "Valitse...",
            "orChoose": "...tai valitse...",
            "chooseWorkDateRange": "Määritä työn alku- ja loppupäivät",
            "chooseWorkDuration": "Määritä työn kesto...",
            "clear": "Tyhjennä",
            "close": "Sulje",
            "confirm": "Vahvista",
            "copy": "Kopio",
            "copyToClipboard": "Kopioi",
            "copyAsNew": "Kopioi uudeksi",
            "copyAsRequest": "Kopio pyynnöksi",
            "dateNotChosen": "päivämäärä ei valittuna",
            "delete": "Poista",
            "demo": "KOKEILUVERSIO",
            "dismiss": "Hylkää",
            "done": "Valmis",
            "edit": "Muokkaa",
            "gotIt": "Ymmärrän",
            "isDeleting": "Poistetaan...",
            "isSaving": "Tallennetaan...",
            "learnMore": "Lue lisää",
            "login": "Kirjaudu",
            "logout": "Kirjaudu ulos",
            "logoutAlt": "Päätä nykyinen sessio",
            "minCharacters": "Kirjoita vähintään 3 merkkiä...",
            "moreInfo": "Lisätietoja",
            "navigation": "Navigaatio",
            "newCalculation": "Uusi laskelma",
            "previous": "Edellinen",
            "next": "Seuraava",
            "no": "Ei",
            "noteRequiredField": "* Pakollinen kenttä",
            "noThanks": "Ei kiitos",
            "ok": "OK",
            "oldVersion": "vanha versio",
            "pay": "Maksa",
            "pleaseWait": "Ole hyvä ja odota...",
            "postpone": "Ei nyt",
            "printable": "Tuloste",
            "recalculate": "Päivitä laskelma",
            "register": "Rekisteröidy",
            "save": "Tallenna",
            "saveEdited": "Tallenna muutokset",
            "makeOrder": "Tee tilaus",
            "search": "Hae...",
            "searchByName": "Hae nimeltä...",
            "select": "Valitse",
            "selectAlt": "Valitse...",
            "sendEmail": "Lähetä sähköposti",
            "show": "Näytä",
            "skip": "Ohita",
            "sureToDeleteRecord": "Haluatko varmasti poistaa tämän tietueen?",
            "today": "Tämä päivä",
            "updateCalculation": "Päivitä laskelma",
            "updatingCalculation": "Päivitetään laskelmaa...",
            "use": "Ota käyttöön",
            "yes": "Kyllä",
            "dateFormats": {
                "dm": "pv.kk."
            },
            "loading": "Ladataan",
            "monthShort0": "joulu",
            "monthShort1": "tammi",
            "monthShort2": "helmi",
            "monthShort3": "maalis",
            "monthShort4": "huhti",
            "monthShort5": "touko",
            "monthShort6": "kesä",
            "monthShort7": "heinä",
            "monthShort8": "elo",
            "monthShort9": "syys",
            "monthShort10": "loka",
            "monthShort11": "marras",
            "monthShort12": "joulu",
            "week2": "2 viikkoa",
            "monthHalf": "½ kuukautta",
            "otherPeriod": "Muu periodi"
        },
        "VALIDATION": {
            "IncompleteAdvancePayment": {
                "label": "Palkka ei riitä",
                "description": "Palkka ei riitä ilmoitettuun palkkaennakkoon"
            },
            "IncompletePensionPayment": {
                "label": "Palkka ei riitä",
                "description": "Palkka ei riitä työntekijän osuuteen TyEL-maksusta"
            },
            "IncompleteUnemploymentInsurancePayment": {
                "label": "Palkka ei riitä",
                "description": "Palkka ei riitä työntekijän osuuteen työttömyysvakuutusmaksusta"
            },
            "IncompleteUnionPayment": {
                "label": "Palkka ei riitä",
                "description": "Palkka ei riitä AY-jäsenmaksuun"
            },
            "IncompleteOtherDeductions": {
                "label": "Palkka ei riitä",
                "description": "Palkka ei riitä ilmoitettuihin muihin vähennyksiin"
            },
            "IncompletePrepaidExpenses": {
                "label": "Palkka ei riitä",
                "description": "Palkka ei riitä ennakkoon maksettuihin kulukorvauksiin"
            },
            "MissingOccupationCode": {
                "label": "Ammattiluokitus puuttuu",
                "description": "Työn tyyppi puuttuu. Lisää se kohdassa 1 hakemalla Tilastokeskuksen luokituksesta. Ammattiluokitus on pakollinen tieto Tulorekisterin palkkatietoilmoituksessa."
            },
            "IllegalWorkerForCompanyType": {
                "label": "Ei-sallittu palkka",
                "description": "Yksityinen elinkeinonharjoittaja eli toiminimi ei voi maksaa itselleen palkkaa. Palkanmaksu hoidetaan yksityisnostoina. Kirjanpitäjäsi voi neuvoa sinua miten toimia."
            },
            "NegativeRowTotalNotSupported": {
                "label": "Rivillä ei sallita negatiivista summaa",
                "description": "Rivin yhteenlaskettu summa on negatiivinen. Rivillä ei sallita negatiivista summaa."
            },
            "ValidationErrors": {
                "sxyEmail": "Sähköpostin muoto on väärä",
                "sxyMobilePhone": "Puhelinnumeron muoto on väärä",
                "minlength": "Pituus vähintään {{minlength}} merkkiä",
                "maxlength": "Pituus enintään {{maxlength}} merkkiä",
                "sxyIban": "TIlinumeron (IBAN) muoto on väärä",
                "sxyTaxPercent": "Veroprosentin muoto on väärä",
                "sxyCurrency": "Rahamäärän muoto on väärä",
                "sxyPersonalIdFi": "Henkilötunnuksen muoto on väärä",
                "sxyCompanyIdFi": "Y-tunnuksen muoto on väärä",
                "sxyPostalCodeFi": "Postinumeron muoto on väärä",
                "sxySmsVerificationCode": "Tarkista varmennuskoodi",
                "sxyNumber": "Kentän pitää olla numero",
                "sxyInteger": "Kentän pitää olla kokonaisluku",
                "sxyPensionContractNumber": "Tarkista sopimusnumero",
                "sxyTemporaryPensionContractNumber": "Syötit tilapäisen sopimuksen numeron.",
                "required": "Kenttä on pakollinen"
            },
            "Payroll": {
                "NoCalculations": {
                    "label": "Ei yhtään laskelmaa."
                },
                "Calc": {
                    "TotalGreaterThan0": {
                        "label": "Palkkalaskelman summa on nolla"
                    },
                    "FirstNameNotEmpty": {
                        "label": "Työntekijän etunimi puuttuu"
                    },
                    "LastNameNotEmpty": {
                        "label": "Työntekijän sukunimi puuttuu"
                    },
                    "SocialSecurityNumber": {
                        "label": "Henkilötunnus on virheellinen."
                    },
                    "SocialSecurityNumber_InTest": {
                        "label": "Henkilötunnus on virheellinen. Testissä voit käyttää tarkistusnumerona tähteä ('*')"
                    },
                    "IbanNotEmpty": {
                        "label": "Tilinumero puuttuu"
                    },
                    "IbanInvalid": {
                        "label": "Tilinumero on virheellinen (IBAN-muoto)"
                    },
                    "EmailAddress": {
                        "label": "Sähköposti on virheellinen"
                    },
                    "TelephoneOrEmailNotEmpty": {
                        "label": "Anna jompikumpi tai molemmat yhteystiedot (puhelinnumero ja sähköposti)."
                    },
                    "TaxCardType": {
                        "label": "Verokortti puuttuu tai tyyppiä ei ole määritetty."
                    },
                    "TaxPercent": {
                        "label": "Veroprosenttia ei ole määritetty"
                    },
                    "PayrollIdConflict": {
                        "label": "Laskelman palkkalista-tunnus on virheellinen."
                    },
                    "InvalidStatusForPayroll": {
                        "label": "Palkkalistan laskelmalla väärä status."
                    }
                }
            },
            "Files": {
                "MaxFileSize": "Ladattava tiedosto on liian suuri",
                "Empty": "Ladattava tiedosto on tyhjä",
                "NoFiles": "Kutsun mukana ei tullut yhtään tiedostoa.",
                "SaveError": "Tuntematon virhe tiedoston tallennuksessa.",
                "ContentTypeError": "Tiedostomuotoa ei hyväksytä"
            }
        }
    },
    "": [
        "",
        "",
        "",
        "",
        "",
        ""
    ]
};
_dictionary["sv"] = {
    "SALAXY": {
        "ENUM": {
            "AbcSection": {
                "association": {
                    "description": "",
                    "label": "Föreningar"
                },
                "blog": {
                    "description": "",
                    "label": "Blogg"
                },
                "businessOwner": {
                    "description": "",
                    "label": "Företagare"
                },
                "documentTemplates": {
                    "description": "",
                    "label": "Dokument och formulär"
                },
                "doNotShow": {
                    "description": "",
                    "label": "Ej visad till användare (endast Admin)"
                },
                "employee": {
                    "description": "",
                    "label": "Anställd"
                },
                "employment": {
                    "description": "",
                    "label": "Anställningsförhållande och arbetsavtal"
                },
                "entrepreneur": {
                    "description": "",
                    "label": "Företag eller samfund"
                },
                "examples": {
                    "description": "",
                    "label": "Exempel av anställningssituationer"
                },
                "householdEmployer": {
                    "description": "",
                    "label": "Hushåll"
                },
                "instructionsAndExamples": {
                    "description": "",
                    "label": "Bruksanvisning"
                },
                "insurance": {
                    "description": "",
                    "label": "Försäkringar och pension"
                },
                "palkkausGeneral": {
                    "description": "",
                    "label": "Information om Palkkaus.fi-tjänsten"
                },
                "palkkausInstructions": {
                    "description": "",
                    "label": "Bruksavisningar"
                },
                "personEmployer": {
                    "description": "",
                    "label": "Hushållsarbetsgivare"
                },
                "press": {
                    "description": "",
                    "label": "Meddelanden och material"
                },
                "productLongDescription": {
                    "description": "",
                    "label": "Produktbeskrivning"
                },
                "salary": {
                    "description": "",
                    "label": "Löneräkning och lönebetalning"
                },
                "undefined": {
                    "description": "",
                    "label": "Nya artiklar / odefinierat"
                },
                "worker": {
                    "description": "",
                    "label": "Arbetsgivare"
                }
            },
            "AgeRange": {
                "age_15": {
                    "description": "",
                    "label": "15 år"
                },
                "age16": {
                    "description": "",
                    "label": "16 år"
                },
                "age17": {
                    "description": "",
                    "label": "17 år"
                },
                "age18_52": {
                    "description": "",
                    "label": "18-52 år"
                },
                "age53_62": {
                    "description": "",
                    "label": "53-62 år"
                },
                "age63_64": {
                    "description": "",
                    "label": "63-64 år"
                },
                "age65_67": {
                    "description": "",
                    "label": "65-67 år"
                },
                "age68AndOVer": {
                    "description": "",
                    "label": "68 år och över"
                },
                "unknown": {
                    "description": "",
                    "label": "Okänd"
                }
            },
            "ApiTestErrorType": {
                "default": {
                    "description": "",
                    "label": "Default"
                },
                "userFriendly": {
                    "description": "",
                    "label": "Användarvänlig"
                }
            },
            "ApiValidationErrorType": {
                "general": {
                    "label": "Allmän"
                },
                "invalid": {
                    "label": "Ogiltig"
                },
                "required": {
                    "label": "Krävs"
                },
                "warning": {
                    "label": ""
                }
            },
            "AuthenticationMethod": {
                "auth0Database": {
                    "description": "",
                    "label": "E-post-konto"
                },
                "emailPwdLocal": {
                    "description": "",
                    "label": "Databas"
                },
                "facebook": {
                    "description": "",
                    "label": "Facebook-konto"
                },
                "google": {
                    "description": "",
                    "label": "Google eller Gmail-konto"
                },
                "internalLocalhost": {
                    "description": "",
                    "label": ""
                },
                "linkedIn": {
                    "description": "",
                    "label": "LinkedIn-konto"
                },
                "microsoft": {
                    "description": "",
                    "label": "Microsoft-konto"
                },
                "salaxy": {
                    "description": "",
                    "label": ""
                },
                "test": {
                    "description": "",
                    "label": ""
                },
                "undefined": {
                    "description": "",
                    "label": "Okänd"
                },
                "x509": {
                    "description": "",
                    "label": ""
                }
            },
            "AuthorizationStatus": {
                "accessDenied": {
                    "description": "",
                    "label": "Tillträde förbjudet"
                },
                "expiredOauthTokdescription": "",
                "expiredOauthToklabel": "Session föråldrad",
                "invalidOAuthTokdescription": "",
                "invalidOAuthToklabel": "Fel i autentisering",
                "noOauthTokdescription": "",
                "noOauthToklabel": "Fel i autentisering (ingen token)",
                "oK": {
                    "description": "",
                    "label": "OK"
                },
                "undefined": {
                    "description": "",
                    "label": "Odefinierad"
                }
            },
            "AuthorizationType": {
                "companyContract": {
                    "description": "",
                    "label": "Arbetsgivarkontrakt"
                },
                "employerAuthorization": {
                    "description": "",
                    "label": "Fullmakt"
                },
                "manual": {
                    "description": "",
                    "label": "Fullmakt inlämnat skilt"
                },
                "none": {
                    "description": "",
                    "label": "Ej identifierad"
                },
                "temporary": {
                    "description": "",
                    "label": "Tillfällig identifiering"
                },
                "workerContract": {
                    "description": "",
                    "label": "Arbetstagarkontrakt"
                }
            },
            "AvatarPictureType": {
                "gravatar": {
                    "description": "",
                    "label": "Gravatar"
                },
                "icon": {
                    "description": "",
                    "label": "Ikon"
                },
                "uploaded": {
                    "description": "",
                    "label": "Bild från egen dator"
                }
            },
            "BlobFileType": {
                "authorizationPdf": {
                    "description": "",
                    "label": "Fullmakt"
                },
                "avatar": {
                    "description": "",
                    "label": "Ikon"
                },
                "calcReport": {
                    "description": "",
                    "label": ""
                },
                "expensesReceipt": {
                    "description": "",
                    "label": "Kvitto för utlägg"
                },
                "monthlyReport": {
                    "description": "",
                    "label": "Månatlig rapport"
                },
                "raksaloki": {
                    "description": "",
                    "label": "Kvitto för utlägg"
                },
                "taxCard": {
                    "description": "",
                    "label": "Skattekort"
                },
                "template": {
                    "description": "",
                    "label": "Mall"
                },
                "unknown": {
                    "description": "",
                    "label": "Okänd"
                },
                "yearlyReport": {
                    "description": "",
                    "label": "Årlig rapport"
                }
            },
            "BlobRepository": {
                "cdnImages": {
                    "description": "",
                    "label": ""
                },
                "fileSystemContent": {
                    "description": "",
                    "label": ""
                },
                "gitContent": {
                    "description": "",
                    "label": ""
                },
                "payload": {
                    "description": "",
                    "label": ""
                },
                "reports": {
                    "description": "",
                    "label": ""
                },
                "systemFiles": {
                    "description": "",
                    "label": ""
                },
                "userFiles": {
                    "description": "",
                    "label": ""
                },
                "versionHistory": {
                    "description": "",
                    "label": ""
                }
            },
            "CalculationRowSource": {
                "manualRow": {
                    "description": "",
                    "label": "Tilläggsrad"
                },
                "salaryPage": {
                    "description": "",
                    "label": "Huvudlön"
                },
                "tesSelection": {
                    "description": "",
                    "label": "Användarfall"
                }
            },
            "CalculationRowType": {
                "accomodationBenefit": {
                    "amountLabel": "",
                    "description": "Beskattningsbar boendeförmån.",
                    "iconText": "",
                    "label": "Boendetillägg",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "advance": {
                    "amountLabel": "",
                    "description": "Avdrag pga. löneförskott som betalats ut tidigare.",
                    "iconText": "",
                    "label": "Löneförskott",
                    "moreInfo": "",
                    "priceLabel": "Förskottsbetalning"
                },
                "board": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "chainsawReduction": {
                    "amountLabel": "",
                    "description": "Avdrag för bruk av motorsåg, i specialfall (förskottsbetalningslag § 15, förskottsbetalnings 15§).",
                    "iconText": "",
                    "label": "Välj…",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "childCareSubsidy": {
                    "amountLabel": "",
                    "description": "FPA stöd för kommunala arbetare för barnvård. Påverkar sidokostnader.",
                    "iconText": "FPA",
                    "label": "Barnvårdsunderstöd",
                    "moreInfo": "",
                    "priceLabel": "FPA betalar"
                },
                "compensation": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "Arbetskompensation",
                    "moreInfo": "",
                    "priceLabel": "Arbetsersättning"
                },
                "dailyAllowanceHalf": {
                    "amountLabel": "Dagar",
                    "description": "Halvdagsersättning, 19 euro, om arbetsresan är över 6 timmar eller 15 km.",
                    "iconText": 19,
                    "label": "Halvdagsersättning",
                    "moreInfo": "",
                    "priceLabel": "Euro / dag"
                },
                "employmentTermination": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "eveningAddition": {
                    "amountLabel": "Timmar",
                    "description": "Ersättning för kvällsarbete enligt kollektivavtal.",
                    "iconText": "KVÄLL",
                    "label": "Kvällstillägg",
                    "moreInfo": "",
                    "priceLabel": "Tillägg (per timme)"
                },
                "expenses": {
                    "amountLabel": "",
                    "description": "Ersättning för utlägg som arbetstagaren gjort för arbetsgivarens del (resekostnader, kontorsmaterial etc.).",
                    "iconText": "kostnad",
                    "label": "Ersättning för utlägg",
                    "moreInfo": "",
                    "priceLabel": "Erssättning för kostnader"
                },
                "foreclosure": {
                    "amountLabel": "",
                    "description": "Löneerhållning, betalt rakt till befallningsmannen.",
                    "iconText": "",
                    "label": "Löneerhållning",
                    "moreInfo": "",
                    "priceLabel": "Summa"
                },
                "foreclosureByPalkkaus": {
                    "amountLabel": "",
                    "description": "Löneerhållning gjort av Palkkaus.fi, betalt rakt till befallningsmannen.",
                    "iconText": "",
                    "label": "Löneerhållning av Palkkaus.fi",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "holidayBonus": {
                    "amountLabel": "Procent",
                    "description": "Semesterersättning enligt rådande kollektivavtal.",
                    "iconText": "Kollektivavtal",
                    "label": "Semesterersättning",
                    "moreInfo": "",
                    "priceLabel": "Lön för semestertid"
                },
                "holidayCompensation": {
                    "amountLabel": "Procent",
                    "description": "Ersättning som betalas ut ifall man inte håller sin årliga semester.",
                    "iconText": "11,5%",
                    "label": "Semestertillägg",
                    "moreInfo": "",
                    "priceLabel": "Lönesumma"
                },
                "holidaySalary": {
                    "amountLabel": "",
                    "description": "Lön för årlig semester.",
                    "iconText": "semester",
                    "label": "Semesterlön",
                    "moreInfo": "",
                    "priceLabel": "Lön för semestertid"
                },
                "hourlySalary": {
                    "amountLabel": "",
                    "description": "Lönebetalning baserat på insatta timmar.",
                    "iconText": "timme",
                    "label": "Timlön",
                    "moreInfo": "",
                    "priceLabel": "Timlön"
                },
                "irIncomeType": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "mealCompensation": {
                    "amountLabel": "Dagar",
                    "description": "Måltidsersättning när dagsersättning inte kan betalas.",
                    "iconText": "måltid",
                    "label": "Måltidsersättning",
                    "moreInfo": "",
                    "priceLabel": "Ersättning / dag"
                },
                "milageDaily": {
                    "amountLabel": "Dagar",
                    "description": "Kilometerersättning enligt rådande kollektivavtal.",
                    "iconText": "km",
                    "label": "Daglig kilometerersättning",
                    "moreInfo": "",
                    "priceLabel": "Ersättning / dag"
                },
                "milageOther": {
                    "amountLabel": "Dagar",
                    "description": "Övrig/annan kilometerersättning.",
                    "iconText": "km",
                    "label": "Annan kilometerersättning",
                    "moreInfo": "",
                    "priceLabel": "Ersättning / dag"
                },
                "milageOwnCar": {
                    "amountLabel": "",
                    "description": "Kilometerersättning för bruk av egen bil.",
                    "iconText": "0,43€",
                    "label": "Kilometerersättning",
                    "moreInfo": "",
                    "priceLabel": "Ersättning / km"
                },
                "monthlySalary": {
                    "amountLabel": "",
                    "description": "Fast månadslön.",
                    "iconText": "månad",
                    "label": "Månadslön",
                    "moreInfo": "",
                    "priceLabel": "Månatlig lön"
                },
                "nightimeAddition": {
                    "amountLabel": "Timmar",
                    "description": "Ersättning för nattararbete enligt kollektivavtal.",
                    "iconText": "NAT",
                    "label": "Nattarbetstillägg",
                    "moreInfo": "",
                    "priceLabel": "Tillägg (per timme)"
                },
                "otherAdditions": {
                    "amountLabel": "",
                    "description": "Övriga tillägg enligt kollektivavtal.",
                    "iconText": "tillägg",
                    "label": "Övriga tillägg",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "otherBenefit": {
                    "amountLabel": "",
                    "description": "Övriga beskattningsbara förmåner.",
                    "iconText": "Förmån",
                    "label": "Övriga förmåner",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "otherCompensation": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "otherDeductions": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "overtime": {
                    "amountLabel": "Procent",
                    "description": "Övertidsersättningar.",
                    "iconText": "över",
                    "label": "Övertidskompensation",
                    "moreInfo": "",
                    "priceLabel": "Lönesumma"
                },
                "phoneBenefit": {
                    "amountLabel": "Månader",
                    "description": "Beskattningsbar mobiltelefonförmån.",
                    "iconText": 20,
                    "label": "Mobiltelefonförmån",
                    "moreInfo": "",
                    "priceLabel": "Telefonförmån / mån"
                },
                "prepaidExpenses": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "remuneration": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "salary": {
                    "amountLabel": "",
                    "description": "Klumpsumma för insatt arbete.",
                    "iconText": "D",
                    "label": "Lön eller provision",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "saturdayAddition": {
                    "amountLabel": "Procent",
                    "description": "Tillägg för lördagsarbete enligt kollektivavtal.",
                    "iconText": "LÖR",
                    "label": "Lördagstillägg",
                    "moreInfo": "",
                    "priceLabel": "Lönesumma"
                },
                "sundayWork": {
                    "amountLabel": "",
                    "description": "Tillägg för söndagsarbete enligt kollektivavtal.",
                    "iconText": "SÖN",
                    "label": "Söndags- och helgdagstillägg",
                    "moreInfo": "",
                    "priceLabel": "Lönesumma"
                },
                "tesWorktimeShortening": {
                    "amountLabel": "Procent",
                    "description": "Skild lönedel som är definierad enligt kollektivavtal. Även känt som \"pekkasdagar\" på finska.",
                    "iconText": "Kollektivavtal",
                    "label": "Ersättning för arbetstidsutjämning",
                    "moreInfo": "",
                    "priceLabel": "Lönesumma"
                },
                "toolCompensation": {
                    "amountLabel": "Dagar",
                    "description": "Ersättning för använding av egna arbetsrverktyg. Ersättningen enligt rådande kollektivavtal.",
                    "iconText": "",
                    "label": "Arbetsredskapsersättning",
                    "moreInfo": "",
                    "priceLabel": "Ersättning / dag"
                },
                "totalEmployerPayment": {
                    "amountLabel": "",
                    "description": "Uträkning av totalkostnader: vad lönebetalningen kostar för arbetsgivaren.",
                    "iconText": "sum",
                    "label": "Total kostnad",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "totals": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "Totalt",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "totalWorkerPayment": {
                    "amountLabel": "",
                    "description": "Uträkning av nettolönen: vad som blir kvar i handen efter skatter och andra avdrag.",
                    "iconText": "net",
                    "label": "Nettolön",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "unknown": {
                    "amountLabel": "",
                    "description": "Radtyp odefinierad.",
                    "iconText": "",
                    "label": "Välj…",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "workingTimeCompensation": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "carBenefit": {
                    "label": "",
                    "description": "",
                    "iconText": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "unionPayment": {
                    "amountLabel": "",
                    "description": "Fackföreningsavgift betalt rakt till fackföreningen, om arbetstagaren så önskar.",
                    "iconText": "Fackförening",
                    "label": "Fackföreningsmedlemskap",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "dailyAllowance": {
                    "amountLabel": "Dagar",
                    "description": "Dagsersättning, 40 euro, om arbetsresan är över 10 timmar eller 15 km.",
                    "iconText": 40,
                    "label": "Dagsersättning",
                    "moreInfo": "",
                    "priceLabel": "Euro / dag"
                },
                "mealBenefit": {
                    "amountLabel": "",
                    "description": "Beskattningsbar måltidsförmån.",
                    "iconText": "mat",
                    "label": "Måltidsförmån",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "nonProfitOrg": {
                    "amountLabel": "",
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                },
                "subsidisedCommute": {
                    "description": "",
                    "iconText": "",
                    "label": "",
                    "moreInfo": "",
                    "priceLabel": ""
                }
            },
            "CalculationRowUnit": {
                "count": {
                    "description": "",
                    "label": "st"
                },
                "days": {
                    "description": "",
                    "label": "dagar"
                },
                "kilometers": {
                    "description": "",
                    "label": "km"
                },
                "percent": {
                    "description": "",
                    "label": "%"
                },
                "undefined": {
                    "description": "",
                    "label": ""
                }
            },
            "CalculationStatus": {
                "draft": {
                    "description": "",
                    "label": "Utkast"
                },
                "externalPaymentCanceled": {
                    "description": "",
                    "label": "Utbetalning avbruten utanför Salaxy-tjänsten"
                },
                "externalPaymentError": {
                    "description": "",
                    "label": "Fel (utanför Salaxy-tjänsten)"
                },
                "externalPaymentStarted": {
                    "description": "",
                    "label": "Utbetalning påbörjad utnaför Salaxy-tjänsten"
                },
                "externalPaymentSucceeded": {
                    "description": "",
                    "label": "Utbetalning genomförd utanför Salaxy-tjänsten"
                },
                "paymentCanceled": {
                    "description": "",
                    "label": "Utbetalning avbruten"
                },
                "paymentError": {
                    "description": "",
                    "label": "Fel i utbetalning"
                },
                "paymentRefunded": {
                    "description": "",
                    "label": "Utbetalning avbruten och returnerad"
                },
                "paymentStarted": {
                    "description": "",
                    "label": "Utbetalning påbörjad"
                },
                "paymentSucceeded": {
                    "description": "",
                    "label": "Utbetalning genomförd"
                },
                "paymentWorkerCopy": {
                    "description": "",
                    "label": "Arbetstagarens kvitto"
                },
                "template": {
                    "description": "",
                    "label": ""
                },
                "workerRequestAccepted": {
                    "description": "",
                    "label": "Lönespecifikation gjord av arbetstagaren godkänd"
                },
                "workerRequestDeclined": {
                    "description": "",
                    "label": "Lönespecifikation gjord av arbetstagaren avslagen"
                },
                "workerRequested": {
                    "description": "",
                    "label": "Lönespecifikation gjord av arbetstagaren"
                },
                "payrollDraft": {
                    "description": "",
                    "label": ""
                },
                "proDraft": {
                    "label": ""
                }
            },
            "CompanyType": {
                "fiOy": {
                    "description": "",
                    "label": "Aktiebolag, även bostadsaktiebolag och publika aktiebolag"
                },
                "fiRy": {
                    "description": "",
                    "label": "Föreningar"
                },
                "fiTm": {
                    "description": "",
                    "label": "Privat näringsidkare eller jordbrukare"
                },
                "fiYy": {
                    "description": "",
                    "label": "Annan, t.ex. Kommanditbolag, öppna bolag etc."
                },
                "unknown": {
                    "description": "",
                    "label": ""
                }
            },
            "ContractPartyType": {
                "customContact": {
                    "description": "",
                    "label": ""
                },
                "person": {
                    "description": "",
                    "label": ""
                }
            },
            "DateOfBirthAccuracy": {
                "ageBased": {
                    "description": "",
                    "label": "Åldersbaserad"
                },
                "ageGroupBased": {
                    "description": "",
                    "label": "Åldersgruppbaserad"
                },
                "assumption": {
                    "description": "",
                    "label": "Antagande"
                },
                "exact": {
                    "description": "",
                    "label": "Exakt datum"
                },
                "monthCorrect": {
                    "description": "",
                    "label": "Rätt månad"
                },
                "verified": {
                    "description": "",
                    "label": "Bekräftat"
                }
            },
            "EmployerType": {
                "fullTimeEmployer": {
                    "description": "",
                    "label": "Fortlöpande kontrakt eller över 8178 € / 6 månader"
                },
                "miniEmployer": {
                    "description": "",
                    "label": "Under 1300 € / år"
                },
                "smallEmployer": {
                    "description": "",
                    "label": "Minst 1300 € / år"
                },
                "tyelOwnContractEmployer": {
                    "description": "",
                    "label": "ArPL-årskontrakt eller omskött av kunden"
                },
                "unknown": {
                    "description": "",
                    "label": "Okänd"
                }
            },
            "EmploymentContract": {
                "annualLeave": {
                    "label": "Annual leave"
                },
                "benefitsException": {
                    "label": "Luontaisedut"
                },
                "noticeException": {
                    "label": "Term of notice"
                },
                "otherTerms": {
                    "label": "Other terms"
                }
            },
            "EmploymentRelationType": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "salary": {
                    "label": "",
                    "description": ""
                },
                "hourlySalary": {
                    "label": "",
                    "description": ""
                },
                "monthlySalary": {
                    "label": "",
                    "description": ""
                },
                "compensation": {
                    "label": "",
                    "description": ""
                },
                "boardMember": {
                    "label": "",
                    "description": ""
                },
                "entrepreneur": {
                    "label": "",
                    "description": ""
                },
                "entrepreneurNew": {
                    "label": "",
                    "description": ""
                },
                "farmer": {
                    "label": "",
                    "description": ""
                },
                "athlete": {
                    "label": "",
                    "description": ""
                },
                "employedByStateEmploymentFund": {
                    "label": "",
                    "description": ""
                },
                "keyEmployee": {
                    "label": "",
                    "description": ""
                },
                "performingArtist": {
                    "label": "",
                    "description": ""
                }
            },
            "EmploymentSalaryType": {
                "hourlyPay": {
                    "description": "",
                    "label": "Timlön",
                    "metricAbbrev": ""
                },
                "montlyPay": {
                    "description": "",
                    "label": "Månadslön",
                    "metricAbbrev": ""
                },
                "otherPay": {
                    "description": "",
                    "label": "Annan"
                },
                "unknown": {
                    "description": "",
                    "label": "Välj…"
                }
            },
            "EmploymentType": {
                "fullTime": {
                    "description": "",
                    "label": "Tills vidare anställning"
                },
                "job": {
                    "description": "",
                    "label": "Engångsarbete"
                },
                "partTime": {
                    "description": "",
                    "label": "Visstidsanställd"
                },
                "unknown": {
                    "description": "",
                    "label": "Välj…"
                }
            },
            "EmploymentWorkHoursType": {
                "hourPerThreeWeeks": {
                    "description": "",
                    "label": "Timmar/tre veckor"
                },
                "hourPerTwoWeeks": {
                    "description": "",
                    "label": "Timmar/två veckor"
                },
                "hoursPerDay": {
                    "description": "",
                    "label": "Timmar/dygn"
                },
                "hoursPerWeek": {
                    "description": "",
                    "label": "Timmar/vecka"
                }
            },
            "FrameworkAgreement": {
                "childCare": {
                    "description": "Tills vidare barnskötare och där tillhörande stöd.",
                    "label": "Övrig barnomsorg"
                },
                "cleaning": {
                    "description": "Städ- och fastighetsarbete.",
                    "label": "Städ- och fastighetsbranschen"
                },
                "construction": {
                    "description": "Arbete enligt kollektivavtalet för byggnadsbranschen.",
                    "label": "Byggnads- och renoveringsarbete"
                },
                "entrepreneur": {
                    "description": "Företagarens egen lön.",
                    "label": "Företagare"
                },
                "mll": {
                    "description": "Lön för MLL:s barnskötare.",
                    "label": "MLL rekommendationer"
                },
                "notDefined": {
                    "description": "Kollektivavtal eller rekommendation odefinierat.",
                    "label": "Odefinierad"
                },
                "other": {
                    "description": "Annat arbete eller inget kollektivavtal.",
                    "label": "Övrigt arbete"
                },
                "santaClaus": {
                    "description": "Hembesök av jultomten.",
                    "label": "Jultomte"
                }
            },
            "Gender": {
                "female": {
                    "description": "",
                    "label": "Kvinna"
                },
                "male": {
                    "description": "",
                    "label": "Man"
                },
                "unknown": {
                    "description": "",
                    "label": ""
                }
            },
            "HelttiIndustry": {
                "i": {
                    "description": "",
                    "label": "Boende- och näringsverksamhet"
                },
                "j": {
                    "description": "",
                    "label": "Informationssystem och kommunikation"
                },
                "k": {
                    "description": "",
                    "label": "Finans- och försäkringsverksamhet"
                },
                "m": {
                    "description": "",
                    "label": "Professional, scientific and technical activities"
                },
                "n": {
                    "description": "",
                    "label": "Administrations- och stödverksamhet"
                },
                "notDefined": {
                    "description": "",
                    "label": "Välj…"
                },
                "o": {
                    "description": "",
                    "label": "Offentlig förvaltning och nationellt försvar"
                },
                "other": {
                    "description": "",
                    "label": "Övriga industrier"
                },
                "q": {
                    "description": "",
                    "label": "Hälso- och socialverksamhet"
                },
                "r": {
                    "description": "",
                    "label": "Konst, nöje och rekration"
                },
                "s": {
                    "description": "",
                    "label": "Övrig serviceverksamhet"
                }
            },
            "HelttiProductPackage": {
                "large": {
                    "description": "",
                    "label": "Hifi"
                },
                "medium": {
                    "description": "",
                    "label": "Tillväxt"
                },
                "notDefined": {
                    "description": "",
                    "label": "Inget kontrakt"
                },
                "small": {
                    "description": "",
                    "label": "Start"
                }
            },
            "HouseHoldUseCaseTree": {
                "childCare": {
                    "description": "",
                    "kela": {
                        "description": "",
                        "label": ""
                    },
                    "label": "",
                    "mll": {
                        "description": "",
                        "label": ""
                    },
                    "other": {
                        "description": "",
                        "label": ""
                    }
                },
                "cleaning": {
                    "51530": {
                        "description": "",
                        "label": ""
                    },
                    "53221": {
                        "description": "",
                        "label": ""
                    },
                    "61132": {
                        "description": "",
                        "label": ""
                    },
                    "91110": {
                        "description": "",
                        "label": ""
                    },
                    "description": "",
                    "label": "",
                    "other": {
                        "description": "",
                        "label": ""
                    }
                },
                "construction": {
                    "carpenter": {
                        "description": "",
                        "label": ""
                    },
                    "description": "",
                    "floor": {
                        "description": "",
                        "label": ""
                    },
                    "label": "",
                    "new": {
                        "description": "",
                        "label": ""
                    },
                    "painter": {
                        "description": "",
                        "label": ""
                    },
                    "renovation": {
                        "description": "",
                        "label": ""
                    },
                    "roof": {
                        "description": "",
                        "label": ""
                    }
                },
                "other": {
                    "51530": {
                        "description": "",
                        "label": "Fastighetsskötare"
                    },
                    "53112": {
                        "description": "",
                        "label": "Familjedagvårdare"
                    },
                    "53212": {
                        "description": "",
                        "label": "Vårdare av utvecklingshämmade"
                    },
                    "53213": {
                        "description": "",
                        "label": "Vårdare inom socialsektorn"
                    },
                    "53221": {
                        "description": "",
                        "label": "Hemvårdspersonal"
                    },
                    "53222": {
                        "description": "",
                        "label": "Personliga assistenter, närståendevårdare m.fl."
                    },
                    "61112": {
                        "description": "",
                        "label": "Arbetsledare och arbetare inom åkerodling"
                    },
                    "61132": {
                        "description": "",
                        "label": "Arbetsledare och anställda inom trädgårds- och växthusodling"
                    },
                    "62100": {
                        "description": "",
                        "label": "Skogsbrukare och skogsarbetare"
                    },
                    "71110": {
                        "description": "",
                        "label": "Byggnadsarbetare"
                    },
                    "71150": {
                        "description": "",
                        "label": "Timmermän och byggnadssnickare"
                    },
                    "71210": {
                        "description": "",
                        "label": "Takmontörer och takreparatörer"
                    },
                    "71310": {
                        "description": "",
                        "label": "Byggnadsmålare m.fl."
                    },
                    "91110": {
                        "description": "",
                        "label": "Hembiträden och städare"
                    },
                    "description": "",
                    "label": "Annan",
                    "undefined": {
                        "description": "",
                        "label": "Annan"
                    }
                }
            },
            "InsuranceCompany": {
                "aktia": {
                    "description": "",
                    "label": "Aktia"
                },
                "alandia": {
                    "description": "",
                    "label": "Alandia"
                },
                "ålands": {
                    "description": "",
                    "label": "Ålands"
                },
                "aVakuutus": {
                    "description": "",
                    "label": "A-Vakuutus"
                },
                "fennia": {
                    "description": "",
                    "label": "Fennia"
                },
                "folksam": {
                    "description": "",
                    "label": "Folksam"
                },
                "if": {
                    "description": "",
                    "label": "If"
                },
                "lähiTapiola": {
                    "description": "",
                    "label": "LähiTapiola"
                },
                "none": {
                    "description": "",
                    "label": "(Välj försäkringsbolag)"
                },
                "other": {
                    "description": "",
                    "label": "Annat bolag"
                },
                "pohjantähti": {
                    "description": "",
                    "label": "Pohjantähti"
                },
                "pohjola": {
                    "description": "",
                    "label": "OP Vakuutus"
                },
                "redarnas": {
                    "description": "",
                    "label": "Redarnas"
                },
                "tryg": {
                    "description": "",
                    "label": "Tryg"
                },
                "turva": {
                    "description": "",
                    "label": "Turva"
                }
            },
            "LegalEntityType": {
                "company": {
                    "description": "",
                    "label": "FO-nummer"
                },
                "partner": {
                    "description": "",
                    "label": "Partner"
                },
                "person": {
                    "description": "",
                    "label": "Person"
                },
                "personCreatedByEmployer": {
                    "description": "",
                    "label": "Arbetstagare"
                },
                "undefined": {
                    "description": "",
                    "label": "Okänd"
                }
            },
            "MessageType": {
                "email": {
                    "description": "",
                    "label": "E-post"
                },
                "sms": {
                    "description": "",
                    "label": "Textmeddelande"
                }
            },
            "OnboardingStatus": {
                "created": {
                    "description": "",
                    "label": "Skapad"
                },
                "done": {
                    "description": "",
                    "label": "Slutförd"
                },
                "opdescription": "",
                "oplabel": "Pågående"
            },
            "PalkkausCampaignPricing": {
                "campaignAfterFirstUse": {
                    "description": "",
                    "label": ""
                },
                "campaignFirstUse": {
                    "description": "",
                    "label": ""
                },
                "companyFreeTrial": {
                    "description": "",
                    "label": ""
                },
                "none": {
                    "description": "",
                    "label": ""
                }
            },
            "PartnerSite": {
                "careDotCom": {
                    "description": "",
                    "label": ""
                },
                "dev": {
                    "description": "",
                    "label": ""
                },
                "duunitori": {
                    "description": "",
                    "label": ""
                },
                "example": {
                    "description": "",
                    "label": ""
                },
                "mol": {
                    "description": "",
                    "label": ""
                },
                "palkkaapakolaindescription": "",
                "palkkaapakolainlabel": "",
                "palkkaus": {
                    "description": "",
                    "label": ""
                },
                "palkkausEmployerFillIn": {
                    "description": "",
                    "label": ""
                },
                "palkkausIdentified": {
                    "description": "",
                    "label": ""
                },
                "raksa": {
                    "description": "",
                    "label": ""
                },
                "refugeeJobs": {
                    "description": "",
                    "label": ""
                },
                "talkkarit": {
                    "description": "",
                    "label": ""
                },
                "unknown": {
                    "description": "",
                    "label": ""
                }
            },
            "PaymentStatus": {
                "bankDelivered": {
                    "description": "",
                    "label": "Godkänt av banken"
                },
                "bankError": {
                    "description": "",
                    "label": "Fel hos banken"
                },
                "bankPartialError": {
                    "description": "",
                    "label": "Fel hos banken"
                },
                "bankTechApproval": {
                    "description": "",
                    "label": "Mottaget av banken"
                },
                "cancelled": {
                    "description": "",
                    "label": "Betalning avrbuten"
                },
                "new": {
                    "description": "",
                    "label": ""
                },
                "paid": {
                    "description": "",
                    "label": "Betalning genomförd"
                },
                "sentToBank": {
                    "description": "",
                    "label": "Skickat till banken"
                },
                "unknown": {
                    "description": "",
                    "label": "Okänd"
                }
            },
            "PayrollStatus": {
                "draft": {
                    "label": "Utkast"
                },
                "paymentStarted": {
                    "label": "Utbetalning påbörjad"
                },
                "paymentSucceeded": {
                    "label": "Utbetalning genomförd"
                },
                "paymentCanceled": {
                    "label": "Utbetalning avbruten"
                },
                "paymentError": {
                    "label": "Fel i utbetalning"
                },
                "template": {
                    "label": ""
                }
            },
            "PensionCompany": {
                "elo": {
                    "description": "",
                    "label": "Elo"
                },
                "etera": {
                    "description": "",
                    "label": "Etera"
                },
                "ilmarindescription": "",
                "ilmarinen": {
                    "label": "Ilmarinen"
                },
                "none": {
                    "description": "",
                    "label": "Välj…"
                },
                "other": {
                    "description": "",
                    "label": "Annat bolag"
                },
                "pensionsAlandia": {
                    "description": "",
                    "label": "Alandia"
                },
                "varma": {
                    "description": "",
                    "label": "Varma"
                },
                "veritas": {
                    "description": "",
                    "label": "Veritas"
                },
                "apteekkien": {
                    "description": "",
                    "label": "Apteekkien Eläkekassa"
                },
                "verso": {
                    "description": "",
                    "label": "Verso"
                }
            },
            "PensionCalculation": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "employee": {
                    "label": "",
                    "description": ""
                },
                "entrepreneur": {
                    "label": "",
                    "description": ""
                },
                "smallEntrepreneur": {
                    "label": "",
                    "description": ""
                },
                "partialOwner": {
                    "label": "",
                    "description": ""
                },
                "farmer": {
                    "label": "",
                    "description": ""
                },
                "smallFarmer": {
                    "label": "",
                    "description": ""
                },
                "athlete": {
                    "label": "",
                    "description": ""
                },
                "compensation": {
                    "label": "",
                    "description": ""
                },
                "boardRemuneration": {
                    "label": "",
                    "description": ""
                }
            },
            "Product": {
                "accounting": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "baseService": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "healthCareHeltti": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "insurance": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "pension": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "pensionEntrepreneur": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "tax": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "taxCard": {
                    "description": "",
                    "label": "",
                    "status": ""
                },
                "unemployment": {
                    "description": "",
                    "label": "",
                    "status": "",
                    "statusTVR": ""
                }
            },
            "ProductListFilter": {
                "all": {
                    "description": "",
                    "label": ""
                },
                "available": {
                    "description": "",
                    "label": ""
                }
            },
            "Profession": {
                "0": {
                    "label": "Militärer"
                },
                "1": {
                    "label": "Chefer"
                },
                "2": {
                    "label": "Specialister"
                },
                "3": {
                    "label": "Experter"
                },
                "4": {
                    "label": "Kontors- och kundtjänstpersonal"
                },
                "5": {
                    "label": "Service- och försäljningspersonal"
                },
                "6": {
                    "label": "Jordbrukare, skogsarbetare m.fl."
                },
                "7": {
                    "label": "Byggnads-, reparations- och tillverkningsarbetare"
                },
                "8": {
                    "label": "Process- och transportarbetare"
                },
                "9": {
                    "label": "Övriga arbetstagare"
                },
                "11": {
                    "label": "Chefer, högre tjänstemän och organisationschefer"
                },
                "12": {
                    "label": "Administrativa och kommersiella chefer"
                },
                "13": {
                    "label": "Chefer inom tillverkning, utbildning, vård m.m."
                },
                "14": {
                    "label": "Chefer inom hotell och restaurangbranschen, detaljhandel och andra servicenäringar"
                },
                "21": {
                    "label": "Specialister inom naturvetenskap och teknik"
                },
                "22": {
                    "label": "Hälso- och sjukvårdsspecialister"
                },
                "23": {
                    "label": "Lärare och andra specialister inom undervisningsbranschen"
                },
                "24": {
                    "label": "Specialister inom företagsekonomi och administration"
                },
                "25": {
                    "label": "Specialister inom informations- och kommunikationsteknologi"
                },
                "26": {
                    "label": "Specialister inom juridik samt inom social- och kultursektorn"
                },
                "31": {
                    "label": "Experter inom naturvetenskap och teknik"
                },
                "32": {
                    "label": "Hälso- och sjukvårdsexperter"
                },
                "33": {
                    "label": "Experter inom företagsekonomi och administration"
                },
                "34": {
                    "label": "Juridiska assistenter samt experter inom social- och kultursektorn"
                },
                "35": {
                    "label": "Experter inom informations- och kommunikationsteknologi"
                },
                "41": {
                    "label": "Kontorspersonal"
                },
                "42": {
                    "label": "Kundtjänstpersonal"
                },
                "43": {
                    "label": "Kontorspersonal inom ekonomi- och lagerförvaltning"
                },
                "44": {
                    "label": "Annan kontors- och kundtjänstpersonal"
                },
                "51": {
                    "label": "Servicepersonal"
                },
                "52": {
                    "label": "Försäljare, butiksinnehavare m.fl."
                },
                "53": {
                    "label": "Vård- och omsorgspersonal"
                },
                "54": {
                    "label": "Säkerhets- och bevakningspersonal"
                },
                "61": {
                    "label": "Jordbrukare och djuruppfödare m.fl."
                },
                "62": {
                    "label": "Arbetare inom skogsbruk och fiske"
                },
                "63": {
                    "label": "Växtodlare, fiskare och jägare (självhushållning)"
                },
                "71": {
                    "label": "Byggnadsarbetare m.fl. (utom elmontörer)"
                },
                "72": {
                    "label": "Verkstads- och gjuteriarbetare samt montörer och reparatörer"
                },
                "73": {
                    "label": "Konsthantverkare, finmekaniker och tryckeripersonal"
                },
                "74": {
                    "label": "Personal inom el- och elektronikbranschen"
                },
                "75": {
                    "label": "Personal inom livsmedel, trä, textil m.m."
                },
                "81": {
                    "label": "Processarbetare"
                },
                "82": {
                    "label": "Hopsättare, industriprodukter"
                },
                "83": {
                    "label": "Transportarbetare"
                },
                "91": {
                    "label": "Städare, hembiträden och andra rengöringsarbetare"
                },
                "92": {
                    "label": "Medhjälpare inom jordbruk, skogsbruk och fiske"
                },
                "93": {
                    "label": "Medhjälpare inom industrin och byggverksamhet m.fl."
                },
                "94": {
                    "label": "Köks- och restaurangbiträden"
                },
                "95": {
                    "label": "Gatuförsäljare, skoputsare m.fl."
                },
                "96": {
                    "label": "Gaturenhållningsarbetare och avfallshanterare m.fl."
                },
                "111": {
                    "label": "Högre tjänstemän och organisationschefer"
                },
                "112": {
                    "label": "Verkställande direktörer och verkschefer"
                },
                "121": {
                    "label": "Chefer inom företagstjänster och administration"
                },
                "122": {
                    "label": "Försäljnings-, marknadsförings- och utvecklingschefer"
                },
                "131": {
                    "label": "Chefer inom jordbruk, skogsbruk och fiske"
                },
                "132": {
                    "label": "Produktionschefer inom industri, gruvdrift, byggverksamhet och distribution"
                },
                "133": {
                    "label": "Chefer inom informations- och kommunikationsteknologi (IKT)"
                },
                "134": {
                    "label": "Chefer inom utbildning, vård, omsorg och finansiell verksamhet"
                },
                "141": {
                    "label": "Hotell- och restaurangchefer"
                },
                "142": {
                    "label": "Chefer inom detalj- och partihandel"
                },
                "143": {
                    "label": "Chefer inom andra servicenäringar"
                },
                "211": {
                    "label": "Specialister inom naturvetenskap och geovetenskap"
                },
                "212": {
                    "label": "Specialister inom matematik och statistik"
                },
                "213": {
                    "label": "Specialister inom biovetenskap"
                },
                "214": {
                    "label": "Specialister inom teknik (utom elektroteknik)"
                },
                "215": {
                    "label": "Specialister inom elektroteknik"
                },
                "216": {
                    "label": "Arkitekter, planerare och lantmätare"
                },
                "221": {
                    "label": "Läkare"
                },
                "222": {
                    "label": "Specialister inom vårdarbete"
                },
                "223": {
                    "label": "Specialister inom traditionella och alternativa vårdformer"
                },
                "224": {
                    "label": "Producenter av andra hälsovårdstjänster"
                },
                "225": {
                    "label": "Veterinärer"
                },
                "226": {
                    "label": "Andra hälso- och sjukvårdsspecialister"
                },
                "231": {
                    "label": "Universitets- och högskollärare"
                },
                "232": {
                    "label": "Lärare i yrkesämnen"
                },
                "233": {
                    "label": "Gymnasie- och högstadielärare"
                },
                "234": {
                    "label": "Lågstadie-och barnträdgårdslärare"
                },
                "235": {
                    "label": "Andra specialister inom undervisning"
                },
                "241": {
                    "label": "Specialister inom finanssektorn"
                },
                "242": {
                    "label": "Specialister inom administration"
                },
                "243": {
                    "label": "Specialister inom försäljning, marknadsföring och information"
                },
                "251": {
                    "label": "Specialister inom systemarbete"
                },
                "252": {
                    "label": "Specialister, databaser, -nätverk och systemprogram"
                },
                "261": {
                    "label": "Juridiska specialister"
                },
                "262": {
                    "label": "Bibliotekarier, arkivarier och specialister inom museisektorn"
                },
                "263": {
                    "label": "Specialister inom samhälls- och socialsektorn samt inom religion"
                },
                "264": {
                    "label": "Journalister, författare och språkvetare"
                },
                "265": {
                    "label": "Konstnärer"
                },
                "311": {
                    "label": "Experter inom fysik, kemi och teknik"
                },
                "312": {
                    "label": "Arbetsledare inom gruvdrift, industri och byggverksamhet"
                },
                "313": {
                    "label": "Experter inom processövervakning"
                },
                "314": {
                    "label": "Experter inom biovetenskap"
                },
                "315": {
                    "label": "Fartygs-, flyg- och hamntrafikbefäl och -ledare"
                },
                "321": {
                    "label": "Tekniska experter inom hälso- och sjukvården"
                },
                "322": {
                    "label": "Sjukskötare, barnmorskor m.fl."
                },
                "323": {
                    "label": "Utövare av naturmedicin och alternativ medicin"
                },
                "324": {
                    "label": "Seminörer m.fl."
                },
                "325": {
                    "label": "Andra hälso- och sjukvårdsexperter"
                },
                "331": {
                    "label": "Experter inom finansiering, försäkring och redovisning"
                },
                "332": {
                    "label": "Inköps- och försäljningsagenter"
                },
                "333": {
                    "label": "Förmedlare av företagstjänster"
                },
                "334": {
                    "label": "Administrativa och specialiserade sekreterare"
                },
                "335": {
                    "label": "Tjänstemän inom beredning och bevakning i den offentliga förvaltningen"
                },
                "341": {
                    "label": "Juridiska assistenter samt personal inom socialsektorn och församlingar"
                },
                "342": {
                    "label": "Idrottare, idrottstränare och -instruktörer m.fl."
                },
                "343": {
                    "label": "Experter inom konst och kultur samt kökschefer"
                },
                "351": {
                    "label": "IKT-tekniker samt användarstöd"
                },
                "352": {
                    "label": "Teletekniker samt radio- och tv-tekniker"
                },
                "411": {
                    "label": "Kontorsassistenter"
                },
                "412": {
                    "label": "Kontorssekreterare"
                },
                "413": {
                    "label": "Textbehandlare och dataregistrerare"
                },
                "421": {
                    "label": "Kassapersonal m.fl."
                },
                "422": {
                    "label": "Annan kundtjänstpersonal"
                },
                "431": {
                    "label": "Löneräknare, försäkringshandläggare m.fl."
                },
                "432": {
                    "label": "Kontorspersonal inom transport och lager"
                },
                "441": {
                    "label": "Annan kontors- och kundtjänstpersonal"
                },
                "511": {
                    "label": "Personal inom resetjänster, konduktörer och guider"
                },
                "512": {
                    "label": "Restaurang- och storhushållspersonal"
                },
                "513": {
                    "label": "Serveringspersonal"
                },
                "514": {
                    "label": "Frisörer, kosmetologer m.fl."
                },
                "515": {
                    "label": "Arbetsledare inom städning och fastighetsskötsel"
                },
                "516": {
                    "label": "Annan servicepersonal, personliga tjänster"
                },
                "521": {
                    "label": "Gatu- och torgförsäljare"
                },
                "522": {
                    "label": "Försäljare och butiksinnehavare"
                },
                "523": {
                    "label": "Butikskassörer och biljettförsäljare"
                },
                "524": {
                    "label": "Annan försäljningspersonal"
                },
                "531": {
                    "label": "Barnskötare och skolgångsbiträden"
                },
                "532": {
                    "label": "Närvårdare, annan vårdpersonal och hemvårdare"
                },
                "541": {
                    "label": "Säkerhets- och bevakningspersonal"
                },
                "611": {
                    "label": "Åker- och trädgårdsodlare"
                },
                "612": {
                    "label": "Djuruppfödare"
                },
                "613": {
                    "label": "Växtodlare och djuruppfödare, blandad drift"
                },
                "621": {
                    "label": "Skogsbrukare och skogsarbetare"
                },
                "622": {
                    "label": "Fiskodlare, fiskare och jägare"
                },
                "631": {
                    "label": "Växtodlare (självhushållning)"
                },
                "632": {
                    "label": "Boskapsuppfödare (självhushållning)"
                },
                "633": {
                    "label": "Växtodlare och boskapsuppfödare (självhushållning)"
                },
                "634": {
                    "label": "Fiskare och jägare (självhushållning)"
                },
                "711": {
                    "label": "Byggnadsarbetare m.fl."
                },
                "712": {
                    "label": "Byggnadshantverkare"
                },
                "713": {
                    "label": "Målare och saneringsarbetare"
                },
                "721": {
                    "label": "Gjuteriarbetare, svetsare, plåtslagare m.fl."
                },
                "722": {
                    "label": "Smeder, verktygsmakare och maskinställare"
                },
                "723": {
                    "label": "Maskinmontörer och reparatörer"
                },
                "731": {
                    "label": "Konsthantverkare och finmekaniker"
                },
                "732": {
                    "label": "Tryckeripersonal"
                },
                "741": {
                    "label": "Elmontörer och -reparatörer"
                },
                "742": {
                    "label": "Montörer och reparatörer inom elektronik och teleteknik"
                },
                "751": {
                    "label": "Styckare, bagare, mejerister m.fl."
                },
                "752": {
                    "label": "Trävaruhanterare, snickare m.fl."
                },
                "753": {
                    "label": "Personal inom konfektionsbranschen m.fl."
                },
                "754": {
                    "label": "Annan personal, oklassificerad under andra moment i huvudgrupp 7"
                },
                "811": {
                    "label": "Maskinoperatörer i gruv- och stenbrottsarbete"
                },
                "812": {
                    "label": "Processoperatörer och efterbehandlare, metallindustri"
                },
                "813": {
                    "label": "Processoperatörer, kemisk industri och fotografiska produkter"
                },
                "814": {
                    "label": "Processoperatörer, gummi-, plast- och pappersvaruindustri"
                },
                "815": {
                    "label": "Processoperatörer, textil-, skinn- och läderindustri"
                },
                "816": {
                    "label": "Processoperatörer, livsmedelsindustri"
                },
                "817": {
                    "label": "Processoperatörer, sågvaror samt pappers- och kartongindustri"
                },
                "818": {
                    "label": "Andra processoperatörer"
                },
                "821": {
                    "label": "Hopsättare, industriprodukter"
                },
                "831": {
                    "label": "Spårtrafikförare m.fl."
                },
                "832": {
                    "label": "Person- och paketbilsförare samt motorcykelförare"
                },
                "833": {
                    "label": "Förare av tunga motorfordon"
                },
                "834": {
                    "label": "Arbetsmaskinförare"
                },
                "835": {
                    "label": "Däckmanskap m.fl. sjötrafikarbetare"
                },
                "911": {
                    "label": "Hem-, hotell- och kontorsstädare m.fl."
                },
                "912": {
                    "label": "Fordonstvättare och fönsterputsare m.fl."
                },
                "921": {
                    "label": "Medhjälpare inom jordbruk, skogsbruk och fiske"
                },
                "931": {
                    "label": "Medhjälpare inom gruvdrift och byggverksamhet"
                },
                "932": {
                    "label": "Medhjälpare inom tillverkning"
                },
                "933": {
                    "label": "Godshanterare, lagerarbetare m.fl."
                },
                "941": {
                    "label": "Köks- och restaurangbiträden"
                },
                "951": {
                    "label": "Reklamutdelare, skoputsare m.fl."
                },
                "952": {
                    "label": "Gatuförsäljare (utom livsmedel)"
                },
                "961": {
                    "label": "Avfallshanterare"
                },
                "962": {
                    "label": "Tidningsutdelare, bud m.fl."
                },
                "1111": {
                    "label": "Lagstiftare"
                },
                "1112": {
                    "label": "Högre tjänstemän inom offentlig förvaltning"
                },
                "1113": {
                    "label": "Stam- och byhövdingar"
                },
                "1114": {
                    "label": "Ledare i organisationssektorn"
                },
                "1120": {
                    "label": "Verkställande direktörer och verkschefer"
                },
                "1211": {
                    "label": "Ekonomichefer"
                },
                "1212": {
                    "label": "Personalchefer"
                },
                "1213": {
                    "label": "Politik- och planeringschefer"
                },
                "1219": {
                    "label": "Övriga chefer inom företagstjänster och administration"
                },
                "1221": {
                    "label": "Försäljnings- och marknadsföringschefer"
                },
                "1222": {
                    "label": "Reklam- och kommunikationschefer, PR-chefer"
                },
                "1223": {
                    "label": "Forsknings- och utvecklingschefer"
                },
                "1311": {
                    "label": "Chefer inom jord- och skogsbruk"
                },
                "1312": {
                    "label": "Chefer inom vattenbruk och fiske"
                },
                "1321": {
                    "label": "Produktionschefer inom industri"
                },
                "1322": {
                    "label": "Produktionschefer inom gruvdrift"
                },
                "1323": {
                    "label": "Produktionschefer inom byggverksamhet"
                },
                "1324": {
                    "label": "Inköps- och distributionschefer m.fl."
                },
                "1330": {
                    "label": "Chefer inom informations- och kommunikationsteknik (IKT)"
                },
                "1341": {
                    "label": "Chefer inom barnomsorg"
                },
                "1342": {
                    "label": "Chefer inom hälso- och sjukvård"
                },
                "1343": {
                    "label": "Chefer inom äldrevård"
                },
                "1344": {
                    "label": "Chefer inom socialvård"
                },
                "1345": {
                    "label": "Chefer inom utbildning"
                },
                "1346": {
                    "label": "Chefer inom bank- och försäkringstjänster"
                },
                "1349": {
                    "label": "Övriga chefer inom samhälleliga tjänster"
                },
                "1411": {
                    "label": "Hotellchefer"
                },
                "1412": {
                    "label": "Restaurangchefer"
                },
                "1420": {
                    "label": "Chefer inom detalj- och partihandel"
                },
                "1431": {
                    "label": "Chefer för sport-, fritids- och kulturcenter"
                },
                "1439": {
                    "label": "Övriga chefer inom servicenäringar"
                },
                "2111": {
                    "label": "Fysiker och astronomer"
                },
                "2112": {
                    "label": "Meteorologer"
                },
                "2113": {
                    "label": "Kemister"
                },
                "2114": {
                    "label": "Geologer och geofysiker"
                },
                "2120": {
                    "label": "Matematiker, aktuarier och statistiker"
                },
                "2131": {
                    "label": "Biologer, botanister, zoologer m.fl."
                },
                "2132": {
                    "label": "Specialister inom jordbruk, skogsbruk och fiske"
                },
                "2133": {
                    "label": "Specialister inom miljö- och naturskydd"
                },
                "2141": {
                    "label": "Specialister inom industriell produktion och produktionsteknik"
                },
                "2142": {
                    "label": "Specialister inom anläggningsarbeten"
                },
                "2143": {
                    "label": "Specialister inom miljöteknik"
                },
                "2144": {
                    "label": "Specialister inom maskinteknik"
                },
                "2145": {
                    "label": "Specialister inom träförädling och kemisk processteknik"
                },
                "2146": {
                    "label": "Specialister inom gruvindustri, metallurgi m.fl."
                },
                "2149": {
                    "label": "Övriga specialister inom teknik"
                },
                "2151": {
                    "label": "Specialister inom elteknik"
                },
                "2152": {
                    "label": "Specialister inom elektronik"
                },
                "2153": {
                    "label": "Specialister inom IKT-branschen"
                },
                "2161": {
                    "label": "Arkitekter inom husbyggande"
                },
                "2162": {
                    "label": "Landskapsarkitekter"
                },
                "2163": {
                    "label": "Produkt- och modedesigner"
                },
                "2164": {
                    "label": "Samhälls- och trafikplanerare"
                },
                "2165": {
                    "label": "Specialister inom kartläggning och lantmäteri"
                },
                "2166": {
                    "label": "Grafiska designer och multimediadesigner"
                },
                "2211": {
                    "label": "Allmänläkare"
                },
                "2212": {
                    "label": "Överläkare och specialistläkare"
                },
                "2221": {
                    "label": "Överskötare och avdelningsskötare"
                },
                "2222": {
                    "label": "Ledande barnmorskor"
                },
                "2230": {
                    "label": "Specialister inom traditionella och alternativa vårdformer"
                },
                "2240": {
                    "label": "Producenter av andra hälsotjänster"
                },
                "2250": {
                    "label": "Veterinärer"
                },
                "2261": {
                    "label": "Tandläkare"
                },
                "2262": {
                    "label": "Provisorer"
                },
                "2263": {
                    "label": "Specialister inom miljöhälsa och arbetarskydd"
                },
                "2264": {
                    "label": "Specialister inom fysioterapi"
                },
                "2265": {
                    "label": "Specialister inom näringslära"
                },
                "2266": {
                    "label": "Audiologer och logopeder"
                },
                "2267": {
                    "label": "Specialister inom optometri"
                },
                "2269": {
                    "label": "Övriga specialister inom hälso- och sjukvården utan annan klassificering"
                },
                "2310": {
                    "label": "Universitets- och yrkeshögskolelärare"
                },
                "2320": {
                    "label": "Lärare i yrkesämnen"
                },
                "2330": {
                    "label": "Gymnasielärare och högstadielärare"
                },
                "2341": {
                    "label": "Lågstadielärare"
                },
                "2342": {
                    "label": "Barnträdgårdslärare"
                },
                "2351": {
                    "label": "Specialister i pedagogiska metoder"
                },
                "2352": {
                    "label": "Speciallärare"
                },
                "2353": {
                    "label": "Övriga språklärare"
                },
                "2354": {
                    "label": "Övriga musiklärare"
                },
                "2355": {
                    "label": "Övriga lärare i konstnärliga ämnen"
                },
                "2356": {
                    "label": "Övriga lärare och utbildare inom informationsteknik"
                },
                "2359": {
                    "label": "Studiehandledare och övriga specialister inom undervisning"
                },
                "2411": {
                    "label": "Specialister inom redovisning och revision"
                },
                "2412": {
                    "label": "Finans- och investeringsrådgivare"
                },
                "2413": {
                    "label": "Finansanalytiker"
                },
                "2421": {
                    "label": "Specialister inom ledarskap och organisationer"
                },
                "2422": {
                    "label": "Specialister inom utveckling av administration och näringar"
                },
                "2423": {
                    "label": "Specialister inom personaladministration och karriärplanering"
                },
                "2424": {
                    "label": "Specialister inom personalutveckling och utbildning"
                },
                "2431": {
                    "label": "Specialister inom reklam och marknadsföring"
                },
                "2432": {
                    "label": "Informatörer"
                },
                "2433": {
                    "label": "Försäljningsingenjörer och läkemedelsrepresentanter (utom IKT)"
                },
                "2434": {
                    "label": "Specialister inom försäljning av informations- och kommunikationsteknik (IKT)"
                },
                "2511": {
                    "label": "Specialister inom applikationsarkitektur"
                },
                "2512": {
                    "label": "Applikationsplanerare"
                },
                "2513": {
                    "label": "Webb- och multimediautvecklare"
                },
                "2514": {
                    "label": "Applikationsprogrammerare"
                },
                "2519": {
                    "label": "Övriga program- och applikationsutvecklare"
                },
                "2521": {
                    "label": "Databasutvecklare och databasansvariga"
                },
                "2522": {
                    "label": "Systemadministratörer"
                },
                "2523": {
                    "label": "Nätverksspecialister"
                },
                "2529": {
                    "label": "Övriga databas- och nätverksspecialister"
                },
                "2611": {
                    "label": "Advokater"
                },
                "2612": {
                    "label": "Domare"
                },
                "2619": {
                    "label": "Övriga specialister inom juridik"
                },
                "2621": {
                    "label": "Arkivarier och specialister inom museisektorn"
                },
                "2622": {
                    "label": "Bibliotekarier, informatiker m.fl."
                },
                "2631": {
                    "label": "Nationalekonomer"
                },
                "2632": {
                    "label": "Samhälls- och kulturforskare"
                },
                "2633": {
                    "label": "Historiker, statsvetare och filosofer"
                },
                "2634": {
                    "label": "Psykologer"
                },
                "2635": {
                    "label": "Specialister inom socialt arbete"
                },
                "2636": {
                    "label": "Präster och övriga specialister inom religion"
                },
                "2641": {
                    "label": "Författare m.fl."
                },
                "2642": {
                    "label": "Journalister"
                },
                "2643": {
                    "label": "Översättare, tolkar och andra språkvetare"
                },
                "2651": {
                    "label": "Bildkonstnärer"
                },
                "2652": {
                    "label": "Musiker, sångare och kompositörer"
                },
                "2653": {
                    "label": "Danskonstnärer och koreografer"
                },
                "2654": {
                    "label": "Regissörer och producenter"
                },
                "2655": {
                    "label": "Skådespelare"
                },
                "2656": {
                    "label": "Presentatörer, konferencierer m.fl."
                },
                "2659": {
                    "label": "Övriga konstnärer"
                },
                "3111": {
                    "label": "Tekniska experter inom naturvetenskap"
                },
                "3112": {
                    "label": "Experter inom byggande"
                },
                "3113": {
                    "label": "Experter inom elteknik"
                },
                "3114": {
                    "label": "Experter inom elektronik"
                },
                "3115": {
                    "label": "Experter inom maskinteknik"
                },
                "3116": {
                    "label": "Experter inom kemisk processteknik"
                },
                "3117": {
                    "label": "Experter inom gruvindustri och metallurgi"
                },
                "3118": {
                    "label": "Tekniska ritare"
                },
                "3119": {
                    "label": "Övriga experter inom fysik, kemi och teknik"
                },
                "3121": {
                    "label": "Arbetsledare inom gruvdrift"
                },
                "3122": {
                    "label": "Arbetsledare inom industri"
                },
                "3123": {
                    "label": "Arbetsledare inom byggverksamhet"
                },
                "3131": {
                    "label": "Processövervakare, kraftverk"
                },
                "3132": {
                    "label": "Processövervakare, förbränningsstationer och vattenreningsverk"
                },
                "3133": {
                    "label": "Processövervakare, kemisk industri"
                },
                "3134": {
                    "label": "Processövervakare, raffinering av petroleum och naturgas"
                },
                "3135": {
                    "label": "Processövervakare, metallframställning"
                },
                "3139": {
                    "label": "Övriga experter inom processövervakning"
                },
                "3141": {
                    "label": "Laboranter m.fl."
                },
                "3142": {
                    "label": "Jordbruks- och fiskeritekniker"
                },
                "3143": {
                    "label": "Skogsbrukstekniker"
                },
                "3151": {
                    "label": "Maskinchefer och -mästare på fartyg"
                },
                "3152": {
                    "label": "Befäl och styrmän inom sjötrafik"
                },
                "3153": {
                    "label": "Flygkaptener och -styrmän"
                },
                "3154": {
                    "label": "Flygledare"
                },
                "3155": {
                    "label": "Tekniska experter inom flygövervakning"
                },
                "3211": {
                    "label": "Experter, bilddiagnostik och medicinteknisk utrustning"
                },
                "3212": {
                    "label": "Bioanalytiker (hälsovården)"
                },
                "3213": {
                    "label": "Farmaceuter"
                },
                "3214": {
                    "label": "Tand- och hjälpmedelstekniker"
                },
                "3221": {
                    "label": "Sjukskötare m.fl."
                },
                "3222": {
                    "label": "Barnmorskor"
                },
                "3230": {
                    "label": "Utövare av naturmedicin och alternativ medicin"
                },
                "3240": {
                    "label": "Seminörer m.fl."
                },
                "3251": {
                    "label": "Munhygienister"
                },
                "3252": {
                    "label": "Patientadministratörer"
                },
                "3253": {
                    "label": "Hälsorådgivare"
                },
                "3254": {
                    "label": "Optiker"
                },
                "3255": {
                    "label": "Fysioterapeuter m.fl."
                },
                "3256": {
                    "label": "Sjukvårdsassistenter"
                },
                "3257": {
                    "label": "Hälso- och arbetarskyddsinspektörer"
                },
                "3258": {
                    "label": "Akutvårdare inom sjuktransporten"
                },
                "3259": {
                    "label": "Övriga experter inom hälso- och sjukvården utan annan klassificering"
                },
                "3311": {
                    "label": "Värdepappers- och valutamäklare"
                },
                "3312": {
                    "label": "Kredit- och låneexperter"
                },
                "3313": {
                    "label": "Experter inom bokföring och redovisning"
                },
                "3314": {
                    "label": "Experter inom statistik och matematik"
                },
                "3315": {
                    "label": "Värderare och skadeinspektörer"
                },
                "3321": {
                    "label": "Försäljare av försäkringstjänster"
                },
                "3322": {
                    "label": "Försäljningsrepresentanter"
                },
                "3323": {
                    "label": "Inköpare"
                },
                "3324": {
                    "label": "Affärsförmedlare"
                },
                "3331": {
                    "label": "Speditörer, tull- och fartygsklarerare"
                },
                "3332": {
                    "label": "Konferens- och evenemangsarrangörer"
                },
                "3333": {
                    "label": "Arbetsförmedlare"
                },
                "3334": {
                    "label": "Fastighetsmäklare och disponenter"
                },
                "3339": {
                    "label": "Övriga experter inom affärslivet"
                },
                "3341": {
                    "label": "Arbetsledare för kontorspersonal"
                },
                "3342": {
                    "label": "Juristsekreterare"
                },
                "3343": {
                    "label": "Ledningsassistenter och avdelningssekreterare"
                },
                "3344": {
                    "label": "Byråsekreterare, hälso- och sjukvård"
                },
                "3351": {
                    "label": "Tull- och gränstjänstemän"
                },
                "3352": {
                    "label": "Skatteberedare och -inspektörer"
                },
                "3353": {
                    "label": "Handläggare av socialskyddsförmåner"
                },
                "3354": {
                    "label": "Tillståndstjänstemän"
                },
                "3355": {
                    "label": "Kommissarier och överkonstaplar"
                },
                "3359": {
                    "label": "Övriga tjänstemän inom beredning och tillsyn inom offentlig förvaltning"
                },
                "3411": {
                    "label": "Juridiska assistenter och experter inom intresseorganisationer"
                },
                "3412": {
                    "label": "Handledare och rådgivare inom socialsektorn"
                },
                "3413": {
                    "label": "Församlingspersonal"
                },
                "3421": {
                    "label": "Idrottare"
                },
                "3422": {
                    "label": "Idrottstränare och funktionärer"
                },
                "3423": {
                    "label": "Idrottsinstruktörer och fritidsledare"
                },
                "3431": {
                    "label": "Fotografer"
                },
                "3432": {
                    "label": "Inredningsplanerare m.fl."
                },
                "3433": {
                    "label": "Galleri-, musei- och bibliotekstekniker"
                },
                "3434": {
                    "label": "Kökschefer"
                },
                "3435": {
                    "label": "Övriga experter inom konst och kultur"
                },
                "3511": {
                    "label": "Driftoperatörer"
                },
                "3512": {
                    "label": "Datasupportpersonal"
                },
                "3513": {
                    "label": "Nätverkstekniker"
                },
                "3514": {
                    "label": "Webbmaster och webbtekniker"
                },
                "3521": {
                    "label": "Sändnings- och AV-tekniker"
                },
                "3522": {
                    "label": "Tekniska experter inom telekommunikation"
                },
                "4110": {
                    "label": "Kontorsassistenter"
                },
                "4120": {
                    "label": "Kontorssekreterare"
                },
                "4131": {
                    "label": "Textbehandlare"
                },
                "4132": {
                    "label": "Dataregistrerare"
                },
                "4211": {
                    "label": "Banktjänstemän m.fl."
                },
                "4212": {
                    "label": "Vadförmedlare, croupierer m.fl."
                },
                "4213": {
                    "label": "Pantlånare"
                },
                "4214": {
                    "label": "Inkasserare"
                },
                "4221": {
                    "label": "Resebyråtjänstemän"
                },
                "4222": {
                    "label": "Telefonservicerådgivare"
                },
                "4223": {
                    "label": "Växeltelefonister"
                },
                "4224": {
                    "label": "Hotellreceptionister"
                },
                "4225": {
                    "label": "Kundrådgivare vid informationsdisk"
                },
                "4226": {
                    "label": "Receptions- och rådgivningspersonal"
                },
                "4227": {
                    "label": "Undersöknings- och marknadsundersökningsintervjuare"
                },
                "4229": {
                    "label": "Övrig kundtjänstpersonal utan annan klassificering"
                },
                "4311": {
                    "label": "Kontorspersonal inom ekonomiförvaltning"
                },
                "4312": {
                    "label": "Kontorspersonal inom statistik-, finansierings- och försäkringssektorn"
                },
                "4313": {
                    "label": "Löneräknare"
                },
                "4321": {
                    "label": "Lagerförvaltare m.fl."
                },
                "4322": {
                    "label": "Produktionsassistenter"
                },
                "4323": {
                    "label": "Kontorspersonal inom transport"
                },
                "4411": {
                    "label": "Bibliotekspersonal"
                },
                "4412": {
                    "label": "Brevbärare och postsorterare"
                },
                "4413": {
                    "label": "Kodare, korrekturläsare m.fl."
                },
                "4414": {
                    "label": "Skrivare m.fl."
                },
                "4415": {
                    "label": "Arkivanställda"
                },
                "4416": {
                    "label": "Assisterande kontorspersonal inom personalförvaltning"
                },
                "4419": {
                    "label": "Övrig kontors- och kundtjänstpersonal utan annan klassificering"
                },
                "5111": {
                    "label": "Flygvärdinnor, purser m.fl."
                },
                "5112": {
                    "label": "Konduktörer, biljettkontrollanter m.fl."
                },
                "5113": {
                    "label": "Guider"
                },
                "5120": {
                    "label": "Restaurang- och storhushållspersonal"
                },
                "5131": {
                    "label": "Servitörer"
                },
                "5132": {
                    "label": "Bartendrar"
                },
                "5141": {
                    "label": "Frisörer"
                },
                "5142": {
                    "label": "Kosmetologer m.fl."
                },
                "5151": {
                    "label": "Arbetsledare inom städning på kontor, hotell m.fl."
                },
                "5152": {
                    "label": "Hushållerskor i privata hem"
                },
                "5153": {
                    "label": "Fastighetsskötare"
                },
                "5161": {
                    "label": "Astrologer, siare m.fl."
                },
                "5162": {
                    "label": "Personliga betjänter"
                },
                "5163": {
                    "label": "Personal inom begravningstjänster"
                },
                "5164": {
                    "label": "Djurskötare och djurfrisörer"
                },
                "5165": {
                    "label": "Trafiklärare"
                },
                "5169": {
                    "label": "Övrig servicepersonal inom personliga tjänster utan annan klassificering"
                },
                "5211": {
                    "label": "Kiosk- och torgförsäljare"
                },
                "5212": {
                    "label": "Gatuförsäljare (livsmedel)"
                },
                "5221": {
                    "label": "Butiksinnehavare (småföretagare)"
                },
                "5222": {
                    "label": "Butiksföreståndare"
                },
                "5223": {
                    "label": "Försäljare"
                },
                "5230": {
                    "label": "Butikskassörer, biljettförsäljare m.fl."
                },
                "5241": {
                    "label": "Modeller"
                },
                "5242": {
                    "label": "Varudemonstratörer"
                },
                "5243": {
                    "label": "Direktförsäljare"
                },
                "5244": {
                    "label": "Försäljare, telefonförsäljning och kontaktcenter"
                },
                "5245": {
                    "label": "Bensinstationspersonal"
                },
                "5246": {
                    "label": "Försäljare, kaféer och barer"
                },
                "5249": {
                    "label": "Övrig försäljningspersonal utan annan klassificering"
                },
                "5311": {
                    "label": "Personal inom barnomsorgen"
                },
                "5312": {
                    "label": "Skolgångsbiträden"
                },
                "5321": {
                    "label": "Närvårdare"
                },
                "5322": {
                    "label": "Hemvårdare (hemvårdstjänster)"
                },
                "5329": {
                    "label": "Övrig personal inom hälso- och sjukvården"
                },
                "5411": {
                    "label": "Brandmän"
                },
                "5412": {
                    "label": "Poliser"
                },
                "5413": {
                    "label": "Fångvaktare"
                },
                "5414": {
                    "label": "Väktare"
                },
                "5419": {
                    "label": "Övrig säkerhetspersonal"
                },
                "6111": {
                    "label": "Odlare, åkerbruk och frilandsodling"
                },
                "6112": {
                    "label": "Odlare av fruktträd och buskar m.fl."
                },
                "6113": {
                    "label": "Odlare och arbetare inom trädgårds- och växthusodling"
                },
                "6114": {
                    "label": "Odlare av blandade växtslag"
                },
                "6121": {
                    "label": "Uppfödare av kött- och mjölkboskap och andra husdjur"
                },
                "6122": {
                    "label": "Fjäderfäuppfödare"
                },
                "6123": {
                    "label": "Biodlare m.fl."
                },
                "6129": {
                    "label": "Övriga djuruppfödare och djurskötare"
                },
                "6130": {
                    "label": "Växtodlare och djuruppfödare, blandad drift"
                },
                "6210": {
                    "label": "Skogsbrukare och skogsarbetare"
                },
                "6221": {
                    "label": "Fiskodlare och fiskodlingspersonal"
                },
                "6222": {
                    "label": "Fiskare"
                },
                "6223": {
                    "label": "Djuphavsfiskare"
                },
                "6224": {
                    "label": "Viltvårdare och jägare"
                },
                "6310": {
                    "label": "Växtodlare (självhushållning)"
                },
                "6320": {
                    "label": "Djuruppfödare (självhushållning)"
                },
                "6330": {
                    "label": "Växtodlare och djuruppfödare (självhushållning)"
                },
                "6340": {
                    "label": "Fiskare och jägare (självhushållning)"
                },
                "7111": {
                    "label": "Byggnadsarbetare"
                },
                "7112": {
                    "label": "Murare m.fl."
                },
                "7113": {
                    "label": "Stenhuggare m.fl."
                },
                "7114": {
                    "label": "Betongarbetare och armerare"
                },
                "7115": {
                    "label": "Timmermän och byggnadssnickare"
                },
                "7119": {
                    "label": "Övriga byggnadsarbetare"
                },
                "7121": {
                    "label": "Takmontörer och takreparatörer"
                },
                "7122": {
                    "label": "Golvläggare"
                },
                "7123": {
                    "label": "Rappare"
                },
                "7124": {
                    "label": "Isoleringsmontörer"
                },
                "7125": {
                    "label": "Glasmästare"
                },
                "7126": {
                    "label": "Rörläggare"
                },
                "7127": {
                    "label": "Ventilations- och kylmontörer"
                },
                "7131": {
                    "label": "Byggnadsmålare m.fl."
                },
                "7132": {
                    "label": "Sprutlackerare"
                },
                "7133": {
                    "label": "Saneringsarbetare och sotare"
                },
                "7211": {
                    "label": "Formare och kärnmakare"
                },
                "7212": {
                    "label": "Svetsare och gasskärare"
                },
                "7213": {
                    "label": "Tunnplåtslagare"
                },
                "7214": {
                    "label": "Grovplåtslagare och stålkonstruktionsmontörer"
                },
                "7215": {
                    "label": "Kabelläggare och riggare"
                },
                "7221": {
                    "label": "Smeder"
                },
                "7222": {
                    "label": "Verktygsmakare och låssmeder"
                },
                "7223": {
                    "label": "Maskinställare och verkstadsmekaniker"
                },
                "7224": {
                    "label": "Maskinslipare, -polerare och -vässare"
                },
                "7231": {
                    "label": "Motorfordonsmontörer och -reparatörer"
                },
                "7232": {
                    "label": "Flygmontörer och flygreparatörer"
                },
                "7233": {
                    "label": "Maskinmontörer och -reparatörer (jordbruks- och industrimaskiner)"
                },
                "7234": {
                    "label": "Cykelreparatörer m.fl."
                },
                "7311": {
                    "label": "Urmakare och övriga tillverkare av finmekaniska instrument"
                },
                "7312": {
                    "label": "Musikinstrumentmakare och -stämmare"
                },
                "7313": {
                    "label": "Juvel-, guld- och silversmeder"
                },
                "7314": {
                    "label": "Ler- och tegelgjutare, drejare"
                },
                "7315": {
                    "label": "Glasblåsare, -skärare, -slipare och -efterbehandlare"
                },
                "7316": {
                    "label": "Glasgravörer, glasetsare och skyltmålare"
                },
                "7317": {
                    "label": "Konsthantverkare i trä m.m."
                },
                "7318": {
                    "label": "Konsthantverkare i textil, läder m.m."
                },
                "7319": {
                    "label": "Övriga konsthantverkare"
                },
                "7321": {
                    "label": "Prepressoperatörer"
                },
                "7322": {
                    "label": "Tryckare"
                },
                "7323": {
                    "label": "Efterbehandlare och bokbinderiarbetare"
                },
                "7411": {
                    "label": "Byggnadselmontörer"
                },
                "7412": {
                    "label": "Övriga elmontörer"
                },
                "7413": {
                    "label": "Linjemontörer och -reparatörer"
                },
                "7421": {
                    "label": "Montörer och reparatörer, elektronik och automation"
                },
                "7422": {
                    "label": "Montörer och reparatörer, IKT"
                },
                "7511": {
                    "label": "Slaktare, fiskberedare m.fl."
                },
                "7512": {
                    "label": "Bagare och konditorer"
                },
                "7513": {
                    "label": "Mejerister, ostmästare m.fl."
                },
                "7514": {
                    "label": "Tillverkare av frukt- och grönsaksprodukter"
                },
                "7515": {
                    "label": "Kvalitetsbedömare (mat och dryck)"
                },
                "7516": {
                    "label": "Tillverkare av tobaksprodukter"
                },
                "7521": {
                    "label": "Trävaruhanterare"
                },
                "7522": {
                    "label": "Möbelsnickare m.fl."
                },
                "7523": {
                    "label": "Maskinsnickare"
                },
                "7531": {
                    "label": "Skräddare, ateljésömmerskor, körsnärer och modister"
                },
                "7532": {
                    "label": "Tillskärare och modellmästare"
                },
                "7533": {
                    "label": "Broderare och andra textilsömmare"
                },
                "7534": {
                    "label": "Tapetserare"
                },
                "7535": {
                    "label": "Garvare och skinnberedare"
                },
                "7536": {
                    "label": "Skomakare m.fl."
                },
                "7541": {
                    "label": "Dykare"
                },
                "7542": {
                    "label": "Laddare och sprängare"
                },
                "7543": {
                    "label": "Klassificerare och kvalitetskontrollanter (utom drycker och livsmedel)"
                },
                "7544": {
                    "label": "Röksanerare, skadedjurs- och ogrässanerare"
                },
                "7549": {
                    "label": "Övrig personal, oklassificerad under andra moment i huvudgrupp 7"
                },
                "8111": {
                    "label": "Gruv- och stenbrottsarbetare"
                },
                "8112": {
                    "label": "Anrikningsarbetare"
                },
                "8113": {
                    "label": "Slagborrare och djupborrare"
                },
                "8114": {
                    "label": "Processoperatörer inom betongindustri m.fl."
                },
                "8121": {
                    "label": "Processoperatörer inom metallindustri"
                },
                "8122": {
                    "label": "Ytbeläggare och efterbehandlare inom metallindustri"
                },
                "8131": {
                    "label": "Processoperatörer, kemisk industri m.fl."
                },
                "8132": {
                    "label": "Processoperatörer, fotografiska produkter"
                },
                "8141": {
                    "label": "Processoperatörer, gummiindustri"
                },
                "8142": {
                    "label": "Processoperatörer, plastindustri"
                },
                "8143": {
                    "label": "Processoperatörer, pappersvaruindustri"
                },
                "8151": {
                    "label": "Maskinoperatörer, fibertillverkning, spinning och spolning"
                },
                "8152": {
                    "label": "Maskinoperatörer, vävning och stickning"
                },
                "8153": {
                    "label": "Symaskinsoperatörer"
                },
                "8154": {
                    "label": "Maskinoperatörer, tvättning, blekning och färgning"
                },
                "8155": {
                    "label": "Maskinoperatörer, pälsskinnsberedning, färgning"
                },
                "8156": {
                    "label": "Processoperatörer, sko- och väskindustri"
                },
                "8157": {
                    "label": "Tvätteripersonal"
                },
                "8159": {
                    "label": "Övriga processoperatörer inom textil-, skinn- och läderindustri"
                },
                "8160": {
                    "label": "Processoperatörer, livsmedelsindustri"
                },
                "8171": {
                    "label": "Processoperatörer, pappers-, kartong- och massaindustri"
                },
                "8172": {
                    "label": "Processoperatörer, trä- och sågvaror"
                },
                "8181": {
                    "label": "Ugnsoperatörer, glas- och keramikindustri"
                },
                "8182": {
                    "label": "Operatörer och eldare m.fl., ångmaskiner och ångpannor"
                },
                "8183": {
                    "label": "Maskinoperatörer, packning, påfyllning och märkning"
                },
                "8189": {
                    "label": "Övriga processoperatörer utan annan klassificering"
                },
                "8211": {
                    "label": "Hopsättare, verkstads- och metallprodukter"
                },
                "8212": {
                    "label": "Hopsättare, elektrisk och elektronisk utrustning"
                },
                "8219": {
                    "label": "Övriga hopsättare av industriprodukter"
                },
                "8311": {
                    "label": "Lokförare"
                },
                "8312": {
                    "label": "Bangårdspersonal m.fl."
                },
                "8321": {
                    "label": "Motorcykelbud m.fl."
                },
                "8322": {
                    "label": "Person-, taxi- och paketbilsförare"
                },
                "8331": {
                    "label": "Buss- och spårvagnsförare"
                },
                "8332": {
                    "label": "Lastbils- och specialfordonsförare"
                },
                "8341": {
                    "label": "Förare av jordbruks- och skogsmaskiner"
                },
                "8342": {
                    "label": "Anläggningsmaskinförare m.fl."
                },
                "8343": {
                    "label": "Kranförare"
                },
                "8344": {
                    "label": "Stuveriarbetare och truckförare m.fl."
                },
                "8350": {
                    "label": "Däckmanskap, sjötrafikarbetare m.fl."
                },
                "9111": {
                    "label": "Hembiträden och städare"
                },
                "9112": {
                    "label": "Kontors- och hotellstädare m.fl."
                },
                "9121": {
                    "label": "Rengörare och pressare"
                },
                "9122": {
                    "label": "Fordonstvättare"
                },
                "9123": {
                    "label": "Fönsterputsare"
                },
                "9129": {
                    "label": "Övriga rengöringsarbetare"
                },
                "9211": {
                    "label": "Medhjälpare, jordbruk"
                },
                "9212": {
                    "label": "Medhjälpare, djuruppfödning"
                },
                "9213": {
                    "label": "Medhjälpare, växtodling och djuruppfödning, blandad drift"
                },
                "9214": {
                    "label": "Medhjälpare, trädgårdsodling"
                },
                "9215": {
                    "label": "Medhjälpare, skogsbruk"
                },
                "9216": {
                    "label": "Medhjälpare, fiske och vattenbruk"
                },
                "9311": {
                    "label": "Medhjälpare, gruvor"
                },
                "9312": {
                    "label": "Medhjälpare, anläggningsverksamhet"
                },
                "9313": {
                    "label": "Medhjälpare, byggnadsverksamhet"
                },
                "9321": {
                    "label": "Handpaketerare"
                },
                "9329": {
                    "label": "Övriga medhjälpare inom industrin"
                },
                "9331": {
                    "label": "Förare av hand- och pedaldrivna bilar"
                },
                "9332": {
                    "label": "Förare av djurdragna fordon"
                },
                "9333": {
                    "label": "Godshanterare, lagerarbetare m.fl."
                },
                "9334": {
                    "label": "Varupåfyllare"
                },
                "9411": {
                    "label": "Personal inom snabbmatssektorn"
                },
                "9412": {
                    "label": "Köksbiträden"
                },
                "9510": {
                    "label": "Reklamutdelare, skoputsare m.fl."
                },
                "9520": {
                    "label": "Gatuförsäljare (utom livsmedel)"
                },
                "9611": {
                    "label": "Avfallsinsamlare"
                },
                "9612": {
                    "label": "Avfallssorterare"
                },
                "9613": {
                    "label": "Gatsopare m.fl."
                },
                "9621": {
                    "label": "Tidnings- och reklamutdelare, bud"
                },
                "9622": {
                    "label": "Diversearbetare"
                },
                "9623": {
                    "label": "Mätaravläsare m.fl."
                },
                "9624": {
                    "label": "Vattenhämtare och vedinsamlare"
                },
                "9629": {
                    "label": "Övrig personal utan annan klassificering"
                },
                "11121": {
                    "label": "Direktörer inom statens centralförvaltning"
                },
                "11122": {
                    "label": "Direktörer och högre tjänstemän inom statlig distrikts- och lokalförvaltning"
                },
                "11141": {
                    "label": "Chefer i arbetsmarknads- och näringslivsorganisationer"
                },
                "11142": {
                    "label": "Chefer i andra organisationer"
                },
                "21321": {
                    "label": "Specialister inom jordbruk och fiske"
                },
                "21322": {
                    "label": "Specialister inom skogsbruk"
                },
                "21531": {
                    "label": "Forskare inom teleteknik"
                },
                "21532": {
                    "label": "Forskare inom informationsteknik"
                },
                "22121": {
                    "label": "Överläkare"
                },
                "22122": {
                    "label": "Specialistläkare"
                },
                "22211": {
                    "label": "Överskötare"
                },
                "22212": {
                    "label": "Avdelningsskötare"
                },
                "23101": {
                    "label": "Professorer"
                },
                "23102": {
                    "label": "Lektorer och överassistenter (universitet)"
                },
                "23103": {
                    "label": "Assistenter och timlärare (universitet)"
                },
                "23104": {
                    "label": "Överlärare (yrkeshögskolor)"
                },
                "23105": {
                    "label": "Lektorer (yrkeshögskolor)"
                },
                "23106": {
                    "label": "Timlärare m.fl. (yrkeshögskolor)"
                },
                "23301": {
                    "label": "Lärare i matematiska ämnen"
                },
                "23302": {
                    "label": "Lärare i modersmål och litteratur"
                },
                "23303": {
                    "label": "Lärare i konst- och färdighetsämnen"
                },
                "23304": {
                    "label": "Övriga högstadie- och gymnasielärare"
                },
                "23411": {
                    "label": "Klasslärare"
                },
                "23412": {
                    "label": "Ämneslärare (lågstadiet)"
                },
                "23591": {
                    "label": "Studiehandledare"
                },
                "23592": {
                    "label": "Övriga specialister inom undervisning"
                },
                "26211": {
                    "label": "Arkivarier"
                },
                "26212": {
                    "label": "Specialister inom museisektorn"
                },
                "26351": {
                    "label": "Socialarbetare m.fl."
                },
                "26352": {
                    "label": "Planerare inom socialsektorn m.fl."
                },
                "26421": {
                    "label": "Redaktionschefer och redaktionssekreterare, programchefer"
                },
                "26422": {
                    "label": "Redaktörer vid tidningar m.fl."
                },
                "26423": {
                    "label": "Radio- och TV-redaktörer"
                },
                "31121": {
                    "label": "Experter inom husbyggnad"
                },
                "31122": {
                    "label": "Experter inom anläggningsarbeten"
                },
                "31123": {
                    "label": "Experter inom kartläggning och lantmäteri"
                },
                "31521": {
                    "label": "Fartygsbefäl och styrmän (stora fartyg)"
                },
                "31522": {
                    "label": "Befäl (mindre fartyg)"
                },
                "31523": {
                    "label": "Hamntrafikledare och hamnkaptener"
                },
                "32141": {
                    "label": "Tandtekniker"
                },
                "32142": {
                    "label": "Hjälpmedelstekniker"
                },
                "32211": {
                    "label": "Sjukskötare"
                },
                "32212": {
                    "label": "Hälsovårdare"
                },
                "32591": {
                    "label": "Ergoterapeuter"
                },
                "32592": {
                    "label": "Övriga terapeuter"
                },
                "33341": {
                    "label": "Fastighetsmäklare"
                },
                "33342": {
                    "label": "Disponenter"
                },
                "34111": {
                    "label": "Rättegångsombud och utsökningsmän"
                },
                "34112": {
                    "label": "Ombud, funktionärer m.fl. experter inom organisationssektorn"
                },
                "34113": {
                    "label": "Konsumentrådgivare m.fl."
                },
                "34121": {
                    "label": "Handledare inom socialsektorn"
                },
                "34122": {
                    "label": "Ungdomsledare (ej församl.)"
                },
                "34123": {
                    "label": "Handledare och sysselsättningsledare"
                },
                "34131": {
                    "label": "Diakoner och diakonissor"
                },
                "34139": {
                    "label": "Övriga församlingsarbetare"
                },
                "34351": {
                    "label": "Scriptor och övriga experter inom scenteknik"
                },
                "34359": {
                    "label": "Övriga experter inom konst- och konstindustrisektorn"
                },
                "42291": {
                    "label": "Nödcentraloperatörer"
                },
                "42299": {
                    "label": "Övrig kundtjänstpersonal utan annan klassificering"
                },
                "43231": {
                    "label": "Spårtrafikledare, trafiksamordnare m.fl."
                },
                "43239": {
                    "label": "Övriga kontorstjänstemän inom transport och spedition"
                },
                "44121": {
                    "label": "Brevbärare"
                },
                "44122": {
                    "label": "Kontorsvaktmästare"
                },
                "51201": {
                    "label": "Kockar, kokerskor och kallskänkor"
                },
                "51202": {
                    "label": "Restaurangföreståndare och skiftledare"
                },
                "51631": {
                    "label": "Begravningsbyråföreståndare m.fl."
                },
                "51632": {
                    "label": "Övrig begravningspersonal"
                },
                "53111": {
                    "label": "Barnskötare, daghem och andra institutioner m.fl."
                },
                "53112": {
                    "label": "Familjedagvårdare"
                },
                "53113": {
                    "label": "Barnklubbsledare m.fl."
                },
                "53211": {
                    "label": "Mentalhälsovårdare"
                },
                "53212": {
                    "label": "Vårdare av utvecklingshämmade"
                },
                "53213": {
                    "label": "Vårdare inom socialsektorn"
                },
                "53219": {
                    "label": "Övriga närvårdare"
                },
                "53221": {
                    "label": "Hemvårdspersonal"
                },
                "53222": {
                    "label": "Personliga assistenter, närståendevårdare m.fl."
                },
                "53291": {
                    "label": "Tandskötare"
                },
                "53292": {
                    "label": "Instrumentvårdare"
                },
                "53293": {
                    "label": "Läkemedelsarbetare på apotek"
                },
                "53294": {
                    "label": "Massörer och konditionsskötare"
                },
                "61111": {
                    "label": "Åkerodlare"
                },
                "61112": {
                    "label": "Arbetsledare och arbetare inom åkerodling"
                },
                "61131": {
                    "label": "Trädgårds- och växthusodlare"
                },
                "61132": {
                    "label": "Arbetsledare och anställda inom trädgårds- och växthusodling"
                },
                "61211": {
                    "label": "Boskapsuppfödare m.fl."
                },
                "61212": {
                    "label": "Boskapsskötare m.fl."
                },
                "61213": {
                    "label": "Sällskapsdjursuppfödare"
                },
                "61214": {
                    "label": "Lantbruksavbytare"
                },
                "61291": {
                    "label": "Pälsdjurs- och renskötare"
                },
                "61299": {
                    "label": "Övriga djurskötare utan annan klassificering"
                },
                "62211": {
                    "label": "Fiskodlingsföretagare"
                },
                "62212": {
                    "label": "Arbetsledare och arbetare inom fiskodling"
                },
                "74211": {
                    "label": "Elektronikmontörer och -reparatörer"
                },
                "74212": {
                    "label": "Automationsmontörer och -reparatörer"
                },
                "81821": {
                    "label": "Maskinreparatörer, kraftverk och avfallsbehandlingsanläggningar"
                },
                "81822": {
                    "label": "Övriga maskinreparatörer m.fl."
                },
                "83441": {
                    "label": "Stuveriarbetare"
                },
                "83442": {
                    "label": "Truckförare m.fl."
                },
                "91121": {
                    "label": "Kontorsstädare m.fl."
                },
                "91122": {
                    "label": "Hotellstädare"
                },
                "91123": {
                    "label": "Sjukhus- och vårdbiträden"
                },
                "91124": {
                    "label": "Daghemsbiträden"
                },
                "91129": {
                    "label": "Övriga städare utan annan klassificering"
                },
                "01": {
                    "label": "Officerare"
                },
                "011": {
                    "label": "Officerare"
                },
                "0110": {
                    "label": "Officerare"
                },
                "02": {
                    "label": "Underofficerare"
                },
                "021": {
                    "label": "Underofficerare"
                },
                "0210": {
                    "label": "Underofficerare"
                },
                "03": {
                    "label": "Yrkesutbildad personal inom militären"
                },
                "031": {
                    "label": "Yrkesutbildad personal inom militären"
                },
                "0310": {
                    "label": "Yrkesutbildad personal inom militären"
                },
                "#X": {
                    "label": "Okänd"
                },
                "#XX": {
                    "label": "Okänd"
                },
                "#XXX": {
                    "label": "Okänd"
                },
                "#XXXX": {
                    "label": "Okänd"
                },
                "#XXXXX": {
                    "label": "Okänd"
                }
            },
            "ReportCategory": {
                "all": {
                    "description": "",
                    "label": ""
                },
                "monthly": {
                    "description": "",
                    "label": ""
                },
                "yearly": {
                    "description": "",
                    "label": ""
                }
            },
            "ReportType": {
                "employerReport": {
                    "description": "",
                    "label": "Arbetstagarrapport"
                },
                "employmentContract": {
                    "description": "",
                    "label": "Arbetskontrakt"
                },
                "example": {
                    "description": "",
                    "label": "Exempel"
                },
                "householdDeduction": {
                    "description": "",
                    "label": "Hushållsavdrag"
                },
                "insurance": {
                    "description": "",
                    "label": "Försäkring"
                },
                "monthlyDetails": {
                    "description": "",
                    "label": "Månatliga detlajer"
                },
                "monthlyLiikekirjuri": {
                    "description": "",
                    "label": ""
                },
                "monthlyPension": {
                    "description": "",
                    "label": "Månatlig pension"
                },
                "monthlyRapko": {
                    "description": "",
                    "label": ""
                },
                "paymentReport": {
                    "description": "",
                    "label": "Betalningsrapport"
                },
                "salarySlip": {
                    "description": "",
                    "label": "Lönekvitto"
                },
                "salarySlipPaid": {
                    "description": "",
                    "label": "Lönekvitto betalt"
                },
                "taxHouseholdDeduction14B": {
                    "description": "",
                    "label": ""
                },
                "taxHouseholdDeduction14BSpouseA": {
                    "description": "",
                    "label": ""
                },
                "taxHouseholdDeduction14BSpouseB": {
                    "description": "",
                    "label": ""
                },
                "taxMonthly4001": {
                    "description": "",
                    "label": "Månatlig skatt"
                },
                "taxYearly7801": {
                    "description": "",
                    "label": "Årlig skatt"
                },
                "undefined": {
                    "description": "",
                    "label": "Odefinierad"
                },
                "unemployment": {
                    "description": "",
                    "label": "Arbetslöshet"
                },
                "yearEndReport": {
                    "description": "",
                    "label": "Årsslutsrapport"
                },
                "yearlyDetails": {
                    "description": "",
                    "label": "Årliga uppgifter"
                },
                "yearlyWorkerSummary": {
                    "description": "",
                    "label": ""
                }
            },
            "SalaryKind": {
                "compensation": {
                    "description": "",
                    "label": "Kompensation"
                },
                "fixedSalary": {
                    "description": "",
                    "label": "Fast lön"
                },
                "hourlySalary": {
                    "description": "",
                    "label": "Timlön"
                },
                "monthlySalary": {
                    "description": "",
                    "label": "Månadslön"
                },
                "totalEmployerPayment": {
                    "description": "",
                    "label": ""
                },
                "totalWorkerPayment": {
                    "description": "",
                    "label": ""
                },
                "undefined": {
                    "description": "",
                    "label": "Odefinierad"
                }
            },
            "SalaryPeriod": {
                "fixed": {
                    "description": "",
                    "label": ""
                },
                "hourly": {
                    "description": "",
                    "label": ""
                },
                "monthly": {
                    "description": "",
                    "label": ""
                },
                "notDefined": {
                    "description": "",
                    "label": ""
                }
            },
            "SalaryPerMonthRange": {
                "noPensionRequired": {
                    "description": "",
                    "label": "Under 57,10 €"
                },
                "normal": {
                    "description": "",
                    "label": "57,10 € eller över"
                },
                "unknown": {
                    "description": "",
                    "label": "Okänd"
                }
            },
            "SalaryPerYearRange": {
                "noMonthlyReporting": {
                    "description": "",
                    "label": "203 - 1500 €"
                },
                "noReportingNecessary": {
                    "description": "",
                    "label": "3 - 200 €"
                },
                "normal": {
                    "description": "",
                    "label": "Över 1500 €"
                },
                "zeroSalary": {
                    "description": "",
                    "label": 2
                }
            },
            "TaxCardIncomeType": {
                "externalSalaries": {
                    "description": "",
                    "label": "Utomstående löner"
                },
                "previousEmployerSalaries": {
                    "description": "Lön som personen förtjänat tidigare under samma år. Markera dem i euro i en klumpsumma.",
                    "label": "Lön betalt av tidigare arbetsgivare"
                },
                "salaxyCalculation": {
                    "description": "",
                    "label": "Salaxy uträkning"
                },
                "unknown": {
                    "description": "",
                    "label": "Okänd"
                }
            },
            "TaxCardState": {
                "approved": {
                    "description": "",
                    "label": "Godkänd"
                },
                "new": {
                    "description": "",
                    "label": "Ny"
                },
                "rejected": {
                    "description": "",
                    "label": "Avslagen"
                },
                "waiting": {
                    "description": "",
                    "label": "Väntar"
                }
            },
            "TaxCardType": {
                "example": {
                    "description": "",
                    "label": "Exempel på skattekort"
                },
                "freelancer": {
                    "description": "",
                    "label": "Frilansare"
                },
                "noTaxCard": {
                    "description": "",
                    "label": "Inget skattekort"
                },
                "noTaxPrepayment": {
                    "description": "",
                    "label": "Ingen förskottsinnehållning"
                },
                "others": {
                    "description": "",
                    "label": "Annan"
                },
                "sideIncome": {
                    "description": "",
                    "label": "Sidoinkomst"
                },
                "steps": {
                    "description": "",
                    "label": ""
                },
                "taxCardA": {
                    "description": "",
                    "label": "A"
                },
                "taxCardB": {
                    "description": "",
                    "label": "B"
                }
            },
            "TaxDeductionWorkCategories": {
                "carework": {
                    "description": "",
                    "label": "Omvårdnadsarbete"
                },
                "homeImprovement": {
                    "description": "",
                    "label": "Hemförbättringsarbete"
                },
                "householdwork": {
                    "description": "",
                    "label": "Hushållsarbete"
                },
                "none": {
                    "description": "",
                    "label": "Välj…"
                },
                "ownPropety": {
                    "description": "",
                    "label": "Fritidshus i eget bruk"
                },
                "relativesProperty": {
                    "description": "",
                    "label": "Föräldrars eller släktingars fritidshus"
                }
            },
            "TesSubtype": {
                "constructionCarpenter": {
                    "description": "",
                    "label": ""
                },
                "constructionFloor": {
                    "description": "",
                    "label": ""
                },
                "constructionFreeContract": {
                    "description": "",
                    "label": ""
                },
                "constructionOther": {
                    "description": "",
                    "label": ""
                },
                "notSelected": {
                    "description": "",
                    "label": ""
                }
            },
            "TestEnum": {
                "valueEight": {
                    "description": "",
                    "label": ""
                },
                "valueFive": {
                    "description": "",
                    "label": ""
                },
                "valueFour": {
                    "description": "",
                    "label": ""
                },
                "valueNine": {
                    "description": "",
                    "label": ""
                },
                "valueOne": {
                    "description": "",
                    "label": ""
                },
                "valueSevdescription": "",
                "valueSevlabel": "",
                "valueSix": {
                    "description": "",
                    "label": ""
                },
                "valueTdescription": "",
                "valueThree": {
                    "description": "",
                    "label": ""
                },
                "valueTlabel": "",
                "valueTwo": {
                    "description": "",
                    "label": ""
                },
                "valueZero": {
                    "description": "",
                    "label": ""
                }
            },
            "UnionPaymentType": {
                "notSelected": {
                    "description": "",
                    "label": "Inget medlemskap"
                },
                "other": {
                    "description": "",
                    "label": "Annan fackförening"
                },
                "raksaNormal": {
                    "description": "",
                    "label": ""
                },
                "raksaUnemploymentOnly": {
                    "description": "",
                    "label": ""
                }
            },
            "WebSiteUserRole": {
                "company": {
                    "description": "",
                    "label": "Företagare"
                },
                "household": {
                    "description": "",
                    "label": "Arbetsgivare"
                },
                "none": {
                    "description": "",
                    "label": "Välj…"
                },
                "worker": {
                    "description": "",
                    "label": "Arbetstagare"
                }
            },
            "YtjCompanyType": {
                "alandFederation": {
                    "description": "",
                    "label": "Åländskt företag"
                },
                "asoAssociation": {
                    "description": "",
                    "label": "Bostadsrättsförening"
                },
                "association": {
                    "description": "",
                    "label": "Idelogisk förening"
                },
                "condominium": {
                    "description": "",
                    "label": "Fastighets aktiebolag"
                },
                "cooperativeBank": {
                    "description": "",
                    "label": "Andelsbank"
                },
                "europeanCooperative": {
                    "description": "",
                    "label": "Europeiskt andelslag"
                },
                "europeanCooperativeBank": {
                    "description": "",
                    "label": "Europeisk andelsbank"
                },
                "federationOfMunicipalitiesEstablishment": {
                    "description": "",
                    "label": "Federal inrättning"
                },
                "financialAssociation": {
                    "description": "",
                    "label": "Ekonomisk förening"
                },
                "forestCareAssociation": {
                    "description": "",
                    "label": "Skogsbruksförening"
                },
                "foundation": {
                    "description": "",
                    "label": "Fond"
                },
                "housingCooperative": {
                    "description": "",
                    "label": "Bostadsandelslag"
                },
                "hypoAssociation": {
                    "description": "",
                    "label": "Hypoteksförening"
                },
                "insuranceAssociation": {
                    "description": "",
                    "label": "Försäkringsförening"
                },
                "ky": {
                    "description": "",
                    "label": "Kommanditbolag"
                },
                "municipalEstablishment": {
                    "description": "",
                    "label": "Kommunal inrättning"
                },
                "mutualInsuranceAssociation": {
                    "description": "",
                    "label": "Ömsesidig skadeförsäkringsförening"
                },
                "noCompanyType": {
                    "description": "",
                    "label": "Ingen företagsform"
                },
                "openCompany": {
                    "description": "",
                    "label": "Öppet bolag"
                },
                "osuuskunta": {
                    "description": "",
                    "label": "Andelslag"
                },
                "otherAssociation": {
                    "description": "",
                    "label": "Annan förening"
                },
                "otherFinancialAssociation": {
                    "description": "",
                    "label": "Annan finansiell förening"
                },
                "oy": {
                    "description": "",
                    "label": "Aktiebolag"
                },
                "privateEntrepreneur": {
                    "description": "",
                    "label": "Privat näringsidkare"
                },
                "reindeerHerdingCooperative": {
                    "description": "",
                    "label": "Renbetes association"
                },
                "savingsBank": {
                    "description": "",
                    "label": "Sparbank"
                },
                "specialPurposeAssociation": {
                    "description": "",
                    "label": "Förening grundad på särskild lagstiftning"
                },
                "stateEstablishment": {
                    "description": "",
                    "label": "Statligt företag"
                },
                "unknown": {
                    "description": "",
                    "label": "Okänd företagsform"
                }
            },
            "TaxcardKind": {
                "undefined": {
                    "label": ""
                },
                "noTaxCard": {
                    "label": ""
                },
                "defaultYearly": {
                    "label": ""
                },
                "replacement": {
                    "label": ""
                },
                "others": {
                    "label": ""
                },
                "historical": {
                    "label": ""
                }
            },
            "CarBenefitCode": {
                "limitedCarBenefit": {
                    "label": ""
                },
                "fullCarBenefit": {
                    "label": ""
                }
            },
            "AgeGroupCode": {
                "a": {
                    "label": ""
                },
                "b": {
                    "label": ""
                },
                "c": {
                    "label": ""
                },
                "u": {
                    "label": ""
                }
            },
            "AllowanceCode": {
                "mealAllowance": {
                    "label": ""
                },
                "partialDailyAllowance": {
                    "label": ""
                },
                "fullDailyAllowance": {
                    "label": ""
                },
                "internationalDailyAllowance": {
                    "label": ""
                },
                "expensesWorkingAbroad": {
                    "label": ""
                }
            },
            "BoardKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                }
            },
            "IrFlags": {
                "noMoney": {
                    "label": ""
                },
                "oneOff": {
                    "label": ""
                },
                "unjustEnrichment": {
                    "label": ""
                }
            },
            "CalculationFlag": {
                "exclude": {
                    "label": ""
                },
                "pensionInsurance": {
                    "label": ""
                },
                "accidentInsurance": {
                    "label": ""
                },
                "unemploymentInsurance": {
                    "label": ""
                },
                "healthInsurance": {
                    "label": ""
                },
                "noTax": {
                    "label": ""
                },
                "tax": {
                    "label": ""
                },
                "taxDeduction": {
                    "label": ""
                },
                "cfNoPayment": {
                    "label": ""
                },
                "cfPayment": {
                    "label": ""
                },
                "cfDeduction": {
                    "label": ""
                },
                "cfDeductionAtSalaxy": {
                    "label": ""
                }
            },
            "IrInsuranceExceptions": {
                "includeAll": {
                    "label": ""
                },
                "includePension": {
                    "label": ""
                },
                "includeHealthInsurance": {
                    "label": ""
                },
                "includeUnemployment": {
                    "label": ""
                },
                "includeAccidentInsurance": {
                    "label": ""
                },
                "excludeAll": {
                    "label": ""
                },
                "excludePension": {
                    "label": ""
                },
                "excludeHealthInsurance": {
                    "label": ""
                },
                "excludeUnemployment": {
                    "label": ""
                },
                "excludeAccidentInsurance": {
                    "label": ""
                }
            },
            "UnionPaymentKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "raksaNormal": {
                    "label": "",
                    "description": ""
                },
                "raksaUnemploymentOnly": {
                    "label": "",
                    "description": ""
                },
                "other": {
                    "label": "",
                    "description": ""
                }
            },
            "SubsidisedCommuteKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "noDeduction": {
                    "label": "",
                    "description": ""
                },
                "singleDeduction": {
                    "label": "",
                    "description": ""
                },
                "periodicalDeduction": {
                    "label": "",
                    "description": ""
                }
            },
            "NonProfitOrgKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "kilometreAllowance": {
                    "label": "",
                    "description": ""
                },
                "dailyAllowance": {
                    "label": "",
                    "description": ""
                },
                "accomodationAllowance": {
                    "label": "",
                    "description": ""
                }
            },
            "MealBenefitKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "cateringContract": {
                    "label": "",
                    "description": ""
                },
                "mealTicket": {
                    "label": "",
                    "description": ""
                },
                "taxableAmount": {
                    "label": "",
                    "description": ""
                },
                "mealAllowance": {
                    "label": "",
                    "description": ""
                },
                "institute": {
                    "label": "",
                    "description": ""
                },
                "teacher": {
                    "label": "",
                    "description": ""
                },
                "restaurantWorker": {
                    "label": "",
                    "description": ""
                }
            },
            "DailyAllowanceKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "fullDailyAllowance": {
                    "label": "",
                    "description": ""
                },
                "partialDailyAllowance": {
                    "label": "",
                    "description": ""
                },
                "internationalDailyAllowance": {
                    "label": "",
                    "description": ""
                },
                "mealAllowance": {
                    "label": "",
                    "description": ""
                }
            },
            "CarBenefitKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "limitedCarBenefit": {
                    "label": "",
                    "description": ""
                },
                "fullCarBenefit": {
                    "label": "",
                    "description": ""
                }
            },
            "EmploymentTerminationKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "noticePeriodCompensation": {
                    "label": "",
                    "description": ""
                },
                "monetaryWorkingTimeBankCompensation": {
                    "label": "",
                    "description": ""
                },
                "terminationAndLayOffDamages": {
                    "label": "",
                    "description": ""
                },
                "voluntaryTerminationCompensation": {
                    "label": "",
                    "description": ""
                },
                "pensionPaidByEmployer": {
                    "label": "",
                    "description": ""
                }
            },
            "IrIncomeTypeKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                }
            },
            "OtherCompensationKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "meetingFee": {
                    "label": "",
                    "description": ""
                },
                "lectureFee": {
                    "label": "",
                    "description": ""
                },
                "positionOfTrustCompensation": {
                    "label": "",
                    "description": ""
                },
                "accruedTimeOffCompensation": {
                    "label": "",
                    "description": ""
                },
                "membershipOfGoverningBodyCompensation": {
                    "label": "",
                    "description": ""
                },
                "monetaryGiftForEmployees": {
                    "label": "",
                    "description": ""
                },
                "useCompensationAsEarnedIncome": {
                    "label": "",
                    "description": ""
                },
                "useCompensationAsCapitalIncome": {
                    "label": "",
                    "description": ""
                },
                "otherTaxableIncomeAsEarnedIncome": {
                    "label": "",
                    "description": ""
                },
                "stockOptionsAndGrants": {
                    "label": "",
                    "description": ""
                },
                "employeeInventionCompensation": {
                    "label": "",
                    "description": ""
                },
                "capitalIncomePayment": {
                    "label": "",
                    "description": ""
                },
                "workEffortBasedDividendsAsWage": {
                    "label": "",
                    "description": ""
                },
                "workEffortBasedDividendsAsNonWage": {
                    "label": "",
                    "description": ""
                },
                "employeeStockOption": {
                    "label": "",
                    "description": ""
                },
                "employeeStockOptionWithLowerPrice": {
                    "label": "",
                    "description": ""
                }
            },
            "RemunerationKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "initiativeFee": {
                    "label": "",
                    "description": ""
                },
                "bonusPay": {
                    "label": "",
                    "description": ""
                },
                "commission": {
                    "label": "",
                    "description": ""
                },
                "performanceBonus": {
                    "label": "",
                    "description": ""
                },
                "shareIssueForEmployees": {
                    "label": "",
                    "description": ""
                },
                "profitSharingBonus": {
                    "label": "",
                    "description": ""
                }
            },
            "WorkingTimeCompensationKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "emergencyWorkCompensation": {
                    "label": "",
                    "description": ""
                },
                "eveningWorkCompensation": {
                    "label": "",
                    "description": ""
                },
                "eveningShiftAllowance": {
                    "label": "",
                    "description": ""
                },
                "saturdayPay": {
                    "label": "",
                    "description": ""
                },
                "extraWorkPremium": {
                    "label": "",
                    "description": ""
                },
                "otherCompensation": {
                    "label": "",
                    "description": ""
                },
                "waitingTimeCompensation": {
                    "label": "",
                    "description": ""
                },
                "sundayWorkCompensation": {
                    "label": "",
                    "description": ""
                },
                "standByCompensation": {
                    "label": "",
                    "description": ""
                },
                "weeklyRestCompensation": {
                    "label": "",
                    "description": ""
                },
                "overtimeCompensation": {
                    "label": "",
                    "description": ""
                },
                "nightWorkAllowance": {
                    "label": "",
                    "description": ""
                },
                "nightShiftCompensation": {
                    "label": "",
                    "description": ""
                }
            },
            "HolidayYearInitType": {
                "ignore": {
                    "label": ""
                },
                "createEmpty": {
                    "label": ""
                },
                "createMonths": {
                    "label": ""
                },
                "createFromCalcs": {
                    "label": ""
                }
            },
            "HolidayCode": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "permanent14Days": {
                    "label": "",
                    "description": ""
                },
                "permanent35Hours": {
                    "label": "",
                    "description": ""
                },
                "temporaryTimeOff": {
                    "label": "",
                    "description": ""
                },
                "holidayCompensation": {
                    "label": "",
                    "description": ""
                },
                "holidayCompensationIncluded": {
                    "label": "",
                    "description": ""
                },
                "noHolidays": {
                    "label": "",
                    "description": ""
                }
            },
            "HolidayAccrualKind": {
                "manual": {
                    "label": ""
                },
                "saldo": {
                    "label": ""
                },
                "calculation": {
                    "label": ""
                },
                "holiday": {
                    "label": ""
                },
                "holidayCompensated": {
                    "label": ""
                }
            },
            "AbsenceCauseCode": {
                "unpaidLeave": {
                    "label": ""
                },
                "personalReason": {
                    "label": ""
                },
                "illness": {
                    "label": "Sjukdom"
                },
                "partTimeSickLeave": {
                    "label": "Partiell sjukfrånvaro"
                },
                "parentalLeave": {
                    "label": "Moderskaps-, faderskaps- och föräldraledighet"
                },
                "specialMaternityLeave": {
                    "label": "Särskild moderskapsledighet"
                },
                "rehabilitation": {
                    "label": "Rehabilitering"
                },
                "childIllness": {
                    "label": "Sjukt barn eller tvingande familjeskäl"
                },
                "partTimeChildCareLeave": {
                    "label": "Partiell vårdledighet"
                },
                "training": {
                    "label": "Utbildning"
                },
                "jobAlternationLeave": {
                    "label": "Alterneringsledighet"
                },
                "studyLeave": {
                    "label": "Studieledighet"
                },
                "industrialAction": {
                    "label": "Strejk eller lockout"
                },
                "interruptionInWorkProvision": {
                    "label": "Avbrott i utbud av arbete"
                },
                "leaveOfAbsence": {
                    "label": "Tjänstledighet"
                },
                "militaryRefresherTraining": {
                    "label": "Repetitionsövning"
                },
                "militaryService": {
                    "label": "Militär- eller civiltjänst"
                },
                "layOff": {
                    "label": "Permittering"
                },
                "childCareLeave": {
                    "label": "Vårdledighet"
                },
                "midWeekHoliday": {
                    "label": "Söckenhelg"
                },
                "accruedHoliday": {
                    "label": "Pekkasledighet"
                },
                "occupationalAccident": {
                    "label": "Arbetsolycka"
                },
                "annualLeave": {
                    "label": "Semester"
                },
                "partTimeAbsenceDueToRehabilitation": {
                    "label": "Partiell frånvaro på grund av rehabilitering"
                },
                "other": {
                    "label": "Annan orsak"
                }
            },
            "AnnualLeavePaymentKind": {
                "undefined": {
                    "label": "",
                    "description": ""
                },
                "manualSalary": {
                    "label": "",
                    "description": ""
                },
                "manualCompensation": {
                    "label": "",
                    "description": ""
                },
                "manualBonus": {
                    "label": "",
                    "description": ""
                },
                "paidCalc": {
                    "label": "",
                    "description": ""
                },
                "draftCalc": {
                    "label": "",
                    "description": ""
                },
                "info": {
                    "label": "",
                    "description": ""
                },
                "startSaldo": {
                    "label": "",
                    "description": ""
                },
                "endSaldo": {
                    "label": "",
                    "description": ""
                },
                "total": {
                    "label": "",
                    "description": ""
                }
            },
            "HolidayBonusPaymentMethod": {
                "none": {
                    "label": ""
                },
                "payForHolidaySalary": {
                    "label": ""
                },
                "paySummerBonus": {
                    "label": ""
                },
                "pay24Days": {
                    "label": ""
                },
                "payAllBonus": {
                    "label": ""
                }
            },
            "PeriodType": {
                "month": {
                    "label": ""
                },
                "quarter": {
                    "label": ""
                },
                "year": {
                    "label": ""
                },
                "custom": {
                    "label": ""
                }
            },
            "PricingModel": {
                "palkkausFee": {
                    "label": ""
                },
                "noFee": {
                    "label": ""
                },
                "fixedFee": {
                    "label": ""
                }
            },
            "ServiceModel": {
                "shared": {
                    "label": ""
                },
                "partnerOnly": {
                    "label": ""
                }
            },
            "WageBasis": {
                "undefined": {
                    "label": ""
                },
                "monthly": {
                    "label": ""
                },
                "hourly": {
                    "label": ""
                },
                "performanceBased": {
                    "label": ""
                },
                "other": {
                    "label": ""
                }
            }
        },
        "UI_TERMS": {
            "add": "Lägg till",
            "addNew": "",
            "addRow": "Lägg till rad",
            "areYouSure": "",
            "back": "Tillbaka",
            "calculate": "Beräkna",
            "calculations": "Beräkningar",
            "cancel": "Avbryt",
            "cancelEditing": "",
            "choose": "Välj…",
            "orChoose": "",
            "chooseWorkDateRange": "",
            "chooseWorkDuration": "",
            "clear": "Avmarkera",
            "close": "Stäng",
            "confirm": "",
            "copy": "",
            "copyToClipboard": "",
            "copyAsNew": "Kopiera som ny",
            "copyAsRequest": "",
            "dateNotChosen": "",
            "delete": "Ta bort",
            "demo": "",
            "dismiss": "Avslå",
            "done": "Färdig",
            "edit": "Ändra",
            "gotIt": "Jag förstår",
            "isDeleting": "",
            "isSaving": "",
            "learnMore": "Läs mer",
            "login": "Logga in",
            "logout": "Logga ut",
            "logoutAlt": "",
            "minCharacters": "Skriv minst 3 tecken…",
            "moreInfo": "Tilläggsuppgifter",
            "navigation": "Navigering",
            "newCalculation": "Ny beräkning",
            "previous": "",
            "next": "Nästa",
            "no": "",
            "noteRequiredField": "",
            "noThanks": "Nej tack",
            "ok": "OK",
            "oldVersion": "",
            "pay": "Betala",
            "pleaseWait": "",
            "postpone": "Inte nu",
            "printable": "Utskrift",
            "recalculate": "Uppdatera uträkning",
            "register": "Registrera dig",
            "save": "Spara",
            "saveEdited": "Spara ändringarna",
            "makeOrder": "",
            "search": "",
            "searchByName": "",
            "select": "Välj",
            "selectAlt": "Välj...",
            "sendEmail": "Skicka e-postmeddelande",
            "show": "Visa",
            "skip": "Hoppa över",
            "sureToDeleteRecord": "",
            "today": "I dag",
            "updateCalculation": "",
            "updatingCalculation": "",
            "use": "Ta i bruk",
            "yes": "Ja",
            "dateFormats": {
                "dm": ""
            },
            "loading": "",
            "monthShort0": "",
            "monthShort1": "",
            "monthShort2": "",
            "monthShort3": "",
            "monthShort4": "",
            "monthShort5": "",
            "monthShort6": "",
            "monthShort7": "",
            "monthShort8": "",
            "monthShort9": "",
            "monthShort10": "",
            "monthShort11": "",
            "monthShort12": "",
            "week2": "",
            "monthHalf": "",
            "otherPeriod": ""
        },
        "VALIDATION": {
            "IncompleteAdvancePayment": {
                "label": "",
                "description": ""
            },
            "IncompletePensionPayment": {
                "label": "",
                "description": ""
            },
            "IncompleteUnemploymentInsurancePayment": {
                "label": "",
                "description": ""
            },
            "IncompleteUnionPayment": {
                "label": "",
                "description": ""
            },
            "IncompleteOtherDeductions": {
                "label": "",
                "description": ""
            },
            "IncompletePrepaidExpenses": {
                "label": "",
                "description": ""
            },
            "MissingOccupationCode": {
                "label": "",
                "description": ""
            },
            "IllegalWorkerForCompanyType": {
                "label": "",
                "description": ""
            },
            "NegativeRowTotalNotSupported": {
                "label": "",
                "description": ""
            },
            "ValidationErrors": {
                "sxyEmail": "",
                "sxyMobilePhone": "",
                "minlength": "",
                "maxlength": "",
                "sxyIban": "",
                "sxyTaxPercent": "",
                "sxyCurrency": "",
                "sxyPersonalIdFi": "",
                "sxyCompanyIdFi": "",
                "sxyPostalCodeFi": "",
                "sxySmsVerificationCode": "",
                "sxyNumber": "",
                "sxyInteger": "",
                "sxyPensionContractNumber": "",
                "sxyTemporaryPensionContractNumber": "",
                "required": ""
            },
            "Payroll": {
                "NoCalculations": {
                    "label": ""
                },
                "Calc": {
                    "TotalGreaterThan0": {
                        "label": ""
                    },
                    "FirstNameNotEmpty": {
                        "label": ""
                    },
                    "LastNameNotEmpty": {
                        "label": ""
                    },
                    "SocialSecurityNumber": {
                        "label": ""
                    },
                    "SocialSecurityNumber_InTest": {
                        "label": ""
                    },
                    "IbanNotEmpty": {
                        "label": ""
                    },
                    "IbanInvalid": {
                        "label": ""
                    },
                    "EmailAddress": {
                        "label": ""
                    },
                    "TelephoneOrEmailNotEmpty": {
                        "label": ""
                    },
                    "TaxCardType": {
                        "label": ""
                    },
                    "TaxPercent": {
                        "label": ""
                    },
                    "PayrollIdConflict": {
                        "label": ""
                    },
                    "InvalidStatusForPayroll": {
                        "label": ""
                    }
                }
            },
            "Files": {
                "MaxFileSize": "",
                "Empty": "",
                "NoFiles": "",
                "SaveError": "",
                "ContentTypeError": ""
            }
        }
    },
    "": [
        "",
        "",
        "",
        "",
        "",
        ""
    ]
};
/** Internationalization dictionary
@hidden */
exports.dictionary = _dictionary;

},{}],44:[function(require,module,exports){
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
__export(require("./dictionary"));

},{"./dictionary":43}],45:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/* tslint:disable */
/** @hidden */
exports.occupationsData = [{ "id": "01100", "code": "01100", "labelFi": "Upseerit", "labelEn": "Commissioned armed forces officers", "labelSv": "Officerare", "searchFi": "01100 upseerit", "searchEn": "01100 commissioned armed forces officers", "searchSv": "01100 officerare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "02100", "code": "02100", "labelFi": "Aliupseerit", "labelEn": "Non-commissioned armed forces officers", "labelSv": "Underofficerare", "searchFi": "02100 aliupseerit", "searchEn": "02100 non-commissioned armed forces officers", "searchSv": "02100 underofficerare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "03100", "code": "03100", "labelFi": "Sotilasammattihenkilöstö", "labelEn": "Armed forces occupations, other ranks", "labelSv": "Yrkesutbildad personal inom militären", "searchFi": "03100 sotilasammattihenkilöstö", "searchEn": "03100 armed forces occupations, other ranks", "searchSv": "03100 yrkesutbildad personal inom militären", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "11110", "code": "11110", "labelFi": "Lainsäätäjät", "labelEn": "Legislators", "labelSv": "Lagstiftare", "searchFi": "11110 lainsäätäjät", "searchEn": "11110 legislators", "searchSv": "11110 lagstiftare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "11121", "code": "11121", "labelFi": "Valtion keskushallinnon johtajat", "labelEn": "Senior central government officials", "labelSv": "Direktörer inom statens centralförvaltning", "searchFi": "11121 valtion keskushallinnon johtajat", "searchEn": "11121 senior central government officials", "searchSv": "11121 direktörer inom statens centralförvaltning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "11122", "code": "11122", "labelFi": "Alue- ja paikallishallinnon johtajat ja ylimmät virkamiehet", "labelEn": "Senior district and local government officials and senior officials", "labelSv": "Direktörer och högre tjänstemän inom statlig distrikts- och lokalförvaltning", "searchFi": "11122 alue- ja paikallishallinnon johtajat ja ylimmät virkamiehet", "searchEn": "11122 senior district and local government officials and senior officials", "searchSv": "11122 direktörer och högre tjänstemän inom statlig distrikts- och lokalförvaltning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "11141", "code": "11141", "labelFi": "Työmarkkina- ja elinkeinoelämän järjestöjen johtajat", "labelEn": "Senior officials of employers', workers' and other economic-interest organisations", "labelSv": "Chefer i arbetsmarknads- och näringslivsorganisationer", "searchFi": "11141 työmarkkina- ja elinkeinoelämän järjestöjen johtajat", "searchEn": "11141 senior officials of employers', workers' and other economic-interest organisations", "searchSv": "11141 chefer i arbetsmarknads- och näringslivsorganisationer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "11142", "code": "11142", "labelFi": "Muiden järjestöjen johtajat", "labelEn": "Senior officials of humanitarian and other special-interest organisations", "labelSv": "Chefer i andra organisationer", "searchFi": "11142 muiden järjestöjen johtajat", "searchEn": "11142 senior officials of humanitarian and other special-interest organisations", "searchSv": "11142 chefer i andra organisationer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "11200", "code": "11200", "labelFi": "Toimitusjohtajat ja pääjohtajat", "labelEn": "Managing directors and chief executives", "labelSv": "Verkställande direktörer och verkschefer", "searchFi": "11200 toimitusjohtajat ja pääjohtajat tj ceo", "searchEn": "11200 managing directors and chief executives", "searchSv": "11200 verkställande direktörer och verkschefer", "freeTextFi": "tj ceo", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "11200-bm", "code": "11200", "labelFi": "Hallituksen jäsen", "labelEn": "Board member", "labelSv": "Styrelsemedlem", "searchFi": "11200 hallituksen jäsen", "searchEn": "11200 board member", "searchSv": "11200 styrelsemedlem", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "12110", "code": "12110", "labelFi": "Talousjohtajat", "labelEn": "Finance managers", "labelSv": "Ekonomichefer", "searchFi": "12110 talousjohtajat", "searchEn": "12110 finance managers", "searchSv": "12110 ekonomichefer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "12120", "code": "12120", "labelFi": "Henkilöstöjohtajat", "labelEn": "Human resource managers", "labelSv": "Personalchefer", "searchFi": "12120 henkilöstöjohtajat", "searchEn": "12120 human resource managers", "searchSv": "12120 personalchefer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "12130", "code": "12130", "labelFi": "Politiikka- ja suunnittelujohtajat", "labelEn": "Policy and planning managers", "labelSv": "Politik- och planeringschefer", "searchFi": "12130 politiikka- ja suunnittelujohtajat", "searchEn": "12130 policy and planning managers", "searchSv": "12130 politik- och planeringschefer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "12190", "code": "12190", "labelFi": "Muut hallintojohtajat ja kaupalliset johtajat", "labelEn": "Business services and administration managers not elsewhere classified", "labelSv": "Övriga chefer inom företagstjänster och administration", "searchFi": "12190 muut hallintojohtajat ja kaupalliset johtajat", "searchEn": "12190 business services and administration managers not elsewhere classified", "searchSv": "12190 övriga chefer inom företagstjänster och administration", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "12210", "code": "12210", "labelFi": "Myynti- ja markkinointijohtajat", "labelEn": "Sales and marketing managers", "labelSv": "Försäljnings- och marknadsföringschefer", "searchFi": "12210 myynti- ja markkinointijohtajat sales", "searchEn": "12210 sales and marketing managers", "searchSv": "12210 försäljnings- och marknadsföringschefer", "freeTextFi": "sales", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "12220", "code": "12220", "labelFi": "Mainos- ja tiedotusjohtajat", "labelEn": "Advertising and public relations managers", "labelSv": "Reklam- och kommunikationschefer, PR-chefer", "searchFi": "12220 mainos- ja tiedotusjohtajat", "searchEn": "12220 advertising and public relations managers", "searchSv": "12220 reklam- och kommunikationschefer, pr-chefer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "12230", "code": "12230", "labelFi": "Tutkimus- ja kehitysjohtajat", "labelEn": "Research and development managers", "labelSv": "Forsknings- och utvecklingschefer", "searchFi": "12230 tutkimus- ja kehitysjohtajat", "searchEn": "12230 research and development managers", "searchSv": "12230 forsknings- och utvecklingschefer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "13110", "code": "13110", "labelFi": "Maa- ja metsätalouden johtajat", "labelEn": "Agricultural and forestry production managers", "labelSv": "Chefer inom jord- och skogsbruk", "searchFi": "13110 maa- ja metsätalouden johtajat", "searchEn": "13110 agricultural and forestry production managers", "searchSv": "13110 chefer inom jord- och skogsbruk", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "13120", "code": "13120", "labelFi": "Vesiviljely- ja kalatalouden johtajat", "labelEn": "Aquaculture and fisheries production managers", "labelSv": "Chefer inom vattenbruk och fiske", "searchFi": "13120 vesiviljely- ja kalatalouden johtajat", "searchEn": "13120 aquaculture and fisheries production managers", "searchSv": "13120 chefer inom vattenbruk och fiske", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "13210", "code": "13210", "labelFi": "Teollisuuden tuotantojohtajat", "labelEn": "Manufacturing managers", "labelSv": "Produktionschefer inom industri", "searchFi": "13210 teollisuuden tuotantojohtajat", "searchEn": "13210 manufacturing managers", "searchSv": "13210 produktionschefer inom industri", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "13220", "code": "13220", "labelFi": "Kaivostoiminnan tuotantojohtajat", "labelEn": "Mining managers", "labelSv": "Produktionschefer inom gruvdrift", "searchFi": "13220 kaivostoiminnan tuotantojohtajat", "searchEn": "13220 mining managers", "searchSv": "13220 produktionschefer inom gruvdrift", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "13230", "code": "13230", "labelFi": "Rakennustoiminnan tuotantojohtajat", "labelEn": "Construction managers", "labelSv": "Produktionschefer inom byggverksamhet", "searchFi": "13230 rakennustoiminnan tuotantojohtajat", "searchEn": "13230 construction managers", "searchSv": "13230 produktionschefer inom byggverksamhet", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "13240", "code": "13240", "labelFi": "Hankinta- ja jakelujohtajat", "labelEn": "Supply, distribution and related managers", "labelSv": "Inköps- och distributionschefer m.fl.", "searchFi": "13240 hankinta- ja jakelujohtajat", "searchEn": "13240 supply, distribution and related managers", "searchSv": "13240 inköps- och distributionschefer m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "13300", "code": "13300", "labelFi": "Tieto- ja viestintäteknologiajohtajat", "labelEn": "Information and communications technology service managers", "labelSv": "Chefer inom informations- och kommunikationsteknik (IKT)", "searchFi": "13300 tieto- ja viestintäteknologiajohtajat", "searchEn": "13300 information and communications technology service managers", "searchSv": "13300 chefer inom informations- och kommunikationsteknik (ikt)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "13410", "code": "13410", "labelFi": "Lastenhoidon johtajat", "labelEn": "Child care services managers", "labelSv": "Chefer inom barnomsorg", "searchFi": "13410 lastenhoidon johtajat", "searchEn": "13410 child care services managers", "searchSv": "13410 chefer inom barnomsorg", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "13420", "code": "13420", "labelFi": "Terveydenhuollon johtajat", "labelEn": "Health services managers", "labelSv": "Chefer inom hälso- och sjukvård", "searchFi": "13420 terveydenhuollon johtajat", "searchEn": "13420 health services managers", "searchSv": "13420 chefer inom hälso- och sjukvård", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "13430", "code": "13430", "labelFi": "Vanhustenhuollon johtajat", "labelEn": "Aged care services managers", "labelSv": "Chefer inom äldrevård", "searchFi": "13430 vanhustenhuollon johtajat", "searchEn": "13430 aged care services managers", "searchSv": "13430 chefer inom äldrevård", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "13440", "code": "13440", "labelFi": "Sosiaalihuollon johtajat", "labelEn": "Social welfare managers", "labelSv": "Chefer inom socialvård", "searchFi": "13440 sosiaalihuollon johtajat", "searchEn": "13440 social welfare managers", "searchSv": "13440 chefer inom socialvård", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "13450", "code": "13450", "labelFi": "Opetusalan johtajat", "labelEn": "Education managers", "labelSv": "Chefer inom utbildning", "searchFi": "13450 opetusalan johtajat", "searchEn": "13450 education managers", "searchSv": "13450 chefer inom utbildning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "13460", "code": "13460", "labelFi": "Rahoitus- ja vakuutuspalvelujen johtajat", "labelEn": "Financial and insurance services branch managers", "labelSv": "Chefer inom bank- och försäkringstjänster", "searchFi": "13460 rahoitus- ja vakuutuspalvelujen johtajat", "searchEn": "13460 financial and insurance services branch managers", "searchSv": "13460 chefer inom bank- och försäkringstjänster", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "13490", "code": "13490", "labelFi": "Muut yhteiskunnan palvelujen johtajat", "labelEn": "Professional services managers not elsewhere classified", "labelSv": "Övriga chefer inom samhälleliga tjänster", "searchFi": "13490 muut yhteiskunnan palvelujen johtajat", "searchEn": "13490 professional services managers not elsewhere classified", "searchSv": "13490 övriga chefer inom samhälleliga tjänster", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "14110", "code": "14110", "labelFi": "Hotellinjohtajat", "labelEn": "Hotel managers", "labelSv": "Hotellchefer", "searchFi": "14110 hotellinjohtajat", "searchEn": "14110 hotel managers", "searchSv": "14110 hotellchefer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "14120", "code": "14120", "labelFi": "Ravintolanjohtajat", "labelEn": "Restaurant managers", "labelSv": "Restaurangchefer", "searchFi": "14120 ravintolanjohtajat", "searchEn": "14120 restaurant managers", "searchSv": "14120 restaurangchefer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "14200", "code": "14200", "labelFi": "Vähittäis- ja tukkukaupan johtajat", "labelEn": "Retail and wholesale trade managers", "labelSv": "Chefer inom detalj- och partihandel", "searchFi": "14200 vähittäis- ja tukkukaupan johtajat", "searchEn": "14200 retail and wholesale trade managers", "searchSv": "14200 chefer inom detalj- och partihandel", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "14310", "code": "14310", "labelFi": "Urheilu-, vapaa-aika- ja kulttuurikeskusten johtajat", "labelEn": "Sports, recreation and cultural centre managers", "labelSv": "Chefer för sport-, fritids- och kulturcenter", "searchFi": "14310 urheilu-, vapaa-aika- ja kulttuurikeskusten johtajat", "searchEn": "14310 sports, recreation and cultural centre managers", "searchSv": "14310 chefer för sport-, fritids- och kulturcenter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "14390", "code": "14390", "labelFi": "Muut palvelualojen johtajat", "labelEn": "", "labelSv": "Övriga chefer inom servicenäringar", "searchFi": "14390 muut palvelualojen johtajat", "searchEn": "14390", "searchSv": "14390 övriga chefer inom servicenäringar", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21110", "code": "21110", "labelFi": "Fyysikot ja astronomit", "labelEn": "Physicists and astronomers", "labelSv": "Fysiker och astronomer", "searchFi": "21110 fyysikot ja astronomit", "searchEn": "21110 physicists and astronomers", "searchSv": "21110 fysiker och astronomer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21120", "code": "21120", "labelFi": "Meteorologit", "labelEn": "Meteorologists", "labelSv": "Meteorologer", "searchFi": "21120 meteorologit", "searchEn": "21120 meteorologists", "searchSv": "21120 meteorologer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21130", "code": "21130", "labelFi": "Kemistit", "labelEn": "Chemists", "labelSv": "Kemister", "searchFi": "21130 kemistit", "searchEn": "21130 chemists", "searchSv": "21130 kemister", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21140", "code": "21140", "labelFi": "Geologit ja geofyysikot", "labelEn": "Geologists and geophysicists", "labelSv": "Geologer och geofysiker", "searchFi": "21140 geologit ja geofyysikot", "searchEn": "21140 geologists and geophysicists", "searchSv": "21140 geologer och geofysiker", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21200", "code": "21200", "labelFi": "Matemaatikot, aktuaarit ja tilastotieteilijät", "labelEn": "Mathematicians, actuaries and statisticians", "labelSv": "Matematiker, aktuarier och statistiker", "searchFi": "21200 matemaatikot, aktuaarit ja tilastotieteilijät", "searchEn": "21200 mathematicians, actuaries and statisticians", "searchSv": "21200 matematiker, aktuarier och statistiker", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21310", "code": "21310", "labelFi": "Biologit, kasvi- ja eläintieteilijät ym. erityisasiantuntijat", "labelEn": "Biologists, botanists, zoologists and related professionals", "labelSv": "Biologer, botanister, zoologer m.fl.", "searchFi": "21310 biologit, kasvi- ja eläintieteilijät ym. erityisasiantuntijat", "searchEn": "21310 biologists, botanists, zoologists and related professionals", "searchSv": "21310 biologer, botanister, zoologer m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21321", "code": "21321", "labelFi": "Maa- ja kalatalouden erityisasiantuntijat", "labelEn": "Agronomists and fishery professionals", "labelSv": "Specialister inom jordbruk och fiske", "searchFi": "21321 maa- ja kalatalouden erityisasiantuntijat", "searchEn": "21321 agronomists and fishery professionals", "searchSv": "21321 specialister inom jordbruk och fiske", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21322", "code": "21322", "labelFi": "Metsätalouden erityisasiantuntijat", "labelEn": "Forestry professionals", "labelSv": "Specialister inom skogsbruk", "searchFi": "21322 metsätalouden erityisasiantuntijat", "searchEn": "21322 forestry professionals", "searchSv": "21322 specialister inom skogsbruk", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21330", "code": "21330", "labelFi": "Ympäristön- ja luonnonsuojelun erityisasiantuntijat", "labelEn": "Environmental protection professionals", "labelSv": "Specialister inom miljö- och naturskydd", "searchFi": "21330 ympäristön- ja luonnonsuojelun erityisasiantuntijat", "searchEn": "21330 environmental protection professionals", "searchSv": "21330 specialister inom miljö- och naturskydd", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21410", "code": "21410", "labelFi": "Teollisen valmistuksen ja tuotantotekniikan erityisasiantuntijat", "labelEn": "Industrial and production engineers", "labelSv": "Specialister inom industriell produktion och produktionsteknik", "searchFi": "21410 teollisen valmistuksen ja tuotantotekniikan erityisasiantuntijat", "searchEn": "21410 industrial and production engineers", "searchSv": "21410 specialister inom industriell produktion och produktionsteknik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21420", "code": "21420", "labelFi": "Maa- ja vesirakentamisen erityisasiantuntijat", "labelEn": "Civil engineers", "labelSv": "Specialister inom anläggningsarbeten", "searchFi": "21420 maa- ja vesirakentamisen erityisasiantuntijat", "searchEn": "21420 civil engineers", "searchSv": "21420 specialister inom anläggningsarbeten", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21430", "code": "21430", "labelFi": "Ympäristötekniikan erityisasiantuntijat", "labelEn": "Environmental engineers", "labelSv": "Specialister inom miljöteknik", "searchFi": "21430 ympäristötekniikan erityisasiantuntijat", "searchEn": "21430 environmental engineers", "searchSv": "21430 specialister inom miljöteknik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21440", "code": "21440", "labelFi": "Konetekniikan erityisasiantuntijat", "labelEn": "Mechanical engineers", "labelSv": "Specialister inom maskinteknik", "searchFi": "21440 konetekniikan erityisasiantuntijat", "searchEn": "21440 mechanical engineers", "searchSv": "21440 specialister inom maskinteknik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21450", "code": "21450", "labelFi": "Puunjalostuksen ja kemian prosessitekniikan erityisasiantuntijat", "labelEn": "Chemical engineers", "labelSv": "Specialister inom träförädling och kemisk processteknik", "searchFi": "21450 puunjalostuksen ja kemian prosessitekniikan erityisasiantuntijat", "searchEn": "21450 chemical engineers", "searchSv": "21450 specialister inom träförädling och kemisk processteknik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21460", "code": "21460", "labelFi": "Kaivosteollisuuden, metallurgian ym. erityisasiantuntijat", "labelEn": "Mining engineers, metallurgists and related professionals", "labelSv": "Specialister inom gruvindustri, metallurgi m.fl.", "searchFi": "21460 kaivosteollisuuden, metallurgian ym. erityisasiantuntijat", "searchEn": "21460 mining engineers, metallurgists and related professionals", "searchSv": "21460 specialister inom gruvindustri, metallurgi m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21490", "code": "21490", "labelFi": "Muut tekniikan erityisasiantuntijat", "labelEn": "Engineering professionals not elsewhere classified", "labelSv": "Övriga specialister inom teknik", "searchFi": "21490 muut tekniikan erityisasiantuntijat", "searchEn": "21490 engineering professionals not elsewhere classified", "searchSv": "21490 övriga specialister inom teknik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21510", "code": "21510", "labelFi": "Sähkötekniikan erityisasiantuntijat", "labelEn": "Electrical engineers", "labelSv": "Specialister inom elteknik", "searchFi": "21510 sähkötekniikan erityisasiantuntijat", "searchEn": "21510 electrical engineers", "searchSv": "21510 specialister inom elteknik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21520", "code": "21520", "labelFi": "Elektroniikan erityisasiantuntijat", "labelEn": "Electronics engineers", "labelSv": "Specialister inom elektronik", "searchFi": "21520 elektroniikan erityisasiantuntijat", "searchEn": "21520 electronics engineers", "searchSv": "21520 specialister inom elektronik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21531", "code": "21531", "labelFi": "Tietoliikenneteknologian tutkijat", "labelEn": "Telecommunications researchers", "labelSv": "Forskare inom teleteknik", "searchFi": "21531 tietoliikenneteknologian tutkijat", "searchEn": "21531 telecommunications researchers", "searchSv": "21531 forskare inom teleteknik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21532", "code": "21532", "labelFi": "Tietotekniikka-alan tutkijat", "labelEn": "Information technology researchers", "labelSv": "Forskare inom informationsteknik", "searchFi": "21532 tietotekniikka-alan tutkijat", "searchEn": "21532 information technology researchers", "searchSv": "21532 forskare inom informationsteknik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21610", "code": "21610", "labelFi": "Talonrakennuksen arkkitehdit", "labelEn": "Building architects", "labelSv": "Arkitekter inom husbyggande", "searchFi": "21610 talonrakennuksen arkkitehdit", "searchEn": "21610 building architects", "searchSv": "21610 arkitekter inom husbyggande", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21620", "code": "21620", "labelFi": "Maisema-arkkitehdit", "labelEn": "Landscape architects", "labelSv": "Landskapsarkitekter", "searchFi": "21620 maisema-arkkitehdit", "searchEn": "21620 landscape architects", "searchSv": "21620 landskapsarkitekter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21630", "code": "21630", "labelFi": "Tuote- ja vaatesuunnittelijat", "labelEn": "Product and garment designers", "labelSv": "Produkt- och modedesigner", "searchFi": "21630 tuote- ja vaatesuunnittelijat", "searchEn": "21630 product and garment designers", "searchSv": "21630 produkt- och modedesigner", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21640", "code": "21640", "labelFi": "Yhdyskunta- ja liikennesuunnittelijat", "labelEn": "Town and traffic planners", "labelSv": "Samhälls- och trafikplanerare", "searchFi": "21640 yhdyskunta- ja liikennesuunnittelijat", "searchEn": "21640 town and traffic planners", "searchSv": "21640 samhälls- och trafikplanerare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21650", "code": "21650", "labelFi": "Kartoituksen ja maanmittauksen erityisasiantuntijat", "labelEn": "Cartographers and surveyors", "labelSv": "Specialister inom kartläggning och lantmäteri", "searchFi": "21650 kartoituksen ja maanmittauksen erityisasiantuntijat", "searchEn": "21650 cartographers and surveyors", "searchSv": "21650 specialister inom kartläggning och lantmäteri", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "21660", "code": "21660", "labelFi": "Graafiset ja multimediasuunnittelijat", "labelEn": "Graphic and multimedia designers", "labelSv": "Grafiska designer och multimediadesigner", "searchFi": "21660 graafiset ja multimediasuunnittelijat", "searchEn": "21660 graphic and multimedia designers", "searchSv": "21660 grafiska designer och multimediadesigner", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "22110", "code": "22110", "labelFi": "Yleislääkärit", "labelEn": "Generalist medical practitioners", "labelSv": "Allmänläkare", "searchFi": "22110 yleislääkärit", "searchEn": "22110 generalist medical practitioners", "searchSv": "22110 allmänläkare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "22121", "code": "22121", "labelFi": "Ylilääkärit", "labelEn": "Senior physicians", "labelSv": "Överläkare", "searchFi": "22121 ylilääkärit", "searchEn": "22121 senior physicians", "searchSv": "22121 överläkare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "22122", "code": "22122", "labelFi": "Erikoislääkärit", "labelEn": "Specialists", "labelSv": "Specialistläkare", "searchFi": "22122 erikoislääkärit", "searchEn": "22122 specialists", "searchSv": "22122 specialistläkare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "22211", "code": "22211", "labelFi": "Ylihoitajat", "labelEn": "Matrons", "labelSv": "Överskötare", "searchFi": "22211 ylihoitajat", "searchEn": "22211 matrons", "searchSv": "22211 överskötare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "22212", "code": "22212", "labelFi": "Osastonhoitajat", "labelEn": "Ward sisters", "labelSv": "Avdelningsskötare", "searchFi": "22212 osastonhoitajat", "searchEn": "22212 ward sisters", "searchSv": "22212 avdelningsskötare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "22500", "code": "22500", "labelFi": "Eläinlääkärit", "labelEn": "Veterinarians", "labelSv": "Veterinärer", "searchFi": "22500 eläinlääkärit", "searchEn": "22500 veterinarians", "searchSv": "22500 veterinärer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "22610", "code": "22610", "labelFi": "Hammaslääkärit", "labelEn": "Dentists", "labelSv": "Tandläkare", "searchFi": "22610 hammaslääkärit", "searchEn": "22610 dentists", "searchSv": "22610 tandläkare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "22620", "code": "22620", "labelFi": "Proviisorit", "labelEn": "Pharmacists", "labelSv": "Provisorer", "searchFi": "22620 proviisorit", "searchEn": "22620 pharmacists", "searchSv": "22620 provisorer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "22630", "code": "22630", "labelFi": "Ympäristöterveyden ja työsuojelun erityisasiantuntijat", "labelEn": "Environmental and occupational health and hygiene professionals", "labelSv": "Specialister inom miljöhälsa och arbetarskydd", "searchFi": "22630 ympäristöterveyden ja työsuojelun erityisasiantuntijat", "searchEn": "22630 environmental and occupational health and hygiene professionals", "searchSv": "22630 specialister inom miljöhälsa och arbetarskydd", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "22650", "code": "22650", "labelFi": "Ravitsemusalan erityisasiantuntijat", "labelEn": "Dieticians and nutritionists", "labelSv": "Specialister inom näringslära", "searchFi": "22650 ravitsemusalan erityisasiantuntijat", "searchEn": "22650 dieticians and nutritionists", "searchSv": "22650 specialister inom näringslära", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "22660", "code": "22660", "labelFi": "Kuulontutkijat ja puheterapeutit", "labelEn": "Audiologists and speech therapists", "labelSv": "Audiologer och logopeder", "searchFi": "22660 kuulontutkijat ja puheterapeutit", "searchEn": "22660 audiologists and speech therapists", "searchSv": "22660 audiologer och logopeder", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "22690", "code": "22690", "labelFi": "Muut muualla luokittelemattomat terveydenhuollon erityisasiantuntijat", "labelEn": "Health professionals not elsewhere classified", "labelSv": "Övriga specialister inom hälso- och sjukvården utan annan klassificering", "searchFi": "22690 muut muualla luokittelemattomat terveydenhuollon erityisasiantuntijat", "searchEn": "22690 health professionals not elsewhere classified", "searchSv": "22690 övriga specialister inom hälso- och sjukvården utan annan klassificering", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23101", "code": "23101", "labelFi": "Professorit", "labelEn": "Professors", "labelSv": "Professorer", "searchFi": "23101 professorit", "searchEn": "23101 professors", "searchSv": "23101 professorer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23102", "code": "23102", "labelFi": "Lehtorit ja yliassistentit (yliopisto)", "labelEn": "Lecturers and senior assistants (university)", "labelSv": "Lektorer och överassistenter (universitet)", "searchFi": "23102 lehtorit ja yliassistentit (yliopisto)", "searchEn": "23102 lecturers and senior assistants (university)", "searchSv": "23102 lektorer och överassistenter (universitet)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23103", "code": "23103", "labelFi": "Assistentit ja tuntiopettajat (yliopisto)", "labelEn": "Assistants and part-time lecturers (university)", "labelSv": "Assistenter och timlärare (universitet)", "searchFi": "23103 assistentit ja tuntiopettajat (yliopisto)", "searchEn": "23103 assistants and part-time lecturers (university)", "searchSv": "23103 assistenter och timlärare (universitet)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23104", "code": "23104", "labelFi": "Yliopettajat (AMK)", "labelEn": "Head teachers (polytechnics)", "labelSv": "Överlärare (yrkeshögskolor)", "searchFi": "23104 yliopettajat (amk)", "searchEn": "23104 head teachers (polytechnics)", "searchSv": "23104 överlärare (yrkeshögskolor)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23105", "code": "23105", "labelFi": "Lehtorit (AMK)", "labelEn": "Lecturers (polytechnics)", "labelSv": "Lektorer (yrkeshögskolor)", "searchFi": "23105 lehtorit (amk)", "searchEn": "23105 lecturers (polytechnics)", "searchSv": "23105 lektorer (yrkeshögskolor)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23106", "code": "23106", "labelFi": "Tuntiopettajat ym. (AMK)", "labelEn": "Part-time lecturers, etc. (polytechnics)", "labelSv": "Timlärare m.fl. (yrkeshögskolor)", "searchFi": "23106 tuntiopettajat ym. (amk)", "searchEn": "23106 part-time lecturers, etc. (polytechnics)", "searchSv": "23106 timlärare m.fl. (yrkeshögskolor)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23200", "code": "23200", "labelFi": "Ammatillisen koulutuksen opettajat", "labelEn": "Vocational education teachers", "labelSv": "Lärare i yrkesämnen", "searchFi": "23200 ammatillisen koulutuksen opettajat", "searchEn": "23200 vocational education teachers", "searchSv": "23200 lärare i yrkesämnen", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23301", "code": "23301", "labelFi": "Matemaattisten aineiden opettajat", "labelEn": "Teachers in mathematical subjects", "labelSv": "Lärare i matematiska ämnen", "searchFi": "23301 matemaattisten aineiden opettajat", "searchEn": "23301 teachers in mathematical subjects", "searchSv": "23301 lärare i matematiska ämnen", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23302", "code": "23302", "labelFi": "Äidinkielen ja kirjallisuuden opettajat", "labelEn": "Native language and literature teachers", "labelSv": "Lärare i modersmål och litteratur", "searchFi": "23302 äidinkielen ja kirjallisuuden opettajat", "searchEn": "23302 native language and literature teachers", "searchSv": "23302 lärare i modersmål och litteratur", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23303", "code": "23303", "labelFi": "Taito- ja taideaineiden opettajat", "labelEn": "Crafts and art teachers", "labelSv": "Lärare i konst- och färdighetsämnen", "searchFi": "23303 taito- ja taideaineiden opettajat", "searchEn": "23303 crafts and art teachers", "searchSv": "23303 lärare i konst- och färdighetsämnen", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23304", "code": "23304", "labelFi": "Muut peruskoulun yläluokkien ja lukion opettajat", "labelEn": "Other secondary education teaching professionals", "labelSv": "Övriga högstadie- och gymnasielärare", "searchFi": "23304 muut peruskoulun yläluokkien ja lukion opettajat", "searchEn": "23304 other secondary education teaching professionals", "searchSv": "23304 övriga högstadie- och gymnasielärare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23411", "code": "23411", "labelFi": "Luokanopettajat", "labelEn": "Primary education teaching professionals", "labelSv": "Klasslärare", "searchFi": "23411 luokanopettajat", "searchEn": "23411 primary education teaching professionals", "searchSv": "23411 klasslärare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23412", "code": "23412", "labelFi": "Aineenopettajat (peruskoulun alaluokat)", "labelEn": "Primary education teaching professionals", "labelSv": "Ämneslärare (lågstadiet)", "searchFi": "23412 aineenopettajat (peruskoulun alaluokat)", "searchEn": "23412 primary education teaching professionals", "searchSv": "23412 ämneslärare (lågstadiet)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23420", "code": "23420", "labelFi": "Lastentarhanopettajat", "labelEn": "Early childhood educators", "labelSv": "Barnträdgårdslärare", "searchFi": "23420 lastentarhanopettajat", "searchEn": "23420 early childhood educators", "searchSv": "23420 barnträdgårdslärare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23510", "code": "23510", "labelFi": "Opetusmenetelmien erityisasiantuntijat", "labelEn": "Education methods specialists", "labelSv": "Specialister i pedagogiska metoder", "searchFi": "23510 opetusmenetelmien erityisasiantuntijat", "searchEn": "23510 education methods specialists", "searchSv": "23510 specialister i pedagogiska metoder", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23520", "code": "23520", "labelFi": "Erityisopettajat", "labelEn": "Special needs teachers", "labelSv": "Speciallärare", "searchFi": "23520 erityisopettajat", "searchEn": "23520 special needs teachers", "searchSv": "23520 speciallärare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23530", "code": "23530", "labelFi": "Muut kieltenopettajat", "labelEn": "Other language teachers", "labelSv": "Övriga språklärare", "searchFi": "23530 muut kieltenopettajat", "searchEn": "23530 other language teachers", "searchSv": "23530 övriga språklärare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23540", "code": "23540", "labelFi": "Muut musiikin opettajat", "labelEn": "Other music teachers", "labelSv": "Övriga musiklärare", "searchFi": "23540 muut musiikin opettajat", "searchEn": "23540 other music teachers", "searchSv": "23540 övriga musiklärare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23550", "code": "23550", "labelFi": "Muut taideaineiden opettajat", "labelEn": "Other arts teachers", "labelSv": "Övriga lärare i konstnärliga ämnen", "searchFi": "23550 muut taideaineiden opettajat", "searchEn": "23550 other arts teachers", "searchSv": "23550 övriga lärare i konstnärliga ämnen", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23560", "code": "23560", "labelFi": "Muut tietotekniikan opettajat ja kouluttajat", "labelEn": "Information technology trainers", "labelSv": "Övriga lärare och utbildare inom informationsteknik", "searchFi": "23560 muut tietotekniikan opettajat ja kouluttajat", "searchEn": "23560 information technology trainers", "searchSv": "23560 övriga lärare och utbildare inom informationsteknik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23591", "code": "23591", "labelFi": "Opinto-ohjaajat", "labelEn": "Career counsellors", "labelSv": "Studiehandledare", "searchFi": "23591 opinto-ohjaajat", "searchEn": "23591 career counsellors", "searchSv": "23591 studiehandledare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "23592", "code": "23592", "labelFi": "Muut opetuksen erityisasiantuntijat", "labelEn": "Other teaching professionals", "labelSv": "Övriga specialister inom undervisning", "searchFi": "23592 muut opetuksen erityisasiantuntijat", "searchEn": "23592 other teaching professionals", "searchSv": "23592 övriga specialister inom undervisning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "24110", "code": "24110", "labelFi": "Laskentatoimen erityisasiantuntijat ja tilintarkastajat", "labelEn": "Accountants", "labelSv": "Specialister inom redovisning och revision", "searchFi": "24110 laskentatoimen erityisasiantuntijat ja tilintarkastajat", "searchEn": "24110 accountants", "searchSv": "24110 specialister inom redovisning och revision", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "24120", "code": "24120", "labelFi": "Rahoitus- ja sijoitusneuvojat", "labelEn": "Financial and investment advisers", "labelSv": "Finans- och investeringsrådgivare", "searchFi": "24120 rahoitus- ja sijoitusneuvojat", "searchEn": "24120 financial and investment advisers", "searchSv": "24120 finans- och investeringsrådgivare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "24130", "code": "24130", "labelFi": "Rahoitusanalyytikot", "labelEn": "Financial analysts", "labelSv": "Finansanalytiker", "searchFi": "24130 rahoitusanalyytikot", "searchEn": "24130 financial analysts", "searchSv": "24130 finansanalytiker", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "24210", "code": "24210", "labelFi": "Johtamisen ja organisaatioiden erityisasiantuntijat", "labelEn": "Management and organization analysts", "labelSv": "Specialister inom ledarskap och organisationer", "searchFi": "24210 johtamisen ja organisaatioiden erityisasiantuntijat", "searchEn": "24210 management and organization analysts", "searchSv": "24210 specialister inom ledarskap och organisationer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "24220", "code": "24220", "labelFi": "Hallinnon ja elinkeinojen kehittämisen erityisasiantuntijat", "labelEn": "Policy administration professionals", "labelSv": "Specialister inom utveckling av administration och näringar", "searchFi": "24220 hallinnon ja elinkeinojen kehittämisen erityisasiantuntijat", "searchEn": "24220 policy administration professionals", "searchSv": "24220 specialister inom utveckling av administration och näringar", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "24230", "code": "24230", "labelFi": "Henkilöstöhallinnon erityisasiantuntijat ja urasuunnittelijat", "labelEn": "Personnel and careers professionals", "labelSv": "Specialister inom personaladministration och karriärplanering", "searchFi": "24230 henkilöstöhallinnon erityisasiantuntijat ja urasuunnittelijat", "searchEn": "24230 personnel and careers professionals", "searchSv": "24230 specialister inom personaladministration och karriärplanering", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "24240", "code": "24240", "labelFi": "Henkilöstön kehittämisen erityisasiantuntijat ja kouluttajat", "labelEn": "Training and staff development professionals", "labelSv": "Specialister inom personalutveckling och utbildning", "searchFi": "24240 henkilöstön kehittämisen erityisasiantuntijat ja kouluttajat", "searchEn": "24240 training and staff development professionals", "searchSv": "24240 specialister inom personalutveckling och utbildning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "24310", "code": "24310", "labelFi": "Mainonnan ja markkinoinnin erityisasiantuntijat", "labelEn": "Advertising and marketing professionals", "labelSv": "Specialister inom reklam och marknadsföring", "searchFi": "24310 mainonnan ja markkinoinnin erityisasiantuntijat", "searchEn": "24310 advertising and marketing professionals", "searchSv": "24310 specialister inom reklam och marknadsföring", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "24320", "code": "24320", "labelFi": "Tiedottajat", "labelEn": "Public relations professionals", "labelSv": "Informatörer", "searchFi": "24320 tiedottajat", "searchEn": "24320 public relations professionals", "searchSv": "24320 informatörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "24330", "code": "24330", "labelFi": "Myynti-insinöörit ja lääke-esittelijät (pl. tieto- ja viestintätekniikka)", "labelEn": "Technical and medical sales professionals (excluding ICT)", "labelSv": "Försäljningsingenjörer och läkemedelsrepresentanter (utom IKT)", "searchFi": "24330 myynti-insinöörit ja lääke-esittelijät (pl. tieto- ja viestintätekniikka)", "searchEn": "24330 technical and medical sales professionals (excluding ict)", "searchSv": "24330 försäljningsingenjörer och läkemedelsrepresentanter (utom ikt)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "24340", "code": "24340", "labelFi": "Tieto- ja viestintätekniikan myynnin erityisasiantuntijat", "labelEn": "Information and communications technology sales professionals", "labelSv": "Specialister inom försäljning av informations- och kommunikationsteknik (IKT)", "searchFi": "24340 tieto- ja viestintätekniikan myynnin erityisasiantuntijat", "searchEn": "24340 information and communications technology sales professionals", "searchSv": "24340 specialister inom försäljning av informations- och kommunikationsteknik (ikt)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "25110", "code": "25110", "labelFi": "Sovellusarkkitehdit", "labelEn": "Systems analysts", "labelSv": "Specialister inom applikationsarkitektur", "searchFi": "25110 sovellusarkkitehdit", "searchEn": "25110 systems analysts", "searchSv": "25110 specialister inom applikationsarkitektur", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "25120", "code": "25120", "labelFi": "Sovellussuunnittelijat", "labelEn": "Software developers", "labelSv": "Applikationsplanerare", "searchFi": "25120 sovellussuunnittelijat ohjelmoija koodaaja", "searchEn": "25120 software developers", "searchSv": "25120 applikationsplanerare", "freeTextFi": "ohjelmoija koodaaja", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "25130", "code": "25130", "labelFi": "Web- ja multimediakehittäjät", "labelEn": "Web and multimedia developers", "labelSv": "Webb- och multimediautvecklare", "searchFi": "25130 web- ja multimediakehittäjät www html java php", "searchEn": "25130 web and multimedia developers", "searchSv": "25130 webb- och multimediautvecklare", "freeTextFi": "www html java php", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "25140", "code": "25140", "labelFi": "Sovellusohjelmoijat", "labelEn": "Applications programmers", "labelSv": "Applikationsprogrammerare", "searchFi": "25140 sovellusohjelmoijat", "searchEn": "25140 applications programmers", "searchSv": "25140 applikationsprogrammerare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "25190", "code": "25190", "labelFi": "Muut ohjelmisto- ja sovelluskehittäjät", "labelEn": "Software and applications developers and analysts not elsewhere classified", "labelSv": "Övriga program- och applikationsutvecklare", "searchFi": "25190 muut ohjelmisto- ja sovelluskehittäjät", "searchEn": "25190 software and applications developers and analysts not elsewhere classified", "searchSv": "25190 övriga program- och applikationsutvecklare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "25210", "code": "25210", "labelFi": "Tietokantasuunnittelijat ja -vastaavat", "labelEn": "Database designers and administrators", "labelSv": "Databasutvecklare och databasansvariga", "searchFi": "25210 tietokantasuunnittelijat ja -vastaavat", "searchEn": "25210 database designers and administrators", "searchSv": "25210 databasutvecklare och databasansvariga", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "25220", "code": "25220", "labelFi": "Tietojärjestelmien ylläpitäjät", "labelEn": "Systems administrators", "labelSv": "Systemadministratörer", "searchFi": "25220 tietojärjestelmien ylläpitäjät", "searchEn": "25220 systems administrators", "searchSv": "25220 systemadministratörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "25230", "code": "25230", "labelFi": "Tietoverkkojen erityisasiantuntijat", "labelEn": "Computer network professionals", "labelSv": "Nätverksspecialister", "searchFi": "25230 tietoverkkojen erityisasiantuntijat", "searchEn": "25230 computer network professionals", "searchSv": "25230 nätverksspecialister", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "25290", "code": "25290", "labelFi": "Muut tietokanta- ja tietoverkkojen erityisasiantuntijat", "labelEn": "Database and network professionals not elsewhere classified", "labelSv": "Övriga databas- och nätverksspecialister", "searchFi": "25290 muut tietokanta- ja tietoverkkojen erityisasiantuntijat", "searchEn": "25290 database and network professionals not elsewhere classified", "searchSv": "25290 övriga databas- och nätverksspecialister", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26110", "code": "26110", "labelFi": "Asianajajat", "labelEn": "Lawyers", "labelSv": "Advokater", "searchFi": "26110 asianajajat", "searchEn": "26110 lawyers", "searchSv": "26110 advokater", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26120", "code": "26120", "labelFi": "Tuomioistuinlakimiehet", "labelEn": "Judges", "labelSv": "Domare", "searchFi": "26120 tuomioistuinlakimiehet", "searchEn": "26120 judges", "searchSv": "26120 domare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26190", "code": "26190", "labelFi": "Muut lainopilliset erityisasiantuntijat", "labelEn": "Legal professionals not elsewhere classified", "labelSv": "Övriga specialister inom juridik", "searchFi": "26190 muut lainopilliset erityisasiantuntijat", "searchEn": "26190 legal professionals not elsewhere classified", "searchSv": "26190 övriga specialister inom juridik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26211", "code": "26211", "labelFi": "Arkistonhoitajat", "labelEn": "Archivists", "labelSv": "Arkivarier", "searchFi": "26211 arkistonhoitajat", "searchEn": "26211 archivists", "searchSv": "26211 arkivarier", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26212", "code": "26212", "labelFi": "Museoalan erityisasiantuntijat", "labelEn": "Curators", "labelSv": "Specialister inom museisektorn", "searchFi": "26212 museoalan erityisasiantuntijat", "searchEn": "26212 curators", "searchSv": "26212 specialister inom museisektorn", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26220", "code": "26220", "labelFi": "Kirjastonhoitajat, informaatikot ym.", "labelEn": "Librarians and related information professionals", "labelSv": "Bibliotekarier, informatiker m.fl.", "searchFi": "26220 kirjastonhoitajat, informaatikot ym.", "searchEn": "26220 librarians and related information professionals", "searchSv": "26220 bibliotekarier, informatiker m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26310", "code": "26310", "labelFi": "Ekonomistit", "labelEn": "Economists", "labelSv": "Nationalekonomer", "searchFi": "26310 ekonomistit", "searchEn": "26310 economists", "searchSv": "26310 nationalekonomer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26320", "code": "26320", "labelFi": "Yhteiskunta- ja kulttuuritutkijat", "labelEn": "Sociologists, anthropologists and related professionals", "labelSv": "Samhälls- och kulturforskare", "searchFi": "26320 yhteiskunta- ja kulttuuritutkijat", "searchEn": "26320 sociologists, anthropologists and related professionals", "searchSv": "26320 samhälls- och kulturforskare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26330", "code": "26330", "labelFi": "Historioitsijat, politiikan tutkijat ja filosofit", "labelEn": "Philosophers, historians and political scientists", "labelSv": "Historiker, statsvetare och filosofer", "searchFi": "26330 historioitsijat, politiikan tutkijat ja filosofit", "searchEn": "26330 philosophers, historians and political scientists", "searchSv": "26330 historiker, statsvetare och filosofer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26340", "code": "26340", "labelFi": "Psykologit", "labelEn": "Psychologists", "labelSv": "Psykologer", "searchFi": "26340 psykologit", "searchEn": "26340 psychologists", "searchSv": "26340 psykologer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26351", "code": "26351", "labelFi": "Sosiaalityöntekijät ym.", "labelEn": "Social workers, etc.", "labelSv": "Socialarbetare m.fl.", "searchFi": "26351 sosiaalityöntekijät ym.", "searchEn": "26351 social workers, etc.", "searchSv": "26351 socialarbetare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26352", "code": "26352", "labelFi": "Sosiaalialan suunnittelijat ym.", "labelEn": "Social planners, etc.", "labelSv": "Planerare inom socialsektorn m.fl.", "searchFi": "26352 sosiaalialan suunnittelijat ym.", "searchEn": "26352 social planners, etc.", "searchSv": "26352 planerare inom socialsektorn m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26360", "code": "26360", "labelFi": "Papit ym. uskonnollisen elämän erityisasiantuntijat", "labelEn": "Religious professionals", "labelSv": "Präster och övriga specialister inom religion", "searchFi": "26360 papit ym. uskonnollisen elämän erityisasiantuntijat", "searchEn": "26360 religious professionals", "searchSv": "26360 präster och övriga specialister inom religion", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26410", "code": "26410", "labelFi": "Kirjailijat ym.", "labelEn": "Authors and related writers", "labelSv": "Författare m.fl.", "searchFi": "26410 kirjailijat ym.", "searchEn": "26410 authors and related writers", "searchSv": "26410 författare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26421", "code": "26421", "labelFi": "Toimituspäälliköt ja -sihteerit, ohjelmapäälliköt", "labelEn": "Managing editors and subeditors", "labelSv": "Redaktionschefer och redaktionssekreterare, programchefer", "searchFi": "26421 toimituspäälliköt ja -sihteerit, ohjelmapäälliköt", "searchEn": "26421 managing editors and subeditors", "searchSv": "26421 redaktionschefer och redaktionssekreterare, programchefer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26422", "code": "26422", "labelFi": "Lehtien yms. toimittajat", "labelEn": "Journalists", "labelSv": "Redaktörer vid tidningar m.fl.", "searchFi": "26422 lehtien yms. toimittajat", "searchEn": "26422 journalists", "searchSv": "26422 redaktörer vid tidningar m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26423", "code": "26423", "labelFi": "Radio- ja tv-toimittajat", "labelEn": "Radio and television journalists", "labelSv": "Radio- och TV-redaktörer", "searchFi": "26423 radio- ja tv-toimittajat", "searchEn": "26423 radio and television journalists", "searchSv": "26423 radio- och tv-redaktörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26430", "code": "26430", "labelFi": "Kääntäjät, tulkit ja muut kielitieteilijät", "labelEn": "Translators, interpreters and other linguists", "labelSv": "Översättare, tolkar och andra språkvetare", "searchFi": "26430 kääntäjät, tulkit ja muut kielitieteilijät", "searchEn": "26430 translators, interpreters and other linguists", "searchSv": "26430 översättare, tolkar och andra språkvetare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26510", "code": "26510", "labelFi": "Kuvataiteilijat", "labelEn": "Visual artists", "labelSv": "Bildkonstnärer", "searchFi": "26510 kuvataiteilijat", "searchEn": "26510 visual artists", "searchSv": "26510 bildkonstnärer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26520", "code": "26520", "labelFi": "Muusikot, laulajat ja säveltäjät", "labelEn": "Musicians, singers and composers", "labelSv": "Musiker, sångare och kompositörer", "searchFi": "26520 muusikot, laulajat ja säveltäjät", "searchEn": "26520 musicians, singers and composers", "searchSv": "26520 musiker, sångare och kompositörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26530", "code": "26530", "labelFi": "Tanssitaiteilijat ja koreografit", "labelEn": "Dancers and choreographers", "labelSv": "Danskonstnärer och koreografer", "searchFi": "26530 tanssitaiteilijat ja koreografit", "searchEn": "26530 dancers and choreographers", "searchSv": "26530 danskonstnärer och koreografer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26540", "code": "26540", "labelFi": "Ohjaajat ja tuottajat", "labelEn": "Film, stage and related directors and producers", "labelSv": "Regissörer och producenter", "searchFi": "26540 ohjaajat ja tuottajat", "searchEn": "26540 film, stage and related directors and producers", "searchSv": "26540 regissörer och producenter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26550", "code": "26550", "labelFi": "Näyttelijät", "labelEn": "Actors", "labelSv": "Skådespelare", "searchFi": "26550 näyttelijät", "searchEn": "26550 actors", "searchSv": "26550 skådespelare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26560", "code": "26560", "labelFi": "Juontajat, kuuluttajat ym.", "labelEn": "Announcers on radio, television and other media", "labelSv": "Presentatörer, konferencierer m.fl.", "searchFi": "26560 juontajat, kuuluttajat ym.", "searchEn": "26560 announcers on radio, television and other media", "searchSv": "26560 presentatörer, konferencierer m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "26590", "code": "26590", "labelFi": "Muut taiteilijat", "labelEn": "Creative and performing artists not elsewhere classified", "labelSv": "Övriga konstnärer", "searchFi": "26590 muut taiteilijat", "searchEn": "26590 creative and performing artists not elsewhere classified", "searchSv": "26590 övriga konstnärer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31110", "code": "31110", "labelFi": "Luonnontieteen tekniset asiantuntijat", "labelEn": "Chemical and physical science technicians", "labelSv": "Tekniska experter inom naturvetenskap", "searchFi": "31110 luonnontieteen tekniset asiantuntijat", "searchEn": "31110 chemical and physical science technicians", "searchSv": "31110 tekniska experter inom naturvetenskap", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31121", "code": "31121", "labelFi": "Talonrakentamisen asiantuntijat", "labelEn": "Building construction technicians", "labelSv": "Experter inom husbyggnad", "searchFi": "31121 talonrakentamisen asiantuntijat", "searchEn": "31121 building construction technicians", "searchSv": "31121 experter inom husbyggnad", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31122", "code": "31122", "labelFi": "Maa- ja vesirakentamisen asiantuntijat", "labelEn": "Civil engineering technicians", "labelSv": "Experter inom anläggningsarbeten", "searchFi": "31122 maa- ja vesirakentamisen asiantuntijat", "searchEn": "31122 civil engineering technicians", "searchSv": "31122 experter inom anläggningsarbeten", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31123", "code": "31123", "labelFi": "Kartoituksen ja maanmittauksen asiantuntijat", "labelEn": "Cartographic and surveying technicians", "labelSv": "Experter inom kartläggning och lantmäteri", "searchFi": "31123 kartoituksen ja maanmittauksen asiantuntijat", "searchEn": "31123 cartographic and surveying technicians", "searchSv": "31123 experter inom kartläggning och lantmäteri", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31130", "code": "31130", "labelFi": "Sähkötekniikan asiantuntijat", "labelEn": "Electrical engineering technicians", "labelSv": "Experter inom elteknik", "searchFi": "31130 sähkötekniikan asiantuntijat", "searchEn": "31130 electrical engineering technicians", "searchSv": "31130 experter inom elteknik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31140", "code": "31140", "labelFi": "Elektroniikan asiantuntijat", "labelEn": "Electronics engineering technicians", "labelSv": "Experter inom elektronik", "searchFi": "31140 elektroniikan asiantuntijat", "searchEn": "31140 electronics engineering technicians", "searchSv": "31140 experter inom elektronik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31150", "code": "31150", "labelFi": "Konetekniikan asiantuntijat", "labelEn": "Mechanical engineering technicians", "labelSv": "Experter inom maskinteknik", "searchFi": "31150 konetekniikan asiantuntijat", "searchEn": "31150 mechanical engineering technicians", "searchSv": "31150 experter inom maskinteknik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31160", "code": "31160", "labelFi": "Kemian prosessitekniikan asiantuntijat", "labelEn": "Chemical engineering technicians", "labelSv": "Experter inom kemisk processteknik", "searchFi": "31160 kemian prosessitekniikan asiantuntijat", "searchEn": "31160 chemical engineering technicians", "searchSv": "31160 experter inom kemisk processteknik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31170", "code": "31170", "labelFi": "Kaivosteollisuuden ja metallurgian asiantuntijat", "labelEn": "Mining and metallurgical technicians", "labelSv": "Experter inom gruvindustri och metallurgi", "searchFi": "31170 kaivosteollisuuden ja metallurgian asiantuntijat", "searchEn": "31170 mining and metallurgical technicians", "searchSv": "31170 experter inom gruvindustri och metallurgi", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31180", "code": "31180", "labelFi": "Tekniset piirtäjät", "labelEn": "Draughtspersons", "labelSv": "Tekniska ritare", "searchFi": "31180 tekniset piirtäjät", "searchEn": "31180 draughtspersons", "searchSv": "31180 tekniska ritare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31190", "code": "31190", "labelFi": "Muut fysiikan, kemian ja teknisten alojen asiantuntijat", "labelEn": "Physical and engineering science technicians not elsewhere classified", "labelSv": "Övriga experter inom fysik, kemi och teknik", "searchFi": "31190 muut fysiikan, kemian ja teknisten alojen asiantuntijat", "searchEn": "31190 physical and engineering science technicians not elsewhere classified", "searchSv": "31190 övriga experter inom fysik, kemi och teknik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31210", "code": "31210", "labelFi": "Kaivostyönjohtajat", "labelEn": "Mining supervisors", "labelSv": "Arbetsledare inom gruvdrift", "searchFi": "31210 kaivostyönjohtajat", "searchEn": "31210 mining supervisors", "searchSv": "31210 arbetsledare inom gruvdrift", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31220", "code": "31220", "labelFi": "Teollisuuden työnjohtajat", "labelEn": "Manufacturing supervisors", "labelSv": "Arbetsledare inom industri", "searchFi": "31220 teollisuuden työnjohtajat", "searchEn": "31220 manufacturing supervisors", "searchSv": "31220 arbetsledare inom industri", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31230", "code": "31230", "labelFi": "Rakennusalan työnjohtajat", "labelEn": "Construction supervisors", "labelSv": "Arbetsledare inom byggverksamhet", "searchFi": "31230 rakennusalan työnjohtajat", "searchEn": "31230 construction supervisors", "searchSv": "31230 arbetsledare inom byggverksamhet", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31310", "code": "31310", "labelFi": "Voimalaitosten prosessinhoitajat", "labelEn": "Power production plant operators", "labelSv": "Processövervakare, kraftverk", "searchFi": "31310 voimalaitosten prosessinhoitajat", "searchEn": "31310 power production plant operators", "searchSv": "31310 processövervakare, kraftverk", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31320", "code": "31320", "labelFi": "Jätteenpoltto- ja vedenpuhdistuslaitosten prosessinhoitajat", "labelEn": "Incinerator and water treatment plant operators", "labelSv": "Processövervakare, förbränningsstationer och vattenreningsverk", "searchFi": "31320 jätteenpoltto- ja vedenpuhdistuslaitosten prosessinhoitajat", "searchEn": "31320 incinerator and water treatment plant operators", "searchSv": "31320 processövervakare, förbränningsstationer och vattenreningsverk", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31330", "code": "31330", "labelFi": "Kemianteollisuuden prosessinhoitajat", "labelEn": "Chemical processing plant controllers", "labelSv": "Processövervakare, kemisk industri", "searchFi": "31330 kemianteollisuuden prosessinhoitajat", "searchEn": "31330 chemical processing plant controllers", "searchSv": "31330 processövervakare, kemisk industri", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31340", "code": "31340", "labelFi": "Öljy- ja maakaasujalostamon prosessinhoitajat", "labelEn": "Petroleum and natural gas refining plant operators", "labelSv": "Processövervakare, raffinering av petroleum och naturgas", "searchFi": "31340 öljy- ja maakaasujalostamon prosessinhoitajat", "searchEn": "31340 petroleum and natural gas refining plant operators", "searchSv": "31340 processövervakare, raffinering av petroleum och naturgas", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31350", "code": "31350", "labelFi": "Metallien jalostuksen prosessinhoitajat", "labelEn": "Metal production process controllers", "labelSv": "Processövervakare, metallframställning", "searchFi": "31350 metallien jalostuksen prosessinhoitajat", "searchEn": "31350 metal production process controllers", "searchSv": "31350 processövervakare, metallframställning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31390", "code": "31390", "labelFi": "Muut prosessinvalvonnan asiantuntijat", "labelEn": "Process control technicians not elsewhere classified", "labelSv": "Övriga experter inom processövervakning", "searchFi": "31390 muut prosessinvalvonnan asiantuntijat", "searchEn": "31390 process control technicians not elsewhere classified", "searchSv": "31390 övriga experter inom processövervakning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31410", "code": "31410", "labelFi": "Laborantit ym.", "labelEn": "Life science technicians (excluding medical)", "labelSv": "Laboranter m.fl.", "searchFi": "31410 laborantit ym.", "searchEn": "31410 life science technicians (excluding medical)", "searchSv": "31410 laboranter m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31420", "code": "31420", "labelFi": "Maa- ja kalatalousteknikot", "labelEn": "Agricultural technicians", "labelSv": "Jordbruks- och fiskeritekniker", "searchFi": "31420 maa- ja kalatalousteknikot", "searchEn": "31420 agricultural technicians", "searchSv": "31420 jordbruks- och fiskeritekniker", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31430", "code": "31430", "labelFi": "Metsätalousteknikot", "labelEn": "Forestry technicians", "labelSv": "Skogsbrukstekniker", "searchFi": "31430 metsätalousteknikot", "searchEn": "31430 forestry technicians", "searchSv": "31430 skogsbrukstekniker", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31510", "code": "31510", "labelFi": "Laivojen konepäälliköt ja -mestarit", "labelEn": "Ships' engineers", "labelSv": "Maskinchefer och -mästare på fartyg", "searchFi": "31510 laivojen konepäälliköt ja -mestarit", "searchEn": "31510 ships' engineers", "searchSv": "31510 maskinchefer och -mästare på fartyg", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31521", "code": "31521", "labelFi": "Isojen alusten päälliköt ja perämiehet", "labelEn": "Large ships' officers and mates", "labelSv": "Fartygsbefäl och styrmän (stora fartyg)", "searchFi": "31521 isojen alusten päälliköt ja perämiehet", "searchEn": "31521 large ships' officers and mates", "searchSv": "31521 fartygsbefäl och styrmän (stora fartyg)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31522", "code": "31522", "labelFi": "Pienten alusten päälliköt", "labelEn": "Small ships' officers", "labelSv": "Befäl (mindre fartyg)", "searchFi": "31522 pienten alusten päälliköt", "searchEn": "31522 small ships' officers", "searchSv": "31522 befäl (mindre fartyg)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31523", "code": "31523", "labelFi": "Satamaliikenteen ohjaajat ja satamakapteenit", "labelEn": "Harbour traffic controllers and harbour masters", "labelSv": "Hamntrafikledare och hamnkaptener", "searchFi": "31523 satamaliikenteen ohjaajat ja satamakapteenit", "searchEn": "31523 harbour traffic controllers and harbour masters", "searchSv": "31523 hamntrafikledare och hamnkaptener", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31530", "code": "31530", "labelFi": "Lentokapteenit ja -perämiehet", "labelEn": "Aircraft pilots and related associate professionals", "labelSv": "Flygkaptener och -styrmän", "searchFi": "31530 lentokapteenit ja -perämiehet", "searchEn": "31530 aircraft pilots and related associate professionals", "searchSv": "31530 flygkaptener och -styrmän", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31540", "code": "31540", "labelFi": "Lennonjohtajat", "labelEn": "Air traffic controllers", "labelSv": "Flygledare", "searchFi": "31540 lennonjohtajat", "searchEn": "31540 air traffic controllers", "searchSv": "31540 flygledare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "31550", "code": "31550", "labelFi": "Lennonvalvonnan tekniset asiantuntijat", "labelEn": "Air traffic safety electronics technicians", "labelSv": "Tekniska experter inom flygövervakning", "searchFi": "31550 lennonvalvonnan tekniset asiantuntijat", "searchEn": "31550 air traffic safety electronics technicians", "searchSv": "31550 tekniska experter inom flygövervakning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32110", "code": "32110", "labelFi": "Lääketieteellisen kuvantamis- ja laitetekniikan asiantuntijat", "labelEn": "Medical imaging and therapeutic equipment technicians", "labelSv": "Experter, bilddiagnostik och medicinteknisk utrustning", "searchFi": "32110 lääketieteellisen kuvantamis- ja laitetekniikan asiantuntijat", "searchEn": "32110 medical imaging and therapeutic equipment technicians", "searchSv": "32110 experter, bilddiagnostik och medicinteknisk utrustning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32120", "code": "32120", "labelFi": "Bioanalyytikot (terveydenhuolto)", "labelEn": "Medical and pathology laboratory technicians", "labelSv": "Bioanalytiker (hälsovården)", "searchFi": "32120 bioanalyytikot (terveydenhuolto)", "searchEn": "32120 medical and pathology laboratory technicians", "searchSv": "32120 bioanalytiker (hälsovården)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32130", "code": "32130", "labelFi": "Farmaseutit", "labelEn": "Pharmaceutical technicians and assistants", "labelSv": "Farmaceuter", "searchFi": "32130 farmaseutit", "searchEn": "32130 pharmaceutical technicians and assistants", "searchSv": "32130 farmaceuter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32141", "code": "32141", "labelFi": "Hammasteknikot", "labelEn": "Dental technicians", "labelSv": "Tandtekniker", "searchFi": "32141 hammasteknikot", "searchEn": "32141 dental technicians", "searchSv": "32141 tandtekniker", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32142", "code": "32142", "labelFi": "Apuvälineteknikot", "labelEn": "Prosthetist-orthotists", "labelSv": "Hjälpmedelstekniker", "searchFi": "32142 apuvälineteknikot", "searchEn": "32142 prosthetist-orthotists", "searchSv": "32142 hjälpmedelstekniker", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32211", "code": "32211", "labelFi": "Sairaanhoitajat", "labelEn": "Nurses", "labelSv": "Sjukskötare", "searchFi": "32211 sairaanhoitajat", "searchEn": "32211 nurses", "searchSv": "32211 sjukskötare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32212", "code": "32212", "labelFi": "Terveydenhoitajat", "labelEn": "Public health nurses", "labelSv": "Hälsovårdare", "searchFi": "32212 terveydenhoitajat", "searchEn": "32212 public health nurses", "searchSv": "32212 hälsovårdare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32220", "code": "32220", "labelFi": "Kätilöt", "labelEn": "Midwifery associate professionals", "labelSv": "Barnmorskor", "searchFi": "32220 kätilöt", "searchEn": "32220 midwifery associate professionals", "searchSv": "32220 barnmorskor", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32300", "code": "32300", "labelFi": "Luontais- ja vaihtoehtohoitajat", "labelEn": "Traditional and complementary medicine associate professionals", "labelSv": "Utövare av naturmedicin och alternativ medicin", "searchFi": "32300 luontais- ja vaihtoehtohoitajat", "searchEn": "32300 traditional and complementary medicine associate professionals", "searchSv": "32300 utövare av naturmedicin och alternativ medicin", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32400", "code": "32400", "labelFi": "Seminologit ym.", "labelEn": "Veterinary technicians and assistants", "labelSv": "Seminörer m.fl.", "searchFi": "32400 seminologit ym.", "searchEn": "32400 veterinary technicians and assistants", "searchSv": "32400 seminörer m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32510", "code": "32510", "labelFi": "Suuhygienistit", "labelEn": "Dental assistants and therapists", "labelSv": "Munhygienister", "searchFi": "32510 suuhygienistit", "searchEn": "32510 dental assistants and therapists", "searchSv": "32510 munhygienister", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32540", "code": "32540", "labelFi": "Optikot", "labelEn": "Dispensing opticians", "labelSv": "Optiker", "searchFi": "32540 optikot", "searchEn": "32540 dispensing opticians", "searchSv": "32540 optiker", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32550", "code": "32550", "labelFi": "Fysioterapeutit ym.", "labelEn": "Physiotherapy technicians and assistants", "labelSv": "Fysioterapeuter m.fl.", "searchFi": "32550 fysioterapeutit ym.", "searchEn": "32550 physiotherapy technicians and assistants", "searchSv": "32550 fysioterapeuter m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32570", "code": "32570", "labelFi": "Terveys- ja työsuojelutarkastajat", "labelEn": "Environmental and occupational health inspectors and associates", "labelSv": "Hälso- och arbetarskyddsinspektörer", "searchFi": "32570 terveys- ja työsuojelutarkastajat", "searchEn": "32570 environmental and occupational health inspectors and associates", "searchSv": "32570 hälso- och arbetarskyddsinspektörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32580", "code": "32580", "labelFi": "Sairaankuljetuksen ensihoitajat", "labelEn": "Ambulance workers", "labelSv": "Akutvårdare inom sjuktransporten", "searchFi": "32580 sairaankuljetuksen ensihoitajat", "searchEn": "32580 ambulance workers", "searchSv": "32580 akutvårdare inom sjuktransporten", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32591", "code": "32591", "labelFi": "Toimintaterapeutit", "labelEn": "Occupational therapists", "labelSv": "Ergoterapeuter", "searchFi": "32591 toimintaterapeutit", "searchEn": "32591 occupational therapists", "searchSv": "32591 ergoterapeuter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "32592", "code": "32592", "labelFi": "Muut terapeutit", "labelEn": "Other therapists", "labelSv": "Övriga terapeuter", "searchFi": "32592 muut terapeutit", "searchEn": "32592 other therapists", "searchSv": "32592 övriga terapeuter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33110", "code": "33110", "labelFi": "Arvopaperi- ja valuuttakauppiaat", "labelEn": "Securities and finance dealers and brokers", "labelSv": "Värdepappers- och valutamäklare", "searchFi": "33110 arvopaperi- ja valuuttakauppiaat", "searchEn": "33110 securities and finance dealers and brokers", "searchSv": "33110 värdepappers- och valutamäklare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33120", "code": "33120", "labelFi": "Luotto- ja laina-asiantuntijat", "labelEn": "Credit and loans officers", "labelSv": "Kredit- och låneexperter", "searchFi": "33120 luotto- ja laina-asiantuntijat", "searchEn": "33120 credit and loans officers", "searchSv": "33120 kredit- och låneexperter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33130", "code": "33130", "labelFi": "Kirjanpidon ja laskentatoimen asiantuntijat", "labelEn": "Accounting associate professionals", "labelSv": "Experter inom bokföring och redovisning", "searchFi": "33130 kirjanpidon ja laskentatoimen asiantuntijat", "searchEn": "33130 accounting associate professionals", "searchSv": "33130 experter inom bokföring och redovisning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33140", "code": "33140", "labelFi": "Tilastointi- ja matematiikka-asiantuntijat", "labelEn": "Statistical, mathematical and related associate professionals", "labelSv": "Experter inom statistik och matematik", "searchFi": "33140 tilastointi- ja matematiikka-asiantuntijat", "searchEn": "33140 statistical, mathematical and related associate professionals", "searchSv": "33140 experter inom statistik och matematik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33150", "code": "33150", "labelFi": "Arvioitsijat ja vahinkotarkastajat", "labelEn": "Valuers and loss assessors", "labelSv": "Värderare och skadeinspektörer", "searchFi": "33150 arvioitsijat ja vahinkotarkastajat", "searchEn": "33150 valuers and loss assessors", "searchSv": "33150 värderare och skadeinspektörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33210", "code": "33210", "labelFi": "Vakuutusalan palvelumyyjät", "labelEn": "Insurance representatives", "labelSv": "Försäljare av försäkringstjänster", "searchFi": "33210 vakuutusalan palvelumyyjät", "searchEn": "33210 insurance representatives", "searchSv": "33210 försäljare av försäkringstjänster", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33220", "code": "33220", "labelFi": "Myyntiedustajat", "labelEn": "Commercial sales representatives", "labelSv": "Försäljningsrepresentanter", "searchFi": "33220 myyntiedustajat sales", "searchEn": "33220 commercial sales representatives", "searchSv": "33220 försäljningsrepresentanter", "freeTextFi": "sales", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "33230", "code": "33230", "labelFi": "Sisäänostajat", "labelEn": "Buyers", "labelSv": "Inköpare", "searchFi": "33230 sisäänostajat", "searchEn": "33230 buyers", "searchSv": "33230 inköpare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33240", "code": "33240", "labelFi": "Kaupanvälittäjät", "labelEn": "Trade brokers", "labelSv": "Affärsförmedlare", "searchFi": "33240 kaupanvälittäjät", "searchEn": "33240 trade brokers", "searchSv": "33240 affärsförmedlare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33310", "code": "33310", "labelFi": "Huolitsijat, tulli- ja laivanselvittäjät", "labelEn": "Clearing and forwarding agents", "labelSv": "Speditörer, tull- och fartygsklarerare", "searchFi": "33310 huolitsijat, tulli- ja laivanselvittäjät", "searchEn": "33310 clearing and forwarding agents", "searchSv": "33310 speditörer, tull- och fartygsklarerare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33320", "code": "33320", "labelFi": "Konferenssi- ja tapahtumajärjestäjät", "labelEn": "Conference and event planners", "labelSv": "Konferens- och evenemangsarrangörer", "searchFi": "33320 konferenssi- ja tapahtumajärjestäjät", "searchEn": "33320 conference and event planners", "searchSv": "33320 konferens- och evenemangsarrangörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33330", "code": "33330", "labelFi": "Työnvälittäjät", "labelEn": "Employment agents and contractors", "labelSv": "Arbetsförmedlare", "searchFi": "33330 työnvälittäjät", "searchEn": "33330 employment agents and contractors", "searchSv": "33330 arbetsförmedlare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33341", "code": "33341", "labelFi": "Kiinteistönvälittäjät", "labelEn": "Estate agents", "labelSv": "Fastighetsmäklare", "searchFi": "33341 kiinteistönvälittäjät", "searchEn": "33341 estate agents", "searchSv": "33341 fastighetsmäklare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33342", "code": "33342", "labelFi": "Isännöitsijät", "labelEn": "Property managers", "labelSv": "Disponenter", "searchFi": "33342 isännöitsijät", "searchEn": "33342 property managers", "searchSv": "33342 disponenter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33390", "code": "33390", "labelFi": "Muut liike-elämän asiantuntijat", "labelEn": "Business services agents not elsewhere classified", "labelSv": "Övriga experter inom affärslivet", "searchFi": "33390 muut liike-elämän asiantuntijat", "searchEn": "33390 business services agents not elsewhere classified", "searchSv": "33390 övriga experter inom affärslivet", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33410", "code": "33410", "labelFi": "Toimistotyön esimiehet", "labelEn": "Office supervisors", "labelSv": "Arbetsledare för kontorspersonal", "searchFi": "33410 toimistotyön esimiehet", "searchEn": "33410 office supervisors", "searchSv": "33410 arbetsledare för kontorspersonal", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33420", "code": "33420", "labelFi": "Asianajosihteerit", "labelEn": "Legal secretaries", "labelSv": "Juristsekreterare", "searchFi": "33420 asianajosihteerit", "searchEn": "33420 legal secretaries", "searchSv": "33420 juristsekreterare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33430", "code": "33430", "labelFi": "Johdon sihteerit ja osastosihteerit", "labelEn": "Administrative and executive secretaries", "labelSv": "Ledningsassistenter och avdelningssekreterare", "searchFi": "33430 johdon sihteerit ja osastosihteerit", "searchEn": "33430 administrative and executive secretaries", "searchSv": "33430 ledningsassistenter och avdelningssekreterare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33440", "code": "33440", "labelFi": "Toimistosihteerit (terveydenhuolto)", "labelEn": "Medical secretaries", "labelSv": "Byråsekreterare, hälso- och sjukvård", "searchFi": "33440 toimistosihteerit (terveydenhuolto)", "searchEn": "33440 medical secretaries", "searchSv": "33440 byråsekreterare, hälso- och sjukvård", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33510", "code": "33510", "labelFi": "Tulli- ja rajavirkamiehet", "labelEn": "Customs and border inspectors", "labelSv": "Tull- och gränstjänstemän", "searchFi": "33510 tulli- ja rajavirkamiehet", "searchEn": "33510 customs and border inspectors", "searchSv": "33510 tull- och gränstjänstemän", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33520", "code": "33520", "labelFi": "Verovalmistelijat ja -tarkastajat", "labelEn": "Government tax and excise officials", "labelSv": "Skatteberedare och -inspektörer", "searchFi": "33520 verovalmistelijat ja -tarkastajat", "searchEn": "33520 government tax and excise officials", "searchSv": "33520 skatteberedare och -inspektörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33530", "code": "33530", "labelFi": "Sosiaaliturvaetuuksien käsittelijät", "labelEn": "Government social benefits officials", "labelSv": "Handläggare av socialskyddsförmåner", "searchFi": "33530 sosiaaliturvaetuuksien käsittelijät", "searchEn": "33530 government social benefits officials", "searchSv": "33530 handläggare av socialskyddsförmåner", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33540", "code": "33540", "labelFi": "Lupavirkamiehet", "labelEn": "Government licensing officials", "labelSv": "Tillståndstjänstemän", "searchFi": "33540 lupavirkamiehet", "searchEn": "33540 government licensing officials", "searchSv": "33540 tillståndstjänstemän", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33550", "code": "33550", "labelFi": "Komisariot ja ylikonstaapelit", "labelEn": "Police inspectors and detectives", "labelSv": "Kommissarier och överkonstaplar", "searchFi": "33550 komisariot ja ylikonstaapelit", "searchEn": "33550 police inspectors and detectives", "searchSv": "33550 kommissarier och överkonstaplar", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "33590", "code": "33590", "labelFi": "Muut julkishallinnon valmistelu- ja valvontavirkamiehet", "labelEn": "Regulatory government associate professionals not elsewhere classified", "labelSv": "Övriga tjänstemän inom beredning och tillsyn inom offentlig förvaltning", "searchFi": "33590 muut julkishallinnon valmistelu- ja valvontavirkamiehet", "searchEn": "33590 regulatory government associate professionals not elsewhere classified", "searchSv": "33590 övriga tjänstemän inom beredning och tillsyn inom offentlig förvaltning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34111", "code": "34111", "labelFi": "Oikeudenkäyntiasiamiehet ja ulosottomiehet", "labelEn": "Legal and related business associate professionals", "labelSv": "Rättegångsombud och utsökningsmän", "searchFi": "34111 oikeudenkäyntiasiamiehet ja ulosottomiehet", "searchEn": "34111 legal and related business associate professionals", "searchSv": "34111 rättegångsombud och utsökningsmän", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34112", "code": "34112", "labelFi": "Asiamiehet, toimitsijat ym. järjestöalan asiantuntijat", "labelEn": "Agents, officials and other organisation associate professionals", "labelSv": "Ombud, funktionärer m.fl. experter inom organisationssektorn", "searchFi": "34112 asiamiehet, toimitsijat ym. järjestöalan asiantuntijat", "searchEn": "34112 agents, officials and other organisation associate professionals", "searchSv": "34112 ombud, funktionärer m.fl. experter inom organisationssektorn", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34113", "code": "34113", "labelFi": "Kuluttajaneuvojat ym.", "labelEn": "Consumer advisers, etc.", "labelSv": "Konsumentrådgivare m.fl.", "searchFi": "34113 kuluttajaneuvojat ym.", "searchEn": "34113 consumer advisers, etc.", "searchSv": "34113 konsumentrådgivare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34121", "code": "34121", "labelFi": "Sosiaalialan ohjaajat", "labelEn": "Social instructors", "labelSv": "Handledare inom socialsektorn", "searchFi": "34121 sosiaalialan ohjaajat", "searchEn": "34121 social instructors", "searchSv": "34121 handledare inom socialsektorn", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34122", "code": "34122", "labelFi": "Nuorisotyön ohjaajat (ei srk.)", "labelEn": "Youth leaders (not parishes)", "labelSv": "Ungdomsledare (ej församl.)", "searchFi": "34122 nuorisotyön ohjaajat (ei srk.)", "searchEn": "34122 youth leaders (not parishes)", "searchSv": "34122 ungdomsledare (ej församl.)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34123", "code": "34123", "labelFi": "Työn- ja askarteluohjaajat", "labelEn": "Work and craft leaders", "labelSv": "Handledare och sysselsättningsledare", "searchFi": "34123 työn- ja askarteluohjaajat", "searchEn": "34123 work and craft leaders", "searchSv": "34123 handledare och sysselsättningsledare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34131", "code": "34131", "labelFi": "Diakonit ja diakonissat", "labelEn": "Deacons and deaconesses", "labelSv": "Diakoner och diakonissor", "searchFi": "34131 diakonit ja diakonissat", "searchEn": "34131 deacons and deaconesses", "searchSv": "34131 diakoner och diakonissor", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34139", "code": "34139", "labelFi": "Muut seurakuntatyöntekijät", "labelEn": "Other religious associate professionals", "labelSv": "Övriga församlingsarbetare", "searchFi": "34139 muut seurakuntatyöntekijät", "searchEn": "34139 other religious associate professionals", "searchSv": "34139 övriga församlingsarbetare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34210", "code": "34210", "labelFi": "Urheilijat", "labelEn": "Athletes and sports players", "labelSv": "Idrottare", "searchFi": "34210 urheilijat", "searchEn": "34210 athletes and sports players", "searchSv": "34210 idrottare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34220", "code": "34220", "labelFi": "Urheiluvalmentajat ja toimitsijat", "labelEn": "Sports coaches, instructors and officials", "labelSv": "Idrottstränare och funktionärer", "searchFi": "34220 urheiluvalmentajat ja toimitsijat", "searchEn": "34220 sports coaches, instructors and officials", "searchSv": "34220 idrottstränare och funktionärer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34230", "code": "34230", "labelFi": "Liikunnan ja vapaa-ajan ohjaajat", "labelEn": "Fitness and recreation instructors and program leaders", "labelSv": "Idrottsinstruktörer och fritidsledare", "searchFi": "34230 liikunnan ja vapaa-ajan ohjaajat", "searchEn": "34230 fitness and recreation instructors and program leaders", "searchSv": "34230 idrottsinstruktörer och fritidsledare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34310", "code": "34310", "labelFi": "Valokuvaajat", "labelEn": "Photographers", "labelSv": "Fotografer", "searchFi": "34310 valokuvaajat", "searchEn": "34310 photographers", "searchSv": "34310 fotografer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34320", "code": "34320", "labelFi": "Sisustussuunnittelijat ym.", "labelEn": "Interior designers and decorators", "labelSv": "Inredningsplanerare m.fl.", "searchFi": "34320 sisustussuunnittelijat ym.", "searchEn": "34320 interior designers and decorators", "searchSv": "34320 inredningsplanerare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34330", "code": "34330", "labelFi": "Gallerioiden, museoiden ja kirjastojen tekniset työntekijät", "labelEn": "Gallery, museum and library technicians", "labelSv": "Galleri-, musei- och bibliotekstekniker", "searchFi": "34330 gallerioiden, museoiden ja kirjastojen tekniset työntekijät", "searchEn": "34330 gallery, museum and library technicians", "searchSv": "34330 galleri-, musei- och bibliotekstekniker", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34340", "code": "34340", "labelFi": "Keittiöpäälliköt", "labelEn": "Chefs", "labelSv": "Kökschefer", "searchFi": "34340 keittiöpäälliköt", "searchEn": "34340 chefs", "searchSv": "34340 kökschefer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34351", "code": "34351", "labelFi": "Kuvaussihteerit ja muut näyttämötekniset asiantuntijat", "labelEn": "Producer's assistants and other stagecraft associate professionals", "labelSv": "Scriptor och övriga experter inom scenteknik", "searchFi": "34351 kuvaussihteerit ja muut näyttämötekniset asiantuntijat", "searchEn": "34351 producer's assistants and other stagecraft associate professionals", "searchSv": "34351 scriptor och övriga experter inom scenteknik", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "34359", "code": "34359", "labelFi": "Muut taide- ja kulttuurialan tekniset asiantuntijat", "labelEn": "Other artistic and cultural associate professionals", "labelSv": "Övriga experter inom konst- och konstindustrisektorn", "searchFi": "34359 muut taide- ja kulttuurialan tekniset asiantuntijat", "searchEn": "34359 other artistic and cultural associate professionals", "searchSv": "34359 övriga experter inom konst- och konstindustrisektorn", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "35110", "code": "35110", "labelFi": "Käytön operaattorit", "labelEn": "Information and communications technology operations technicians", "labelSv": "Driftoperatörer", "searchFi": "35110 käytön operaattorit", "searchEn": "35110 information and communications technology operations technicians", "searchSv": "35110 driftoperatörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "35120", "code": "35120", "labelFi": "Käytön tukihenkilöt", "labelEn": "Information and communications technology user support technicians", "labelSv": "Datasupportpersonal", "searchFi": "35120 käytön tukihenkilöt", "searchEn": "35120 information and communications technology user support technicians", "searchSv": "35120 datasupportpersonal", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "35130", "code": "35130", "labelFi": "Tietoverkkoteknikot", "labelEn": "Computer network and systems technicians", "labelSv": "Nätverkstekniker", "searchFi": "35130 tietoverkkoteknikot", "searchEn": "35130 computer network and systems technicians", "searchSv": "35130 nätverkstekniker", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "35140", "code": "35140", "labelFi": "Webmasterit ja -teknikot", "labelEn": "Web technicians", "labelSv": "Webbmaster och webbtekniker", "searchFi": "35140 webmasterit ja -teknikot", "searchEn": "35140 web technicians", "searchSv": "35140 webbmaster och webbtekniker", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "35210", "code": "35210", "labelFi": "Lähetys- ja audiovisuaaliteknikot", "labelEn": "Broadcasting and audio-visual technicians", "labelSv": "Sändnings- och AV-tekniker", "searchFi": "35210 lähetys- ja audiovisuaaliteknikot", "searchEn": "35210 broadcasting and audio-visual technicians", "searchSv": "35210 sändnings- och av-tekniker", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "35220", "code": "35220", "labelFi": "Televiestinnän tekniset asiantuntijat", "labelEn": "Telecommunications engineering technicians", "labelSv": "Tekniska experter inom telekommunikation", "searchFi": "35220 televiestinnän tekniset asiantuntijat", "searchEn": "35220 telecommunications engineering technicians", "searchSv": "35220 tekniska experter inom telekommunikation", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "41100", "code": "41100", "labelFi": "Toimistoavustajat", "labelEn": "General office clerks", "labelSv": "Kontorsassistenter", "searchFi": "41100 toimistoavustajat", "searchEn": "41100 general office clerks", "searchSv": "41100 kontorsassistenter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "41200", "code": "41200", "labelFi": "Yleissihteerit", "labelEn": "Secretaries (general)", "labelSv": "Kontorssekreterare", "searchFi": "41200 yleissihteerit", "searchEn": "41200 secretaries (general)", "searchSv": "41200 kontorssekreterare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "41310", "code": "41310", "labelFi": "Tekstinkäsittelijät", "labelEn": "Typists and word processing operators", "labelSv": "Textbehandlare", "searchFi": "41310 tekstinkäsittelijät", "searchEn": "41310 typists and word processing operators", "searchSv": "41310 textbehandlare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "41320", "code": "41320", "labelFi": "Tallentajat", "labelEn": "Data entry clerks", "labelSv": "Dataregistrerare", "searchFi": "41320 tallentajat", "searchEn": "41320 data entry clerks", "searchSv": "41320 dataregistrerare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "42110", "code": "42110", "labelFi": "Pankki- ym. toimihenkilöt", "labelEn": "Bank tellers and related clerks", "labelSv": "Banktjänstemän m.fl.", "searchFi": "42110 pankki- ym. toimihenkilöt", "searchEn": "42110 bank tellers and related clerks", "searchSv": "42110 banktjänstemän m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "42120", "code": "42120", "labelFi": "Vedonvälittäjät, bingo- ja kasinopelin hoitajat ym.", "labelEn": "Bookmakers, croupiers and related gaming workers", "labelSv": "Vadförmedlare, croupierer m.fl.", "searchFi": "42120 vedonvälittäjät, bingo- ja kasinopelin hoitajat ym.", "searchEn": "42120 bookmakers, croupiers and related gaming workers", "searchSv": "42120 vadförmedlare, croupierer m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "42130", "code": "42130", "labelFi": "Panttilainaajat", "labelEn": "Pawnbrokers and money-lenders", "labelSv": "Pantlånare", "searchFi": "42130 panttilainaajat", "searchEn": "42130 pawnbrokers and money-lenders", "searchSv": "42130 pantlånare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "42140", "code": "42140", "labelFi": "Maksujenperijät", "labelEn": "Debt-collectors and related workers", "labelSv": "Inkasserare", "searchFi": "42140 maksujenperijät", "searchEn": "42140 debt-collectors and related workers", "searchSv": "42140 inkasserare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "42210", "code": "42210", "labelFi": "Matkatoimistovirkailijat", "labelEn": "Travel consultants and clerks", "labelSv": "Resebyråtjänstemän", "searchFi": "42210 matkatoimistovirkailijat", "searchEn": "42210 travel consultants and clerks", "searchSv": "42210 resebyråtjänstemän", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "42220", "code": "42220", "labelFi": "Puhelinpalveluneuvojat", "labelEn": "Contact centre information clerks", "labelSv": "Telefonservicerådgivare", "searchFi": "42220 puhelinpalveluneuvojat", "searchEn": "42220 contact centre information clerks", "searchSv": "42220 telefonservicerådgivare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "42230", "code": "42230", "labelFi": "Puhelinvaihteenhoitajat", "labelEn": "Telephone switchboard operators", "labelSv": "Växeltelefonister", "searchFi": "42230 puhelinvaihteenhoitajat", "searchEn": "42230 telephone switchboard operators", "searchSv": "42230 växeltelefonister", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "42240", "code": "42240", "labelFi": "Hotellin vastaanottovirkailijat", "labelEn": "Hotel receptionists", "labelSv": "Hotellreceptionister", "searchFi": "42240 hotellin vastaanottovirkailijat", "searchEn": "42240 hotel receptionists", "searchSv": "42240 hotellreceptionister", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "42250", "code": "42250", "labelFi": "Informaatiopisteen asiakasneuvojat", "labelEn": "Enquiry clerks", "labelSv": "Kundrådgivare vid informationsdisk", "searchFi": "42250 informaatiopisteen asiakasneuvojat", "searchEn": "42250 enquiry clerks", "searchSv": "42250 kundrådgivare vid informationsdisk", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "42260", "code": "42260", "labelFi": "Vastaanoton ja neuvonnan hoitajat", "labelEn": "Receptionists (general)", "labelSv": "Receptions- och rådgivningspersonal", "searchFi": "42260 vastaanoton ja neuvonnan hoitajat", "searchEn": "42260 receptionists (general)", "searchSv": "42260 receptions- och rådgivningspersonal", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "42270", "code": "42270", "labelFi": "Tutkimus- ja markkinatutkimushaastattelijat", "labelEn": "Survey and market research interviewers", "labelSv": "Undersöknings- och marknadsundersökningsintervjuare", "searchFi": "42270 tutkimus- ja markkinatutkimushaastattelijat", "searchEn": "42270 survey and market research interviewers", "searchSv": "42270 undersöknings- och marknadsundersökningsintervjuare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "42291", "code": "42291", "labelFi": "Hälytyspäivystäjät", "labelEn": "Emergency officers", "labelSv": "Nödcentraloperatörer", "searchFi": "42291 hälytyspäivystäjät", "searchEn": "42291 emergency officers", "searchSv": "42291 nödcentraloperatörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "42299", "code": "42299", "labelFi": "Muut muualla luokittelemattomat asiakaspalvelutyöntekijät", "labelEn": "Other client information clerks not elsewhere classified", "labelSv": "Övrig kundtjänstpersonal utan annan klassificering", "searchFi": "42299 muut muualla luokittelemattomat asiakaspalvelutyöntekijät", "searchEn": "42299 other client information clerks not elsewhere classified", "searchSv": "42299 övrig kundtjänstpersonal utan annan klassificering", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "43110", "code": "43110", "labelFi": "Taloushallinnon toimistotyöntekijät", "labelEn": "Accounting and bookkeeping clerks", "labelSv": "Kontorspersonal inom ekonomiförvaltning", "searchFi": "43110 taloushallinnon toimistotyöntekijät", "searchEn": "43110 accounting and bookkeeping clerks", "searchSv": "43110 kontorspersonal inom ekonomiförvaltning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "43120", "code": "43120", "labelFi": "Tilasto-, rahoitus- ja vakuutusalan toimistotyöntekijät", "labelEn": "Statistical, finance and insurance clerks", "labelSv": "Kontorspersonal inom statistik-, finansierings- och försäkringssektorn", "searchFi": "43120 tilasto-, rahoitus- ja vakuutusalan toimistotyöntekijät", "searchEn": "43120 statistical, finance and insurance clerks", "searchSv": "43120 kontorspersonal inom statistik-, finansierings- och försäkringssektorn", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "43130", "code": "43130", "labelFi": "Palkanlaskijat", "labelEn": "Payroll clerks", "labelSv": "Löneräknare", "searchFi": "43130 palkanlaskijat", "searchEn": "43130 payroll clerks", "searchSv": "43130 löneräknare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "43210", "code": "43210", "labelFi": "Varastonhoitajat ym.", "labelEn": "Stock clerks", "labelSv": "Lagerförvaltare m.fl.", "searchFi": "43210 varastonhoitajat ym.", "searchEn": "43210 stock clerks", "searchSv": "43210 lagerförvaltare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "43220", "code": "43220", "labelFi": "Tuotannon valmistelijat", "labelEn": "Production clerks", "labelSv": "Produktionsassistenter", "searchFi": "43220 tuotannon valmistelijat", "searchEn": "43220 production clerks", "searchSv": "43220 produktionsassistenter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "43231", "code": "43231", "labelFi": "Raideliikenteen ohjaajat, ajojärjestelijät ym.", "labelEn": "Rail traffic controllers, traffic co-ordinators, etc.", "labelSv": "Spårtrafikledare, trafiksamordnare m.fl.", "searchFi": "43231 raideliikenteen ohjaajat, ajojärjestelijät ym.", "searchEn": "43231 rail traffic controllers, traffic co-ordinators, etc.", "searchSv": "43231 spårtrafikledare, trafiksamordnare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "43239", "code": "43239", "labelFi": "Muut kuljetuksen ja huolinnan toimistotyöntekijät", "labelEn": "Other transport clerks", "labelSv": "Övriga kontorstjänstemän inom transport och spedition", "searchFi": "43239 muut kuljetuksen ja huolinnan toimistotyöntekijät", "searchEn": "43239 other transport clerks", "searchSv": "43239 övriga kontorstjänstemän inom transport och spedition", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "44110", "code": "44110", "labelFi": "Kirjastotyöntekijät", "labelEn": "Library clerks", "labelSv": "Bibliotekspersonal", "searchFi": "44110 kirjastotyöntekijät", "searchEn": "44110 library clerks", "searchSv": "44110 bibliotekspersonal", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "44121", "code": "44121", "labelFi": "Postinkantajat", "labelEn": "Mail carriers", "labelSv": "Brevbärare", "searchFi": "44121 postinkantajat", "searchEn": "44121 mail carriers", "searchSv": "44121 brevbärare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "44122", "code": "44122", "labelFi": "Toimistovahtimestarit", "labelEn": "Porters", "labelSv": "Kontorsvaktmästare", "searchFi": "44122 toimistovahtimestarit", "searchEn": "44122 porters", "searchSv": "44122 kontorsvaktmästare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "44130", "code": "44130", "labelFi": "Koodaajat, oikolukijat ym.", "labelEn": "Coding, proof-reading and related clerks", "labelSv": "Kodare, korrekturläsare m.fl.", "searchFi": "44130 koodaajat, oikolukijat ym.", "searchEn": "44130 coding, proof-reading and related clerks", "searchSv": "44130 kodare, korrekturläsare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "44150", "code": "44150", "labelFi": "Arkistotyöntekijät", "labelEn": "Filing and copying clerks", "labelSv": "Arkivanställda", "searchFi": "44150 arkistotyöntekijät", "searchEn": "44150 filing and copying clerks", "searchSv": "44150 arkivanställda", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "44160", "code": "44160", "labelFi": "Henkilöstöhallinnon avustavat toimistotyöntekijät", "labelEn": "Personnel clerks", "labelSv": "Assisterande kontorspersonal inom personalförvaltning", "searchFi": "44160 henkilöstöhallinnon avustavat toimistotyöntekijät", "searchEn": "44160 personnel clerks", "searchSv": "44160 assisterande kontorspersonal inom personalförvaltning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "44190", "code": "44190", "labelFi": "Muut muualla luokittelemattomat toimisto- ja asiakaspalvelutyöntekijät", "labelEn": "Clerical support workers not elsewhere classified", "labelSv": "Övrig kontors- och kundtjänstpersonal utan annan klassificering", "searchFi": "44190 muut muualla luokittelemattomat toimisto- ja asiakaspalvelutyöntekijät", "searchEn": "44190 clerical support workers not elsewhere classified", "searchSv": "44190 övrig kontors- och kundtjänstpersonal utan annan klassificering", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "51110", "code": "51110", "labelFi": "Lentoemännät, purserit ym.", "labelEn": "Travel attendants and travel stewards", "labelSv": "Flygvärdinnor, purser m.fl.", "searchFi": "51110 lentoemännät, purserit ym.", "searchEn": "51110 travel attendants and travel stewards", "searchSv": "51110 flygvärdinnor, purser m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "51120", "code": "51120", "labelFi": "Konduktöörit, lipuntarkastajat ym.", "labelEn": "Transport conductors", "labelSv": "Konduktörer, biljettkontrollanter m.fl.", "searchFi": "51120 konduktöörit, lipuntarkastajat ym.", "searchEn": "51120 transport conductors", "searchSv": "51120 konduktörer, biljettkontrollanter m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "51130", "code": "51130", "labelFi": "Matkaoppaat", "labelEn": "Travel guides", "labelSv": "Guider", "searchFi": "51130 matkaoppaat", "searchEn": "51130 travel guides", "searchSv": "51130 guider", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "51201", "code": "51201", "labelFi": "Kokit, keittäjät ja kylmäköt", "labelEn": "Cooks", "labelSv": "Kockar, kokerskor och kallskänkor", "searchFi": "51201 kokit, keittäjät ja kylmäköt ravintola kahvila", "searchEn": "51201 cooks", "searchSv": "51201 kockar, kokerskor och kallskänkor", "freeTextFi": "ravintola kahvila", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "51202", "code": "51202", "labelFi": "Ravintolaesimiehet ja vuoropäälliköt", "labelEn": "Restaurant services supervisors and shift managers", "labelSv": "Restaurangföreståndare och skiftledare", "searchFi": "51202 ravintolaesimiehet ja vuoropäälliköt ravintola kahvila", "searchEn": "51202 restaurant services supervisors and shift managers", "searchSv": "51202 restaurangföreståndare och skiftledare", "freeTextFi": "ravintola kahvila", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "51310", "code": "51310", "labelFi": "Tarjoilijat", "labelEn": "Waiters", "labelSv": "Servitörer", "searchFi": "51310 tarjoilijat ravintola kahvila", "searchEn": "51310 waiters", "searchSv": "51310 servitörer", "freeTextFi": "ravintola kahvila", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "51320", "code": "51320", "labelFi": "Baarimestarit", "labelEn": "Bartenders", "labelSv": "Bartendrar", "searchFi": "51320 baarimestarit ravintola kahvila", "searchEn": "51320 bartenders", "searchSv": "51320 bartendrar", "freeTextFi": "ravintola kahvila", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "51410", "code": "51410", "labelFi": "Kampaajat ja parturit", "labelEn": "Hairdressers", "labelSv": "Frisörer", "searchFi": "51410 kampaajat ja parturit", "searchEn": "51410 hairdressers", "searchSv": "51410 frisörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "51420", "code": "51420", "labelFi": "Kosmetologit ym.", "labelEn": "Beauticians and related workers", "labelSv": "Kosmetologer m.fl.", "searchFi": "51420 kosmetologit ym.", "searchEn": "51420 beauticians and related workers", "searchSv": "51420 kosmetologer m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "51510", "code": "51510", "labelFi": "Siivoustyön esimiehet toimistoissa, hotelleissa ja muissa laitoksissa", "labelEn": "Cleaning and housekeeping supervisors in offices, hotels and other establishments", "labelSv": "Arbetsledare inom städning på kontor, hotell m.fl.", "searchFi": "51510 siivoustyön esimiehet toimistoissa, hotelleissa ja muissa laitoksissa", "searchEn": "51510 cleaning and housekeeping supervisors in offices, hotels and other establishments", "searchSv": "51510 arbetsledare inom städning på kontor, hotell m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "51520", "code": "51520", "labelFi": "Yksityiskotien taloudenhoitajat", "labelEn": "Domestic housekeepers", "labelSv": "Hushållerskor i privata hem", "searchFi": "51520 yksityiskotien taloudenhoitajat", "searchEn": "51520 domestic housekeepers", "searchSv": "51520 hushållerskor i privata hem", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "51530", "code": "51530", "labelFi": "Kiinteistöhuollon työntekijät", "labelEn": "Building caretakers", "labelSv": "Fastighetsskötare", "searchFi": "51530 kiinteistöhuollon työntekijät talonmies huolto siivous", "searchEn": "51530 building caretakers", "searchSv": "51530 fastighetsskötare", "freeTextFi": "talonmies huolto siivous", "freeTextEn": "", "freeTextSv": "", "keyword": "company household" }, { "id": "51610", "code": "51610", "labelFi": "Astrologit, ennustajat ym.", "labelEn": "Astrologers, fortune-tellers and related workers", "labelSv": "Astrologer, siare m.fl.", "searchFi": "51610 astrologit, ennustajat ym.", "searchEn": "51610 astrologers, fortune-tellers and related workers", "searchSv": "51610 astrologer, siare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "51631", "code": "51631", "labelFi": "Hautaustoimistonhoitajat ym.", "labelEn": "Undertakers and related funeral workers", "labelSv": "Begravningsbyråföreståndare m.fl.", "searchFi": "51631 hautaustoimistonhoitajat ym.", "searchEn": "51631 undertakers and related funeral workers", "searchSv": "51631 begravningsbyråföreståndare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "51632", "code": "51632", "labelFi": "Muut hautaustyöntekijät", "labelEn": "Other funeral workers", "labelSv": "Övrig begravningspersonal", "searchFi": "51632 muut hautaustyöntekijät", "searchEn": "51632 other funeral workers", "searchSv": "51632 övrig begravningspersonal", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "51640", "code": "51640", "labelFi": "Eläintenhoitajat ja lemmikkieläinten trimmaajat", "labelEn": "Pet groomers and animal care workers", "labelSv": "Djurskötare och djurfrisörer", "searchFi": "51640 eläintenhoitajat ja lemmikkieläinten trimmaajat", "searchEn": "51640 pet groomers and animal care workers", "searchSv": "51640 djurskötare och djurfrisörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "51650", "code": "51650", "labelFi": "Ajo-opettajat", "labelEn": "Driving instructors", "labelSv": "Trafiklärare", "searchFi": "51650 ajo-opettajat", "searchEn": "51650 driving instructors", "searchSv": "51650 trafiklärare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "51690", "code": "51690", "labelFi": "Muualla luokittelemattomat henkilökohtaisen palvelun työntekijät", "labelEn": "Personal services workers not elsewhere classified", "labelSv": "Övrig servicepersonal inom personliga tjänster utan annan klassificering", "searchFi": "51690 muualla luokittelemattomat henkilökohtaisen palvelun työntekijät", "searchEn": "51690 personal services workers not elsewhere classified", "searchSv": "51690 övrig servicepersonal inom personliga tjänster utan annan klassificering", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "52110", "code": "52110", "labelFi": "Kioski- ja torimyyjät", "labelEn": "Stall and market salespersons", "labelSv": "Kiosk- och torgförsäljare", "searchFi": "52110 kioski- ja torimyyjät", "searchEn": "52110 stall and market salespersons", "searchSv": "52110 kiosk- och torgförsäljare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "52120", "code": "52120", "labelFi": "Katumyyjät (elintarvikkeet)", "labelEn": "Street food salespersons", "labelSv": "Gatuförsäljare (livsmedel)", "searchFi": "52120 katumyyjät (elintarvikkeet)", "searchEn": "52120 street food salespersons", "searchSv": "52120 gatuförsäljare (livsmedel)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "52210", "code": "52210", "labelFi": "Kauppiaat (pienyrittäjät)", "labelEn": "Shop keepers", "labelSv": "Butiksinnehavare (småföretagare)", "searchFi": "52210 kauppiaat (pienyrittäjät) kauppa", "searchEn": "52210 shop keepers", "searchSv": "52210 butiksinnehavare (småföretagare)", "freeTextFi": "kauppa", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "52220", "code": "52220", "labelFi": "Myymäläesimiehet", "labelEn": "Shop supervisors", "labelSv": "Butiksföreståndare", "searchFi": "52220 myymäläesimiehet kauppa", "searchEn": "52220 shop supervisors", "searchSv": "52220 butiksföreståndare", "freeTextFi": "kauppa", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "52230", "code": "52230", "labelFi": "Myyjät", "labelEn": "Shop sales assistants", "labelSv": "Försäljare", "searchFi": "52230 myyjät kauppa", "searchEn": "52230 shop sales assistants", "searchSv": "52230 försäljare", "freeTextFi": "kauppa", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "52300", "code": "52300", "labelFi": "Kassanhoitajat ja lipunmyyjät", "labelEn": "Cashiers and ticket clerks", "labelSv": "Butikskassörer, biljettförsäljare m.fl.", "searchFi": "52300 kassanhoitajat ja lipunmyyjät kauppa", "searchEn": "52300 cashiers and ticket clerks", "searchSv": "52300 butikskassörer, biljettförsäljare m.fl.", "freeTextFi": "kauppa", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "52410", "code": "52410", "labelFi": "Mallit", "labelEn": "Fashion and other models", "labelSv": "Modeller", "searchFi": "52410 mallit", "searchEn": "52410 fashion and other models", "searchSv": "52410 modeller", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "52420", "code": "52420", "labelFi": "Tuote-esittelijät", "labelEn": "Sales demonstrators", "labelSv": "Varudemonstratörer", "searchFi": "52420 tuote-esittelijät", "searchEn": "52420 sales demonstrators", "searchSv": "52420 varudemonstratörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "52430", "code": "52430", "labelFi": "Suoramyyjät", "labelEn": "Door to door salespersons", "labelSv": "Direktförsäljare", "searchFi": "52430 suoramyyjät", "searchEn": "52430 door to door salespersons", "searchSv": "52430 direktförsäljare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "52440", "code": "52440", "labelFi": "Puhelin- ja asiakaspalvelukeskusten myyjät", "labelEn": "Contact centre salespersons", "labelSv": "Försäljare, telefonförsäljning och kontaktcenter", "searchFi": "52440 puhelin- ja asiakaspalvelukeskusten myyjät", "searchEn": "52440 contact centre salespersons", "searchSv": "52440 försäljare, telefonförsäljning och kontaktcenter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "52450", "code": "52450", "labelFi": "Huoltamotyöntekijät", "labelEn": "Service station attendants", "labelSv": "Bensinstationspersonal", "searchFi": "52450 huoltamotyöntekijät", "searchEn": "52450 service station attendants", "searchSv": "52450 bensinstationspersonal", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "52460", "code": "52460", "labelFi": "Kahvila- ja baarimyyjät", "labelEn": "Food service counter attendants", "labelSv": "Försäljare, kaféer och barer", "searchFi": "52460 kahvila- ja baarimyyjät", "searchEn": "52460 food service counter attendants", "searchSv": "52460 försäljare, kaféer och barer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "52490", "code": "52490", "labelFi": "Muut muualla luokittelemattomat myyntityöntekijät", "labelEn": "Sales workers not elsewhere classified", "labelSv": "Övrig försäljningspersonal utan annan klassificering", "searchFi": "52490 muut muualla luokittelemattomat myyntityöntekijät", "searchEn": "52490 sales workers not elsewhere classified", "searchSv": "52490 övrig försäljningspersonal utan annan klassificering", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "53111", "code": "53111", "labelFi": "Päiväkotien ja muiden laitosten lastenhoitajat ym.", "labelEn": "Childminders in kindergartens and other institutions", "labelSv": "Barnskötare, daghem och andra institutioner m.fl.", "searchFi": "53111 päiväkotien ja muiden laitosten lastenhoitajat ym.", "searchEn": "53111 childminders in kindergartens and other institutions", "searchSv": "53111 barnskötare, daghem och andra institutioner m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "53112", "code": "53112", "labelFi": "Perhepäivähoitajat", "labelEn": "Private childminders", "labelSv": "Familjedagvårdare", "searchFi": "53112 perhepäivähoitajat lastenhoito", "searchEn": "53112 private childminders", "searchSv": "53112 familjedagvårdare", "freeTextFi": "lastenhoito", "freeTextEn": "", "freeTextSv": "", "keyword": "household" }, { "id": "53112-temp", "code": "53112", "labelFi": "Tilapäinen lastenhoito", "labelEn": "Tilapäinen lastenhoito EN", "labelSv": "Tilapäinen lastenhoito SV", "searchFi": "53112 tilapäinen lastenhoito mll", "searchEn": "53112 tilapäinen lastenhoito en", "searchSv": "53112 tilapäinen lastenhoito sv", "freeTextFi": "mll", "freeTextEn": "", "freeTextSv": "", "keyword": "household" }, { "id": "53113", "code": "53113", "labelFi": "Lastenkerhojen ohjaajat ym.", "labelEn": "Children's club leaders", "labelSv": "Barnklubbsledare m.fl.", "searchFi": "53113 lastenkerhojen ohjaajat ym.", "searchEn": "53113 children's club leaders", "searchSv": "53113 barnklubbsledare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "53120", "code": "53120", "labelFi": "Koulunkäyntiavustajat", "labelEn": "Teachers' aides", "labelSv": "Skolgångsbiträden", "searchFi": "53120 koulunkäyntiavustajat", "searchEn": "53120 teachers' aides", "searchSv": "53120 skolgångsbiträden", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "53211", "code": "53211", "labelFi": "Mielenterveyshoitajat", "labelEn": "Practical mental nurses", "labelSv": "Mentalhälsovårdare", "searchFi": "53211 mielenterveyshoitajat", "searchEn": "53211 practical mental nurses", "searchSv": "53211 mentalhälsovårdare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "53212", "code": "53212", "labelFi": "Kehitysvammaisten hoitajat", "labelEn": "Mental handicap nurses", "labelSv": "Vårdare av utvecklingshämmade", "searchFi": "53212 kehitysvammaisten hoitajat", "searchEn": "53212 mental handicap nurses", "searchSv": "53212 vårdare av utvecklingshämmade", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "household" }, { "id": "53213", "code": "53213", "labelFi": "Sosiaalialan hoitajat", "labelEn": "Social work assistants", "labelSv": "Vårdare inom socialsektorn", "searchFi": "53213 sosiaalialan hoitajat", "searchEn": "53213 social work assistants", "searchSv": "53213 vårdare inom socialsektorn", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "household" }, { "id": "53219", "code": "53219", "labelFi": "Muut lähihoitajat", "labelEn": "Other practical nurses", "labelSv": "Övriga närvårdare", "searchFi": "53219 muut lähihoitajat", "searchEn": "53219 other practical nurses", "searchSv": "53219 övriga närvårdare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "53221", "code": "53221", "labelFi": "Kotityöpalvelutyöntekijät", "labelEn": "Household service workers", "labelSv": "Hemvårdspersonal", "searchFi": "53221 kotityöpalvelutyöntekijät kodinhoitaja", "searchEn": "53221 household service workers", "searchSv": "53221 hemvårdspersonal", "freeTextFi": "kodinhoitaja", "freeTextEn": "", "freeTextSv": "", "keyword": "household" }, { "id": "53222", "code": "53222", "labelFi": "Henkilökohtaiset avustajat, omaishoitajat ym.", "labelEn": "Personal care workers, family carers, etc.", "labelSv": "Personliga assistenter, närståendevårdare m.fl.", "searchFi": "53222 henkilökohtaiset avustajat, omaishoitajat ym. kodinhoitaja", "searchEn": "53222 personal care workers, family carers, etc.", "searchSv": "53222 personliga assistenter, närståendevårdare m.fl.", "freeTextFi": "kodinhoitaja", "freeTextEn": "", "freeTextSv": "", "keyword": "household" }, { "id": "53291", "code": "53291", "labelFi": "Hammashoitajat", "labelEn": "Dental assistants", "labelSv": "Tandskötare", "searchFi": "53291 hammashoitajat", "searchEn": "53291 dental assistants", "searchSv": "53291 tandskötare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "53292", "code": "53292", "labelFi": "Välinehuoltajat", "labelEn": "Equipment maintenance assistants", "labelSv": "Instrumentvårdare", "searchFi": "53292 välinehuoltajat", "searchEn": "53292 equipment maintenance assistants", "searchSv": "53292 instrumentvårdare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "53293", "code": "53293", "labelFi": "Apteekkien lääketyöntekijät", "labelEn": "Pharmaceutical assistants", "labelSv": "Läkemedelsarbetare på apotek", "searchFi": "53293 apteekkien lääketyöntekijät", "searchEn": "53293 pharmaceutical assistants", "searchSv": "53293 läkemedelsarbetare på apotek", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "53294", "code": "53294", "labelFi": "Hierojat ja kuntohoitajat", "labelEn": "Massage therapists and practical rehabilitation nurses", "labelSv": "Massörer och konditionsskötare", "searchFi": "53294 hierojat ja kuntohoitajat", "searchEn": "53294 massage therapists and practical rehabilitation nurses", "searchSv": "53294 massörer och konditionsskötare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "54110", "code": "54110", "labelFi": "Palomiehet", "labelEn": "Fire-fighters", "labelSv": "Brandmän", "searchFi": "54110 palomiehet", "searchEn": "54110 fire-fighters", "searchSv": "54110 brandmän", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "54120", "code": "54120", "labelFi": "Poliisit", "labelEn": "Police officers", "labelSv": "Poliser", "searchFi": "54120 poliisit", "searchEn": "54120 police officers", "searchSv": "54120 poliser", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "54130", "code": "54130", "labelFi": "Vanginvartijat", "labelEn": "Prison guards", "labelSv": "Fångvaktare", "searchFi": "54130 vanginvartijat", "searchEn": "54130 prison guards", "searchSv": "54130 fångvaktare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "54140", "code": "54140", "labelFi": "Vartijat", "labelEn": "Security guards", "labelSv": "Väktare", "searchFi": "54140 vartijat", "searchEn": "54140 security guards", "searchSv": "54140 väktare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "54190", "code": "54190", "labelFi": "Muut suojelu- ja vartiointityöntekijät", "labelEn": "Protective services workers not elsewhere classified", "labelSv": "Övrig säkerhetspersonal", "searchFi": "54190 muut suojelu- ja vartiointityöntekijät", "searchEn": "54190 protective services workers not elsewhere classified", "searchSv": "54190 övrig säkerhetspersonal", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "61111", "code": "61111", "labelFi": "Peltoviljelijät", "labelEn": "Crop growers", "labelSv": "Åkerodlare", "searchFi": "61111 peltoviljelijät", "searchEn": "61111 crop growers", "searchSv": "61111 åkerodlare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "61112", "code": "61112", "labelFi": "Peltoviljelytyönjohtajat ja -työntekijät", "labelEn": "Field crop supervisors and workers", "labelSv": "Arbetsledare och arbetare inom åkerodling", "searchFi": "61112 peltoviljelytyönjohtajat ja -työntekijät", "searchEn": "61112 field crop supervisors and workers", "searchSv": "61112 arbetsledare och arbetare inom åkerodling", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "household" }, { "id": "61120", "code": "61120", "labelFi": "Hedelmäpuiden ja pensaiden yms. kasvattajat", "labelEn": "Tree and shrub crop growers", "labelSv": "Odlare av fruktträd och buskar m.fl.", "searchFi": "61120 hedelmäpuiden ja pensaiden yms. kasvattajat", "searchEn": "61120 tree and shrub crop growers", "searchSv": "61120 odlare av fruktträd och buskar m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "61131", "code": "61131", "labelFi": "Puutarhurit ja kasvihuoneviljelijät", "labelEn": "Gardeners, horticultural and nursery growers", "labelSv": "Trädgårds- och växthusodlare", "searchFi": "61131 puutarhurit ja kasvihuoneviljelijät", "searchEn": "61131 gardeners, horticultural and nursery growers", "searchSv": "61131 trädgårds- och växthusodlare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "61132", "code": "61132", "labelFi": "Puutarha- ja kasvihuonetyönjohtajat ja - työntekijät", "labelEn": "Gardeners, horticultural and nursery growers and workers", "labelSv": "Arbetsledare och anställda inom trädgårds- och växthusodling", "searchFi": "61132 puutarha- ja kasvihuonetyönjohtajat ja - työntekijät ruohonleikkuu", "searchEn": "61132 gardeners, horticultural and nursery growers and workers", "searchSv": "61132 arbetsledare och anställda inom trädgårds- och växthusodling", "freeTextFi": "ruohonleikkuu", "freeTextEn": "", "freeTextSv": "", "keyword": "household" }, { "id": "61140", "code": "61140", "labelFi": "Yhdistetyn maan- ja vihannesviljelyn tai puutarhanhoidon ym. harjoittajat", "labelEn": "Mixed crop growers", "labelSv": "Odlare av blandade växtslag", "searchFi": "61140 yhdistetyn maan- ja vihannesviljelyn tai puutarhanhoidon ym. harjoittajat", "searchEn": "61140 mixed crop growers", "searchSv": "61140 odlare av blandade växtslag", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "61211", "code": "61211", "labelFi": "Karjankasvattajat ym.", "labelEn": "Dairy and livestock producers", "labelSv": "Boskapsuppfödare m.fl.", "searchFi": "61211 karjankasvattajat ym.", "searchEn": "61211 dairy and livestock producers", "searchSv": "61211 boskapsuppfödare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "61212", "code": "61212", "labelFi": "Karjanhoitajat ym.", "labelEn": "Dairy and livestock workers", "labelSv": "Boskapsskötare m.fl.", "searchFi": "61212 karjanhoitajat ym.", "searchEn": "61212 dairy and livestock workers", "searchSv": "61212 boskapsskötare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "61213", "code": "61213", "labelFi": "Lemmikkieläinten kasvattajat", "labelEn": "Pet producers", "labelSv": "Sällskapsdjursuppfödare", "searchFi": "61213 lemmikkieläinten kasvattajat", "searchEn": "61213 pet producers", "searchSv": "61213 sällskapsdjursuppfödare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "61214", "code": "61214", "labelFi": "Maatalouslomittajat", "labelEn": "Farm relief workers", "labelSv": "Lantbruksavbytare", "searchFi": "61214 maatalouslomittajat", "searchEn": "61214 farm relief workers", "searchSv": "61214 lantbruksavbytare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "61220", "code": "61220", "labelFi": "Siipikarjankasvattajat", "labelEn": "Poultry producers", "labelSv": "Fjäderfäuppfödare", "searchFi": "61220 siipikarjankasvattajat", "searchEn": "61220 poultry producers", "searchSv": "61220 fjäderfäuppfödare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "61230", "code": "61230", "labelFi": "Mehiläistenhoitajat ym.", "labelEn": "Apiarists and sericulturists", "labelSv": "Biodlare m.fl.", "searchFi": "61230 mehiläistenhoitajat ym.", "searchEn": "61230 apiarists and sericulturists", "searchSv": "61230 biodlare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "61291", "code": "61291", "labelFi": "Turkiseläinten ja porojen kasvattajat", "labelEn": "Fur and reindeer producers", "labelSv": "Pälsdjurs- och renskötare", "searchFi": "61291 turkiseläinten ja porojen kasvattajat", "searchEn": "61291 fur and reindeer producers", "searchSv": "61291 pälsdjurs- och renskötare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "61299", "code": "61299", "labelFi": "Muualla luokittelemattomat eläintenhoitajat", "labelEn": "Animal workers not elsewhere classified", "labelSv": "Övriga djurskötare utan annan klassificering", "searchFi": "61299 muualla luokittelemattomat eläintenhoitajat", "searchEn": "61299 animal workers not elsewhere classified", "searchSv": "61299 övriga djurskötare utan annan klassificering", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "61300", "code": "61300", "labelFi": "Yhdistetyn maanviljelyn ja eläintenkasvatuksen harjoittajat", "labelEn": "Mixed crop and animal producers", "labelSv": "Växtodlare och djuruppfödare, blandad drift", "searchFi": "61300 yhdistetyn maanviljelyn ja eläintenkasvatuksen harjoittajat", "searchEn": "61300 mixed crop and animal producers", "searchSv": "61300 växtodlare och djuruppfödare, blandad drift", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "62100", "code": "62100", "labelFi": "Metsurit ja metsätyöntekijät", "labelEn": "Forestry and related workers", "labelSv": "Skogsbrukare och skogsarbetare", "searchFi": "62100 metsurit ja metsätyöntekijät", "searchEn": "62100 forestry and related workers", "searchSv": "62100 skogsbrukare och skogsarbetare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "household" }, { "id": "62211", "code": "62211", "labelFi": "Kalanviljely-yrittäjät", "labelEn": "Fish farmers", "labelSv": "Fiskodlingsföretagare", "searchFi": "62211 kalanviljely-yrittäjät", "searchEn": "62211 fish farmers", "searchSv": "62211 fiskodlingsföretagare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "62212", "code": "62212", "labelFi": "Kalanviljelytyönjohtajat ja -työntekijät", "labelEn": "Fishery supervisors and workers", "labelSv": "Arbetsledare och arbetare inom fiskodling", "searchFi": "62212 kalanviljelytyönjohtajat ja -työntekijät", "searchEn": "62212 fishery supervisors and workers", "searchSv": "62212 arbetsledare och arbetare inom fiskodling", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "62220", "code": "62220", "labelFi": "Kalastajat", "labelEn": "Inland and coastal waters fishery workers", "labelSv": "Fiskare", "searchFi": "62220 kalastajat", "searchEn": "62220 inland and coastal waters fishery workers", "searchSv": "62220 fiskare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "62240", "code": "62240", "labelFi": "Riistanhoitajat ja metsästäjät", "labelEn": "Hunters and trappers", "labelSv": "Viltvårdare och jägare", "searchFi": "62240 riistanhoitajat ja metsästäjät", "searchEn": "62240 hunters and trappers", "searchSv": "62240 viltvårdare och jägare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "71110", "code": "71110", "labelFi": "Talonrakentajat", "labelEn": "House builders", "labelSv": "Byggnadsarbetare", "searchFi": "71110 talonrakentajat rakennus remontti", "searchEn": "71110 house builders", "searchSv": "71110 byggnadsarbetare", "freeTextFi": "rakennus remontti", "freeTextEn": "", "freeTextSv": "", "keyword": "company household" }, { "id": "71120", "code": "71120", "labelFi": "Muurarit ym.", "labelEn": "Bricklayers and related workers", "labelSv": "Murare m.fl.", "searchFi": "71120 muurarit ym. rakennus remontti", "searchEn": "71120 bricklayers and related workers", "searchSv": "71120 murare m.fl.", "freeTextFi": "rakennus remontti", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "71130", "code": "71130", "labelFi": "Kivenhakkaajat ja -leikkaajat ym.", "labelEn": "Stonemasons, stone cutters, splitters and carvers", "labelSv": "Stenhuggare m.fl.", "searchFi": "71130 kivenhakkaajat ja -leikkaajat ym.", "searchEn": "71130 stonemasons, stone cutters, splitters and carvers", "searchSv": "71130 stenhuggare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "71140", "code": "71140", "labelFi": "Betonirakentajat ja raudoittajat", "labelEn": "Concrete placers, concrete finishers and related workers", "labelSv": "Betongarbetare och armerare", "searchFi": "71140 betonirakentajat ja raudoittajat rakennus remontti", "searchEn": "71140 concrete placers, concrete finishers and related workers", "searchSv": "71140 betongarbetare och armerare", "freeTextFi": "rakennus remontti", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "71150", "code": "71150", "labelFi": "Kirvesmiehet ja rakennuspuusepät", "labelEn": "Carpenters and joiners", "labelSv": "Timmermän och byggnadssnickare", "searchFi": "71150 kirvesmiehet ja rakennuspuusepät rakennus remontti", "searchEn": "71150 carpenters and joiners", "searchSv": "71150 timmermän och byggnadssnickare", "freeTextFi": "rakennus remontti", "freeTextEn": "", "freeTextSv": "", "keyword": "company household" }, { "id": "71190", "code": "71190", "labelFi": "Muut rakennustyöntekijät", "labelEn": "Building frame and related trades workers not elsewhere classified", "labelSv": "Övriga byggnadsarbetare", "searchFi": "71190 muut rakennustyöntekijät rakennus remontti", "searchEn": "71190 building frame and related trades workers not elsewhere classified", "searchSv": "71190 övriga byggnadsarbetare", "freeTextFi": "rakennus remontti", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "71210", "code": "71210", "labelFi": "Kattoasentajat ja -korjaajat", "labelEn": "Roofers", "labelSv": "Takmontörer och takreparatörer", "searchFi": "71210 kattoasentajat ja -korjaajat rakennus remontti", "searchEn": "71210 roofers", "searchSv": "71210 takmontörer och takreparatörer", "freeTextFi": "rakennus remontti", "freeTextEn": "", "freeTextSv": "", "keyword": "household" }, { "id": "71220", "code": "71220", "labelFi": "Lattianpäällystystyöntekijät", "labelEn": "Floor layers and tile setters", "labelSv": "Golvläggare", "searchFi": "71220 lattianpäällystystyöntekijät rakennus remontti", "searchEn": "71220 floor layers and tile setters", "searchSv": "71220 golvläggare", "freeTextFi": "rakennus remontti", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "71230", "code": "71230", "labelFi": "Rappaajat", "labelEn": "Plasterers", "labelSv": "Rappare", "searchFi": "71230 rappaajat rakennus remontti", "searchEn": "71230 plasterers", "searchSv": "71230 rappare", "freeTextFi": "rakennus remontti", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "71240", "code": "71240", "labelFi": "Eristäjät", "labelEn": "Insulation workers", "labelSv": "Isoleringsmontörer", "searchFi": "71240 eristäjät rakennus remontti", "searchEn": "71240 insulation workers", "searchSv": "71240 isoleringsmontörer", "freeTextFi": "rakennus remontti", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "71250", "code": "71250", "labelFi": "Lasinasentajat", "labelEn": "Glaziers", "labelSv": "Glasmästare", "searchFi": "71250 lasinasentajat rakennus remontti", "searchEn": "71250 glaziers", "searchSv": "71250 glasmästare", "freeTextFi": "rakennus remontti", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "71260", "code": "71260", "labelFi": "Putkiasentajat", "labelEn": "Plumbers and pipe fitters", "labelSv": "Rörläggare", "searchFi": "71260 putkiasentajat rakennus remontti", "searchEn": "71260 plumbers and pipe fitters", "searchSv": "71260 rörläggare", "freeTextFi": "rakennus remontti", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "71270", "code": "71270", "labelFi": "Ilmastointi- ja jäähdytyslaiteasentajat", "labelEn": "Air conditioning and refrigeration mechanics", "labelSv": "Ventilations- och kylmontörer", "searchFi": "71270 ilmastointi- ja jäähdytyslaiteasentajat", "searchEn": "71270 air conditioning and refrigeration mechanics", "searchSv": "71270 ventilations- och kylmontörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "71310", "code": "71310", "labelFi": "Rakennusmaalarit ym.", "labelEn": "Painters and related workers", "labelSv": "Byggnadsmålare m.fl.", "searchFi": "71310 rakennusmaalarit ym. rakennus remontti", "searchEn": "71310 painters and related workers", "searchSv": "71310 byggnadsmålare m.fl.", "freeTextFi": "rakennus remontti", "freeTextEn": "", "freeTextSv": "", "keyword": "household" }, { "id": "71320", "code": "71320", "labelFi": "Ruiskumaalaajat ja -lakkaajat", "labelEn": "Spray painters and varnishers", "labelSv": "Sprutlackerare", "searchFi": "71320 ruiskumaalaajat ja -lakkaajat", "searchEn": "71320 spray painters and varnishers", "searchSv": "71320 sprutlackerare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "71330", "code": "71330", "labelFi": "Rakennuspuhdistajat ja nuohoojat", "labelEn": "Building structure cleaners", "labelSv": "Saneringsarbetare och sotare", "searchFi": "71330 rakennuspuhdistajat ja nuohoojat", "searchEn": "71330 building structure cleaners", "searchSv": "71330 saneringsarbetare och sotare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "72110", "code": "72110", "labelFi": "Muotin- ja keernantekijät", "labelEn": "Metal moulders and coremakers", "labelSv": "Formare och kärnmakare", "searchFi": "72110 muotin- ja keernantekijät", "searchEn": "72110 metal moulders and coremakers", "searchSv": "72110 formare och kärnmakare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "72120", "code": "72120", "labelFi": "Hitsaajat ja kaasuleikkaajat", "labelEn": "Welders and flamecutters", "labelSv": "Svetsare och gasskärare", "searchFi": "72120 hitsaajat ja kaasuleikkaajat", "searchEn": "72120 welders and flamecutters", "searchSv": "72120 svetsare och gasskärare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "72130", "code": "72130", "labelFi": "Ohutlevysepät", "labelEn": "Sheet-metal workers", "labelSv": "Tunnplåtslagare", "searchFi": "72130 ohutlevysepät", "searchEn": "72130 sheet-metal workers", "searchSv": "72130 tunnplåtslagare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "72140", "code": "72140", "labelFi": "Paksulevysepät ja rautarakennetyöntekijät", "labelEn": "Structural-metal preparers and erectors", "labelSv": "Grovplåtslagare och stålkonstruktionsmontörer", "searchFi": "72140 paksulevysepät ja rautarakennetyöntekijät", "searchEn": "72140 structural-metal preparers and erectors", "searchSv": "72140 grovplåtslagare och stålkonstruktionsmontörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "72150", "code": "72150", "labelFi": "Kaapelin- ja köysienasentajat", "labelEn": "Riggers and cable splicers", "labelSv": "Kabelläggare och riggare", "searchFi": "72150 kaapelin- ja köysienasentajat", "searchEn": "72150 riggers and cable splicers", "searchSv": "72150 kabelläggare och riggare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "72210", "code": "72210", "labelFi": "Sepät", "labelEn": "Blacksmiths, hammersmiths and forging press workers", "labelSv": "Smeder", "searchFi": "72210 sepät", "searchEn": "72210 blacksmiths, hammersmiths and forging press workers", "searchSv": "72210 smeder", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "72220", "code": "72220", "labelFi": "Työkaluntekijät ja lukkosepät", "labelEn": "Toolmakers and related workers", "labelSv": "Verktygsmakare och låssmeder", "searchFi": "72220 työkaluntekijät ja lukkosepät", "searchEn": "72220 toolmakers and related workers", "searchSv": "72220 verktygsmakare och låssmeder", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "72230", "code": "72230", "labelFi": "Koneenasettajat ja koneistajat", "labelEn": "Metal working machine tool setters and operators", "labelSv": "Maskinställare och verkstadsmekaniker", "searchFi": "72230 koneenasettajat ja koneistajat", "searchEn": "72230 metal working machine tool setters and operators", "searchSv": "72230 maskinställare och verkstadsmekaniker", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "72240", "code": "72240", "labelFi": "Konehiojat, kiillottajat ja teroittajat", "labelEn": "Metal polishers, wheel grinders and tool sharpeners", "labelSv": "Maskinslipare, -polerare och -vässare", "searchFi": "72240 konehiojat, kiillottajat ja teroittajat", "searchEn": "72240 metal polishers, wheel grinders and tool sharpeners", "searchSv": "72240 maskinslipare, -polerare och -vässare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "72310", "code": "72310", "labelFi": "Moottoriajoneuvojen asentajat ja korjaajat", "labelEn": "Motor vehicle mechanics and repairers", "labelSv": "Motorfordonsmontörer och -reparatörer", "searchFi": "72310 moottoriajoneuvojen asentajat ja korjaajat korjaamo auto", "searchEn": "72310 motor vehicle mechanics and repairers", "searchSv": "72310 motorfordonsmontörer och -reparatörer", "freeTextFi": "korjaamo auto", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "72320", "code": "72320", "labelFi": "Lentokoneasentajat ja -korjaajat", "labelEn": "Aircraft engine mechanics and repairers", "labelSv": "Flygmontörer och flygreparatörer", "searchFi": "72320 lentokoneasentajat ja -korjaajat", "searchEn": "72320 aircraft engine mechanics and repairers", "searchSv": "72320 flygmontörer och flygreparatörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "72330", "code": "72330", "labelFi": "Maatalous- ja teollisuuskoneasentajat ja -korjaajat", "labelEn": "Agricultural and industrial machinery mechanics and repairers", "labelSv": "Maskinmontörer och -reparatörer (jordbruks- och industrimaskiner)", "searchFi": "72330 maatalous- ja teollisuuskoneasentajat ja -korjaajat", "searchEn": "72330 agricultural and industrial machinery mechanics and repairers", "searchSv": "72330 maskinmontörer och -reparatörer (jordbruks- och industrimaskiner)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "72340", "code": "72340", "labelFi": "Polkupyöränkorjaajat ym.", "labelEn": "Bicycle and related repairers", "labelSv": "Cykelreparatörer m.fl.", "searchFi": "72340 polkupyöränkorjaajat ym.", "searchEn": "72340 bicycle and related repairers", "searchSv": "72340 cykelreparatörer m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "73110", "code": "73110", "labelFi": "Kellosepät ja muut hienomekaanisten instrumenttien tekijät ja korjaajat", "labelEn": "Precision-instrument makers and repairers", "labelSv": "Urmakare och övriga tillverkare av finmekaniska instrument", "searchFi": "73110 kellosepät ja muut hienomekaanisten instrumenttien tekijät ja korjaajat", "searchEn": "73110 precision-instrument makers and repairers", "searchSv": "73110 urmakare och övriga tillverkare av finmekaniska instrument", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "73120", "code": "73120", "labelFi": "Soittimien tekijät ja virittäjät", "labelEn": "Musical instrument makers and tuners", "labelSv": "Musikinstrumentmakare och -stämmare", "searchFi": "73120 soittimien tekijät ja virittäjät", "searchEn": "73120 musical instrument makers and tuners", "searchSv": "73120 musikinstrumentmakare och -stämmare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "73130", "code": "73130", "labelFi": "Koru-, kulta- ja hopeasepät", "labelEn": "Jewellery and precious-metal workers", "labelSv": "Juvel-, guld- och silversmeder", "searchFi": "73130 koru-, kulta- ja hopeasepät", "searchEn": "73130 jewellery and precious-metal workers", "searchSv": "73130 juvel-, guld- och silversmeder", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "73140", "code": "73140", "labelFi": "Saven- ja tiilenvalajat ja dreijaajat", "labelEn": "Potters and related workers", "labelSv": "Ler- och tegelgjutare, drejare", "searchFi": "73140 saven- ja tiilenvalajat ja dreijaajat", "searchEn": "73140 potters and related workers", "searchSv": "73140 ler- och tegelgjutare, drejare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "73150", "code": "73150", "labelFi": "Lasinpuhaltajat, -leikkaajat, -hiojat ja -viimeistelijät", "labelEn": "Glass makers, cutters, grinders and finishers", "labelSv": "Glasblåsare, -skärare, -slipare och -efterbehandlare", "searchFi": "73150 lasinpuhaltajat, -leikkaajat, -hiojat ja -viimeistelijät", "searchEn": "73150 glass makers, cutters, grinders and finishers", "searchSv": "73150 glasblåsare, -skärare, -slipare och -efterbehandlare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "73160", "code": "73160", "labelFi": "Kaivertajat, etsaajat ja koristemaalarit", "labelEn": "Sign writers, decorative painters, engravers and etchers", "labelSv": "Glasgravörer, glasetsare och skyltmålare", "searchFi": "73160 kaivertajat, etsaajat ja koristemaalarit", "searchEn": "73160 sign writers, decorative painters, engravers and etchers", "searchSv": "73160 glasgravörer, glasetsare och skyltmålare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "73170", "code": "73170", "labelFi": "Puu-, kori- yms. käsityötuotteiden tekijät", "labelEn": "Handicraft workers in wood, basketry and related materials", "labelSv": "Konsthantverkare i trä m.m.", "searchFi": "73170 puu-, kori- yms. käsityötuotteiden tekijät", "searchEn": "73170 handicraft workers in wood, basketry and related materials", "searchSv": "73170 konsthantverkare i trä m.m.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "73180", "code": "73180", "labelFi": "Tekstiili-, nahka- yms. käsityötuotteiden tekijät", "labelEn": "Handicraft workers in textile, leather and related materials", "labelSv": "Konsthantverkare i textil, läder m.m.", "searchFi": "73180 tekstiili-, nahka- yms. käsityötuotteiden tekijät", "searchEn": "73180 handicraft workers in textile, leather and related materials", "searchSv": "73180 konsthantverkare i textil, läder m.m.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "73190", "code": "73190", "labelFi": "Muut käsityöntekijät", "labelEn": "Handicraft workers not elsewhere classified", "labelSv": "Övriga konsthantverkare", "searchFi": "73190 muut käsityöntekijät", "searchEn": "73190 handicraft workers not elsewhere classified", "searchSv": "73190 övriga konsthantverkare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "73210", "code": "73210", "labelFi": "Painopinnanvalmistajat", "labelEn": "Pre-press technicians", "labelSv": "Prepressoperatörer", "searchFi": "73210 painopinnanvalmistajat", "searchEn": "73210 pre-press technicians", "searchSv": "73210 prepressoperatörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "73220", "code": "73220", "labelFi": "Painajat", "labelEn": "Printers", "labelSv": "Tryckare", "searchFi": "73220 painajat", "searchEn": "73220 printers", "searchSv": "73220 tryckare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "73230", "code": "73230", "labelFi": "Jälkikäsittelijät ja sitomotyöntekijät", "labelEn": "Print finishing and binding workers", "labelSv": "Efterbehandlare och bokbinderiarbetare", "searchFi": "73230 jälkikäsittelijät ja sitomotyöntekijät", "searchEn": "73230 print finishing and binding workers", "searchSv": "73230 efterbehandlare och bokbinderiarbetare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "74110", "code": "74110", "labelFi": "Rakennussähköasentajat", "labelEn": "Building and related electricians", "labelSv": "Byggnadselmontörer", "searchFi": "74110 rakennussähköasentajat", "searchEn": "74110 building and related electricians", "searchSv": "74110 byggnadselmontörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "74120", "code": "74120", "labelFi": "Muut sähköasentajat", "labelEn": "Electrical mechanics and fitters", "labelSv": "Övriga elmontörer", "searchFi": "74120 muut sähköasentajat", "searchEn": "74120 electrical mechanics and fitters", "searchSv": "74120 övriga elmontörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "74130", "code": "74130", "labelFi": "Linja-asentajat ja -korjaajat", "labelEn": "Electrical line installers and repairers", "labelSv": "Linjemontörer och -reparatörer", "searchFi": "74130 linja-asentajat ja -korjaajat", "searchEn": "74130 electrical line installers and repairers", "searchSv": "74130 linjemontörer och -reparatörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "74211", "code": "74211", "labelFi": "Elektroniikka-asentajat ja -korjaajat", "labelEn": "Electronics installers and repairers", "labelSv": "Elektronikmontörer och -reparatörer", "searchFi": "74211 elektroniikka-asentajat ja -korjaajat tietokone kodinkone", "searchEn": "74211 electronics installers and repairers", "searchSv": "74211 elektronikmontörer och -reparatörer", "freeTextFi": "tietokone kodinkone", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "74212", "code": "74212", "labelFi": "Automaatioasentajat ja -korjaajat", "labelEn": "Automation installers and repairers", "labelSv": "Automationsmontörer och -reparatörer", "searchFi": "74212 automaatioasentajat ja -korjaajat", "searchEn": "74212 automation installers and repairers", "searchSv": "74212 automationsmontörer och -reparatörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "74220", "code": "74220", "labelFi": "Tieto- ja viestintäteknologian asentajat ja korjaajat", "labelEn": "Information and communications technology installers and servicers", "labelSv": "Montörer och reparatörer, IKT", "searchFi": "74220 tieto- ja viestintäteknologian asentajat ja korjaajat tietokone kodinkone", "searchEn": "74220 information and communications technology installers and servicers", "searchSv": "74220 montörer och reparatörer, ikt", "freeTextFi": "tietokone kodinkone", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75110", "code": "75110", "labelFi": "Lihanleikkaajat, kalankäsittelijät ym.", "labelEn": "Butchers, fishmongers and related food preparers", "labelSv": "Slaktare, fiskberedare m.fl.", "searchFi": "75110 lihanleikkaajat, kalankäsittelijät ym.", "searchEn": "75110 butchers, fishmongers and related food preparers", "searchSv": "75110 slaktare, fiskberedare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75120", "code": "75120", "labelFi": "Leipurit ja kondiittorit", "labelEn": "Bakers, pastry-cooks and confectionery makers", "labelSv": "Bagare och konditorer", "searchFi": "75120 leipurit ja kondiittorit", "searchEn": "75120 bakers, pastry-cooks and confectionery makers", "searchSv": "75120 bagare och konditorer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75130", "code": "75130", "labelFi": "Meijeristit, juustomestarit ym.", "labelEn": "Dairy-products makers", "labelSv": "Mejerister, ostmästare m.fl.", "searchFi": "75130 meijeristit, juustomestarit ym.", "searchEn": "75130 dairy-products makers", "searchSv": "75130 mejerister, ostmästare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75140", "code": "75140", "labelFi": "Hedelmä- ja vihannestuotteiden valmistajat", "labelEn": "Fruit, vegetable and related preservers", "labelSv": "Tillverkare av frukt- och grönsaksprodukter", "searchFi": "75140 hedelmä- ja vihannestuotteiden valmistajat", "searchEn": "75140 fruit, vegetable and related preservers", "searchSv": "75140 tillverkare av frukt- och grönsaksprodukter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75150", "code": "75150", "labelFi": "Ruokien ja juomien laaduntarkkailijat", "labelEn": "Food and beverage tasters and graders", "labelSv": "Kvalitetsbedömare (mat och dryck)", "searchFi": "75150 ruokien ja juomien laaduntarkkailijat", "searchEn": "75150 food and beverage tasters and graders", "searchSv": "75150 kvalitetsbedömare (mat och dryck)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75160", "code": "75160", "labelFi": "Tupakkatuotteiden valmistajat", "labelEn": "Tobacco preparers and tobacco products makers", "labelSv": "Tillverkare av tobaksprodukter", "searchFi": "75160 tupakkatuotteiden valmistajat", "searchEn": "75160 tobacco preparers and tobacco products makers", "searchSv": "75160 tillverkare av tobaksprodukter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75210", "code": "75210", "labelFi": "Raakapuun käsittelijät", "labelEn": "Wood treaters", "labelSv": "Trävaruhanterare", "searchFi": "75210 raakapuun käsittelijät", "searchEn": "75210 wood treaters", "searchSv": "75210 trävaruhanterare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75220", "code": "75220", "labelFi": "Huonekalupuusepät ym.", "labelEn": "Cabinet-makers and related workers", "labelSv": "Möbelsnickare m.fl.", "searchFi": "75220 huonekalupuusepät ym.", "searchEn": "75220 cabinet-makers and related workers", "searchSv": "75220 möbelsnickare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75230", "code": "75230", "labelFi": "Konepuusepät", "labelEn": "Woodworking-machine tool setters and operators", "labelSv": "Maskinsnickare", "searchFi": "75230 konepuusepät", "searchEn": "75230 woodworking-machine tool setters and operators", "searchSv": "75230 maskinsnickare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75310", "code": "75310", "labelFi": "Vaatturit, pukuompelijat, turkkurit ja hatuntekijät", "labelEn": "Tailors, dressmakers, furriers and hatters", "labelSv": "Skräddare, ateljésömmerskor, körsnärer och modister", "searchFi": "75310 vaatturit, pukuompelijat, turkkurit ja hatuntekijät", "searchEn": "75310 tailors, dressmakers, furriers and hatters", "searchSv": "75310 skräddare, ateljésömmerskor, körsnärer och modister", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75320", "code": "75320", "labelFi": "Leikkaajat ja mallimestarit", "labelEn": "Garment and related pattern-makers and cutters", "labelSv": "Tillskärare och modellmästare", "searchFi": "75320 leikkaajat ja mallimestarit", "searchEn": "75320 garment and related pattern-makers and cutters", "searchSv": "75320 tillskärare och modellmästare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75330", "code": "75330", "labelFi": "Koru- ja muut tekstiiliompelijat", "labelEn": "Sewing, embroidery and related workers", "labelSv": "Broderare och andra textilsömmare", "searchFi": "75330 koru- ja muut tekstiiliompelijat", "searchEn": "75330 sewing, embroidery and related workers", "searchSv": "75330 broderare och andra textilsömmare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75340", "code": "75340", "labelFi": "Verhoilijat", "labelEn": "Upholsterers and related workers", "labelSv": "Tapetserare", "searchFi": "75340 verhoilijat", "searchEn": "75340 upholsterers and related workers", "searchSv": "75340 tapetserare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75350", "code": "75350", "labelFi": "Turkisten muokkaajat ja nahkurit", "labelEn": "Pelt dressers, tanners and fellmongers", "labelSv": "Garvare och skinnberedare", "searchFi": "75350 turkisten muokkaajat ja nahkurit", "searchEn": "75350 pelt dressers, tanners and fellmongers", "searchSv": "75350 garvare och skinnberedare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75360", "code": "75360", "labelFi": "Suutarit ym.", "labelEn": "Shoemakers and related workers", "labelSv": "Skomakare m.fl.", "searchFi": "75360 suutarit ym.", "searchEn": "75360 shoemakers and related workers", "searchSv": "75360 skomakare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75410", "code": "75410", "labelFi": "Vedenalaistyöntekijät", "labelEn": "Underwater divers", "labelSv": "Dykare", "searchFi": "75410 vedenalaistyöntekijät", "searchEn": "75410 underwater divers", "searchSv": "75410 dykare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75420", "code": "75420", "labelFi": "Panostajat ja räjäyttäjät", "labelEn": "Shotfirers and blasters", "labelSv": "Laddare och sprängare", "searchFi": "75420 panostajat ja räjäyttäjät", "searchEn": "75420 shotfirers and blasters", "searchSv": "75420 laddare och sprängare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75430", "code": "75430", "labelFi": "Luokittelijat ja laaduntarkkailijat (pl. ruoat ja juomat)", "labelEn": "Product graders and testers (excluding foods and beverages)", "labelSv": "Klassificerare och kvalitetskontrollanter (utom drycker och livsmedel)", "searchFi": "75430 luokittelijat ja laaduntarkkailijat (pl. ruoat ja juomat)", "searchEn": "75430 product graders and testers (excluding foods and beverages)", "searchSv": "75430 klassificerare och kvalitetskontrollanter (utom drycker och livsmedel)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75440", "code": "75440", "labelFi": "Savupuhdistajat, tuholais- ja rikkakasvintorjujat", "labelEn": "Fumigators and other pest and weed controllers", "labelSv": "Röksanerare, skadedjurs- och ogrässanerare", "searchFi": "75440 savupuhdistajat, tuholais- ja rikkakasvintorjujat", "searchEn": "75440 fumigators and other pest and weed controllers", "searchSv": "75440 röksanerare, skadedjurs- och ogrässanerare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "75490", "code": "75490", "labelFi": "Muut pääluokkaan 7 muualla luokittelemattomat työntekijät", "labelEn": "Craft and related workers not elsewhere classified", "labelSv": "Övrig personal, oklassificerad under andra moment i huvudgrupp 7", "searchFi": "75490 muut pääluokkaan 7 muualla luokittelemattomat työntekijät", "searchEn": "75490 craft and related workers not elsewhere classified", "searchSv": "75490 övrig personal, oklassificerad under andra moment i huvudgrupp 7", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81110", "code": "81110", "labelFi": "Kaivos- ja louhostyöntekijät", "labelEn": "Miners and quarriers", "labelSv": "Gruv- och stenbrottsarbetare", "searchFi": "81110 kaivos- ja louhostyöntekijät", "searchEn": "81110 miners and quarriers", "searchSv": "81110 gruv- och stenbrottsarbetare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81120", "code": "81120", "labelFi": "Rikastustyöntekijät", "labelEn": "Mineral and stone processing plant operators", "labelSv": "Anrikningsarbetare", "searchFi": "81120 rikastustyöntekijät", "searchEn": "81120 mineral and stone processing plant operators", "searchSv": "81120 anrikningsarbetare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81130", "code": "81130", "labelFi": "Iskuporaajat ja syväkairaajat", "labelEn": "Well drillers and borers and related workers", "labelSv": "Slagborrare och djupborrare", "searchFi": "81130 iskuporaajat ja syväkairaajat", "searchEn": "81130 well drillers and borers and related workers", "searchSv": "81130 slagborrare och djupborrare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81140", "code": "81140", "labelFi": "Betonituote- ym. teollisuuden prosessityöntekijät", "labelEn": "Cement, stone and other mineral products machine operators", "labelSv": "Processoperatörer inom betongindustri m.fl.", "searchFi": "81140 betonituote- ym. teollisuuden prosessityöntekijät", "searchEn": "81140 cement, stone and other mineral products machine operators", "searchSv": "81140 processoperatörer inom betongindustri m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81210", "code": "81210", "labelFi": "Metalliteollisuuden prosessityöntekijät", "labelEn": "Metal processing plant operators", "labelSv": "Processoperatörer inom metallindustri", "searchFi": "81210 metalliteollisuuden prosessityöntekijät", "searchEn": "81210 metal processing plant operators", "searchSv": "81210 processoperatörer inom metallindustri", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81220", "code": "81220", "labelFi": "Metallien teolliset päällystäjät ja viimeistelijät", "labelEn": "Metal finishing, plating and coating machine operators", "labelSv": "Ytbeläggare och efterbehandlare inom metallindustri", "searchFi": "81220 metallien teolliset päällystäjät ja viimeistelijät", "searchEn": "81220 metal finishing, plating and coating machine operators", "searchSv": "81220 ytbeläggare och efterbehandlare inom metallindustri", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81310", "code": "81310", "labelFi": "Kemianteollisuuden prosessityöntekijät ym.", "labelEn": "Chemical products plant and machine operators", "labelSv": "Processoperatörer, kemisk industri m.fl.", "searchFi": "81310 kemianteollisuuden prosessityöntekijät ym.", "searchEn": "81310 chemical products plant and machine operators", "searchSv": "81310 processoperatörer, kemisk industri m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81320", "code": "81320", "labelFi": "Valokuvatuotteiden valmistuksen prosessityöntekijät", "labelEn": "Photographic products machine operators", "labelSv": "Processoperatörer, fotografiska produkter", "searchFi": "81320 valokuvatuotteiden valmistuksen prosessityöntekijät", "searchEn": "81320 photographic products machine operators", "searchSv": "81320 processoperatörer, fotografiska produkter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81410", "code": "81410", "labelFi": "Kumituoteteollisuuden prosessityöntekijät", "labelEn": "Rubber products machine operators", "labelSv": "Processoperatörer, gummiindustri", "searchFi": "81410 kumituoteteollisuuden prosessityöntekijät", "searchEn": "81410 rubber products machine operators", "searchSv": "81410 processoperatörer, gummiindustri", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81420", "code": "81420", "labelFi": "Muovituoteteollisuuden prosessityöntekijät", "labelEn": "Plastic products machine operators", "labelSv": "Processoperatörer, plastindustri", "searchFi": "81420 muovituoteteollisuuden prosessityöntekijät", "searchEn": "81420 plastic products machine operators", "searchSv": "81420 processoperatörer, plastindustri", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81430", "code": "81430", "labelFi": "Paperituoteteollisuuden prosessityöntekijät", "labelEn": "Paper products machine operators", "labelSv": "Processoperatörer, pappersvaruindustri", "searchFi": "81430 paperituoteteollisuuden prosessityöntekijät", "searchEn": "81430 paper products machine operators", "searchSv": "81430 processoperatörer, pappersvaruindustri", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81510", "code": "81510", "labelFi": "Kuitujenkäsittely-, kehruu- ja puolauskoneiden hoitajat", "labelEn": "Fibre preparing, spinning and winding machine operators", "labelSv": "Maskinoperatörer, fibertillverkning, spinning och spolning", "searchFi": "81510 kuitujenkäsittely-, kehruu- ja puolauskoneiden hoitajat", "searchEn": "81510 fibre preparing, spinning and winding machine operators", "searchSv": "81510 maskinoperatörer, fibertillverkning, spinning och spolning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81520", "code": "81520", "labelFi": "Kutoma- ja neulekoneiden hoitajat", "labelEn": "Weaving and knitting machine operators", "labelSv": "Maskinoperatörer, vävning och stickning", "searchFi": "81520 kutoma- ja neulekoneiden hoitajat", "searchEn": "81520 weaving and knitting machine operators", "searchSv": "81520 maskinoperatörer, vävning och stickning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81530", "code": "81530", "labelFi": "Teollisuusompelijat", "labelEn": "Sewing machine operators", "labelSv": "Symaskinsoperatörer", "searchFi": "81530 teollisuusompelijat", "searchEn": "81530 sewing machine operators", "searchSv": "81530 symaskinsoperatörer", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81540", "code": "81540", "labelFi": "Valkaisu-, värjäys- ja puhdistuskoneiden hoitajat", "labelEn": "Bleaching, dyeing and fabric cleaning machine operators", "labelSv": "Maskinoperatörer, tvättning, blekning och färgning", "searchFi": "81540 valkaisu-, värjäys- ja puhdistuskoneiden hoitajat", "searchEn": "81540 bleaching, dyeing and fabric cleaning machine operators", "searchSv": "81540 maskinoperatörer, tvättning, blekning och färgning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81550", "code": "81550", "labelFi": "Turkisten ja nahkojen teolliset käsittelijät, värjääjät ym.", "labelEn": "Fur and leather preparing machine operators", "labelSv": "Maskinoperatörer, pälsskinnsberedning, färgning", "searchFi": "81550 turkisten ja nahkojen teolliset käsittelijät, värjääjät ym.", "searchEn": "81550 fur and leather preparing machine operators", "searchSv": "81550 maskinoperatörer, pälsskinnsberedning, färgning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81560", "code": "81560", "labelFi": "Jalkine- ja laukkuteollisuuden prosessityöntekijät", "labelEn": "Shoemaking and related machine operators", "labelSv": "Processoperatörer, sko- och väskindustri", "searchFi": "81560 jalkine- ja laukkuteollisuuden prosessityöntekijät", "searchEn": "81560 shoemaking and related machine operators", "searchSv": "81560 processoperatörer, sko- och väskindustri", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81570", "code": "81570", "labelFi": "Pesulatyöntekijät", "labelEn": "Laundry machine operators", "labelSv": "Tvätteripersonal", "searchFi": "81570 pesulatyöntekijät", "searchEn": "81570 laundry machine operators", "searchSv": "81570 tvätteripersonal", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81590", "code": "81590", "labelFi": "Muut tekstiili-, turkis- ja nahkatuoteteollisuuden prosessityöntekijät", "labelEn": "Textile, fur and leather products machine operators not elsewhere classified", "labelSv": "Övriga processoperatörer inom textil-, skinn- och läderindustri", "searchFi": "81590 muut tekstiili-, turkis- ja nahkatuoteteollisuuden prosessityöntekijät", "searchEn": "81590 textile, fur and leather products machine operators not elsewhere classified", "searchSv": "81590 övriga processoperatörer inom textil-, skinn- och läderindustri", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81600", "code": "81600", "labelFi": "Elintarviketeollisuuden prosessityöntekijät", "labelEn": "Food and related products machine operators", "labelSv": "Processoperatörer, livsmedelsindustri", "searchFi": "81600 elintarviketeollisuuden prosessityöntekijät", "searchEn": "81600 food and related products machine operators", "searchSv": "81600 processoperatörer, livsmedelsindustri", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81710", "code": "81710", "labelFi": "Paperimassan sekä paperin ja kartongin valmistuksen prosessityöntekijät", "labelEn": "Pulp and papermaking plant operators", "labelSv": "Processoperatörer, pappers-, kartong- och massaindustri", "searchFi": "81710 paperimassan sekä paperin ja kartongin valmistuksen prosessityöntekijät", "searchEn": "81710 pulp and papermaking plant operators", "searchSv": "81710 processoperatörer, pappers-, kartong- och massaindustri", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81720", "code": "81720", "labelFi": "Puu- ja sahatavaran prosessityöntekijät", "labelEn": "Wood processing plant operators", "labelSv": "Processoperatörer, trä- och sågvaror", "searchFi": "81720 puu- ja sahatavaran prosessityöntekijät", "searchEn": "81720 wood processing plant operators", "searchSv": "81720 processoperatörer, trä- och sågvaror", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81810", "code": "81810", "labelFi": "Lasi- ja keramiikkateollisuuden uunienhoitajat", "labelEn": "Glass and ceramics plant operators", "labelSv": "Ugnsoperatörer, glas- och keramikindustri", "searchFi": "81810 lasi- ja keramiikkateollisuuden uunienhoitajat", "searchEn": "81810 glass and ceramics plant operators", "searchSv": "81810 ugnsoperatörer, glas- och keramikindustri", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81821", "code": "81821", "labelFi": "Voima- ja jätteenkäsittelylaitosten laitosmiehet", "labelEn": "Power-production and waste treatment plant workers", "labelSv": "Maskinreparatörer, kraftverk och avfallsbehandlingsanläggningar", "searchFi": "81821 voima- ja jätteenkäsittelylaitosten laitosmiehet", "searchEn": "81821 power-production and waste treatment plant workers", "searchSv": "81821 maskinreparatörer, kraftverk och avfallsbehandlingsanläggningar", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81822", "code": "81822", "labelFi": "Muut laitosmiehet ym.", "labelEn": "Other plant workers, etc.", "labelSv": "Övriga maskinreparatörer m.fl.", "searchFi": "81822 muut laitosmiehet ym.", "searchEn": "81822 other plant workers, etc.", "searchSv": "81822 övriga maskinreparatörer m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81830", "code": "81830", "labelFi": "Pakkaus-, pullotus- ja etiköintikoneiden hoitajat", "labelEn": "Packing, bottling and labelling machine operators", "labelSv": "Maskinoperatörer, packning, påfyllning och märkning", "searchFi": "81830 pakkaus-, pullotus- ja etiköintikoneiden hoitajat", "searchEn": "81830 packing, bottling and labelling machine operators", "searchSv": "81830 maskinoperatörer, packning, påfyllning och märkning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "81890", "code": "81890", "labelFi": "Muut muualla luokittelemattomat prosessityöntekijät", "labelEn": "Stationary plant and machine operators not elsewhere classified", "labelSv": "Övriga processoperatörer utan annan klassificering", "searchFi": "81890 muut muualla luokittelemattomat prosessityöntekijät", "searchEn": "81890 stationary plant and machine operators not elsewhere classified", "searchSv": "81890 övriga processoperatörer utan annan klassificering", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "82110", "code": "82110", "labelFi": "Konepaja- ja metallituotteiden kokoonpanijat", "labelEn": "Mechanical machinery assemblers", "labelSv": "Hopsättare, verkstads- och metallprodukter", "searchFi": "82110 konepaja- ja metallituotteiden kokoonpanijat", "searchEn": "82110 mechanical machinery assemblers", "searchSv": "82110 hopsättare, verkstads- och metallprodukter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "82120", "code": "82120", "labelFi": "Sähkö- ja elektroniikkalaitteiden kokoonpanijat", "labelEn": "Electrical and electronic equipment assemblers", "labelSv": "Hopsättare, elektrisk och elektronisk utrustning", "searchFi": "82120 sähkö- ja elektroniikkalaitteiden kokoonpanijat", "searchEn": "82120 electrical and electronic equipment assemblers", "searchSv": "82120 hopsättare, elektrisk och elektronisk utrustning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "82190", "code": "82190", "labelFi": "Muut teollisuustuotteiden kokoonpanijat", "labelEn": "Assemblers not elsewhere classified", "labelSv": "Övriga hopsättare av industriprodukter", "searchFi": "82190 muut teollisuustuotteiden kokoonpanijat", "searchEn": "82190 assemblers not elsewhere classified", "searchSv": "82190 övriga hopsättare av industriprodukter", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "83110", "code": "83110", "labelFi": "Veturinkuljettajat", "labelEn": "Locomotive engine drivers", "labelSv": "Lokförare", "searchFi": "83110 veturinkuljettajat", "searchEn": "83110 locomotive engine drivers", "searchSv": "83110 lokförare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "83120", "code": "83120", "labelFi": "Jarru-, turvalaite- ja vaihdetyöntekijät", "labelEn": "Railway brake, signal and switch operators", "labelSv": "Bangårdspersonal m.fl.", "searchFi": "83120 jarru-, turvalaite- ja vaihdetyöntekijät", "searchEn": "83120 railway brake, signal and switch operators", "searchSv": "83120 bangårdspersonal m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "83210", "code": "83210", "labelFi": "Moottoripyörälähetit yms.", "labelEn": "Motorcycle drivers", "labelSv": "Motorcykelbud m.fl.", "searchFi": "83210 moottoripyörälähetit yms.", "searchEn": "83210 motorcycle drivers", "searchSv": "83210 motorcykelbud m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "83220", "code": "83220", "labelFi": "Henkilö-, taksi- ja pakettiautonkuljettajat", "labelEn": "Car, taxi and van drivers", "labelSv": "Person-, taxi- och paketbilsförare", "searchFi": "83220 henkilö-, taksi- ja pakettiautonkuljettajat taxi", "searchEn": "83220 car, taxi and van drivers", "searchSv": "83220 person-, taxi- och paketbilsförare", "freeTextFi": "taxi", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "83310", "code": "83310", "labelFi": "Linja-auton- ja raitiovaununkuljettajat", "labelEn": "Bus and tram drivers", "labelSv": "Buss- och spårvagnsförare", "searchFi": "83310 linja-auton- ja raitiovaununkuljettajat", "searchEn": "83310 bus and tram drivers", "searchSv": "83310 buss- och spårvagnsförare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "83320", "code": "83320", "labelFi": "Kuorma-auton ja erikoisajoneuvojen kuljettajat", "labelEn": "Heavy truck and lorry drivers", "labelSv": "Lastbils- och specialfordonsförare", "searchFi": "83320 kuorma-auton ja erikoisajoneuvojen kuljettajat", "searchEn": "83320 heavy truck and lorry drivers", "searchSv": "83320 lastbils- och specialfordonsförare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "83410", "code": "83410", "labelFi": "Maa- ja metsätaloustyökoneiden kuljettajat", "labelEn": "Mobile farm and forestry plant operators", "labelSv": "Förare av jordbruks- och skogsmaskiner", "searchFi": "83410 maa- ja metsätaloustyökoneiden kuljettajat", "searchEn": "83410 mobile farm and forestry plant operators", "searchSv": "83410 förare av jordbruks- och skogsmaskiner", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "83420", "code": "83420", "labelFi": "Maansiirtokoneiden ym. kuljettajat", "labelEn": "Earthmoving and related plant operators", "labelSv": "Anläggningsmaskinförare m.fl.", "searchFi": "83420 maansiirtokoneiden ym. kuljettajat", "searchEn": "83420 earthmoving and related plant operators", "searchSv": "83420 anläggningsmaskinförare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "83430", "code": "83430", "labelFi": "Nosturinkuljettajat", "labelEn": "Crane, hoist and related plant operators", "labelSv": "Kranförare", "searchFi": "83430 nosturinkuljettajat", "searchEn": "83430 crane, hoist and related plant operators", "searchSv": "83430 kranförare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "83441", "code": "83441", "labelFi": "Ahtaajat", "labelEn": "Stevedores", "labelSv": "Stuveriarbetare", "searchFi": "83441 ahtaajat", "searchEn": "83441 stevedores", "searchSv": "83441 stuveriarbetare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "83442", "code": "83442", "labelFi": "Trukinkuljettajat ym.", "labelEn": "Lifting-truck operators, etc.", "labelSv": "Truckförare m.fl.", "searchFi": "83442 trukinkuljettajat ym.", "searchEn": "83442 lifting-truck operators, etc.", "searchSv": "83442 truckförare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "83500", "code": "83500", "labelFi": "Kansimiehistö ym. vesiliikenteen työntekijät", "labelEn": "Ships' deck crews and related workers", "labelSv": "Däckmanskap, sjötrafikarbetare m.fl.", "searchFi": "83500 kansimiehistö ym. vesiliikenteen työntekijät", "searchEn": "83500 ships' deck crews and related workers", "searchSv": "83500 däckmanskap, sjötrafikarbetare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "91110", "code": "91110", "labelFi": "Kotiapulaiset ja -siivoojat", "labelEn": "Domestic cleaners and helpers", "labelSv": "Hembiträden och städare", "searchFi": "91110 kotiapulaiset ja -siivoojat", "searchEn": "91110 domestic cleaners and helpers", "searchSv": "91110 hembiträden och städare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "household" }, { "id": "91121", "code": "91121", "labelFi": "Toimistosiivoojat ym.", "labelEn": "Office cleaners, etc.", "labelSv": "Kontorsstädare m.fl.", "searchFi": "91121 toimistosiivoojat ym.", "searchEn": "91121 office cleaners, etc.", "searchSv": "91121 kontorsstädare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "91122", "code": "91122", "labelFi": "Hotellisiivoojat", "labelEn": "Hotel cleaners", "labelSv": "Hotellstädare", "searchFi": "91122 hotellisiivoojat", "searchEn": "91122 hotel cleaners", "searchSv": "91122 hotellstädare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "91123", "code": "91123", "labelFi": "Sairaala- ja laitosapulaiset", "labelEn": "Hospital and institutional helpers", "labelSv": "Sjukhus- och vårdbiträden", "searchFi": "91123 sairaala- ja laitosapulaiset", "searchEn": "91123 hospital and institutional helpers", "searchSv": "91123 sjukhus- och vårdbiträden", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "91124", "code": "91124", "labelFi": "Päiväkotiapulaiset", "labelEn": "Kindergarten assistants", "labelSv": "Daghemsbiträden", "searchFi": "91124 päiväkotiapulaiset", "searchEn": "91124 kindergarten assistants", "searchSv": "91124 daghemsbiträden", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "91129", "code": "91129", "labelFi": "Muut muualla luokittelemattomat siivoojat", "labelEn": "Other cleaners not elsewhere classified", "labelSv": "Övriga städare utan annan klassificering", "searchFi": "91129 muut muualla luokittelemattomat siivoojat", "searchEn": "91129 other cleaners not elsewhere classified", "searchSv": "91129 övriga städare utan annan klassificering", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "91210", "code": "91210", "labelFi": "Puhdistajat ja prässääjät", "labelEn": "Hand launderers and pressers", "labelSv": "Rengörare och pressare", "searchFi": "91210 puhdistajat ja prässääjät", "searchEn": "91210 hand launderers and pressers", "searchSv": "91210 rengörare och pressare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "91220", "code": "91220", "labelFi": "Ajoneuvojen pesijät", "labelEn": "Vehicle cleaners", "labelSv": "Fordonstvättare", "searchFi": "91220 ajoneuvojen pesijät", "searchEn": "91220 vehicle cleaners", "searchSv": "91220 fordonstvättare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "91230", "code": "91230", "labelFi": "Ikkunanpesijät", "labelEn": "Window cleaners", "labelSv": "Fönsterputsare", "searchFi": "91230 ikkunanpesijät", "searchEn": "91230 window cleaners", "searchSv": "91230 fönsterputsare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "91290", "code": "91290", "labelFi": "Muut puhdistustyöntekijät", "labelEn": "Other cleaning workers", "labelSv": "Övriga rengöringsarbetare", "searchFi": "91290 muut puhdistustyöntekijät", "searchEn": "91290 other cleaning workers", "searchSv": "91290 övriga rengöringsarbetare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "92110", "code": "92110", "labelFi": "Maanviljelyn avustavat työntekijät", "labelEn": "Crop farm labourers", "labelSv": "Medhjälpare, jordbruk", "searchFi": "92110 maanviljelyn avustavat työntekijät", "searchEn": "92110 crop farm labourers", "searchSv": "92110 medhjälpare, jordbruk", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "92120", "code": "92120", "labelFi": "Karjankasvatuksen avustavat työntekijät", "labelEn": "Livestock farm labourers", "labelSv": "Medhjälpare, djuruppfödning", "searchFi": "92120 karjankasvatuksen avustavat työntekijät", "searchEn": "92120 livestock farm labourers", "searchSv": "92120 medhjälpare, djuruppfödning", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "92130", "code": "92130", "labelFi": "Yhdistetyn maanviljelyn ja karjankasvatuksen avustavat työntekijät", "labelEn": "Mixed crop and livestock farm labourers", "labelSv": "Medhjälpare, växtodling och djuruppfödning, blandad drift", "searchFi": "92130 yhdistetyn maanviljelyn ja karjankasvatuksen avustavat työntekijät", "searchEn": "92130 mixed crop and livestock farm labourers", "searchSv": "92130 medhjälpare, växtodling och djuruppfödning, blandad drift", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "92140", "code": "92140", "labelFi": "Avustavat puutarhatyöntekijät", "labelEn": "Garden and horticultural labourers", "labelSv": "Medhjälpare, trädgårdsodling", "searchFi": "92140 avustavat puutarhatyöntekijät", "searchEn": "92140 garden and horticultural labourers", "searchSv": "92140 medhjälpare, trädgårdsodling", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "92150", "code": "92150", "labelFi": "Metsätalouden avustavat työntekijät", "labelEn": "Forestry labourers", "labelSv": "Medhjälpare, skogsbruk", "searchFi": "92150 metsätalouden avustavat työntekijät", "searchEn": "92150 forestry labourers", "searchSv": "92150 medhjälpare, skogsbruk", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "92160", "code": "92160", "labelFi": "Kalatalouden ja vesiviljelyn avustavat työntekijät", "labelEn": "Fishery and aquaculture labourers", "labelSv": "Medhjälpare, fiske och vattenbruk", "searchFi": "92160 kalatalouden ja vesiviljelyn avustavat työntekijät", "searchEn": "92160 fishery and aquaculture labourers", "searchSv": "92160 medhjälpare, fiske och vattenbruk", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "93110", "code": "93110", "labelFi": "Kaivosten avustavat työntekijät", "labelEn": "Mining and quarrying labourers", "labelSv": "Medhjälpare, gruvor", "searchFi": "93110 kaivosten avustavat työntekijät", "searchEn": "93110 mining and quarrying labourers", "searchSv": "93110 medhjälpare, gruvor", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "93120", "code": "93120", "labelFi": "Maa- ja vesirakentamisen avustavat työntekijät", "labelEn": "Civil engineering labourers", "labelSv": "Medhjälpare, anläggningsverksamhet", "searchFi": "93120 maa- ja vesirakentamisen avustavat työntekijät", "searchEn": "93120 civil engineering labourers", "searchSv": "93120 medhjälpare, anläggningsverksamhet", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "93130", "code": "93130", "labelFi": "Rakennusalan avustavat työntekijät", "labelEn": "Building construction labourers", "labelSv": "Medhjälpare, byggnadsverksamhet", "searchFi": "93130 rakennusalan avustavat työntekijät", "searchEn": "93130 building construction labourers", "searchSv": "93130 medhjälpare, byggnadsverksamhet", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "93210", "code": "93210", "labelFi": "Käsinpakkaajat", "labelEn": "Hand packers", "labelSv": "Handpaketerare", "searchFi": "93210 käsinpakkaajat", "searchEn": "93210 hand packers", "searchSv": "93210 handpaketerare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "93290", "code": "93290", "labelFi": "Muut valmistusalan avustavat työntekijät", "labelEn": "Manufacturing labourers not elsewhere classified", "labelSv": "Övriga medhjälpare inom industrin", "searchFi": "93290 muut valmistusalan avustavat työntekijät", "searchEn": "93290 manufacturing labourers not elsewhere classified", "searchSv": "93290 övriga medhjälpare inom industrin", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "93310", "code": "93310", "labelFi": "Käsivetoisten- ja poljinkulkuneuvojen kuljettajat", "labelEn": "Hand and pedal vehicle drivers", "labelSv": "Förare av hand- och pedaldrivna bilar", "searchFi": "93310 käsivetoisten- ja poljinkulkuneuvojen kuljettajat", "searchEn": "93310 hand and pedal vehicle drivers", "searchSv": "93310 förare av hand- och pedaldrivna bilar", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "93320", "code": "93320", "labelFi": "Eläinvetoisten kulkuneuvojen kuljettajat", "labelEn": "Drivers of animal-drawn vehicles and machinery", "labelSv": "Förare av djurdragna fordon", "searchFi": "93320 eläinvetoisten kulkuneuvojen kuljettajat", "searchEn": "93320 drivers of animal-drawn vehicles and machinery", "searchSv": "93320 förare av djurdragna fordon", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "93330", "code": "93330", "labelFi": "Rahdinkäsittelijät, varastotyöntekijät ym.", "labelEn": "Freight handlers", "labelSv": "Godshanterare, lagerarbetare m.fl.", "searchFi": "93330 rahdinkäsittelijät, varastotyöntekijät ym.", "searchEn": "93330 freight handlers", "searchSv": "93330 godshanterare, lagerarbetare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "93340", "code": "93340", "labelFi": "Hyllyjen täyttäjät", "labelEn": "Shelf fillers", "labelSv": "Varupåfyllare", "searchFi": "93340 hyllyjen täyttäjät", "searchEn": "93340 shelf fillers", "searchSv": "93340 varupåfyllare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "94110", "code": "94110", "labelFi": "Pikaruokatyöntekijät", "labelEn": "Fast food preparers", "labelSv": "Personal inom snabbmatssektorn", "searchFi": "94110 pikaruokatyöntekijät", "searchEn": "94110 fast food preparers", "searchSv": "94110 personal inom snabbmatssektorn", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "94120", "code": "94120", "labelFi": "Avustavat keittiötyöntekijät", "labelEn": "Kitchen helpers", "labelSv": "Köksbiträden", "searchFi": "94120 avustavat keittiötyöntekijät", "searchEn": "94120 kitchen helpers", "searchSv": "94120 köksbiträden", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "company" }, { "id": "95100", "code": "95100", "labelFi": "Mainosten jakajat, kengänkiillottajat ym.", "labelEn": "Street and related service workers", "labelSv": "Reklamutdelare, skoputsare m.fl.", "searchFi": "95100 mainosten jakajat, kengänkiillottajat ym.", "searchEn": "95100 street and related service workers", "searchSv": "95100 reklamutdelare, skoputsare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "95200", "code": "95200", "labelFi": "Katumyyjät (pl. elintarvikkeet)", "labelEn": "Street vendors (excluding food)", "labelSv": "Gatuförsäljare (utom livsmedel)", "searchFi": "95200 katumyyjät (pl. elintarvikkeet)", "searchEn": "95200 street vendors (excluding food)", "searchSv": "95200 gatuförsäljare (utom livsmedel)", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "96110", "code": "96110", "labelFi": "Jätteiden kerääjät", "labelEn": "Garbage and recycling collectors", "labelSv": "Avfallsinsamlare", "searchFi": "96110 jätteiden kerääjät", "searchEn": "96110 garbage and recycling collectors", "searchSv": "96110 avfallsinsamlare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "96120", "code": "96120", "labelFi": "Jätteiden lajittelijat", "labelEn": "Refuse sorters", "labelSv": "Avfallssorterare", "searchFi": "96120 jätteiden lajittelijat", "searchEn": "96120 refuse sorters", "searchSv": "96120 avfallssorterare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "96130", "code": "96130", "labelFi": "Kadunlakaisijat ym.", "labelEn": "Sweepers and related labourers", "labelSv": "Gatsopare m.fl.", "searchFi": "96130 kadunlakaisijat ym.", "searchEn": "96130 sweepers and related labourers", "searchSv": "96130 gatsopare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "96210", "code": "96210", "labelFi": "Sanomalehtien jakajat, lähetit ja kantajat", "labelEn": "Messengers, package deliverers and luggage porters", "labelSv": "Tidnings- och reklamutdelare, bud", "searchFi": "96210 sanomalehtien jakajat, lähetit ja kantajat", "searchEn": "96210 messengers, package deliverers and luggage porters", "searchSv": "96210 tidnings- och reklamutdelare, bud", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "96220", "code": "96220", "labelFi": "Satunnaistöiden tekijät", "labelEn": "Odd job persons", "labelSv": "Diversearbetare", "searchFi": "96220 satunnaistöiden tekijät", "searchEn": "96220 odd job persons", "searchSv": "96220 diversearbetare", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "96230", "code": "96230", "labelFi": "Mittareiden lukijat ym.", "labelEn": "Meter readers and vending-machine collectors", "labelSv": "Mätaravläsare m.fl.", "searchFi": "96230 mittareiden lukijat ym.", "searchEn": "96230 meter readers and vending-machine collectors", "searchSv": "96230 mätaravläsare m.fl.", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }, { "id": "96290", "code": "96290", "labelFi": "Muut muualla luokittelemattomat työntekijät", "labelEn": "Elementary workers not elsewhere classified", "labelSv": "Övrig personal utan annan klassificering", "searchFi": "96290 muut muualla luokittelemattomat työntekijät", "searchEn": "96290 elementary workers not elsewhere classified", "searchSv": "96290 övrig personal utan annan klassificering", "freeTextFi": "", "freeTextEn": "", "freeTextSv": "", "keyword": "" }];

},{}],46:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var codegen_1 = require("../codegen");
var model_1 = require("../model");
var Translations_1 = require("./Translations");
/**
 * Provides business logic for Calculation rows:
 * How to create user interfaces, reports etc. based on them and their categories.
 */
var CalcRowsLogic = /** @class */ (function () {
    /**
     * Creates a new CalcRowsLogic helper
     * @param role Role for which the rows are fetched.
     */
    function CalcRowsLogic(role) {
        if (role === void 0) { role = "company"; }
        this.role = role;
    }
    /**
     * Gets a single UI configuration for Calculation row.
     * @param type Type for which the configuration is fetched.
     */
    CalcRowsLogic.getRowConfig = function (type) {
        if (!type) {
            return null;
        }
        var result = CalcRowsLogic.getRowConfigInternal(codegen_1.housholdRows.find(function (x) { return x.id === type; }));
        if (result == null) {
            console.error("Unknown row type: " + type);
        }
        return result;
    };
    /**
     * Gets an indicator string (1-2 characters) for a unit.
     * @param unit Unit that should be described.
     * @returns Given unit indicator or null if none is matched (convert to empty string if necessary).
     */
    CalcRowsLogic.getUnitIndicator = function (unit) {
        // TODO: Consider another location
        // TODO: After views fixed, remove non-plural strings.
        switch (unit) {
            case model_1.Unit.Euro:
            case "eur":
            case "euros":
            case "€":
                return "€";
            case model_1.Unit.Days:
            case model_1.CalculationRowUnit.Days:
            case "day":
                return "pv";
            case model_1.Unit.Hours:
            case model_1.CalculationRowUnit.Hours:
            case "hour":
                return "h";
            case model_1.Unit.Kilometers:
            case model_1.CalculationRowUnit.Kilometers:
            case "km":
                return "km";
            case model_1.Unit.Percent:
            case model_1.CalculationRowUnit.Percent:
            case "%":
                return "%";
            case model_1.Unit.Count:
            case model_1.CalculationRowUnit.Count:
                return "kpl";
            case model_1.Unit.Weeks:
            case "week":
                return "vko";
            case model_1.Unit.Period:
                return "jakso";
            case model_1.CalculationRowUnit.Undefined:
            case model_1.Unit.Undefined:
            case model_1.Unit.One:
            default:
                return null;
        }
    };
    /**
     * Gets the row types by category.
     */
    CalcRowsLogic.prototype.getRowTypesByCategory = function (category) {
        return CalcRowsLogic.rowsByCategory[category] || [];
    };
    /**
     * Gets the row configurations by category(ies).
     * @param categories List of categories to filter by.
     */
    CalcRowsLogic.prototype.getRowConfigsByCategory = function (categories) {
        var types = [];
        for (var _i = 0, _a = categories || []; _i < _a.length; _i++) {
            var cat = _a[_i];
            types.push.apply(types, this.getRowTypesByCategory(cat));
        }
        return this.getRowConfigsByType(types);
    };
    /**
     * Gets the row configurations based on a list of row types.
     * @param types List of types to filter by.
     */
    CalcRowsLogic.prototype.getRowConfigsByType = function (types) {
        types = types || [];
        return this.getRowConfigs().filter(function (x) { return types.indexOf(x.name) >= 0; });
    };
    /**
     * Gets a single UI configuration for Calculation row.
     * This method filters for user role. Use static method to return any row configuration (also faster).
     * @param type Type for which the configuration is fetched.
     */
    CalcRowsLogic.prototype.getRowConfig = function (type) {
        if (!type) {
            return null;
        }
        return this.getRowConfigs().filter(function (x) { return x.name === type; })[0];
    };
    /**
     * Gets all the UI configuration objects for calculation rows.
     */
    CalcRowsLogic.prototype.getRowConfigs = function () {
        if (this.role === "household") {
            return codegen_1.housholdRows.map(function (x) { return CalcRowsLogic.getRowConfigInternal(x); });
        }
        return codegen_1.housholdRows.filter(function (x) {
            return x.id !== model_1.CalculationRowType.ChildCareSubsidy;
        }).map(function (x) { return CalcRowsLogic.getRowConfigInternal(x); });
    };
    /** Converts a raw excel generated row configuration to language-versioned JSON object. */
    // tslint:disable-next-line:member-ordering
    CalcRowsLogic.getRowConfigInternal = function (rowConfig) {
        if (!rowConfig) {
            return null;
        }
        var unit = rowConfig.unit;
        // HACK: Historical stuff in config => Should be fixed in source Excel.
        if (rowConfig.unit === "hours") {
            unit = model_1.CalculationRowUnit.Hours;
        }
        if (rowConfig.unit === "km") {
            unit = model_1.CalculationRowUnit.Kilometers;
        }
        return {
            name: rowConfig.id,
            order: rowConfig.order,
            label: Translations_1.Translations.get("SALAXY.ENUM.CalculationRowType." + rowConfig.id + ".label"),
            descr: Translations_1.Translations.get("SALAXY.ENUM.CalculationRowType." + rowConfig.id + ".description"),
            moreInfo: Translations_1.Translations.getWithDefault("SALAXY.ENUM.CalculationRowType." + rowConfig.id + ".moreInfo", null),
            category: rowConfig.category,
            favorite: rowConfig.favorites || 0,
            color: rowConfig.color || "#eee",
            iconText: Translations_1.Translations.getWithDefault("SALAXY.ENUM.CalculationRowType." + rowConfig.id + ".iconText", null) || "NN",
            price: {
                label: Translations_1.Translations.getWithDefault("SALAXY.ENUM.CalculationRowType." + rowConfig.id + ".priceLabel", null) || "Hinta",
                default: rowConfig.priceDefault || null,
                input: rowConfig.priceInput || "number",
            },
            amount: {
                label: Translations_1.Translations.getWithDefault("SALAXY.ENUM.CalculationRowType." + rowConfig.id + ".amountLabel", null) || "Määrä",
                default: rowConfig.amountDefault || null,
                input: rowConfig.amountInput || "number",
                unit: unit,
            },
            total: {
                input: rowConfig.totalInput || "readOnly",
            },
        };
    };
    /** Raw classification of row types to primary categories. */
    // tslint:disable-next-line:member-ordering - Justification: Logically such long list belongs to the end of file.
    CalcRowsLogic.rowsByCategory = {
        /** Base salary types: the ones that you define directly */
        salary: [
            model_1.CalculationRowType.Salary,
            model_1.CalculationRowType.HourlySalary,
            model_1.CalculationRowType.MonthlySalary,
            model_1.CalculationRowType.Compensation,
            model_1.CalculationRowType.IrIncomeType,
            model_1.CalculationRowType.Board,
        ],
        /** Additions to base salary - typically a percentage of base salary */
        salaryAdditions: [
            model_1.CalculationRowType.Overtime,
            model_1.CalculationRowType.TesWorktimeShortening,
            model_1.CalculationRowType.EveningAddition,
            model_1.CalculationRowType.NightimeAddition,
            model_1.CalculationRowType.SaturdayAddition,
            model_1.CalculationRowType.SundayWork,
            model_1.CalculationRowType.OtherAdditions,
            model_1.CalculationRowType.Remuneration,
            model_1.CalculationRowType.OtherCompensation,
            model_1.CalculationRowType.WorkingTimeCompensation,
            model_1.CalculationRowType.EmploymentTermination,
        ],
        /** Benefits: Not paid as money but taxable income */
        benefits: [
            model_1.CalculationRowType.MealBenefit,
            model_1.CalculationRowType.PhoneBenefit,
            model_1.CalculationRowType.SubsidisedCommute,
            model_1.CalculationRowType.CarBenefit,
            model_1.CalculationRowType.AccomodationBenefit,
            model_1.CalculationRowType.OtherBenefit,
            model_1.CalculationRowType.ChildCareSubsidy,
        ],
        /** Expenses and other non-taxed compensations */
        expenses: [
            model_1.CalculationRowType.DailyAllowance,
            model_1.CalculationRowType.Expenses,
            model_1.CalculationRowType.MilageOwnCar,
            model_1.CalculationRowType.MealCompensation,
            model_1.CalculationRowType.ToolCompensation,
            model_1.CalculationRowType.MilageDaily,
            model_1.CalculationRowType.MilageOther,
            model_1.CalculationRowType.NonProfitOrg,
            model_1.CalculationRowType.DailyAllowanceHalf,
        ],
        /** Holidays */
        holidays: [
            model_1.CalculationRowType.HolidayCompensation,
            model_1.CalculationRowType.HolidayBonus,
            model_1.CalculationRowType.HolidaySalary,
        ],
        /** Deductions */
        deductions: [
            model_1.CalculationRowType.UnionPayment,
            model_1.CalculationRowType.Advance,
            model_1.CalculationRowType.Foreclosure,
            model_1.CalculationRowType.OtherDeductions,
            model_1.CalculationRowType.PrepaidExpenses,
        ],
        /** Types that are used only as temporary / input types in Calculations - not in the results. */
        salaryCalc: [
            model_1.CalculationRowType.TotalWorkerPayment,
            model_1.CalculationRowType.TotalEmployerPayment,
        ],
        /** Other row types */
        other: [
        // CalculationRowType.ChildCareSubsidy,
        ],
    };
    return CalcRowsLogic;
}());
exports.CalcRowsLogic = CalcRowsLogic;

},{"../codegen":39,"../model":73,"./Translations":62}],47:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/** Extension methods for CalculationResult */
var CalculationResultLogic = /** @class */ (function () {
    function CalculationResultLogic() {
    }
    /**
     * Adds Calculation Results together and returns a new CalculationResult
     * @param calculationResults CalculationResults to add.
     * @returns A new CalculationResult.
     */
    CalculationResultLogic.add = function (calculationResults) {
        var _this = this;
        if (calculationResults == null || calculationResults.length === 0) {
            return this.addResults(null, null);
        }
        return calculationResults.reduce(function (sum, item) { return _this.addResults(sum, item); }, this.safeObj(null));
    };
    CalculationResultLogic.addResults = function (c1, c2) {
        c1 = this.safeObj(c1);
        c2 = this.safeObj(c2);
        return {
            totals: this.addTotals(c1.totals, c2.totals),
            workerCalc: this.addWorkerCalc(c1.workerCalc, c2.workerCalc),
            employerCalc: this.addEmployerCalc(c1.employerCalc, c2.employerCalc),
            rows: this.safeArr(c1.rows).concat(this.safeArr(c2.rows)),
            responsibilities: this.safeObj(c1.responsibilities),
            irRows: this.safeArr(c1.irRows).concat(this.safeArr(c2.irRows)),
        };
    };
    CalculationResultLogic.addTotals = function (c1, c2) {
        c1 = this.safeObj(c1);
        c2 = this.safeObj(c2);
        return {
            pension: this.safeNum(c1.pension) + this.safeNum(c2.pension),
            total: this.safeNum(c1.total) + this.safeNum(c2.total),
            totalBaseSalary: this.safeNum(c1.totalBaseSalary) + this.safeNum(c2.totalBaseSalary),
            totalExpenses: this.safeNum(c1.totalExpenses) + this.safeNum(c2.totalExpenses),
            totalGrossSalary: this.safeNum(c1.totalGrossSalary) + this.safeNum(c2.totalGrossSalary),
            totalSocialSecurityBase: this.safeNum(c1.totalSocialSecurityBase) + this.safeNum(c2.totalSocialSecurityBase),
            totalTaxable: this.safeNum(c1.totalTaxable) + this.safeNum(c2.totalTaxable),
            unemployment: this.safeNum(c1.unemployment) + this.safeNum(c2.unemployment),
            totalAccidentInsuranceBase: this.safeNum(c1.totalAccidentInsuranceBase) + this.safeNum(c2.totalAccidentInsuranceBase),
            totalHealthInsuranceBase: this.safeNum(c1.totalHealthInsuranceBase) + this.safeNum(c2.totalHealthInsuranceBase),
            totalPayable: this.safeNum(c1.totalPayable) + this.safeNum(c2.totalPayable),
            totalPensionInsuranceBase: this.safeNum(c1.totalPensionInsuranceBase) + this.safeNum(c2.totalPensionInsuranceBase),
            totalUnemploymentInsuranceBase: this.safeNum(c1.totalUnemploymentInsuranceBase) + this.safeNum(c2.totalUnemploymentInsuranceBase),
        };
    };
    CalculationResultLogic.addWorkerCalc = function (c1, c2) {
        c1 = this.safeObj(c1);
        c2 = this.safeObj(c2);
        return {
            benefits: this.safeNum(c1.benefits) + this.safeNum(c2.benefits),
            deductions: this.safeNum(c1.deductions) + this.safeNum(c2.deductions),
            fullTax: this.safeNum(c1.fullTax) + this.safeNum(c2.fullTax),
            fullOtherDeductions: this.safeNum(c1.fullOtherDeductions) + this.safeNum(c2.fullOtherDeductions),
            fullPension: this.safeNum(c1.fullPension) + this.safeNum(c2.fullPension),
            fullPrepaidExpenses: this.safeNum(c1.fullPrepaidExpenses) + this.safeNum(c2.fullPrepaidExpenses),
            fullSalaryAdvance: this.safeNum(c1.fullSalaryAdvance) + this.safeNum(c2.fullSalaryAdvance),
            fullUnemploymentInsurance: this.safeNum(c1.fullUnemploymentInsurance) + this.safeNum(c2.fullUnemploymentInsurance),
            fullUnionPayment: this.safeNum(c1.fullUnionPayment) + this.safeNum(c2.fullUnionPayment),
            otherDeductions: this.safeNum(c1.otherDeductions) + this.safeNum(c2.otherDeductions),
            pension: this.safeNum(c1.pension) + this.safeNum(c2.pension),
            prepaidExpenses: this.safeNum(c1.prepaidExpenses) + this.safeNum(c2.prepaidExpenses),
            foreclosure: this.safeNum(c1.foreclosure) + this.safeNum(c2.foreclosure),
            salaryAdvance: this.safeNum(c1.salaryAdvance) + this.safeNum(c2.salaryAdvance),
            salaryAfterTax: this.safeNum(c1.salaryAfterTax) + this.safeNum(c2.salaryAfterTax),
            salaryAfterTaxAndForeclosure: this.safeNum(c1.salaryAfterTaxAndForeclosure) + this.safeNum(c2.salaryAfterTaxAndForeclosure),
            salaryPayment: this.safeNum(c1.salaryPayment) + this.safeNum(c2.salaryPayment),
            tax: this.safeNum(c1.tax) + this.safeNum(c2.tax),
            totalWorkerPayment: this.safeNum(c1.totalWorkerPayment) + this.safeNum(c2.totalWorkerPayment),
            unemploymentInsurance: this.safeNum(c1.unemploymentInsurance) + this.safeNum(c2.unemploymentInsurance),
            unionPayment: this.safeNum(c1.unionPayment) + this.safeNum(c2.unionPayment),
            workerSideCosts: this.safeNum(c1.workerSideCosts) + this.safeNum(c2.workerSideCosts),
            totalWorkerPaymentLegacy: this.safeNum(c1.totalWorkerPaymentLegacy) + this.safeNum(c2.totalWorkerPaymentLegacy),
        };
    };
    CalculationResultLogic.addEmployerCalc = function (c1, c2) {
        c1 = this.safeObj(c1);
        c2 = this.safeObj(c2);
        var result = {
            allSideCosts: this.safeNum(c1.allSideCosts) + this.safeNum(c2.allSideCosts),
            deductionPensionSelfPayment: this.safeNum(c1.deductionPensionSelfPayment) + this.safeNum(c2.deductionPensionSelfPayment),
            deductionUnemploymentSelfPayment: this.safeNum(c1.deductionUnemploymentSelfPayment) + this.safeNum(c2.deductionUnemploymentSelfPayment),
            deductionSalaryAdvance: this.safeNum(c1.deductionSalaryAdvance) + this.safeNum(c2.deductionSalaryAdvance),
            deductionForeclosure: this.safeNum(c1.deductionForeclosure) + this.safeNum(c2.deductionForeclosure),
            foreclosureByPalkkaus: this.safeNum(c1.foreclosureByPalkkaus) + this.safeNum(c2.foreclosureByPalkkaus),
            deductionUnionPayment: this.safeNum(c1.deductionUnionPayment) + this.safeNum(c2.deductionUnionPayment),
            deductionOtherDeductions: this.safeNum(c1.deductionOtherDeductions) + this.safeNum(c2.deductionOtherDeductions),
            finalCost: this.safeNum(c1.finalCost) + this.safeNum(c2.finalCost),
            householdDeduction: this.safeNum(c1.householdDeduction) + this.safeNum(c2.householdDeduction),
            mandatorySideCosts: this.safeNum(c1.mandatorySideCosts) + this.safeNum(c2.mandatorySideCosts),
            palkkaus: this.safeNum(c1.palkkaus) + this.safeNum(c2.palkkaus),
            pension: this.safeNum(c1.pension) + this.safeNum(c2.pension),
            socialSecurity: this.safeNum(c1.socialSecurity) + this.safeNum(c2.socialSecurity),
            totalDeductions: this.safeNum(c1.totalDeductions) + this.safeNum(c2.totalDeductions),
            totalPayment: this.safeNum(c1.totalPayment) + this.safeNum(c2.totalPayment),
            totalSalaryCost: this.safeNum(c1.totalSalaryCost) + this.safeNum(c2.totalSalaryCost),
            unemployment: this.safeNum(c1.unemployment) + this.safeNum(c2.unemployment),
            totalPaymentLegacy: this.safeNum(c1.totalPaymentLegacy) + this.safeNum(c2.totalPaymentLegacy),
        };
        result.deductionTaxAndSocialSecuritySelfPayment = this.safeNum(c1.deductionTaxAndSocialSecuritySelfPayment) + this.safeNum(c2.deductionTaxAndSocialSecuritySelfPayment);
        result.deductionWorkerSelfPayment = this.safeNum(c1.deductionWorkerSelfPayment) + this.safeNum(c2.deductionWorkerSelfPayment);
        return result;
    };
    CalculationResultLogic.safeNum = function (value) {
        return value || 0;
    };
    CalculationResultLogic.safeArr = function (value) {
        return value || [];
    };
    CalculationResultLogic.safeObj = function (value) {
        return value || {};
    };
    return CalculationResultLogic;
}());
exports.CalculationResultLogic = CalculationResultLogic;

},{}],48:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var model_1 = require("../model");
var Dates_1 = require("../util/Dates");
var index_1 = require("./model/index");
var Translations_1 = require("./Translations");
/**
 * Provides business logic related to building a salary calculator.
 */
var CalculatorLogic = /** @class */ (function () {
    function CalculatorLogic() {
    }
    /**
     * Gets the first row of the calculation assuring that it exists.
     * This should be the main row of the calculation that replaces the Salary object.
     * @param calc Calculation from which the row is fetched.
     */
    CalculatorLogic.getFirstRow = function (calc) {
        if (!calc) {
            return null;
        }
        this.moveSalaryToRows(calc);
        if (calc.rows.length === 0) {
            calc.rows.push({
                rowType: model_1.CalculationRowType.Unknown,
            });
        }
        return calc.rows[0];
    };
    /**
     * Gets a new blank object with default values, suitable for UI binding.
     * This is a synchronous method - does not go to the server.
     */
    CalculatorLogic.getBlank = function () {
        var blank = {
            employer: {
                avatar: {
                    entityType: model_1.LegalEntityType.Undefined,
                    initials: "?",
                },
                isSelf: true,
            },
            framework: {
                type: model_1.FrameworkAgreement.NotDefined,
            },
            info: {},
            rows: [],
            salary: {
                kind: null,
                price: null,
            },
            worker: {
                avatar: {
                    entityType: model_1.LegalEntityType.Person,
                    initials: "?",
                },
                paymentData: {},
            },
            workflow: {
                status: model_1.CalculationStatus.Draft,
            },
            result: {
                irRows: [],
            },
        };
        return blank;
    };
    /**
     * Returns true if calculation totals should be shown:
     * If there are any such rows that the calculation result makes sense.
     */
    CalculatorLogic.shouldShowTotals = function (calc) {
        if (!calc || !calc.result || !calc.result.totals) {
            return false;
        }
        return calc.result.totals.total > 0;
    };
    /**
     * Get a text that summarizes the start- and end dates as well as the number of work days.
     */
    CalculatorLogic.getDatesSummary = function (calc) {
        var startDate = calc.info.workStartDate;
        var endDate = calc.info.workEndDate;
        var dayCount = calc.framework.numberOfDays;
        if (!startDate && !endDate && !dayCount) {
            return Translations_1.Translations.get("SALAXY.UI_TERMS.chooseWorkDuration");
        }
        var result = "";
        if (startDate || endDate) {
            result = Dates_1.Dates.getFormattedDate(startDate, endDate);
        }
        else {
            result = Translations_1.Translations.get("SALAXY.UI_TERMS.chooseWorkDateRange");
        }
        if (dayCount) {
            result += " (" + dayCount + " " + Translations_1.Translations.get("SALAXY.ENUM.CalculationRowUnit.days.label") + ").";
        }
        return result;
    };
    /**
     * Moves the salary defined in Salary object to rows collection.
     * This is needed in old calculations for backward compatibility until moving to v03.
     * NOTE: In v03 this will be done server-side: The Salary will be removed completely.
     * @param calc Calculation to modify
     */
    CalculatorLogic.moveSalaryToRows = function (calc) {
        var salary = calc.salary;
        if (salary && salary.price > 0) {
            var rowType = model_1.CalculationRowType.Salary;
            switch (salary.kind) {
                case model_1.SalaryKind.Compensation:
                case model_1.SalaryKind.HourlySalary:
                case model_1.SalaryKind.MonthlySalary:
                    // The same underlying enum string
                    rowType = salary.kind;
                    break;
                case model_1.SalaryKind.FixedSalary: // One exception
                    rowType = model_1.CalculationRowType.Salary;
                    break;
                case model_1.SalaryKind.TotalEmployerPayment:
                case model_1.SalaryKind.TotalWorkerPayment:
                case model_1.SalaryKind.Undefined:
                default:
                    // Should never occur => Default to Unknown, which is probably an error.
                    rowType = model_1.CalculationRowType.Unknown;
                    break;
            }
            if (rowType !== model_1.CalculationRowType.Unknown) {
                var newRow = {
                    count: salary.amount,
                    message: salary.message,
                    price: salary.price,
                    rowIndex: -1,
                    rowType: rowType,
                    unit: rowType === model_1.CalculationRowType.HourlySalary ? model_1.CalculationRowUnit.Hours : model_1.CalculationRowUnit.Count,
                };
                calc.rows.push(newRow);
                salary.price = 0;
                salary.amount = 0;
                salary.kind = model_1.SalaryKind.Undefined;
            }
        }
    };
    /**
     * Gets the Avatar of other party in a calculation:
     * Employer or Worker
     */
    CalculatorLogic.getOtherParty = function (calc, currentAvatar) {
        if (currentAvatar) {
            var id = currentAvatar.id;
            if (calc.worker && calc.worker.accountId !== id) {
                return calc.worker.avatar;
            }
            else if (calc.employer && calc.employer.accountId !== id) {
                return calc.employer.avatar;
            }
        }
        return {
            id: null,
            displayName: "?",
            sortableName: "?",
            initials: "?",
            firstName: "n",
            lastName: "n",
            entityType: model_1.LegalEntityType.Undefined,
        };
    };
    /**
     * Gets a total sum for a row category from calculation results.
     * @param calc - Calculation object
     * @param category - Row category (collection of row types)
     */
    CalculatorLogic.getTotalForCategory = function (calc, category) {
        var total = 0.0;
        this.getResultRowsByCategory(calc, category).forEach(function (row) { return total += row.total; });
        return total;
    };
    /**
     * Gets a total sum for a row category from calculation results.
     * @param calc - Calculation object
     * @param types - Array of row types that are included in the result
     */
    CalculatorLogic.getTotalForRowsByType = function (calc) {
        var types = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            types[_i - 1] = arguments[_i];
        }
        var total = 0.0;
        this.getResultRowsByType.apply(this, [calc].concat(types)).forEach(function (row) { return total += row.total; });
        return total;
    };
    /**
     * Filter the result rows of a calculation based on the type
     * @param calc - Calculation object
     * @param types - Array of row types that are included in the result
     */
    CalculatorLogic.getResultRowsByType = function (calc) {
        var types = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            types[_i - 1] = arguments[_i];
        }
        return (!calc.result || !calc.result.rows) ? [] : calc.result.rows.filter(function (value) { return types.indexOf(value.rowType) !== -1; });
    };
    /**
     * Filter the result rows of a calculation based on a row category
     * @param calc - Calculation object
     * @param category - Row category (collection of row types)
     */
    CalculatorLogic.getResultRowsByCategory = function (calc, category) {
        var types = index_1.CalculationRowCategories[category];
        return this.getResultRowsByType.apply(this, [calc].concat(types));
    };
    return CalculatorLogic;
}());
exports.CalculatorLogic = CalculatorLogic;

},{"../model":73,"../util/Dates":81,"./Translations":62,"./model/index":70}],49:[function(require,module,exports){
(function (global){
Object.defineProperty(exports, "__esModule", { value: true });
var model_1 = require("../model");
var util_1 = require("../util");
var Translations_1 = require("./Translations");
var momentImport = (typeof window !== "undefined" ? window['moment'] : typeof global !== "undefined" ? global['moment'] : null);
/** moment variable */
var moment = momentImport;
/**
 * Provides business logic related to displaying / editing an employment contract.
 */
var ContractLogic = /** @class */ (function () {
    function ContractLogic() {
    }
    /**
     * Creates a new contract for the current account.
     * The current account is set as Employer or Worker in this contract.
     * @param isWorker If true, current account is in role Worker.
     * If false, the current account is Employer.
     * @param account The current account object (Person or Company).
     */
    ContractLogic.getBlankForCurrentAccount = function (isWorker, account) {
        var result = this.getBlank();
        if (isWorker) {
            result.worker = ContractLogic.getContractParty(account);
        }
        else {
            result.employer = ContractLogic.getContractParty(account);
        }
        return result;
    };
    /**
     * Gets a new blank object with default values, suitable for UI binding.
     */
    ContractLogic.getBlank = function () {
        var blank = {
            employer: {
                avatar: {},
                contact: {},
            },
            worker: {
                avatar: {},
                contact: {},
            },
            isWorkAtHome: true,
            salary: {},
            createdAt: util_1.Dates.getToday(),
            updatedAt: util_1.Dates.getToday(),
        };
        return blank;
    };
    /**
     * Gets the Avatar of other party in a contract:
     * Employer or Worker
     */
    ContractLogic.getOtherParty = function (contract, currentAvatar) {
        if (currentAvatar) {
            var id = currentAvatar.id;
            if (contract.worker && contract.worker.id !== id) {
                return contract.worker.avatar;
            }
            else if (contract.employer && contract.employer.id !== id) {
                return contract.employer.avatar;
            }
        }
        return {
            id: null,
            displayName: "?",
            sortableName: "?",
            initials: "?",
            firstName: "n",
            lastName: "n",
            entityType: model_1.LegalEntityType.Undefined,
        };
    };
    /** Gets a contract party from an Account object: Person or Company */
    ContractLogic.getContractParty = function (person) {
        return {
            avatar: person.avatar,
            isSelf: true,
            contact: person.contact,
            contractPartyType: model_1.ContractPartyType.Person,
            iban: person.identity.ibanNumber,
            officialId: person.identity.officialId,
        };
    };
    /** Constructs text for price per (such as 15€/h or 2000€/kk) */
    ContractLogic.constructPricePerText = function (formattedPrice, salaryType) {
        if (salaryType === model_1.EmploymentSalaryType.HourlyPay) {
            return formattedPrice + Translations_1.Translations.get("SALAXY.ENUM.EmploymentSalaryType.hourlyPay.metricAbbrev");
        }
        else if (model_1.EmploymentSalaryType.MontlyPay) {
            return formattedPrice + Translations_1.Translations.get("SALAXY.ENUM.EmploymentSalaryType.montlyPay.metricAbbrev");
        }
        else {
            return formattedPrice;
        }
    };
    /** Constructs text for term date */
    ContractLogic.constructTermDateText = function (workType, startDate, endDate) {
        if (startDate && workType === model_1.EmploymentType.FullTime) {
            return moment(startDate).format("DD.MM.YYYY");
        }
        else if (startDate && workType !== model_1.EmploymentType.FullTime) {
            return moment(startDate).format("DD.MM.YYYY") + " - " + moment(endDate).format("DD.MM.YYYY");
        }
        return Translations_1.Translations.get("SALAXY.UI_TERMS.dateNotChosen");
    };
    /** Constructs text salary work hours */
    ContractLogic.constructSalaryWorkHoursText = function (worksHoursType, workHours) {
        if (workHours) {
            switch (worksHoursType) {
                case model_1.EmploymentWorkHoursType.HoursPerDay: return workHours + " " + Translations_1.Translations.get("SALAXY.ENUM.EmploymentWorkHoursType.hoursPerWeek.label");
                case model_1.EmploymentWorkHoursType.HoursPerWeek: return workHours + " " + Translations_1.Translations.get("SALAXY.ENUM.EmploymentWorkHoursType.hoursPerDay.label");
                case model_1.EmploymentWorkHoursType.HourPerTwoWeeks: return workHours + " " + Translations_1.Translations.get("SALAXY.ENUM.EmploymentWorkHoursType.hourPerTwoWeeks.label");
                case model_1.EmploymentWorkHoursType.HourPerThreeWeeks: return workHours + " " + Translations_1.Translations.get("SALAXY.ENUM.EmploymentWorkHoursType.hourPerThreeWeeks.label");
            }
        }
        return workHours;
    };
    /** get full address as two lines or display a human-readable default value
     * @param target Any object that has an contact property
     */
    ContractLogic.constructAddressText = function (party) {
        if (party.contact && party.contact.street && party.contact.postalCode && party.contact.city) {
            return party.contact.street + "<br />" + party.contact.postalCode + " " + party.contact.city.toUpperCase();
        }
        return null;
    };
    return ContractLogic;
}());
exports.ContractLogic = ContractLogic;

}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})
},{"../model":73,"../util":90,"./Translations":62}],50:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var index_1 = require("../model/index");
/**
 * Provides business logic related to displaying / editing Contact objects
 */
var ContractPartyLogic = /** @class */ (function () {
    function ContractPartyLogic() {
    }
    /**
     * Gets a new blank Contact with default values, suitable for UI binding.
     */
    ContractPartyLogic.getBlank = function () {
        return {
            avatar: {
                entityType: null,
                lastName: null,
                pictureType: index_1.AvatarPictureType.Icon,
                isReadOnly: false,
            },
            contact: {
                countryCode: "fi",
            },
            isSelf: false,
            isSigned: false,
            contractPartyType: index_1.ContractPartyType.CustomContact,
            isEmployer: false,
        };
    };
    /** Converts a WorkerAccount object to a ContractParty object. */
    ContractPartyLogic.getFromWorker = function (worker) {
        return {
            avatar: worker.avatar,
            contact: worker.contact,
            contractPartyType: index_1.ContractPartyType.CustomContact,
            iban: worker.ibanNumber,
            id: worker.id,
            isEmployer: false,
            isSelf: false,
            isSigned: false,
            officialId: worker.officialPersonId,
        };
    };
    /** Gets sample contacts for demonstration user interfaces. */
    ContractPartyLogic.getSampleContacts = function () {
        return [
            {
                id: "example-default",
                avatar: {
                    entityType: index_1.LegalEntityType.Person,
                    firstName: "Erkki",
                    lastName: "Esimerkki",
                    displayName: "Erkki Esimerkki",
                    sortableName: "Esimerkki, Erkki",
                    pictureType: index_1.AvatarPictureType.Icon,
                    color: "lime",
                    initials: "EE",
                    url: null,
                    description: "Esimerkkityöntekijä, oletus: 18-52 vuotta, veroprosentti 23%.",
                    id: "example-default",
                },
                contact: {
                    email: "erkki@esimerkki.fi",
                    telephone: "555-5555555",
                    street: "Mallikatu 3",
                    postalCode: "333333",
                    city: "Jokupaikka",
                    countryCode: "fi",
                },
            },
            {
                id: "example-17",
                avatar: {
                    entityType: index_1.LegalEntityType.Person,
                    firstName: "Laura",
                    lastName: "Lukiolainen",
                    displayName: "Laura Lukiolainen",
                    sortableName: "Lukiolainen, Laura",
                    pictureType: index_1.AvatarPictureType.Icon,
                    color: "pink",
                    initials: "LL",
                    url: null,
                    description: "Esimerkki nuoresta työntekijästä: 17 vuotias",
                    id: "example-17",
                },
                contact: {
                    email: "laura@esimerkki.fi",
                    telephone: "222-2222222",
                    street: "Lukiolaisenkatu 5",
                    postalCode: "222222",
                    city: "Jokupaikka",
                    countryCode: "fi",
                },
            },
            {
                id: "example-company",
                avatar: {
                    entityType: index_1.LegalEntityType.Company,
                    firstName: "Mallitakomo Oy",
                    lastName: null,
                    displayName: "Mallitakomo Oy",
                    sortableName: "Mallitakomo Oy",
                    pictureType: index_1.AvatarPictureType.Icon,
                    color: "red",
                    initials: "MT",
                    url: null,
                    description: "Esimerkkiyritys Tampereelta",
                    id: "example-company",
                },
                contact: {
                    email: "takomo@esimerkki.fi",
                    telephone: "888-88888888",
                    street: "Takomokatu 8",
                    postalCode: "8888888",
                    city: "Tampere",
                    countryCode: "fi",
                },
            },
            {
                id: "example-pensioner",
                avatar: {
                    entityType: index_1.LegalEntityType.Person,
                    firstName: "Tanja",
                    lastName: "Eläkeläinen",
                    displayName: "Tanja Eläkeläinen",
                    sortableName: "Eläkeläinen, Tanja",
                    pictureType: index_1.AvatarPictureType.Icon,
                    color: "blue",
                    initials: "TE",
                    url: null,
                    description: "Esimerkki eläkeläisestä: 65-67 vuotias",
                    id: "example-pensioner",
                },
                contact: {
                    email: "tanja@esimerkki.fi",
                    telephone: "777-7777777",
                    street: "Eläkeläisenkatu 7",
                    postalCode: "111111",
                    city: "Jokupaikka",
                    countryCode: "fi",
                },
            },
        ];
    };
    return ContractPartyLogic;
}());
exports.ContractPartyLogic = ContractPartyLogic;

},{"../model/index":73}],51:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var codegen_1 = require("../codegen");
var Translations_1 = require("./Translations");
/**
 * Provides metadata and other helpers for enumerations.
 */
var EnumerationsLogic = /** @class */ (function () {
    function EnumerationsLogic() {
    }
    /**
     * Gets a label text for an enumeration value
     * @param enumType - Name of the Type of the enumeration.
     * @param enumValue - Value for which the label is fetched.
     */
    EnumerationsLogic.getEnumLabel = function (enumType, enumValue) {
        enumType = this.upperCamelCase(enumType);
        enumValue = this.lowerCamelCase(enumValue);
        return Translations_1.Translations.getWithDefault("SALAXY.ENUM." + enumType + "." + enumValue + ".label") || enumValue;
    };
    /**
     * Gets a description text for an enumeration value
     * @param enumType - Name of the Type of the enumeration.
     * @param enumValue - Value for which the description is fetched.
     */
    EnumerationsLogic.getEnumDescr = function (enumType, enumValue) {
        enumType = this.upperCamelCase(enumType);
        enumValue = this.lowerCamelCase(enumValue);
        return Translations_1.Translations.getWithDefault("SALAXY.ENUM." + enumType + "." + enumValue + ".description") || enumValue;
    };
    /**
     * Gets a very short user interface text for an enumeration.
     * Currently only suppotrted for Unit, but we expect more of these.
     * If the texts will be language-versioned, that logic will be here as well.
     * @param enumType - Name of the Type of the enumeration.
     * @param enumValue - Value for which the text is fetched.
     */
    EnumerationsLogic.getEnumShortText = function (enumType, enumValue) {
        enumType = this.upperCamelCase(enumType);
        enumValue = this.lowerCamelCase(enumValue);
        switch (enumType) {
            case "Unit": {
                var unitTexts = {
                    undefined: "kpl?",
                    hour: "h",
                    day: "pv",
                    week: "vko",
                    period: "jaksoa",
                    one: "",
                    count: "kpl",
                    percent: "%",
                    kilometers: "km",
                };
                return unitTexts[enumValue];
            }
            default: {
                throw new Error("Enum type " + enumType + " is not supported in getEnumShortText().");
            }
        }
    };
    /**
     * Gets the metadata (texts etc.) for an enumeration value.
     * @param enumType - Name of the Type of the enumeration.
     * @param enumValue - Value for which the label is fetched.
     */
    EnumerationsLogic.getEnumValueMetadata = function (enumType, enumValue) {
        var typeMetaData = EnumerationsLogic.getEnumMetadata(enumType);
        if (!enumValue || !typeMetaData) {
            return null;
        }
        enumValue = this.lowerCamelCase(enumValue);
        var enumValueObj = typeMetaData.values.filter(function (x) { return x.name === enumValue; })[0];
        return enumValueObj;
    };
    /**
     * Gets the metadata (texts etc.) for an enumeration and its values.
     * @param enumType - Name of the Type of the enumeration.
     */
    EnumerationsLogic.getEnumMetadata = function (enumType) {
        var _this = this;
        if (!enumType) {
            return null;
        }
        enumType = this.upperCamelCase(enumType);
        var enumObj = codegen_1.generatedEnumData.filter(function (x) { return x.name === enumType; })[0];
        var override = EnumerationsLogic.enumDataOverride.filter(function (x) { return x.name === enumType; })[0];
        enumObj = override || enumObj;
        if (!enumObj) {
            return null;
        }
        var result = {
            name: enumType,
            descr: enumObj.description,
            values: enumObj.values.map(function (x) {
                return {
                    type: enumType,
                    name: x.name,
                    order: x.order,
                    label: _this.getEnumLabel(enumType, x.name),
                    descr: _this.getEnumDescr(enumType, x.name),
                };
            }),
        };
        return result;
    };
    EnumerationsLogic.lowerCamelCase = function (text) {
        return text.substr(0, 1).toLowerCase() + text.substr(1);
    };
    EnumerationsLogic.upperCamelCase = function (text) {
        return text.substr(0, 1).toUpperCase() + text.substr(1);
    };
    // tslint:disable: object-literal-key-quotes
    /**
     * Place to override generatedEnumData.
     * TODO: These texts should be moved to C# code server-side and removed from here.
     */
    EnumerationsLogic.enumDataOverride = [{
            "name": "NewEnumName",
            "description": null,
            "values": [
                { "order": 0, "name": "undefined" },
                { "order": 1, "name": "enum1" },
            ],
        },
        {
            "name": "AnnualLeavePaymentKind",
            "description": null,
            "values": [
                { "order": 0, "name": "undefined" },
                { "order": 1, "name": "planned" },
                { "order": 1, "name": "manualSalary" },
                { "order": 1, "name": "manualCompensation" },
                { "order": 1, "name": "manualBonus" },
                { "order": 1, "name": "paidCalc" },
                { "order": 1, "name": "draftCalc" },
                { "order": 1, "name": "info" },
                { "order": 1, "name": "startSaldo" },
                { "order": 1, "name": "total" },
                { "order": 1, "name": "endSaldo" },
            ],
        },
    ];
    return EnumerationsLogic;
}());
exports.EnumerationsLogic = EnumerationsLogic;

},{"../codegen":39,"./Translations":62}],52:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var model_1 = require("../model");
var util_1 = require("../util");
/** Logic for Holiday years and other holiday functionality. */
var HolidaysLogic = /** @class */ (function () {
    function HolidaysLogic() {
    }
    /**
     * Gets the multiplier that is used in Average Daily Salary calculation (keskipäiväpalkka).
     * @param holidays Number of holidays for the year.
     */
    HolidaysLogic.getDailySalaryMultiplier = function (holidays) {
        var multipliers = [0, 0, 1.8, 2.7, 3.6, 4.5, 5.4, 6.3, 7.2, 8.1, 9.0, 9.9, 10.8, 11.8, 12.7, 13.6, 14.5, 15.5, 16.4, 17.4, 18.3, 19.3, 20.3, 21.3, 22.2, 23.2, 24.1, 25.0, 25.9, 26.9, 27.8];
        if (holidays > 30) {
            return multipliers[30] + (holidays - 30) * 0.9;
        }
        return multipliers[holidays];
    };
    /**
     * Gets a new blank holiday year.
     * @param year Holiday accrual year (e.g. 2019) or 0 for current year and -1 for previous year (from -10 to 10).
     * Current year is always from 1.4. until 31.3. e.g. year 2019 is 1.4.2019 until 31.3.2020.
     * The main part of the holidays from holiday accrual year 2019 are kept on summer 2020.
     */
    HolidaysLogic.getBlank = function (year) {
        if (year === void 0) { year = 0; }
        if (year < 11) {
            var currentYear = util_1.Dates.getMonth(util_1.Dates.getToday()) < 4 ? (util_1.Dates.getTodayMoment().year() - 1) : util_1.Dates.getTodayMoment().year();
            year = currentYear + year;
        }
        var result = {
            employmentId: null,
            year: year,
            workerId: null,
            period: {
                start: "{year}-04-01",
                end: "{year + 1}-03-31",
            },
            accrual: {
                months: [],
            },
            leaves: {
                paid: [],
                planned: [],
            },
            spec: {
                code: model_1.HolidayCode.Undefined,
            },
        };
        result.period.daysCount = util_1.Dates.getDuration(result.period.start, result.period.end).asDays();
        return result;
    };
    /** Gets the salary payable type or default type if both are possible. */
    HolidaysLogic.getSalaryPayableType = function (absenseCauseCode) {
        var defaults = {
            unpaidLeave: "unpaid",
            personalReason: "defaultUnpaid",
            illness: "defaultPaid",
            partTimeSickLeave: "defaultUnpaid",
            parentalLeave: "defaultUnpaid",
            specialMaternityLeave: "defaultUnpaid",
            rehabilitation: "defaultUnpaid",
            childIllness: "defaultPaid",
            partTimeChildCareLeave: "defaultUnpaid",
            training: "defaultPaid",
            jobAlternationLeave: "unpaid",
            studyLeave: "unpaid",
            industrialAction: "unpaid",
            interruptionInWorkProvision: "unpaid",
            leaveOfAbsence: "defaultUnpaid",
            militaryRefresherTraining: "defaultUnpaid",
            militaryService: "unpaid",
            layOff: "unpaid",
            childCareLeave: "unpaid",
            midWeekHoliday: "paid",
            accruedHoliday: "paid",
            occupationalAccident: "paid",
            annualLeave: "paid",
            partTimeAbsenceDueToRehabilitation: "paid",
            other: "both",
        };
        return defaults[absenseCauseCode];
    };
    /** Gets different total days calculation of planned leaves. */
    HolidaysLogic.getPlannedLeavesCount = function (holidayYear, type) {
        if (type === void 0) { type = "all"; }
        // TODO: Split period if it starts summer and ands winter.
        var year = holidayYear.year;
        var list = holidayYear.leaves.planned;
        switch (type) {
            case "all":
                return util_1.Arrays.sum(list, function (x) { return x.period.daysCount; });
            case "summer":
                return util_1.Arrays.sum(list.filter(function (x) { return x.period.start < year + "-10-1"; }), function (x) { return x.period.daysCount; });
            case "winter":
                return util_1.Arrays.sum(list.filter(function (x) { return x.period.start >= year + "-10-1"; }), function (x) { return x.period.daysCount; });
            case "holidaysSaldoStart":
                return util_1.Arrays.sum(holidayYear.accrual.months, function (x) { return x.daysAccrued; }) + holidayYear.accrual.startSaldo;
            case "holidaysSaldoEnd":
                return HolidaysLogic.getPlannedLeavesCount(holidayYear, "holidaysSaldoStart") - HolidaysLogic.getPlannedLeavesCount(holidayYear, "all");
        }
        return null;
    };
    /** Gets a calculated total or saldo row for paid calculations */
    HolidaysLogic.getPaidHolidaysCalculation = function (holidayYear, type, dailyHolidaySalary) {
        if (type === void 0) { type = "total"; }
        if (dailyHolidaySalary === void 0) { dailyHolidaySalary = null; }
        switch (type) {
            case "total":
                return {
                    avatar: HolidaysLogic.getPaidCalculationAvatar("total", null),
                    holidayBonus: util_1.Arrays.sum(holidayYear.leaves.paid, function (x) { return x.holidayBonus; }),
                    holidayCompensation: util_1.Arrays.sum(holidayYear.leaves.paid, function (x) { return x.holidayCompensation; }),
                    holidayDays: util_1.Arrays.sum(holidayYear.leaves.paid, function (x) { return x.holidayDays; }),
                    holidaySalary: util_1.Arrays.sum(holidayYear.leaves.paid, function (x) { return x.holidaySalary; }),
                };
            case "startSaldo":
                var holidaySalary = dailyHolidaySalary ? dailyHolidaySalary * holidayYear.accrual.endSaldo : null;
                return {
                    avatar: HolidaysLogic.getPaidCalculationAvatar("startSaldo", null),
                    holidayBonus: (holidaySalary && holidayYear.spec.bonus) ? (holidaySalary * holidayYear.spec.bonus) : null,
                    holidayDays: holidayYear.accrual.endSaldo,
                    holidayCompensation: null,
                    holidaySalary: holidaySalary,
                };
            case "endSaldo":
                var total = HolidaysLogic.getPaidHolidaysCalculation(holidayYear, "total", dailyHolidaySalary);
                var startSaldo = HolidaysLogic.getPaidHolidaysCalculation(holidayYear, "startSaldo", dailyHolidaySalary);
                return {
                    avatar: HolidaysLogic.getPaidCalculationAvatar("endSaldo", null),
                    holidayBonus: startSaldo.holidayBonus ? startSaldo.holidayBonus - total.holidayBonus : null,
                    holidayCompensation: startSaldo.holidaySalary ? startSaldo.holidaySalary - (total.holidaySalary + total.holidayCompensation) : null,
                    holidayDays: startSaldo.holidayDays - total.holidayDays,
                    holidaySalary: null,
                };
        }
        return null;
    };
    /** Gets a display avatar for a paid calculation */
    HolidaysLogic.getPaidCalculationAvatar = function (type, row) {
        if (type === void 0) { type = "row"; }
        switch (type) {
            case "row":
                return {
                    displayName: row.kind === model_1.AnnualLeavePaymentKind.DraftCalc ? "Luonnos " + util_1.Dates.getFormattedDate(row.date) : "Maksettu " + util_1.Dates.getFormattedDate(row.date),
                    description: "Palkkakausi " + util_1.Dates.getFormattedDate(row.period.start, row.period.end),
                    color: "rgb(74, 146, 233)",
                    initials: row.kind === "draftCalc" ? "luonnos" : "maksettu",
                    entityType: model_1.LegalEntityType.Company,
                };
            case "startSaldo":
                return {
                    displayName: "Käytettävissä olevat",
                    description: "Edellisenä vuonna kertyneet lomat",
                    color: "gray",
                    initials: "saldo",
                    entityType: model_1.LegalEntityType.Company,
                };
            case "total":
                return {
                    displayName: "Yhteensä",
                    description: "Käytetyt/maksetut lomapäivät, -rahat ja korvaukset",
                    color: "rgb(74, 146, 233)",
                    initials: "=",
                    entityType: model_1.LegalEntityType.Company,
                };
            case "endSaldo":
                return {
                    displayName: "Maksettavaa tai siirrettävää",
                    description: "Seuraavalle lomavuodelle tai maksettavaa",
                    color: "gray",
                    initials: "saldo",
                    entityType: model_1.LegalEntityType.Company,
                };
        }
    };
    /**
     * Gets the visualisation data for the a holiday year.
     * @param holidayYear The holiday year to visualize
     */
    HolidaysLogic.getYearVisualisation = function (holidayYear) {
        var year = holidayYear.year;
        var todayYear = util_1.Dates.getYear("today");
        var todayMonthIndex = util_1.Dates.getMonth("today") - 4;
        var currentMonthIx = todayYear < year ? todayMonthIndex : (todayYear > year ? todayMonthIndex + 24 : todayMonthIndex + 12);
        return {
            year: year,
            employmentId: holidayYear.employmentId,
            currentMonthIx: currentMonthIx,
            years: [
                { text: year - 1, months: 9, style: "default" },
                { text: year, months: 12, style: "primary" },
                { text: year + 1, months: 4, style: "default" },
            ],
            months: [4, 5, 6, 7, 8, 9, 10, 11, 12, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 1, 2, 3, 4],
            items: [
                { text: "Lomap\u00E4ivien kertym\u00E4: " + holidayYear.accrual.endSaldo + " pv", months: 12, start: 0, style: "default", view: "accrual" },
                { text: "Kes\u00E4lomat: " + HolidaysLogic.getPlannedLeavesCount(holidayYear, "summer") + " pv", months: 5, start: 13, style: "default", view: "holidays-summer" },
                { text: "Talvilomat: " + HolidaysLogic.getPlannedLeavesCount(holidayYear, "winter") + " pv", months: 7, start: 18, style: "default", view: "holidays-winter" },
                { text: "Lomapalkat ja -rahat", months: 12, start: 13, style: "default", view: "paidHolidays" },
            ],
        };
    };
    return HolidaysLogic;
}());
exports.HolidaysLogic = HolidaysLogic;

},{"../model":73,"../util":90}],53:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var codegen_1 = require("../codegen");
var Translations_1 = require("./Translations");
/**
 * Provides business logic for Income types in Incomes Registry (Tulorekisteri).
 */
var IncomeTypesLogic = /** @class */ (function () {
    function IncomeTypesLogic() {
    }
    /**
     * Searches the income type texts (supportedTypes) using the current language version.
     * Returns all types if the search string is less than 2 chars.
     * @param searchString Search text - will be used as case-insensitive. Will be trimmed. Minimum length 2.
     */
    IncomeTypesLogic.search = function (searchString) {
        if (!searchString || searchString.trim().length < 2) {
            return IncomeTypesLogic.supportedTypes;
        }
        searchString = searchString.trim().toLowerCase();
        return IncomeTypesLogic.supportedTypes.filter(function (x) { return x.code.toString().indexOf(searchString) >= 0
            || x.label.toLowerCase().indexOf(searchString) >= 0; });
    };
    /**
     * Gets all codes in Incomes register reporting.
     * This also includes the Salaxy internal codes eg. 1: "Ignored" / "Not reported"
     * For normal language-versioned behavior use cached allTypes field.
     * @param language Language for the label.
     */
    IncomeTypesLogic.getAll = function (language) {
        if (language === void 0) { language = null; }
        language = language || Translations_1.Translations.getLanguage() || "fi";
        var allCodes = [{
                code: 1,
                label: (language === "en" ? "No IR reporting" : (language === "sv" ? "Ingen IR reporting" : "Ei ilmoiteta tulorekisteriin")),
                isNegativeSupported: true,
                pensionInsurance: false,
                accidentInsurance: false,
                unemploymentInsurance: false,
                healthInsurance: false,
                insuranceInformationAllowed: true,
                taxDefault: 0,
                notSupportedError: null,
                description: "Tätä riviä ei ilmoiteta tulorekisteriin. Tällaisia rivejä ovat esimerkiksi palkan yhteydessä.",
                taxAndSidecostsDescr: "Rivin summasta ai vähennetä ennakonpidätystä eikä työnantajan sosiaalivakuutusmaksuja.",
                isSupported: true,
                paymentDefault: 1,
                calcGrouping: "expenses",
            }].concat(this.getOriginal());
        return allCodes;
    };
    /**
     * Gets the original codes in Incomes register.
     * This does not include virtual codes, eg. 1: "Ignored" / "Not reported"
     * For normal language-versioned behavior use cached originalTypes field.
     * @param language Language for the label. Typically use null for automatic language versioning.
     */
    IncomeTypesLogic.getOriginal = function (language) {
        if (language === void 0) { language = null; }
        language = language || Translations_1.Translations.getLanguage() || "fi";
        return codegen_1.incomeTypeCodes.map(function (x) { return ({
            code: x.code,
            label: (language === "en" ? x.nameEn : (language === "sv" ? x.nameSv : x.nameFi)),
            isNegativeSupported: x.isNegativeSupported,
            pensionInsurance: x.pensionInsurance,
            accidentInsurance: x.accidentInsurance,
            unemploymentInsurance: x.unemploymentInsurance,
            healthInsurance: x.healthInsurance,
            insuranceInformationAllowed: x.insuranceInformationAllowed,
            taxDefault: x.taxDefault,
            notSupportedError: x.notSupportedError,
            description: x.description,
            taxAndSidecostsDescr: x.taxAndSidecostsDescr,
            isSupported: x.isSupported,
            paymentDefault: x.paymentDefault,
            calcGrouping: x.calcGrouping,
        }); });
    };
    /** Cached language-versioned list of all types - cached version of getAll() */
    IncomeTypesLogic.allTypes = IncomeTypesLogic.getAll();
    /**
     * Cached language-versioned list of supported types.
     * This is the list of types that you typically use.
     */
    IncomeTypesLogic.supportedTypes = IncomeTypesLogic.getAll().filter(function (x) { return x.isSupported; });
    return IncomeTypesLogic;
}());
exports.IncomeTypesLogic = IncomeTypesLogic;

},{"../codegen":39,"./Translations":62}],54:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var occupationcodes_1 = require("../i18n/occupationcodes");
var index_1 = require("../logic/index");
/**
 * Helper for Statistics Finland Occupation codes and texts related to them.
 * Occupation is used for insurance pricing and reporting..
 */
var Occupations = /** @class */ (function () {
    function Occupations() {
    }
    /** Gets all occupations for all languages. */
    Occupations.getAllForAllLanguages = function () {
        if (this.data.length === 0) {
            var occupations_1 = [];
            occupationcodes_1.occupationsData.forEach(function (x) {
                occupations_1.push({
                    id: x.id,
                    code: x.code,
                    label: x.labelFi,
                    freeText: x.freeTextFi,
                    search: x.searchFi,
                    keyword: x.keyword,
                    lang: "fi",
                });
                occupations_1.push({
                    id: x.id,
                    code: x.code,
                    label: x.labelSv,
                    freeText: x.freeTextSv,
                    search: x.searchSv,
                    keyword: x.keyword,
                    lang: "sv",
                });
                occupations_1.push({
                    id: x.id,
                    code: x.code,
                    label: x.labelEn,
                    freeText: x.freeTextEn,
                    search: x.searchEn,
                    keyword: x.keyword,
                    lang: "en",
                });
            });
            this.data = occupations_1;
        }
        return this.data;
    };
    /**
     * Gets all the items of a given type.
     * @return All occupation entries
     */
    Occupations.getAll = function (language) {
        language = language || index_1.Translations.getLanguage() || "fi";
        return this.getAllForAllLanguages().filter(function (x) { return x.lang === language; });
    };
    /**
     * Searches the occupations.
     * @param searchString String to search for. Typically user input.
     * @param language Language to search for.
     */
    Occupations.search = function (searchString, language) {
        searchString = (searchString || "").toLowerCase();
        if (searchString === "" || null) {
            this.getAll();
        }
        return this.getAll(language).filter(function (x) { return (x.search || "").indexOf(searchString) >= 0; });
    };
    /**
     * Gets a single occupation based on the original Statistics Finland code.
     * @param code - Statistics finland 5-number code.
     * Note that this is different than the Salaxy ID stored in Calculation.
     * Salaxy ID may specify additional suffix separated by dash. For Salaxy ID, use getById() instead.
     * @return Occupation metadata or null if not found.
     */
    Occupations.getByCode = function (code) {
        return this.getAll().find(function (x) { return x.code === code; });
    };
    /**
     * Gets a single occupation based on the its Salaxy ID, which is derived from the original  Statistics Finland code.
     * @param id - Salaxy ID for the occupation.
     * This is the id stored in the calculation, but not the one that is reported to Incomes Register.
     * @return Occupation metadata or null if not found.
     */
    Occupations.getById = function (id) {
        return this.getAll().find(function (x) { return x.id === id; });
    };
    /**
     * Fetches a list of occupations either based on list of IDs or a known keyword.
     * @param idListOrKeyword Either a comma separated list of ID's
     * or a known keyword: "household" and "company" currently supported.
     */
    Occupations.getByIds = function (idListOrKeyword) {
        var hasNumber = /^\d{5}/;
        if (!idListOrKeyword) {
            return [];
        }
        else if (idListOrKeyword.search(hasNumber) > -1) {
            if (idListOrKeyword.indexOf(",") > -1) {
                var splittedIdList_1 = idListOrKeyword.split(",")
                    .map(function (x) { return x.trim(); });
                return this.getAll().filter(function (x) { return splittedIdList_1.indexOf(x.id) > -1; });
            }
            else {
                return this.getAll().filter(function (x) { return (x.id) === idListOrKeyword; });
            }
        }
        else {
            var splittedIdList_2 = idListOrKeyword.split(",");
            return this.getAll().filter(function (x) { return splittedIdList_2
                .some(function (k) { return x.keyword.indexOf(k.trim()) > -1; }); });
        }
    };
    Occupations.data = [];
    return Occupations;
}());
exports.Occupations = Occupations;

},{"../i18n/occupationcodes":45,"../logic/index":66}],55:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var index_1 = require("../codegen/index");
/**
 * Business logic relating to Onboarding process and Digital signature.
 */
var OnboardingLogic = /** @class */ (function () {
    function OnboardingLogic() {
    }
    /** Gets the authentication methods for digital signature. */
    OnboardingLogic.getTupasMethods = function () {
        var cdn = "https://cdn.salaxy.com/img";
        var imageOverrides = [
            "op",
            "nordea",
            "danske",
            "spankki",
            "handelsbanken",
            "mobiilivarmenne",
            "aktia",
            "pop",
            "sp",
            "omasp",
            "alandsbanken",
        ];
        var result = index_1.vismaSignOriginalMethods.map(function (v, i) {
            return {
                id: v.identifier,
                title: v.name,
                img: imageOverrides[i] ? cdn + "/salaxy/sign/" + imageOverrides[i] + ".png" : v.image,
                isPopular: i < 3,
            };
        });
        return result;
    };
    return OnboardingLogic;
}());
exports.OnboardingLogic = OnboardingLogic;

},{"../codegen/index":39}],56:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Business logic relating to payments.
 */
var PaymentLogic = /** @class */ (function () {
    function PaymentLogic() {
    }
    /** Gets the einvoice intermediators */
    PaymentLogic.getEInvoiceIntermediators = function () {
        var result = {
            "HELSFIHH": "Aktia - HELSFIHH",
            "003723327487": "Apix Messaging Oy - 003723327487",
            "BAWCFI22": "Basware Oyj - BAWCFI22",
            "003703575029": "CGI - 003703575029",
            "DABAFIHH": "Danske Bank - DABAFIHH",
            "DNBAFIHX": "DNB - DNBAFIHX",
            "HANDFIHH": "Handelsbanken - HANDFIHH",
            "885790000000418": "HighJump AS - 885790000000418",
            "INEXCHANGE": "InExchange Factorum AB - INEXCHANGE",
            "EXPSYS": "Lexmark Expert Systems AB - EXPSYS",
            "003708599126": "Liaison Technologies Oy - 003708599126",
            "003721291126": "Maventa - 003721291126",
            "003726044706": "Netbox Finland Oy - 003726044706",
            "NDEAFIHH": "Nordea Pankki - NDEAFIHH",
            "E204503": "OpusCapita Solutions Oy - E204503",
            "OKOYFIHH": "Osuuspankit ja Pohjola Pankki - OKOYFIHH",
            "PAGERO": "Pagero - PAGERO",
            "PALETTE": "Palette Software - PALETTE",
            "POPFFI22": "POP Pankki  - POPFFI22",
            "003710948874": "Posti Messaging Oy - 003710948874",
            "003701150617": "PostNord Strålfors Oy - 003701150617",
            "003714377140": "Ropo Capital Oy - 003714377140",
            "SBANFIHH": "S-Pankki - SBANFIHH",
            "TAPIFI22": "S-Pankki (ent. LähiTapiola Pankin tunnus toistaiseksi käytössä) - TAPIFI22",
            "ITELFIHH": "Säästöpankit - ITELFIHH",
            "003701011385": "Tieto Oyj - 003701011385",
            "885060259470028": "Tradeshift - 885060259470028",
            "AABAFI22": "Ålandsbanken - AABAFI22",
        };
        return result;
    };
    return PaymentLogic;
}());
exports.PaymentLogic = PaymentLogic;

},{}],57:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var codegen_1 = require("../codegen");
var Translations_1 = require("./Translations");
/**
 * Framework independendent business logic methods and helpers for Products.
 */
var ProductsLogic = /** @class */ (function () {
    function ProductsLogic() {
    }
    /** Gets the default products for a given role */
    ProductsLogic.getDefault = function (role) {
        var result = this.getAccountProductDefaults();
        if (role === "household" || role === "company") {
            if (role === "household") {
                result.pensionEntrepreneur = null;
            }
        }
        else if (role === "worker") {
            result.accounting = null;
            result.baseService = null;
            result.healthCareHeltti = null;
            result.insurance = null;
            result.pension = null;
            result.tax = null;
            result.unemployment = null;
        }
        return result;
    };
    /**
     * Gets a product based on id.
     * @param accountProducts The account products object containing all the products.
     * @param id Product id to fetch for - this is the name of the property key in accountProducts and id property of the value.
     * @param defaultValue Default value to return if accountProducts or id is falsy or id is not found or object returned by id is falsy.
     */
    ProductsLogic.getProductById = function (accountProducts, id, defaultValue) {
        if (defaultValue === void 0) { defaultValue = null; }
        if (!accountProducts || !id) {
            return defaultValue;
        }
        if (!accountProducts[id]) {
            accountProducts[id] = {};
        }
        var prod = accountProducts[id];
        return prod || defaultValue;
    };
    /**
     * Gets a product of a given type.
     * @param typeName Name of the type (the asme as generic typ T).
     */
    ProductsLogic.getProductByType = function (accountProducts, typeName, defaultValue) {
        if (defaultValue === void 0) { defaultValue = null; }
        switch (typeName) {
            case "HealthCareHelttiProduct":
                return ProductsLogic.getProductById(accountProducts, "healthCareHeltti", defaultValue);
            case "AccountingProduct":
                return ProductsLogic.getProductById(accountProducts, "accounting", defaultValue);
            case "BaseSalaryProduct":
                return ProductsLogic.getProductById(accountProducts, "baseService", defaultValue);
            case "InsuranceProduct":
                return ProductsLogic.getProductById(accountProducts, "insurance", defaultValue);
            case "PensionProduct":
                return ProductsLogic.getProductById(accountProducts, "pension", defaultValue);
            case "TaxProduct":
                return ProductsLogic.getProductById(accountProducts, "tax", defaultValue);
            case "UnemploymentProduct":
                return ProductsLogic.getProductById(accountProducts, "unemployment", defaultValue);
            case "PensionEntrepreneurProduct":
                return ProductsLogic.getProductById(accountProducts, "pensionEntrepreneur", defaultValue);
            default:
                throw new Error("Non-supported product type: " + typeName);
        }
    };
    /** Gets all the products for anonymous user (everything visible) */
    ProductsLogic.getAllProducts = function () {
        return this.getAccountProductDefaults();
    };
    ProductsLogic.getAccountProductDefaults = function () {
        var result = codegen_1.accountProductDefaults;
        for (var key in result) {
            if (result.hasOwnProperty(key)) {
                var product = result[key];
                product.title = Translations_1.Translations.get("SALAXY.ENUM.Product." + key + ".label");
                product.description = Translations_1.Translations.get("SALAXY.ENUM.Product." + key + ".description");
                product.status = Translations_1.Translations.get("SALAXY.ENUM.Product." + key + ".status");
            }
        }
        return result;
    };
    return ProductsLogic;
}());
exports.ProductsLogic = ProductsLogic;

},{"../codegen":39,"./Translations":62}],58:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var model_1 = require("../model");
var Translations_1 = require("./Translations");
/**
 * Salaxy business logic helpers. Mainly helper classes with static helper methods.
 *
 * All implementation should be independent from the framework (Angular 1, Angular, jQuery etc.).
 * Only the following dependencies are accepted:
 *
 * - Moment.js (not currently added)
 * - (New dependencies must be approved by Matti & Olli)
 */
/**
 * Framework independendent business logic methods and helpers for Reporting.
 */
var ReportsLogic = /** @class */ (function () {
    function ReportsLogic() {
    }
    /**
     * Gets a link URL for a yearly report. This is a relative link from the servr root (e.g. "/ReportHtml/YearEndReportJson?year=2017").
     * Typically the environment specific implementation needs to figure out the server address and token.
     * @param type - Type of the report must be one of the yearly reports
     * @param year - Year for the report
     * @param token - Token for authentication. Adds "access_token" to the query string.
     * This is typically required from the environment specific implementation,
     * but in exceptional cases you may use some other authentication mechanism and thus leave this null.
     * @param id - Worker ID for those reports that are specific to one Worker.
     * @param id2 - Second Worker ID for those reports that have two Workers in one report
     */
    ReportsLogic.getYearlyReportUrl = function (type, year, token, id, id2) {
        var url;
        switch (type) {
            case model_1.ReportType.YearEndReport:
                url = "/ReportHtml/YearEndReportJson?year=" + year;
                break;
            case model_1.ReportType.YearlyDetails:
            case model_1.ReportType.Insurance:
            case model_1.ReportType.HouseholdDeduction:
                url = "/ReportHtml/" + type + "?year=" + year;
                break;
            case model_1.ReportType.YearlyWorkerSummary:
                url = "/ReportHtml/" + type + "/" + id + "?year=" + year;
                break;
            case model_1.ReportType.Unemployment:
                url = "/ReportPdf/" + type + "?year=" + year;
                break;
            case model_1.ReportType.TaxYearly7801:
                url = "/ReportPdf/" + type + "/" + id + "?year=" + year;
                break;
            case model_1.ReportType.TaxHouseholdDeduction14B:
            case model_1.ReportType.TaxHouseholdDeduction14BSpouseA:
            case model_1.ReportType.TaxHouseholdDeduction14BSpouseB:
                url = "/ReportPdf/" + type + "/" + id + "?id2=" + (id2 || "") + "&year=" + year;
                break;
            default:
                throw new Error("Not a supported year end report: " + type);
        }
        if (token) {
            url = url + "&access_token=" + token;
        }
        return url;
    };
    /**
     * Gets a URL for a calculation report. This is a relative link from the servr root (e.g. "/ReportHtml/SalarySlip/CALC_ID_HERE").
     * Typically the environment specific implementation needs to figure out the server address and token.
     * @param reportType - Type of report
     * @param calcId - Identifier of the calculation. This method requires that the calculation has been saved.
     * @param token - Token for authentication. Adds "access_token" to the query string.
     * This is typically required from the environment specific implementation,
     * but in exceptional cases you may use some other authentication mechanism and thus leave this null.
     */
    ReportsLogic.getCalcReportUrl = function (reportType, calcId, token) {
        if (!calcId) {
            throw new Error("Calculation ID is required by getCalcReportUrl");
        }
        switch (reportType) {
            case "salarySlip":
            case "paymentReport":
            case "employerReport":
                var url = "/ReportHtml/" + reportType + "/" + calcId;
                if (token) {
                    url = url + "?access_token=" + token;
                }
                return url;
            default:
                throw new Error("Unknown type in getCalcReportUrl: " + reportType);
        }
    };
    /**
     * Gets a URL for a calculation pdf file. This is a relative link from the servr root (e.g. "/ReportPdf/SalarySlip/CALC_ID_HERE").
     * Typically the environment specific implementation needs to figure out the server address and token.
     * @param reportType - Type of report
     * @param calcId - Identifier of the calculation. This method requires that the calculation has been saved.
     * @param inline - If true, the Content-Disposition header is returned with inline parameter.
     * @param token - Token for authentication. Adds "access_token" to the query string.
     * This is typically required from the environment specific implementation,
     * but in exceptional cases you may use some other authentication mechanism and thus leave this null.
     */
    ReportsLogic.getCalcPdfUrl = function (reportType, calcId, inline, token) {
        if (inline === void 0) { inline = false; }
        if (!calcId) {
            throw new Error("Calculation ID is required by getCalcPdfUrl");
        }
        switch (reportType) {
            case "salarySlip":
            case "paymentReport":
            case "employerReport":
                var url = "/ReportPdf/" + reportType + "/" + calcId + "?inline=" + (inline ? "true" : "false");
                if (token) {
                    url += "&access_token=" + token;
                }
                return url;
            default:
                throw new Error("Unknown type in getCalcPdfUrl: " + reportType);
        }
    };
    /** Gets metadata about the supported report types */
    ReportsLogic.getReportTypes = function () {
        // TODO: Merge this with salaxy.moveToCore.enumerations in palkkaus-web-worker project.
        var reportTypes = [
            {
                id: "undefined",
                title: "Valitse...",
                description: "Ei valintaa tai tuntematon tyyppi. ",
                roles: "",
                category: "tech",
            },
            {
                id: "example",
                title: "Esimerkki",
                description: "Esimerkki raportti kehityskäyttöön. Ei dataa, ei parametrejä.",
                roles: "",
                category: "tech",
            },
            {
                id: "monthlyDetails",
                title: "Monthly details",
                description: "The most detailed of the employer monthly reports.",
                roles: "employer",
                category: "monthly",
            },
            {
                id: "taxMonthly4001",
                title: "Monthly tax report (4001)",
                description: "Monthly tax report",
                roles: "employer",
                category: "monthly",
            },
            {
                id: "monthlyPension",
                title: "Monthly pension report",
                description: "Monthly pension report",
                roles: "employer",
                category: "monthly",
            },
            {
                id: "monthlyLiikekirjuri",
                title: "Accounting report (Liikekirjuri)",
                description: "'Liikekirjuri' - a historical monthly report that was used for 2016 and 2017. Will be replaced by Rapko.",
                roles: "company",
                category: "monthly",
            },
            {
                id: "monthlyRapko",
                title: "Accounting report (Rapko)",
                description: "Rapko / Raportointikoodisto is the Finnish standard for accounting.",
                roles: "company",
                category: "monthly",
            },
            {
                id: "yearlyDetails",
                title: "Yearly details",
                description: "Detailed list for employer - this is a general report.",
                roles: "employer",
                category: "yearly",
            },
            {
                id: "yearEndReport",
                title: "Year-end report",
                description: "The year-end report with customer feedback",
                roles: "employer",
                category: "yearly",
            },
            {
                id: "yearlyWorkerSummary",
                title: "Yearly worker summary",
                description: "Detailed report - similar to salary slip - from employer to worker. This report must be given by employer according to Finnish law.",
                roles: "employer",
                category: "yearly",
            },
            {
                id: "taxYearly7801",
                title: "Yearly tax report (7801)",
                description: "Form 7801: Yearly report for Finnish tax authorities",
                roles: "employer",
                category: "yearly",
            },
            {
                id: "unemployment",
                title: "Unemployment insurance report",
                description: "Report for Finnish Unemployment insurance TVR",
                roles: "employer",
                category: "yearly",
            },
            {
                id: "insurance",
                title: "Accident insurance report",
                description: "Report for mandatory accident insurance company",
                roles: "employer",
                category: "yearly",
            },
            {
                id: "householdDeduction",
                title: "Household deduction yearly report",
                description: "General (internal) household deduction yearly report.",
                roles: "household",
                category: "yearly",
            },
            {
                id: "taxHouseholdDeduction14B",
                title: "Household deduction report to authorities (14B)",
                description: "Form 14B: Household deduction report for Finnish tax authorities. All deductible salaries included.",
                roles: "household",
                category: "yearly",
            },
            {
                id: "taxHouseholdDeduction14BSpouseA",
                title: "Household deduction 14B, self only",
                description: "Form 14B: Household deduction report for Finnish tax authorities. Contains only deductible salaries which are attributed to self.",
                roles: "household",
                category: "yearly",
            },
            {
                id: "taxHouseholdDeduction14BSpouseB",
                title: "Household deduction 14B, spouse only",
                description: "Form 14B: Household deduction report for Finnish tax authorities. Contains only deductible salaries which are split to spouse of customer.",
                roles: "household",
                category: "yearly",
            },
            {
                id: "salarySlipCopy",
                title: "Salary slip (worker copy)",
                description: "Copy of the salary slip for the worker.",
                roles: "worker",
                category: "calc",
            },
            {
                id: "salarySlipPaid",
                title: "Salary slip (paid by employer)",
                description: "Salary slip paid by the employer",
                roles: "employer",
                category: "calc",
            },
            {
                id: "employerReport",
                title: "Employer report of salary",
                description: "Report of a single calculation from the Employer point-of-view",
                roles: "employer",
                category: "calc",
            },
            {
                id: "paymentReport",
                title: "Payment report of salary",
                description: "Report of a single calculation from the payments / society point-of-view.",
                roles: "employer",
                category: "calc",
            },
            {
                id: "employmentContract",
                title: "Employment contract",
                description: "Employment contract",
                roles: "all",
                category: "contract",
            },
        ];
        for (var _i = 0, reportTypes_1 = reportTypes; _i < reportTypes_1.length; _i++) {
            var reportType = reportTypes_1[_i];
            reportType.title = Translations_1.Translations.get("SALAXY.ENUM.ReportType." + reportType.id + ".label");
            reportType.description = Translations_1.Translations.get("SALAXY.ENUM.ReportType." + reportType.id + ".description");
        }
        return reportTypes;
    };
    return ReportsLogic;
}());
exports.ReportsLogic = ReportsLogic;

},{"../model":73,"./Translations":62}],59:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var model_1 = require("../model");
var model_2 = require("./model");
/**
 * Provides business logic for role membership rules.
 */
var RoleLogic = /** @class */ (function () {
    function RoleLogic() {
    }
    /**
     * Checks whether the user is in a given role
     * @param session - Session of the current account.
     * @param appStatus - Additional information about the session and application status.
     * @param role - One of the known roles or role from server.
     * You can also use exclamation mark for negative (e.g.)
     * @return Boolean whether user is in the given role
     */
    RoleLogic.isInRole = function (session, appStatus, role) {
        if (!role) {
            return true;
        }
        role = role.trim();
        var isNegative = role.startsWith("!");
        if (isNegative) {
            role = role.substr(1);
        }
        role = (role || "any").trim();
        role = role.substr(0, 1).toLowerCase() + role.substr(1); // Tolerate Capital first letter
        var primaryRole = null;
        var currentAccount = session ? session.currentAccount : null;
        if (currentAccount) {
            if (currentAccount.entityType === model_1.LegalEntityType.Company) {
                primaryRole = model_2.SystemRole.Company; // Company is clear
            }
            else {
                var personAccount = currentAccount;
                if (personAccount.lastLoginAs === model_1.WebSiteUserRole.Worker || (!personAccount.isEmployer && personAccount.isWorker)) {
                    primaryRole = model_2.SystemRole.Worker; // LastLoginAs is clear, but we cannot rely on isWorker directly as some users are both isEmployer=true ans isWorker=true.
                }
                else {
                    primaryRole = model_2.SystemRole.Household; // Default to household if both and no lastLogin.
                }
            }
        }
        var config = salaxy.config;
        var checkRole = function (role) {
            switch (role) {
                // No session required
                case model_2.SystemRole.Unknown:
                    return appStatus.sessionCheckInProgress;
                case model_2.SystemRole.Anon:
                    return !appStatus.sessionCheckInProgress && (!session || !session.isAuthorized);
                case model_2.SystemRole.Init:
                    return appStatus.sessionCheckInProgress;
                case model_2.SystemRole.Hidden:
                    return false;
                case model_2.SystemRole.Test:
                    return !config || config.isTestData;
                case model_2.SystemRole.Prod:
                    return config && !config.isTestData;
                case model_2.SystemRole.Any:
                case "*":
                    return true;
                // Session required (may be checked from primaryRole or currentAccount shortcuts)
                case model_2.SystemRole.Auth:
                    return session && session.isAuthorized;
                case model_2.SystemRole.Worker:
                    return primaryRole === model_2.SystemRole.Worker;
                case model_2.SystemRole.Employer:
                    return primaryRole === model_2.SystemRole.Company || primaryRole === model_2.SystemRole.Household;
                case model_2.SystemRole.Household:
                    return primaryRole === model_2.SystemRole.Household;
                case model_2.SystemRole.Company:
                    return primaryRole === model_2.SystemRole.Company;
                case model_2.SystemRole.Person:
                    return primaryRole === model_2.SystemRole.Worker || primaryRole === model_2.SystemRole.Household;
                case model_2.SystemRole.NonVerified:
                    return currentAccount && !currentAccount.isVerified;
                case model_2.SystemRole.FiTm:
                case model_2.SystemRole.FiOy:
                case model_2.SystemRole.FiRy:
                    return primaryRole === model_2.SystemRole.Company && session.currentAccount.companyType === role;
                default:
                    return (currentAccount && session.currentAccount.identity.roles.indexOf(role) >= 0)
                        || appStatus.clientRoles.indexOf(role) >= 0;
            }
        };
        return isNegative ? !checkRole(role) : checkRole(role);
    };
    /**
     * Returns true if the current account is a member of all of the given roles.
     * Returns true if the roles is null or an empty array or and an empty string.
     * @param session - Session of the current account.
     * @param appStatus - Additional information about the session and application status.
     * @param roles - Array of role values.
     */
    RoleLogic.isInAllRoles = function (session, appStatus, roles) {
        var _this = this;
        if (!roles || roles.length === 0) {
            return true;
        }
        return roles.every(function (x) { return _this.isInRole(session, appStatus, x); });
    };
    /**
     * Returns true if the current account is a member of some of the given roles.
     * Returns true if the roles is null or an empty array or an empty string.
     * @param session - Session of the current account.
     * @param roles - Array of role values.
     */
    RoleLogic.isInSomeRole = function (session, appStatus, roles) {
        var _this = this;
        if (!roles || roles.length === 0) {
            return true;
        }
        return roles.some(function (x) { return _this.isInRole(session, appStatus, x); });
    };
    return RoleLogic;
}());
exports.RoleLogic = RoleLogic;

},{"../model":73,"./model":70}],60:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var util_1 = require("../util");
/**
 * Provides business logic for calculating salary date.
 */
var SalaryDateLogic = /** @class */ (function () {
    function SalaryDateLogic() {
    }
    /**
     * Returns true, if the given date is a valid Salary date for given gross salary payment date.
     *
     * @param salaryDate - Salary date (the date when the salary is in worker).
     * @param iban - Bank account number of the worker.
     * @param paidAt - Date for the gross salary payment.
     * @returns - True if the given dates are not conflicting (salary date is possible for given paid at date).
     */
    SalaryDateLogic.isValidSalaryDate = function (salaryDate, iban, paidAt) {
        if (iban === void 0) { iban = null; }
        if (paidAt === void 0) { paidAt = null; }
        var calculatedSalaryDate = this.CalculateSalaryDate(iban, paidAt, true);
        var currentMoment = util_1.Dates.getMoment(new Date());
        var unshiftedMoment = currentMoment.clone().add(-1 * currentMoment.utcOffset(), "m");
        var unshiftedMomentDate = util_1.Dates.getMoment(util_1.Dates.asDate(unshiftedMoment));
        if (util_1.Dates.isWorkday(salaryDate) &&
            ((util_1.Dates.getWorkdays(calculatedSalaryDate, salaryDate).length - 1) >= this.daysPaymentDueDateDelay) &&
            (util_1.Dates.getMoment(salaryDate).diff(unshiftedMomentDate, "days") <= this.daysToSalaryDate)) {
            return true;
        }
        return false;
    };
    /**
     * Calculates the estimated salary date (the date when the salary is in worker) for the given gross salary payment date.
     *
     * @param iban  - The iban number of the worker.
     * @param paidAt - Date for the salary gross payment.
     * @param isRequestedSalaryDateSet - Flag to indicate, if the requested salary date is set.
     */
    SalaryDateLogic.CalculateSalaryDate = function (iban, paidAt, isRequestedSalaryDateSet) {
        if (iban === void 0) { iban = null; }
        if (paidAt === void 0) { paidAt = null; }
        if (isRequestedSalaryDateSet === void 0) { isRequestedSalaryDateSet = false; }
        var latePaymentDelay = 0;
        var paidAtMoment = util_1.Dates.getMoment(paidAt);
        var daysNonBigBankPaymentDelay = this.daysNonBigBankPaymentDelay;
        if (!paidAtMoment) {
            var d = new Date();
            // time shift needed for backend compatibility
            var unshiftedPaidAtMoment = util_1.Dates.getMoment(d);
            paidAtMoment = unshiftedPaidAtMoment.clone().add(-1 * unshiftedPaidAtMoment.utcOffset(), "m");
            if (util_1.Dates.isWorkday(paidAtMoment)) {
                if (paidAtMoment.date() === unshiftedPaidAtMoment.date()) {
                    if (unshiftedPaidAtMoment.hours() >= 16) {
                        latePaymentDelay = this.daysLatePaymentDelay;
                    }
                }
                else {
                    latePaymentDelay = this.daysLatePaymentDelay;
                }
            }
        }
        else {
            if (util_1.Dates.isWorkday(paidAtMoment)) {
                if (paidAtMoment.date() === paidAtMoment.local().date()) {
                    if (paidAtMoment.local().hours() >= 16) {
                        latePaymentDelay = this.daysLatePaymentDelay;
                    }
                }
                else {
                    latePaymentDelay = this.daysLatePaymentDelay;
                }
            }
        }
        if (isRequestedSalaryDateSet) {
            latePaymentDelay = this.daysLatePaymentDelay;
            daysNonBigBankPaymentDelay = 0;
        }
        var paidAtWorkdayMoment = this.getWorkdayMoment(paidAtMoment);
        var smallBankDelay = this.isBigBank(iban) ? 0 : daysNonBigBankPaymentDelay;
        var aspaTime = this.daysCustomerServiceProcessing;
        var requiredTime = latePaymentDelay + aspaTime + smallBankDelay;
        var salaryDate = util_1.Dates.addWorkdays(paidAtWorkdayMoment, requiredTime);
        return util_1.Dates.asDate(salaryDate);
    };
    SalaryDateLogic.getWorkdayMoment = function (moment) {
        var newMoment = util_1.Dates.getMoment(util_1.Dates.asDate(moment));
        while (true) {
            if (util_1.Dates.isWorkday(newMoment)) {
                return newMoment;
            }
            newMoment.add(1, "days");
        }
    };
    SalaryDateLogic.isBigBank = function (iban) {
        if (iban && iban.length > 6) {
            var id = iban.substr(4, 3);
            if (id.startsWith("1") ||
                id.startsWith("2") ||
                id.startsWith("34") ||
                id.startsWith("8") ||
                id.startsWith("5")) {
                return true;
            }
            return false;
            /*
                    1nn = Nordea Bank(Nordea)
                    2nn = Nordea Bank(Nordea)
                    31n = Handelsbanken(SHB)
                    33n = Skandinaviska Enskilda Banken(SEB)
                    34n = Danske Bank
                    36n = S - Bank
                    37n = DnB NOR Bank(DnB NOR)
                    38n = Swedbank
                    39n = S - Bank
                    4nn = Savings Banks(Sp), local co-operative banks and Aktia Bank
                    5nn = Co - operative banks(Op) and OKO Bank
                    6nn = Bank of Åland
                    713 = Citibank
                    8nn = Danske Bank
              */
        }
    };
    /**
     * Required days to process the incoming payment to worker net payment.
     */
    SalaryDateLogic.daysCustomerServiceProcessing = 1;
    /**
     * Payment delay if the bank is not a big bank.
     */
    SalaryDateLogic.daysNonBigBankPaymentDelay = 1;
    /**
     * Payment delay if the  payment takes place outside bank hours.
     */
    SalaryDateLogic.daysLatePaymentDelay = 1;
    /**
     * Delay needed for the payment transaction date setting for salary.
     */
    SalaryDateLogic.daysPaymentDueDateDelay = 1;
    /**
     * Maximum time from now to salary date.
     */
    SalaryDateLogic.daysToSalaryDate = 90;
    return SalaryDateLogic;
}());
exports.SalaryDateLogic = SalaryDateLogic;

},{"../util":90}],61:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var model_1 = require("../model");
var util_1 = require("../util");
/**
 * Provides business logic related to TaxCards:
 * The Finnish way of determining the widtholding tax that Employer should deduct from Worker salary.
 */
var TaxCard2019Logic = /** @class */ (function () {
    function TaxCard2019Logic() {
    }
    /**
     * Gets a new blank taxcard with default values, suitable for UI binding.
     *
     * @param personalId The personal ID that is used to connect the Taxcard to a person. This is required in save.
     * @param kind If specified, sets the type and defaults according to the type
     * @param year Specifies the year. This is used in December-January when there may be cards from both years.
     * Current year is the default.
     * @param today Allows changing the today date in unit testing etc. Default is actual today.
     */
    TaxCard2019Logic.getBlank = function (personalId, kind, year, today) {
        if (kind === void 0) { kind = null; }
        today = today || util_1.Dates.getToday();
        year = year || util_1.Dates.getTodayMoment().year();
        var newCard = {
            worker: null,
            card: {
                personalId: personalId,
                forYear: year,
                taxPercent: null,
                incomeLimit: null,
                taxPercent2: null,
                kind: model_1.TaxcardKind.Undefined,
                fileUri: null,
                previewUri: null,
                validity: {},
            },
            incomeLog: [],
            id: null,
            createdAt: today,
            updatedAt: today,
            isReadOnly: null,
        };
        newCard.card.date = today; // For backward compatibility. May be removed soon.
        if (kind) {
            newCard.card.kind = kind;
            switch (kind) {
                case model_1.TaxcardKind.Undefined:
                    newCard.card.taxPercent = 23;
                    break;
                case model_1.TaxcardKind.NoTaxCard:
                    newCard.card.taxPercent = 60;
                    newCard.card.validity.start = today;
                    break;
                case model_1.TaxcardKind.DefaultYearly:
                    newCard.card.validity.start = year + "-02-01";
                    newCard.card.validity.end = year + "-12-31";
                    break;
                case model_1.TaxcardKind.Replacement:
                case model_1.TaxcardKind.Others:
                case model_1.TaxcardKind.Historical:
                    newCard.card.validity.start = util_1.Dates.getYear(today) < year ? year + "-01-01"
                        : (util_1.Dates.getYear(today) > year ? year + "-12-31" : today);
                    newCard.card.validity.end = year + "-12-31";
                    break;
            }
        }
        return newCard;
    };
    /**
     * Gets the tax card year for a specific salary date.
     * For January, this is the previous year.
     * @param salaryDate Salary date. If null, today is used.
     */
    TaxCard2019Logic.getTaxCardYear = function (salaryDate) {
        if (salaryDate === void 0) { salaryDate = null; }
        salaryDate = salaryDate || "today";
        var year = util_1.Dates.getYear(salaryDate || "today");
        if (util_1.Dates.getMonth(salaryDate) === 1) {
            // In January, we use the previous year's taxcard.
            year--;
        }
        return year;
    };
    /**
     * Checks if the taxcard is valid for the salary date.
     * @param card Taxcard to check.
     * @param salaryDate Salary date. Default is today.
     */
    TaxCard2019Logic.isTaxcardValid = function (card, salaryDate) {
        if (salaryDate === void 0) { salaryDate = "today"; }
        // TODO: It is unclear whether this method is really needed or can we just rely on server in all cases.
        if (!card || !card.card || !card.card.validity) {
            return false;
        }
        salaryDate = util_1.Dates.asDate(salaryDate) || util_1.Dates.getToday();
        if (!(card.card.validity.start > salaryDate) && !(card.card.validity.end < salaryDate)) {
            return true;
        }
        if (util_1.Dates.getMonth(salaryDate) === 1 && card.card.forYear === util_1.Dates.getYear(salaryDate) - 1) {
            return true;
        }
        return false;
    };
    /**
     * Sorts an array of taxcards to ascending order (latest last).
     * See taxCardSorter for logic.
     */
    TaxCard2019Logic.sortAsc = function (taxcards) {
        return taxcards.sort(TaxCard2019Logic.taxCardSorter);
    };
    /**
     * Sorts an array of taxcards to descending order (latest first).
     * See taxCardSorter for logic.
     */
    TaxCard2019Logic.sortDesc = function (taxcards) {
        return taxcards.sort(function (a, b) { return TaxCard2019Logic.taxCardSorter(a, b) * -1; });
    };
    /**
     * Sorter for taxcards.
     * First sorts based on card date, then based on updatedAt.
     */
    TaxCard2019Logic.taxCardSorter = function (ob1, ob2) {
        if (ob1.updatedAt > ob2.updatedAt) {
            return 1;
        }
        else if (ob1.updatedAt < ob2.updatedAt) {
            return -1;
        }
        if (ob1.updatedAt < ob2.updatedAt) {
            return -1;
        }
        else if (ob1.updatedAt > ob2.updatedAt) {
            return 1;
        }
        return 0;
    };
    /** Gets the current total income that has been registered for a given taxcard. */
    TaxCard2019Logic.getTotalIncome = function (card) {
        if (card && card.incomeLog) {
            return util_1.Numeric.round(util_1.Arrays.sum(card.incomeLog, function (x) { return x.income; }), 2);
        }
        return 0;
    };
    /**
     * Gets information about the the income limit and real percent.
     * Note that this method calculates the real percent i.e.
     * for examples and no tax cards 60%. If you wish to see the example percent here (23%),
     * catch it separately.
     * @param taxcard Card to analyze
     */
    TaxCard2019Logic.getIncomeLimitInfo = function (taxcard) {
        var result = {
            type: model_1.TaxcardKind.Undefined,
            percent: 60,
            hasLimit: false,
            fractionOfLimit: 0,
        };
        if (!taxcard || !taxcard.card || !taxcard.card.kind) {
            return result;
        }
        var card = taxcard.card;
        result.percent = card.taxPercent === 0 ? 0 : card.taxPercent || 60;
        result.type = card.kind;
        var income = this.getTotalIncome(taxcard);
        switch (result.type) {
            // May or may not have limits
            case model_1.TaxcardKind.DefaultYearly:
            case model_1.TaxcardKind.Replacement:
            case model_1.TaxcardKind.Others:
                result.hasLimit = !!(card.incomeLimit && card.taxPercent2);
                if (result.hasLimit) {
                    result.fractionOfLimit = income / card.incomeLimit;
                    if (income > card.incomeLimit && card.taxPercent2) {
                        result.percent = card.taxPercent2;
                    }
                }
                return result;
            // No limit
            case model_1.TaxcardKind.NoTaxCard:
            case model_1.TaxcardKind.Undefined:
            default:
                return result;
        }
    };
    /** Gets the main chart for taxcards */
    TaxCard2019Logic.getMainChart = function (taxcard) {
        var limits = TaxCard2019Logic.getIncomeLimitInfo(taxcard);
        var taxCardIncomeLimit = taxcard.card.incomeLimit;
        var totalIncome = TaxCard2019Logic.getTotalIncome(taxcard);
        var taxPercent = taxcard.card.taxPercent;
        var taxPercent2 = taxcard.card.taxPercent2;
        var incomeSum = 0;
        var incomes = taxcard.incomeLog.map(function (value) {
            incomeSum += value.income;
            return { x: value.paidAt, y: incomeSum };
        });
        if (incomes.length === 0) {
            incomes = [
                { x: taxcard.card.validity.start, y: 0 },
            ];
        }
        var validity = [
            { x: taxcard.card.validity.start, y: 0 },
            { x: taxcard.card.validity.end, y: taxcard.card.incomeLimit },
        ];
        var colorPrimary = util_1.Brand.getBrandColor("primary", "rgba");
        var colorDanger = util_1.Brand.getBrandColor("danger", "rgba");
        var colorWarning = util_1.Brand.getBrandColor("warning", "rgba");
        var result = {
            limits: limits,
            data: [
                incomes,
                validity,
            ],
            labels: null,
            datasets: [
                {
                    label: "Saadut palkat",
                    fill: false,
                    index: 2,
                    lineTension: 0,
                    backgroundColor: colorPrimary,
                    pointBackgroundColor: colorPrimary,
                    pointHoverBackgroundColor: colorPrimary,
                    borderColor: colorPrimary,
                    pointBorderColor: colorPrimary,
                    pointHoverBorderColor: colorPrimary,
                },
                {
                    label: "Tuloraja",
                    backgroundColor: colorWarning,
                    pointBackgroundColor: colorWarning,
                    pointHoverBackgroundColor: colorWarning,
                    borderColor: colorWarning,
                    pointBorderColor: colorWarning,
                    pointHoverBorderColor: colorWarning,
                    fill: false,
                    borderDash: [5, 5],
                    lineTension: 0,
                },
            ],
            options: {
                maintainAspectRatio: false,
                legend: {
                    display: true,
                    position: "bottom",
                },
                title: {
                    display: true,
                    text: "Maksetut palkat ja vuosikohtainen tuloraja",
                },
                scales: {
                    yAxes: [{
                            display: true,
                            ticks: {
                                suggestedMax: taxCardIncomeLimit * 1.5,
                                // OR //
                                beginAtZero: true,
                            },
                        }],
                    xAxes: [{
                            type: "time",
                            time: {
                                displayFormats: {
                                    millisecond: "D.M.YYYY",
                                    second: "D.M.YYYY",
                                    minute: "D.M.YYYY",
                                    hour: "D.M.YYYY",
                                    day: "D.M.YYYY",
                                    week: "D.M.YYYY",
                                    month: "D.M.YYYY",
                                    year: "D.M.YYYY",
                                },
                                minUnit: "day",
                                tooltipFormat: "D.M.YYYY",
                            },
                        }],
                },
                annotation: {
                    annotations: [{
                            type: "line",
                            mode: "horizontal",
                            scaleID: "y-axis-0",
                            value: taxCardIncomeLimit,
                            borderColor: colorDanger,
                            borderWidth: 2,
                            label: {
                                position: "left",
                                enabled: true,
                                content: taxCardIncomeLimit + " €",
                                fontColor: "#fff",
                                fontSize: 11,
                                backgroundColor: colorDanger,
                                yAdjust: 0,
                                xAdjust: 60,
                            },
                        },
                        {
                            type: "line",
                            mode: "horizontal",
                            scaleID: "y-axis-0",
                            value: taxCardIncomeLimit,
                            borderColor: "transparent",
                            borderWidth: 0,
                            label: {
                                position: "left",
                                enabled: true,
                                content: taxPercent2 + " %",
                                fontSize: 16,
                                fontColor: colorDanger,
                                backgroundColor: "transparent",
                                yAdjust: -11,
                                xAdjust: 5,
                            },
                        },
                        {
                            type: "line",
                            mode: "horizontal",
                            scaleID: "y-axis-0",
                            value: taxCardIncomeLimit,
                            borderColor: "transparent",
                            borderWidth: 0,
                            label: {
                                position: "left",
                                enabled: true,
                                content: taxPercent + " %",
                                fontSize: 16,
                                fontColor: colorWarning,
                                backgroundColor: "transparent",
                                yAdjust: 15,
                                xAdjust: 5,
                            },
                        },
                        {
                            type: "line",
                            mode: "horizontal",
                            scaleID: "y-axis-0",
                            value: 0,
                            borderColor: "transparent",
                            borderWidth: 0,
                            label: {
                                position: "right",
                                enabled: true,
                                content: "31.12.2019: " + totalIncome + " €",
                                fontSize: 12,
                                fontColor: colorPrimary,
                                backgroundColor: "#fff",
                                yAdjust: -30,
                                xAdjust: 10,
                            },
                        }],
                },
                tooltips: {
                    backgroundColor: "rgba(255,255,255,1)",
                    titleFontColor: "#000",
                    bodyFontColor: "#000",
                    borderColor: "#000",
                    displayColors: false,
                    intersect: false,
                    enabled: true,
                    mode: "single",
                    callbacks: {
                        label: function (tooltipItem, data) {
                            var label = data.datasets[tooltipItem.datasetIndex].label || "";
                            if (label) {
                                label += " " + tooltipItem.xLabel + ": ";
                            }
                            label += Math.round(tooltipItem.yLabel * 100) / 100;
                            return label;
                        },
                    },
                },
                events: ["mousemove", "click"],
            },
        };
        return result;
    };
    /** Gets the pie chart for the taxcards. This is used for simplistic cases that do not have an income limit. */
    TaxCard2019Logic.getPieChartData = function (taxcard) {
        var limits = TaxCard2019Logic.getIncomeLimitInfo(taxcard);
        var netSalary = 100 - limits.percent;
        var label1Suffix = limits.fractionOfLimit < 1 ? "perusprosentti" : "lisäprosentti";
        var getColorPalette = function (color) {
            return {
                backgroundColor: color,
                pointBackgroundColor: color,
                pointHoverBackgroundColor: color,
                borderColor: color,
                pointBorderColor: color,
                pointHoverBorderColor: color,
            };
        };
        var result = {
            limits: limits,
            data: [
                limits.percent,
                100 - limits.percent,
            ],
            datasets: [
                {
                    label: ["Test", "test 2"],
                },
            ],
            labels: [
                "Ennakonpid\u00E4tys (" + label1Suffix + ") " + util_1.Numeric.formatPercent(limits.percent),
                "K\u00E4teen j\u00E4\u00E4v\u00E4 osuus " + util_1.Numeric.formatPercent(netSalary),
            ],
            colors: [
                getColorPalette(limits.type === model_1.TaxcardKind.NoTaxCard
                    ? util_1.Brand.getBrandColor("danger", "rgba")
                    : util_1.Brand.getBrandColor("warning", "rgba")),
                getColorPalette(util_1.Brand.getBrandColor("primary", "rgba")),
            ],
            options: {
                legend: {
                    display: true,
                    position: "bottom",
                    fullWidth: true,
                    reverse: true,
                },
                tooltips: {
                    enabled: true,
                    mode: "single",
                    bodySpacing: 6,
                    callbacks: {
                        label: function (tooltipItem, data) {
                            return data.labels[tooltipItem.index];
                        },
                    },
                },
                events: ["mousemove", "click"],
            },
        };
        return result;
    };
    return TaxCard2019Logic;
}());
exports.TaxCard2019Logic = TaxCard2019Logic;

},{"../model":73,"../util":90}],62:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var dictionary_1 = require("../i18n/dictionary");
/**
 * Provides universal i18n methods:
 * The core JavaScript code uses this to determine the UI texts and potentially
 * formatting. The frameworks on top of core (Angular, NG1) may have their own
 * frameworks and/or they may integrate to this core i18n.
 */
var Translations = /** @class */ (function () {
    function Translations() {
    }
    /**
     * Translates given key to the current language.
     * @param key - Key for the text.
     * @param interpolateParams - Variables for the interpolation.
     * @returns The translated value in current language or if none is found the key.
     */
    Translations.get = function (key, interpolateParams) {
        var template = this.getWithDefault(key, null);
        if (!template) {
            return key;
        }
        // interpolate
        var regex = /\{\{\s*(\S+)\s*\}\}/g;
        // dotted paths not supported yet.
        // array references not supported yet.
        // tslint:disable-next-line
        return template.replace(regex, function (_unused, varName) {
            if (!interpolateParams) {
                return "";
            }
            return interpolateParams[varName] || "";
        });
    };
    /**
     * Translates given key to the current language.
     * @param key - Key for the text.
     * @param defaultValue - The default value that is returned if the key is not found. Null is the default.
     * @returns The translated value in current language or if none is found the key.
     */
    Translations.getWithDefault = function (key, defaultValue) {
        if (defaultValue === void 0) { defaultValue = null; }
        var subKeys = key.split(".");
        var value = this.dictionary[this.lang];
        for (var _i = 0, subKeys_1 = subKeys; _i < subKeys_1.length; _i++) {
            var subKey = subKeys_1[_i];
            if (value.hasOwnProperty(subKey)) {
                value = value[subKey];
            }
            else {
                return defaultValue;
            }
        }
        return value;
    };
    /**
     * Adds a dictionary.
     * @param lang - ISO language code for the dictionary to be added: fi, en or sv.
     * @param translations - A translations object (json).
     */
    Translations.addDictionary = function (lang, translations) {
        // TODO: This is not a merging addition, it should be.
        this.dictionary[lang] = translations;
    };
    /**
     * Add all dictionaries from a single language object. This object must have language codes as first level keys.
     * @param translations - A translations object (json).
     */
    Translations.addDictionaries = function (translations) {
        for (var key in translations) {
            if (translations.hasOwnProperty(key)) {
                this.addDictionary(key, translations[key]);
            }
        }
    };
    /**
     * Sets the Salaxy user interface language.
     * @param lang - One of the supported languages: "fi", "en" or "sv".
     */
    Translations.setLanguage = function (lang) {
        Translations.lang = lang;
    };
    /**
     * Gets the current user interface language
     * @returns One of the supported languages: "fi", "en" or "sv".
     */
    Translations.getLanguage = function () {
        return Translations.lang;
    };
    /** Current language. */
    Translations.lang = "fi";
    /** Current dictionary object. */
    Translations.dictionary = dictionary_1.dictionary;
    return Translations;
}());
exports.Translations = Translations;

},{"../i18n/dictionary":43}],63:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var model_1 = require("../model");
var util_1 = require("../util");
var EnumerationsLogic_1 = require("./EnumerationsLogic");
/**
 * Provides business logic related to Worker accounts: Workers as Employers see them.
 */
var WorkerLogic = /** @class */ (function () {
    function WorkerLogic() {
    }
    /**
     * Gets a new blank worker account with default values, suitable for UI binding.
     */
    WorkerLogic.getBlank = function () {
        return {
            avatar: {
                pictureType: model_1.AvatarPictureType.Icon,
            },
            employment: {
                irIncomeEarnerTypes: [],
                holidays: {},
                usecase: {
                    data: {},
                },
                work: {
                    salaryDefaults: [],
                },
            },
            contact: {},
            workerInfo: {},
            ageRange: model_1.AgeRange.Age18_52,
            entityType: model_1.LegalEntityType.PersonCreatedByEmployer,
            id: null,
            createdAt: util_1.Dates.getToday(),
            updatedAt: util_1.Dates.getToday(),
            isReadOnly: null,
        };
    };
    /**
     * Creates a new avatar object based on firstName and lastName.
     * This simulates how server will eventually create an avatar object for a worker.
     * @param firstName First name of the person.
     * @param lastName Last name of the person.
     * @param color Avatar color. If not set, this will later be random generated (in this implementation, a static grayish color).
     */
    WorkerLogic.createAvatar = function (firstName, lastName, color) {
        firstName = WorkerLogic.capitalizeFirstLetter((firstName || "").trim()) || " ";
        lastName = WorkerLogic.capitalizeFirstLetter((lastName || "").trim()) || " ";
        color = color || "rgb(21, 83, 93)";
        return {
            color: color,
            displayName: (firstName + " " + lastName).trim() || "?",
            firstName: firstName,
            entityType: model_1.LegalEntityType.PersonCreatedByEmployer,
            initials: (firstName.substr(0, 1) + lastName.substr(0, 1)) || "?",
            lastName: lastName,
            pictureType: model_1.AvatarPictureType.Icon,
            sortableName: ((lastName + ", " + firstName).replace(",", "").trim()) || "?",
        };
    };
    /**
     * Capitalizes the first character of a string.
     * The method is null-safe: Returns null if null, empty if empty.
     * @param text Text for which the first letter is capitalized.
     */
    WorkerLogic.capitalizeFirstLetter = function (text) {
        if (!text) {
            return text;
        }
        return text.charAt(0).toUpperCase() + text.slice(1);
    };
    /**
     * Gets a description text for a WorkerAccount that may be either
     * IWorkerListItem or WorkerAccount.
     * @param worker Worker account to describe. Either account or list item.
     */
    WorkerLogic.getDescription = function (worker) {
        var emptyDescription = "-";
        var describe = function (w) {
            if (w.employment && w.employment.type && w.employment.type !== model_1.EmploymentRelationType.Undefined) {
                var descr = EnumerationsLogic_1.EnumerationsLogic.getEnumLabel("EmploymentRelationType", w.employment.type);
                switch (w.employment.type) {
                    case model_1.EmploymentRelationType.Entrepreneur:
                        if (w.employment.pensionCalculation === model_1.PensionCalculation.Entrepreneur) {
                            descr += " (YEL)";
                        }
                        else if (w.employment.pensionCalculation === model_1.PensionCalculation.PartialOwner) {
                            descr += " (YEL, osaomistaja)";
                        }
                        else if (w.employment.pensionCalculation === model_1.PensionCalculation.SmallEntrepreneur) {
                            descr += " (YEL, ei vakuuttamisvelvollisuutta)";
                        }
                        else if (w.employment.pensionCalculation === model_1.PensionCalculation.Employee) {
                            descr += " (TyEL)";
                        }
                        break;
                    case model_1.EmploymentRelationType.Farmer:
                        if (w.employment.pensionCalculation === model_1.PensionCalculation.Farmer) {
                            descr += " (MYEL)";
                        }
                        else if (w.employment.pensionCalculation === model_1.PensionCalculation.SmallFarmer) {
                            descr += " (MYEL, ei vakuuttamisvelvollisuutta)";
                        }
                        else if (w.employment.pensionCalculation === model_1.PensionCalculation.Employee) {
                            descr += " (TyEL)";
                        }
                        break;
                }
                return descr;
            }
            return w.contact.email || emptyDescription;
        };
        if (!worker) {
            return emptyDescription;
        }
        if (worker.employment) {
            return describe(worker);
        }
        var workerListItem = worker;
        if (!workerListItem.otherPartyInfo) {
            return emptyDescription;
        }
        return describe({
            avatar: workerListItem.otherPartyInfo.avatar,
            contact: {
                email: workerListItem.otherPartyInfo.email,
                telephone: workerListItem.otherPartyInfo.telephone,
            },
            employment: {
                type: workerListItem.data.type,
                pensionCalculation: workerListItem.data.pensionCalculation,
            },
            entityType: workerListItem.otherPartyInfo.avatar.entityType,
            ibanNumber: workerListItem.otherPartyInfo.ibanNumber,
            id: workerListItem.otherId,
            officialPersonId: workerListItem.otherPartyInfo.officialId,
        });
    };
    /** Sample workers for anonymous demo user interfaces. */
    WorkerLogic.getSampleWorkers = function () {
        return [
            {
                avatar: {
                    entityType: model_1.LegalEntityType.PersonCreatedByEmployer,
                    firstName: "Erkki",
                    lastName: "Esimerkki",
                    displayName: "Erkki Esimerkki",
                    sortableName: "Esimerkki, Erkki",
                    pictureType: model_1.AvatarPictureType.Icon,
                    color: "lime",
                    initials: "EE",
                    url: null,
                    description: "Esimerkkityöntekijä, oletus: 18-52 vuotta, veroprosentti 23%.",
                    id: "example-default",
                },
                contact: {
                    email: "erkki.esimerkki@palkkaus.fi",
                    telephone: "09 425 50603",
                },
                workerInfo: {},
                id: "example-default",
            },
            {
                avatar: {
                    entityType: model_1.LegalEntityType.PersonCreatedByEmployer,
                    firstName: "Laura",
                    lastName: "Lukiolainen",
                    displayName: "Laura Lukiolainen",
                    sortableName: "Lukiolainen, Laura",
                    pictureType: model_1.AvatarPictureType.Icon,
                    color: "pink",
                    initials: "LL",
                    url: null,
                    description: "Esimerkki nuoresta työntekijästä: 17 vuotias",
                    id: "example-17",
                },
                contact: {
                    email: "laura.lukiolainen@palkkaus.fi",
                    telephone: "09 425 50603",
                },
                workerInfo: {},
                id: "example-17",
            },
            {
                avatar: {
                    entityType: model_1.LegalEntityType.PersonCreatedByEmployer,
                    firstName: "Tanja",
                    lastName: "Eläkeläinen",
                    displayName: "Tanja Eläkeläinen",
                    sortableName: "Eläkeläinen, Tanja",
                    pictureType: model_1.AvatarPictureType.Icon,
                    color: "blue",
                    initials: "TE",
                    url: null,
                    description: "Esimerkki eläkeläisestä: 65-67 vuotias",
                    id: "example-pensioner",
                },
                contact: {
                    email: "tanja.elakelainen@palkkaus.fi",
                    telephone: "09 425 50603",
                },
                workerInfo: {},
                id: "example-pensioner",
            },
        ];
    };
    /**
     * Sets default values for the worker based on employment type.
     * @param worker - Worker to which default values are set.
     */
    WorkerLogic.setEmploymentDefaultValues = function (worker) {
        if (!worker) {
            return;
        }
        worker.employment.work.description = null;
        worker.employment.work.occupationCode = null;
        switch (worker.employment.type) {
            case model_1.EmploymentRelationType.MonthlySalary:
            case model_1.EmploymentRelationType.HourlySalary:
            case model_1.EmploymentRelationType.Salary:
                worker.employment.pensionCalculation = model_1.PensionCalculation.Employee;
                break;
            case model_1.EmploymentRelationType.EmployedByStateEmploymentFund:
                worker.employment.pensionCalculation = model_1.PensionCalculation.Employee;
                break;
            case model_1.EmploymentRelationType.PerformingArtist:
                worker.employment.pensionCalculation = model_1.PensionCalculation.Employee;
                break;
            case model_1.EmploymentRelationType.KeyEmployee:
                worker.employment.pensionCalculation = model_1.PensionCalculation.Employee;
                break;
            case model_1.EmploymentRelationType.Entrepreneur:
                worker.employment.pensionCalculation = model_1.PensionCalculation.Entrepreneur;
                break;
            case model_1.EmploymentRelationType.Farmer:
                worker.employment.pensionCalculation = model_1.PensionCalculation.Farmer;
                break;
            case model_1.EmploymentRelationType.Compensation:
                worker.employment.pensionCalculation = model_1.PensionCalculation.Compensation;
                break;
            case model_1.EmploymentRelationType.BoardMember:
                worker.employment.pensionCalculation = model_1.PensionCalculation.BoardRemuneration;
                worker.employment.work.occupationCode = "11200-bm";
                worker.employment.work.description = "Hallituksen jäsen";
                break;
            case model_1.EmploymentRelationType.Athlete:
                worker.employment.pensionCalculation = model_1.PensionCalculation.Athlete;
                worker.employment.work.occupationCode = "34210";
                worker.employment.work.description = "Urheilija";
                break;
        }
        worker.employment.work.salaryDefaults = [];
        var defaultRow = {
            rowIndex: 0,
            rowType: null,
            count: null,
            price: null,
            message: null,
        };
        worker.employment.work.salaryDefaults.push(defaultRow);
        defaultRow.message = null;
        switch (worker.employment.type) {
            case model_1.EmploymentRelationType.MonthlySalary:
                defaultRow.rowType = model_1.CalculationRowType.MonthlySalary;
                defaultRow.count = 1;
                defaultRow.price = 0;
                defaultRow.unit = null;
                break;
            case model_1.EmploymentRelationType.HourlySalary:
                defaultRow.rowType = model_1.CalculationRowType.HourlySalary;
                defaultRow.count = 1;
                defaultRow.price = 0;
                defaultRow.unit = model_1.CalculationRowUnit.Hours;
                break;
            case model_1.EmploymentRelationType.Salary:
                defaultRow.rowType = model_1.CalculationRowType.Salary;
                defaultRow.count = 1;
                defaultRow.price = 0;
                defaultRow.unit = null;
                break;
            case model_1.EmploymentRelationType.EmployedByStateEmploymentFund:
                defaultRow.rowType = model_1.CalculationRowType.HourlySalary;
                defaultRow.count = 1;
                defaultRow.price = 0;
                defaultRow.unit = model_1.CalculationRowUnit.Hours;
                break;
            case model_1.EmploymentRelationType.PerformingArtist:
                defaultRow.rowType = model_1.CalculationRowType.Salary;
                defaultRow.count = 1;
                defaultRow.price = 0;
                defaultRow.unit = null;
                break;
            case model_1.EmploymentRelationType.KeyEmployee:
                defaultRow.rowType = model_1.CalculationRowType.MonthlySalary;
                defaultRow.count = 1;
                defaultRow.price = 0;
                defaultRow.unit = null;
                break;
            case model_1.EmploymentRelationType.Entrepreneur:
            case model_1.EmploymentRelationType.Farmer:
                break;
            case model_1.EmploymentRelationType.Compensation:
                defaultRow.rowType = model_1.CalculationRowType.Compensation;
                defaultRow.count = 1;
                defaultRow.price = 0;
                defaultRow.unit = null;
                break;
            case model_1.EmploymentRelationType.BoardMember:
                defaultRow.rowType = model_1.CalculationRowType.Board;
                defaultRow.message = "Hallituspalkkio";
                defaultRow.count = 1;
                defaultRow.price = 0;
                defaultRow.unit = null;
                break;
            case model_1.EmploymentRelationType.Athlete:
                defaultRow.rowType = model_1.CalculationRowType.Salary;
                defaultRow.message = "Urheilijan palkka";
                defaultRow.count = 1;
                defaultRow.price = 0;
                defaultRow.unit = null;
                break;
        }
    };
    /**
     * Returns options object for PensionCalculation selection by employment relation type.
     * @param employmentRelationType Employment relation type of the worker.
     */
    // tslint:disable-next-line:completed-docs
    WorkerLogic.getPensionCalculationOptions = function (employmentRelationType) {
        var types = [];
        switch (employmentRelationType) {
            case model_1.EmploymentRelationType.HourlySalary:
            case model_1.EmploymentRelationType.MonthlySalary:
            case model_1.EmploymentRelationType.Salary:
            case undefined:
            case null:
                types.push(model_1.PensionCalculation.Employee);
                break;
            case "employedByStateEmploymentFund": // EmploymentRelationType.EmployedByStateEmploymentFund
                types.push(model_1.PensionCalculation.Employee);
                break;
            case "performingArtist": // EmploymentRelationType.PerformingArtist
                types.push.apply(// EmploymentRelationType.PerformingArtist
                types, [model_1.PensionCalculation.Employee, model_1.PensionCalculation.Compensation]);
                break;
            case "keyEmployee": // EmploymentRelationType.KeyEmployee
                types.push(model_1.PensionCalculation.Employee);
                break;
            case model_1.EmploymentRelationType.Entrepreneur:
                types.push.apply(types, [model_1.PensionCalculation.Entrepreneur, model_1.PensionCalculation.SmallEntrepreneur, model_1.PensionCalculation.PartialOwner, model_1.PensionCalculation.Employee]);
                break;
            case model_1.EmploymentRelationType.Farmer:
                types.push.apply(types, [model_1.PensionCalculation.Farmer, model_1.PensionCalculation.SmallFarmer, model_1.PensionCalculation.Employee]);
                break;
            case model_1.EmploymentRelationType.Compensation:
                types.push(model_1.PensionCalculation.Compensation);
                break;
            case model_1.EmploymentRelationType.BoardMember:
                types.push(model_1.PensionCalculation.BoardRemuneration);
                break;
            case model_1.EmploymentRelationType.Athlete:
                types.push(model_1.PensionCalculation.Athlete);
                break;
        }
        return types.map(function (type) {
            var label = EnumerationsLogic_1.EnumerationsLogic.getEnumLabel("PensionCalculation", type);
            var descr = EnumerationsLogic_1.EnumerationsLogic.getEnumDescr("PensionCalculation", type);
            return { value: type, text: label, title: descr && descr !== type ? descr : null };
        });
    };
    /**
     * Populates given user with test data.
     * Sets values only if the firstName and lastName have been given.
     * @param worker - Worker to populate with test data.
     */
    WorkerLogic.populateWorkerWithTestData = function (worker) {
        if (!worker || !worker.avatar || !worker.avatar.firstName || !worker.avatar.lastName) {
            return;
        }
        // email
        worker.contact.email = this.cleanupEmailPart(worker.avatar.firstName) + "." + this.cleanupEmailPart(worker.avatar.lastName) + "@palkkaus.fi";
        // phone
        worker.contact.telephone = "040 " + (1000000 + Math.round((Math.random() * 8999999)));
        // hetu
        var birthYear = (new Date().getFullYear()) - (20 + Math.round(Math.random() * 40));
        var birthDate = new Date(new Date(birthYear, 0, 1).getTime() + Math.round(Math.random() * (new Date(birthYear + 1, 11, 31).getTime() - new Date(birthYear, 0, 1).getTime())));
        var separator = birthYear >= 2000 ? "A" : "-";
        var personNumber = 900 + Math.round(Math.random() * 99);
        var checksumLetters = "0123456789ABCDEFHJKLMNPRSTUVWXY";
        var sDate = util_1.Dates.format(birthDate, "DDMMYY");
        var idChecksum = checksumLetters[parseInt(sDate + personNumber, 10) % 31];
        worker.officialPersonId = sDate + separator + personNumber + idChecksum;
        // iban
        var bank = (100000 + Math.round((Math.random() * 99999)));
        var account = (100000 + Math.round((Math.random() * 99999)));
        var bankAccount = bank + "00" + account;
        var ibanValue = bankAccount + "15" + "18" + "00";
        var mod97 = function (value) {
            var checksum = value.slice(0, 2);
            for (var offset = 2; offset < value.length; offset += 7) {
                var fragment = String(checksum) + value.substring(offset, offset + 7);
                checksum = parseInt(fragment, 10) % 97;
            }
            return checksum;
        };
        var remainder = 98 - mod97(ibanValue);
        var ibanChecksum = remainder < 10 ? "0" + remainder : remainder;
        worker.ibanNumber = util_1.Iban.formatIban("FI" + ibanChecksum + bankAccount);
    };
    WorkerLogic.cleanupEmailPart = function (name) {
        if (!name) {
            return name;
        }
        // to lower case
        name = name.toLowerCase();
        // remove accents
        name = name.normalize("NFD").replace(/[\u0300-\u036f]/g, "");
        // leave only letters
        name = name.replace(/[^a-z]+/g, "");
        return name;
    };
    /**
     * Application level single instance of the WorkerLogic.getSampleWorkers() methods.
     * These sample workers can be used and modified in the demo application.
     */
    WorkerLogic.sampleWorkersSingleton = WorkerLogic.getSampleWorkers();
    return WorkerLogic;
}());
exports.WorkerLogic = WorkerLogic;

},{"../model":73,"../util":90,"./EnumerationsLogic":51}],64:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var model_1 = require("../../model");
/** Methods for importing data into Salaxy system. */
var ImportLogic = /** @class */ (function () {
    function ImportLogic() {
    }
    /**
     * Converts a tab-separated values text to raw JSON.
     * Used to converting data copy-pasted from Excel to JSON.
     * @param inputText The TSV string that should be imported.
     * @returns ImportResult object with the data and other realted information.
     */
    ImportLogic.tsvToJson = function (inputText) {
        var result = {
            ignoredLines: 0,
            data: [],
            headers: [],
            errors: [],
        };
        if (!inputText) {
            return result;
        }
        var inputLines = inputText.split(/\r\n|\n/);
        if (inputLines.length === 0) {
            return result;
        }
        result.headers = inputLines[0].split(/\t/);
        for (var i = 1; i < inputLines.length; i++) {
            var data = inputLines[i].split(/\t/);
            var row = {};
            var isEmptyLine = true;
            for (var j = 0; j < result.headers.length; j++) {
                if (j < data.length) {
                    row[result.headers[j]] = data[j];
                    if (data[j]) {
                        isEmptyLine = false;
                    }
                }
            }
            if (isEmptyLine) {
                result.ignoredLines++;
            }
            else {
                if (data.length !== result.headers.length) {
                    row.error = "InvalidColAmount";
                    row.error_msg = "PARSE ERROR: Row " + i + " has " + data.length + " columns whereas the header row has " + result.headers.length + ".";
                }
                result.data.push(row);
            }
        }
        result.errors = result.data.filter(function (x) { return x.error; }).map(function (err) { return ({
            key: null,
            type: model_1.ApiValidationErrorType.General,
            msg: err.error_msg,
            code: err.code,
        }); });
        return result;
    };
    return ImportLogic;
}());
exports.ImportLogic = ImportLogic;

},{"../../model":73}],65:[function(require,module,exports){
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
__export(require("./ImportLogic"));

},{"./ImportLogic":64}],66:[function(require,module,exports){
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
__export(require("./import"));
__export(require("./model"));
__export(require("./usecases"));
__export(require("./CalcRowsLogic"));
__export(require("./CalculationResultLogic"));
__export(require("./CalculatorLogic"));
__export(require("./ContractLogic"));
__export(require("./ContractPartyLogic"));
__export(require("./EnumerationsLogic"));
__export(require("./HolidaysLogic"));
__export(require("./IncomeTypesLogic"));
__export(require("./Occupations"));
__export(require("./OnboardingLogic"));
__export(require("./ProductsLogic"));
__export(require("./ReportsLogic"));
__export(require("./TaxCard2019Logic"));
__export(require("./Translations"));
__export(require("./WorkerLogic"));
__export(require("./RoleLogic"));
__export(require("./SalaryDateLogic"));
__export(require("./PaymentLogic"));

},{"./CalcRowsLogic":46,"./CalculationResultLogic":47,"./CalculatorLogic":48,"./ContractLogic":49,"./ContractPartyLogic":50,"./EnumerationsLogic":51,"./HolidaysLogic":52,"./IncomeTypesLogic":53,"./Occupations":54,"./OnboardingLogic":55,"./PaymentLogic":56,"./ProductsLogic":57,"./ReportsLogic":58,"./RoleLogic":59,"./SalaryDateLogic":60,"./TaxCard2019Logic":61,"./Translations":62,"./WorkerLogic":63,"./import":65,"./model":70,"./usecases":72}],67:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var v01_1 = require("../../model/v01");
/** Categorization / grouping for CalculationRowType */
var CalculationRowCategories = /** @class */ (function () {
    function CalculationRowCategories() {
    }
    /** Base salary types: the ones that you define directly */
    CalculationRowCategories.baseSalary = [
        v01_1.CalculationRowType.Salary,
        v01_1.CalculationRowType.HourlySalary,
        v01_1.CalculationRowType.MonthlySalary,
        v01_1.CalculationRowType.TotalWorkerPayment,
        v01_1.CalculationRowType.TotalEmployerPayment,
        v01_1.CalculationRowType.Compensation,
        // CalculationRowType.IrIncomeType,
        v01_1.CalculationRowType.Board,
    ];
    /** Additions to base salary - typically a percentage of base salary */
    CalculationRowCategories.salaryAdditions = [
        v01_1.CalculationRowType.Overtime,
        v01_1.CalculationRowType.TesWorktimeShortening,
        v01_1.CalculationRowType.EveningAddition,
        v01_1.CalculationRowType.NightimeAddition,
        v01_1.CalculationRowType.SaturdayAddition,
        v01_1.CalculationRowType.SundayWork,
        v01_1.CalculationRowType.HolidayCompensation,
        v01_1.CalculationRowType.HolidayBonus,
        v01_1.CalculationRowType.HolidaySalary,
        v01_1.CalculationRowType.OtherAdditions,
    ];
    /** All salary types: baseSalary and salaryAdditions together */
    CalculationRowCategories.salary = CalculationRowCategories.baseSalary.concat(CalculationRowCategories.salaryAdditions);
    /** Benefits: Not paid as money but taxable income */
    CalculationRowCategories.benefits = [
        v01_1.CalculationRowType.AccomodationBenefit,
        v01_1.CalculationRowType.MealBenefit,
        v01_1.CalculationRowType.PhoneBenefit,
        v01_1.CalculationRowType.OtherBenefit,
    ];
    /** Expenses and other non-taxed compensations */
    CalculationRowCategories.expenses = [
        v01_1.CalculationRowType.Expenses,
        v01_1.CalculationRowType.MilageOwnCar,
        v01_1.CalculationRowType.DailyAllowance,
        v01_1.CalculationRowType.DailyAllowanceHalf,
        v01_1.CalculationRowType.MealCompensation,
        v01_1.CalculationRowType.ToolCompensation,
        v01_1.CalculationRowType.MilageDaily,
        v01_1.CalculationRowType.MilageOther,
        v01_1.CalculationRowType.ChildCareSubsidy,
    ];
    /** Deductions */
    CalculationRowCategories.deductions = [
        v01_1.CalculationRowType.Advance,
        v01_1.CalculationRowType.Foreclosure,
        v01_1.CalculationRowType.OtherDeductions,
        v01_1.CalculationRowType.PrepaidExpenses,
        v01_1.CalculationRowType.UnionPayment,
    ];
    /** Holidays */
    CalculationRowCategories.holidays = [
        v01_1.CalculationRowType.HolidayCompensation,
        v01_1.CalculationRowType.HolidayBonus,
        v01_1.CalculationRowType.HolidaySalary,
    ];
    /**
     * Items in the section called "expenses". Besides expenses, contains also benefits.
     */
    CalculationRowCategories.expensesSection = CalculationRowCategories.expenses.concat(CalculationRowCategories.benefits, CalculationRowCategories.deductions);
    return CalculationRowCategories;
}());
exports.CalculationRowCategories = CalculationRowCategories;

},{"../../model/v01":76}],68:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Primary categorization of Calculation row types.
 */
var CalculationRowCategory;
(function (CalculationRowCategory) {
    CalculationRowCategory["Salary"] = "salary";
    CalculationRowCategory["SalaryAdditions"] = "salaryAdditions";
    CalculationRowCategory["Benefits"] = "benefits";
    CalculationRowCategory["Expenses"] = "expenses";
    CalculationRowCategory["Deductions"] = "deductions";
    CalculationRowCategory["Other"] = "other";
})(CalculationRowCategory = exports.CalculationRowCategory || (exports.CalculationRowCategory = {}));

},{}],69:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Enumerates the system roles:
 * The roles that are not returned from server as account roles but
 * rather as derived from properties of the current session.
 */
var SystemRole;
(function (SystemRole) {
    /** Session check is in progress: The role of the user is unknown. */
    SystemRole["Unknown"] = "unknown";
    /** User is anonymous: The session has been checked and there is no token, token has expired or the token is invalid. */
    SystemRole["Anon"] = "anon";
    /** User is authenticated either as Company or Person */
    SystemRole["Auth"] = "auth";
    /**
     * Initialization is in progress:
     * At the moment, this is the same as Session check period (SystemRole Unknown),
     * but there may later be other server-checks in the initialization.
     */
    SystemRole["Init"] = "init";
    /** User is in Worker role.  */
    SystemRole["Worker"] = "worker";
    /** User is in Employer role: Either Household or Company. */
    SystemRole["Employer"] = "employer";
    /** User is Household (Employer) */
    SystemRole["Household"] = "household";
    /** User is Company (Employer) */
    SystemRole["Company"] = "company";
    /** User is a Person: Employer and/or Worker (not Company) */
    SystemRole["Person"] = "person";
    /** Hidden always returns false. Used to hide items in navigation. */
    SystemRole["Hidden"] = "hidden";
    /** System is running with test data */
    SystemRole["Test"] = "test";
    /** System is runnin with production data */
    SystemRole["Prod"] = "prod";
    /** Finnish personal company ("Yksityinen elinkeinonharjoittaja"). */
    SystemRole["FiTm"] = "fiTm";
    /** Finnish Limited liability company ("Osakeyhtiö"). */
    SystemRole["FiOy"] = "fiOy";
    /** Finnish Association ("yhdistys") */
    SystemRole["FiRy"] = "fiRy";
    /**
     * Any user ("any" or "*") always returns true.
     * Note that in most scenarios also no roles ([], "" or null) are equivalent to Any.
     */
    SystemRole["Any"] = "any";
    /**
     * System role for account that is not verified.
     * Typically this means that the onboarding object should be shown e.g. before payment or on the fornt page.
     * The role is not set while account is not there (anonymous or session check in progress).
     */
    SystemRole["NonVerified"] = "nonVerified";
})(SystemRole = exports.SystemRole || (exports.SystemRole = {}));

},{}],70:[function(require,module,exports){
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
__export(require("./CalculationRowCategories"));
__export(require("./CalculationRowCategory"));
__export(require("./SystemRole"));

},{"./CalculationRowCategories":67,"./CalculationRowCategory":68,"./SystemRole":69}],71:[function(require,module,exports){
(function (global){
Object.defineProperty(exports, "__esModule", { value: true });
var momentImport = (typeof window !== "undefined" ? window['moment'] : typeof global !== "undefined" ? global['moment'] : null);
/** workaround */
var moment = momentImport;
var codegen_1 = require("../../codegen");
var model_1 = require("../../model");
var util_1 = require("../../util");
var CalculatorLogic_1 = require("../CalculatorLogic");
var Translations_1 = require("../Translations");
/**
 * Provides business logic for Calculation usecases:
 * Salary framework contracts ("työehtosopimus") and other salary recommendations
 * that are used as bases for salary calculation.
 */
var UsecasesLogic = /** @class */ (function () {
    function UsecasesLogic() {
    }
    /**
     * Finds a parent group of a given usecase node
     * @param role - Role for which the use cases are filtered.
     * Currently, only "household" is supported, but other roles will follow.
     * @param usecase - The usecase whose parent is fetched.
     * If you pass a group here, the function will return null which will typically mean the tree root in the user interface.
     * @example
     * // Creates a simple calculation
     * const usecase = UsecasesLogic.findUsecaseById("household", "childCare/mll");
     * UsecasesLogic.setUsecase(this.context.calculations.current, usecase);
     * this.context.calculations.recalculateCurrent((calc) => {
     *     calc.worker.paymentData.telephone = "+358401234567";
     * });
     */
    UsecasesLogic.findUsecaseById = function (role, usecaseId) {
        for (var _i = 0, _a = UsecasesLogic.getUsecaseTree("household"); _i < _a.length; _i++) {
            var group = _a[_i];
            for (var _b = 0, _c = group.children || []; _b < _c.length; _b++) {
                var usecase = _c[_b];
                if (usecase.id === usecaseId) {
                    return usecase;
                }
            }
        }
        return null;
    };
    /**
     * Finds a group based on group id or usecase id of a child.
     * @param role - Role for which the use cases are filtered.
     * Currently, only "household" is supported, but other roles will follow.
     * @param useCaseOrGroupId - Identifier of the group or usecase.
     * If id is a usecase id, its parent is returned.
     * @example
     * // Returns a parent of a usecase or null if the selectedItem is a group.
     * const group = UsecasesLogic.findGroupById("household", this.selectedItem.id);
     * if (group.id === this.selectedItem.id) {
     *     return null;
     * }
     * return group;
     */
    UsecasesLogic.findGroupById = function (role, useCaseOrGroupId) {
        for (var _i = 0, _a = UsecasesLogic.getUsecaseTree("household"); _i < _a.length; _i++) {
            var group = _a[_i];
            if (group.id === useCaseOrGroupId) {
                return group;
            }
            for (var _b = 0, _c = group.children || []; _b < _c.length; _b++) {
                var usecase = _c[_b];
                if (usecase.id === useCaseOrGroupId) {
                    return group;
                }
            }
        }
        return null;
    };
    /**
     * Gets a tree of usecases (user interfaces for defining a framework) for a given role.
     * @param role - Role for which the use cases are filtered.
     * Currently, only "household" is supported, but other roles will follow.
     */
    UsecasesLogic.getUsecaseTree = function (role) {
        var tree = codegen_1.householdUsecaseTree;
        for (var _i = 0, tree_1 = tree; _i < tree_1.length; _i++) {
            var group = tree_1[_i];
            this.translate("HouseHoldUseCaseTree", group.id, group);
            for (var _a = 0, _b = group.children; _a < _b.length; _a++) {
                var usecase = _b[_a];
                usecase.badge = usecase.badge || group.badge;
                usecase.icon = usecase.icon || group.icon;
                usecase.uri = usecase.uri || group.uri;
                this.translate("HouseHoldUseCaseTree", usecase.id, usecase);
            }
        }
        return tree;
    };
    /**
     * Abstract the getting of the use case for the calculation.
     * We are expecting changes to the usecase implementation.
     * @param calc Calculation into which the usecase data is stored.
     */
    UsecasesLogic.getUsecaseData = function (calc) {
        if (!calc.usecase || !calc.usecase.uri) {
            var usecase = UsecasesLogic.getUsecaseBackwardCompatibility(calc);
            calc.usecase = {
                uri: usecase.uri,
                label: usecase.label,
                description: usecase.descr,
                data: usecase,
            };
        }
        return calc.usecase.data;
    };
    /**
     * Sets calculation properties based on selected usecase.
     * @param calc Calculation to set
     * @param usecase Usecase to apply.
     * @example
     * // Creates a simple calculation
     * const usecase = UsecasesLogic.findUsecaseById("household", "childCare/mll");
     * UsecasesLogic.setUsecase(this.context.calculations.current, usecase);
     * this.context.calculations.recalculateCurrent((calc) => {
     *     calc.worker.paymentData.telephone = "+358401234567";
     * });
     */
    UsecasesLogic.setUsecase = function (calc, usecase) {
        calc.usecase = {
            uri: usecase.uri,
            label: usecase.label,
            description: usecase.descr,
            data: usecase,
        };
        this.applyUseCase(calc);
        return this.getUsecaseData(calc);
    };
    /**
     * Applies the usecase to a calculation, especially to the old Framework object.
     * Should be called before sending the calculation to the server (recalculate/save).
     * @param calc Calculation where usecase is set to calc.data.usecase.
     */
    UsecasesLogic.applyUseCase = function (calc) {
        var usecase = this.getUsecaseData(calc);
        switch (usecase.uri) {
            case UsecasesLogic.knownUseCases.childCare:
                this.applyUsecaseChildCare(calc);
                break;
            case UsecasesLogic.knownUseCases.mll:
                this.applyUsecaseMll(calc);
                break;
            case UsecasesLogic.knownUseCases.cleaning:
                this.applyUsecaseCleaning(calc);
                break;
            case UsecasesLogic.knownUseCases.construction:
                this.applyUsecaseConstruction(calc);
                break;
            case UsecasesLogic.knownUseCases.entrepreneur:
                // TODO: Not implemented - not a household usecase, but should probably be implemented for backward compatibility.
                break;
            case UsecasesLogic.knownUseCases.santaClaus:
                this.applyUsecaseSantaClaus(calc);
                break;
            case UsecasesLogic.knownUseCases.other:
                this.applyCommonUsecaseProperties(calc);
                break;
            case UsecasesLogic.knownUseCases.notDefined:
                // Nothing applied.
                break;
        }
    };
    /** Applies the constructions salary calculation usecase */
    UsecasesLogic.applyUsecaseConstruction = function (calc) {
        var usecase = this.getUsecaseData(calc);
        var mainRow = CalculatorLogic_1.CalculatorLogic.getFirstRow(calc);
        if (mainRow.rowType === model_1.CalculationRowType.HourlySalary) {
            // Potentially add custom row message here
        }
        else if (mainRow.rowType === model_1.CalculationRowType.MonthlySalary) {
            // Potentially add custom row message here
        }
        else {
            mainRow.rowType = model_1.CalculationRowType.Salary;
        }
        calc.salary.taxDeductionCategories = model_1.TaxDeductionWorkCategories.HomeImprovement;
        usecase.isTesIncludedInSalary = usecase.isTesIncludedInSalary || false;
        usecase.isExpensesCustom = usecase.isExpensesCustom || false;
        usecase.subType = usecase.subType || model_1.TesSubtype.ConstructionCarpenter;
        // HACK: Additional rows are handled on the server-side at the moment.
        //       This should be changed to the new model before going to production.
        var fx = calc.framework;
        fx.type = model_1.FrameworkAgreement.Construction;
        fx.subType = usecase.subType;
        if (usecase.isExpensesCustom) {
            fx.subType = model_1.TesSubtype.ConstructionFreeContract;
        }
        fx.isTesIncludedInSalary = usecase.isTesIncludedInSalary;
        fx.dailyExpenses = usecase.dailyExpenses;
        fx.dailyTravelExpenses = usecase.dailyTravelExpenses;
        fx.dailyTravelExpensesKm = usecase.dailyTravelExpensesKm;
        this.applyCommonUsecaseProperties(calc);
    };
    /** Applies the childCare salary calculation usecase */
    UsecasesLogic.applyUsecaseChildCare = function (calc) {
        var usecase = this.getUsecaseData(calc);
        var mainRow = CalculatorLogic_1.CalculatorLogic.getFirstRow(calc);
        // Salary settings
        if (mainRow.rowType === model_1.CalculationRowType.HourlySalary) {
            mainRow.message = "Lastenhoitajan tuntipalkka";
        }
        else {
            mainRow.rowType = model_1.CalculationRowType.MonthlySalary;
            mainRow.message = "Lastenhoitajan kuukausipalkka";
        }
        calc.salary.taxDeductionCategories = model_1.TaxDeductionWorkCategories.Carework;
        // Child care subsidy and tax deduction
        calc.rows = calc.rows
            .filter(function (x) { return x.rowType !== model_1.CalculationRowType.ChildCareSubsidy; });
        if (usecase.isChildcareSubsidy) {
            calc.rows.push({
                count: 1,
                price: usecase.subsidyAmount,
                rowType: model_1.CalculationRowType.ChildCareSubsidy,
            });
        }
        else {
            usecase.subsidyAmount = null;
        }
        if (usecase.isChildcareSubsidy) {
            usecase.isHouseholdDeductible = false;
        }
        if (usecase.isHouseholdDeductible == null) {
            usecase.isHouseholdDeductible = true;
        }
        this.applyCommonUsecaseProperties(calc);
    };
    /** Applies the cleaning salary calculation usecase */
    UsecasesLogic.applyUsecaseCleaning = function (calc) {
        var usecase = this.getUsecaseData(calc);
        var mainRow = CalculatorLogic_1.CalculatorLogic.getFirstRow(calc);
        if (mainRow.rowType === model_1.CalculationRowType.HourlySalary) {
            // Potentially add custom row message here
        }
        else if (mainRow.rowType === model_1.CalculationRowType.MonthlySalary) {
            // Potentially add custom row message here
        }
        else {
            mainRow.rowType = model_1.CalculationRowType.Salary;
        }
        calc.salary.taxDeductionCategories = model_1.TaxDeductionWorkCategories.Householdwork;
        calc.rows = calc.rows
            .filter(function (x) { return x.rowType !== model_1.CalculationRowType.HolidayCompensation; });
        if (!usecase.isFullTime) {
            var salary = mainRow.count * mainRow.price;
            var percent = usecase.isContractLessThanYear ? 0.09 : 0.115;
            calc.rows.push({
                count: percent,
                price: salary,
                rowType: model_1.CalculationRowType.HolidayCompensation,
            });
        }
        if (usecase.isHouseholdDeductible == null) {
            usecase.isHouseholdDeductible = true;
        }
        this.applyCommonUsecaseProperties(calc);
    };
    /** Applies the MLL salary calculation usecase */
    UsecasesLogic.applyUsecaseMll = function (calc) {
        var usecase = this.getUsecaseData(calc);
        var mainRow = CalculatorLogic_1.CalculatorLogic.getFirstRow(calc);
        var mll = usecase;
        mainRow.rowType = model_1.CalculationRowType.HourlySalary;
        mainRow.message = "Lastenhoitajan tuntipalkka";
        calc.salary.taxDeductionCategories = model_1.TaxDeductionWorkCategories.Carework;
        if (!mainRow.count || mainRow.count < 2) {
            mainRow.count = 2;
        }
        if (!mll.useCustomPrice) {
            mainRow.price = 9.50;
        }
        calc.rows = calc.rows
            .filter(function (x) { return x.rowType !== model_1.CalculationRowType.SundayWork; });
        if (usecase.isSunday) {
            calc.rows.push({
                count: 1,
                price: mainRow.count * mainRow.price,
                rowType: model_1.CalculationRowType.SundayWork,
            });
        }
        // Deductions
        calc.framework.isYksityisenHoidonTuki = false;
        mll.isHouseholdDeductible = true;
        // Defaults to Period
        if (!calc.info.workStartDate) {
            calc.info.workStartDate = util_1.Dates.getToday();
            calc.info.workEndDate = null; // workEndDate is no longer valid
            calc.framework.numberOfDays = null;
        }
        if (!calc.info.workEndDate) {
            calc.info.workEndDate = calc.info.workStartDate;
            calc.framework.numberOfDays = null;
        }
        if (!calc.framework.numberOfDays) {
            calc.framework.numberOfDays = util_1.Dates.getWorkdays(calc.info.workStartDate, calc.info.workEndDate).length;
        }
        this.applyCommonUsecaseProperties(calc);
    };
    UsecasesLogic.applyUsecaseSantaClaus = function (calc) {
        var usecase = this.getUsecaseData(calc);
        var mainRow = CalculatorLogic_1.CalculatorLogic.getFirstRow(calc);
        mainRow.rowType = model_1.CalculationRowType.Salary;
        mainRow.message = "Joulupukin palkka";
        usecase.isHouseholdDeductible = false;
        var year = moment().subtract("month", 6).year();
        var nearestXmsEve = util_1.Dates.asDate(moment([year, 11, 24]));
        calc.info.workStartDate = nearestXmsEve;
        calc.info.workEndDate = nearestXmsEve;
        calc.framework.numberOfDays = 1;
        this.applyCommonUsecaseProperties(calc);
    };
    UsecasesLogic.applyCommonUsecaseProperties = function (calc) {
        var usecase = this.getUsecaseData(calc);
        var mainRow = CalculatorLogic_1.CalculatorLogic.getFirstRow(calc);
        calc.info.occupationCode = usecase.occupation;
        calc.salary.isHouseholdDeductible = usecase.isHouseholdDeductible || false;
        if (mainRow.rowType === model_1.CalculationRowType.HourlySalary) {
            // For hourly salary, default to null so that users really sets the value.
            if (mainRow.count === 0) {
                mainRow.count = null;
            }
        }
        else {
            // We currently do not support multiple months etc. in these user interfaces.
            // API does support them, but they would add unnecessary complexity to UX.
            mainRow.count = 1;
        }
        mainRow.rowType = mainRow.rowType || model_1.CalculationRowType.Salary;
    };
    /**
     * Gets a usecase for calculations that were created before the
     * new user interface and usecase model was stored on the server.
     * @param calc Original calculation.
     */
    UsecasesLogic.getUsecaseBackwardCompatibility = function (calc) {
        var mainRow = CalculatorLogic_1.CalculatorLogic.getFirstRow(calc);
        switch (calc.framework.type) {
            case model_1.FrameworkAgreement.ChildCare:
                if (calc.framework.isYksityisenHoidonTuki) {
                    return UsecasesLogic.findUsecaseById("household", "childCare/kela");
                }
                return UsecasesLogic.findUsecaseById("household", "childCare/other");
            case model_1.FrameworkAgreement.Mll: {
                var usecase = UsecasesLogic.findUsecaseById("household", "childCare/mll");
                if (mainRow.price === 19.00) {
                    usecase.isSunday = true;
                    usecase.useCustomPrice = false;
                }
                else if (mainRow.price === 9.50) {
                    usecase.isSunday = false;
                    usecase.useCustomPrice = false;
                }
                else {
                    usecase.isSunday = false;
                    usecase.useCustomPrice = true;
                }
                return usecase;
            }
            case model_1.FrameworkAgreement.Cleaning:
                return UsecasesLogic.findUsecaseById("household", "cleaning/91110");
            case model_1.FrameworkAgreement.Construction: {
                var usecase = void 0;
                switch (calc.framework.subType) {
                    case model_1.TesSubtype.ConstructionCarpenter:
                        usecase = UsecasesLogic.findUsecaseById("household", "construction/carpenter");
                        break;
                    case model_1.TesSubtype.ConstructionFloor:
                        usecase = UsecasesLogic.findUsecaseById("household", "construction/floor");
                        break;
                    case model_1.TesSubtype.ConstructionFreeContract:
                        usecase = UsecasesLogic.findUsecaseById("household", "construction/carpenter");
                        usecase.isExpensesCustom = true;
                        break;
                    case model_1.TesSubtype.ConstructionOther:
                    case model_1.TesSubtype.NotSelected:
                        usecase = UsecasesLogic.findUsecaseById("household", "construction/other");
                        break;
                }
                usecase.dailyExpenses = calc.framework.dailyExpenses;
                usecase.dailyTravelExpenses = calc.framework.dailyTravelExpenses;
                usecase.dailyTravelExpensesKm = calc.framework.dailyTravelExpensesKm;
                usecase.isHouseholdDeductible = calc.salary.isHouseholdDeductible;
                usecase.isTesIncludedInSalary = calc.framework.isTesIncludedInSalary;
                return usecase;
            }
            case model_1.FrameworkAgreement.Entrepreneur:
                throw new Error("Yrittäjän palkkaa ei voi maksaa kotitalouspalvelussa.");
            // return UsecasesLogic.findUsecaseById("company", "enterpreneur/other");
            case model_1.FrameworkAgreement.SantaClaus:
                throw new Error("Joulupukin palkkiota ei voi maksaa tähän aikaan vuodesta.");
            // return UsecasesLogic.findUsecaseById("household", "campaign/santaClaus");
            case model_1.FrameworkAgreement.NotDefined:
            case model_1.FrameworkAgreement.Other:
            default:
                return UsecasesLogic.findUsecaseById("household", "other/undefined");
        }
    };
    UsecasesLogic.translate = function (name, id, useCaseOrGroup) {
        useCaseOrGroup.label = Translations_1.Translations.get("SALAXY.ENUM." + name + "." + id.replace("/", ".") + ".label") || useCaseOrGroup.label;
        useCaseOrGroup.descr = Translations_1.Translations.get("SALAXY.ENUM." + name + "." + id.replace("/", ".") + ".description") || useCaseOrGroup.descr;
    };
    /**
     * Known use cases in the first implementation.
     * These implementations replace the olf Calc.Framework.Type -based solution that is not very extensible.
     * The naming is still based on the old system for easier compatibility.
     */
    UsecasesLogic.knownUseCases = {
        /** Usecase has not been defined. Note that value is null, not "https://secure.salaxy.com/v02/api/usecases/notDefined" */
        notDefined: null,
        /** Generic child care usecase */
        childCare: "https://secure.salaxy.com/v02/api/usecases/childCare",
        /** Cleaning */
        cleaning: "https://secure.salaxy.com/v02/api/usecases/cleaning",
        /** Construction (Raksa) */
        construction: "https://secure.salaxy.com/v02/api/usecases/construction",
        /** NOT IMPLEMENTED: Entrepreneur use case - not implemented for this release. */
        entrepreneur: "https://secure.salaxy.com/v02/api/usecases/entrepreneur",
        /** Child care according to MLL recommendations. */
        mll: "https://secure.salaxy.com/v02/api/usecases/mll",
        /** NOT IMPLEMENTED: Santa Claus for Christmas campaigns - not implemented for this release. */
        santaClaus: "https://secure.salaxy.com/v02/api/usecases/santaClaus",
        /** Generic household salary payment usecase user interface. */
        other: "https://secure.salaxy.com/v02/api/usecases/other",
    };
    return UsecasesLogic;
}());
exports.UsecasesLogic = UsecasesLogic;

}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})
},{"../../codegen":39,"../../model":73,"../../util":90,"../CalculatorLogic":48,"../Translations":62}],72:[function(require,module,exports){
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
__export(require("./UsecasesLogic"));

},{"./UsecasesLogic":71}],73:[function(require,module,exports){
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
__export(require("./oauth2"));
__export(require("./v01"));
__export(require("./nir"));

},{"./nir":74,"./oauth2":75,"./v01":76}],74:[function(require,module,exports){
/* tslint:disable */
//----------------------
// <auto-generated>
//     Generated using the NSwag toolchain v12.0.1.0 (NJsonSchema v9.12.3.0 (Newtonsoft.Json v11.0.0.0)) (http://NSwag.org)
// </auto-generated>
//----------------------
// ReSharper disable InconsistentNaming
Object.defineProperty(exports, "__esModule", { value: true });
var nir;
(function (nir) {
    /** ActionCode enumeration */
    var ActionCode;
    (function (ActionCode) {
        ActionCode["NewReport"] = "newReport";
        ActionCode["ReplacementReport"] = "replacementReport";
    })(ActionCode = nir.ActionCode || (nir.ActionCode = {}));
    /** AddressType enumeration */
    var AddressType;
    (function (AddressType) {
        AddressType["AddressInHomeCountry"] = "addressInHomeCountry";
        AddressType["AddressInTheCountryOfWork"] = "addressInTheCountryOfWork";
    })(AddressType = nir.AddressType || (nir.AddressType = {}));
    /** AgeGroupCode enumeration */
    var AgeGroupCode;
    (function (AgeGroupCode) {
        AgeGroupCode["A"] = "a";
        AgeGroupCode["B"] = "b";
        AgeGroupCode["C"] = "c";
        AgeGroupCode["U"] = "u";
    })(AgeGroupCode = nir.AgeGroupCode || (nir.AgeGroupCode = {}));
    /** AllowanceCode enumeration */
    var AllowanceCode;
    (function (AllowanceCode) {
        AllowanceCode["MealAllowance"] = "mealAllowance";
        AllowanceCode["PartialDailyAllowance"] = "partialDailyAllowance";
        AllowanceCode["FullDailyAllowance"] = "fullDailyAllowance";
        AllowanceCode["InternationalDailyAllowance"] = "internationalDailyAllowance";
    })(AllowanceCode = nir.AllowanceCode || (nir.AllowanceCode = {}));
    /** BenefitCode enumeration */
    var BenefitCode;
    (function (BenefitCode) {
        BenefitCode["AccommodationBenefit"] = "accommodationBenefit";
        BenefitCode["TelephoneBenefit"] = "telephoneBenefit";
        BenefitCode["MealBenefit"] = "mealBenefit";
        BenefitCode["OtherBenefits"] = "otherBenefits";
    })(BenefitCode = nir.BenefitCode || (nir.BenefitCode = {}));
    /** CarBenefitCode enumeration */
    var CarBenefitCode;
    (function (CarBenefitCode) {
        CarBenefitCode["LimitedCarBenefit"] = "limitedCarBenefit";
        CarBenefitCode["FullCarBenefit"] = "fullCarBenefit";
    })(CarBenefitCode = nir.CarBenefitCode || (nir.CarBenefitCode = {}));
    /** DeliveryDataType enumeration */
    var DeliveryDataType;
    (function (DeliveryDataType) {
        DeliveryDataType["EarningsPaymentReports"] = "earningsPaymentReports";
    })(DeliveryDataType = nir.DeliveryDataType || (nir.DeliveryDataType = {}));
    /** EmploymentCode enumeration */
    var EmploymentCode;
    (function (EmploymentCode) {
        EmploymentCode["FullTime"] = "fullTime";
        EmploymentCode["PartTime"] = "partTime";
        EmploymentCode["NotAvailable"] = "notAvailable";
    })(EmploymentCode = nir.EmploymentCode || (nir.EmploymentCode = {}));
    /** EmploymentEndingCode enumeration */
    var EmploymentEndingCode;
    (function (EmploymentEndingCode) {
        EmploymentEndingCode["EmployeesResignation"] = "employeesResignation";
        EmploymentEndingCode["Other"] = "other";
        EmploymentEndingCode["TerminationGroundsRelatedToEmployeesPerson"] = "terminationGroundsRelatedToEmployeesPerson";
        EmploymentEndingCode["FinancialAndProductionRelatedGrounds"] = "financialAndProductionRelatedGrounds";
        EmploymentEndingCode["JointAgreement"] = "jointAgreement";
        EmploymentEndingCode["Retirement"] = "retirement";
        EmploymentEndingCode["TerminationOfaFixedTermEmployment"] = "terminationOfaFixedTermEmployment";
    })(EmploymentEndingCode = nir.EmploymentEndingCode || (nir.EmploymentEndingCode = {}));
    /** EmploymentEndingType enumeration */
    var EmploymentEndingType;
    (function (EmploymentEndingType) {
        EmploymentEndingType["KevaCodes"] = "kevaCodes";
        EmploymentEndingType["BankOfFinlandCodes"] = "bankOfFinlandCodes";
        EmploymentEndingType["IncomesRegisterCodes"] = "incomesRegisterCodes";
    })(EmploymentEndingType = nir.EmploymentEndingType || (nir.EmploymentEndingType = {}));
    /** ExceptionCode enumeration */
    var ExceptionCode;
    (function (ExceptionCode) {
        ExceptionCode["NoObligationToSocialInsurance"] = "noObligationToSocialInsurance";
        ExceptionCode["NoObligationToHealthInsurance"] = "noObligationToHealthInsurance";
        ExceptionCode["NoObligationToEarningsRelatedPensionInsurance"] = "noObligationToEarningsRelatedPensionInsurance";
        ExceptionCode["NoObligationToAccidentAndOccupationalDiseaseInsurance"] = "noObligationToAccidentAndOccupationalDiseaseInsurance";
        ExceptionCode["NoObligationToUnemploymentInsurance"] = "noObligationToUnemploymentInsurance";
        ExceptionCode["NotSubjectToSocialInsurance"] = "notSubjectToSocialInsurance";
        ExceptionCode["NotSubjectToEarningsRelatedPensionInsurance"] = "notSubjectToEarningsRelatedPensionInsurance";
        ExceptionCode["NotSubjectToAccidentAndOccupationalDiseaseInsurance"] = "notSubjectToAccidentAndOccupationalDiseaseInsurance";
        ExceptionCode["NotSubjectToUnemploymentInsurance"] = "notSubjectToUnemploymentInsurance";
        ExceptionCode["NotSubjectToHealthInsurance"] = "notSubjectToHealthInsurance";
        ExceptionCode["VoluntaryEarningsRelatedPensionInsurance"] = "voluntaryEarningsRelatedPensionInsurance";
    })(ExceptionCode = nir.ExceptionCode || (nir.ExceptionCode = {}));
    /** FaultyControl enumeration */
    var FaultyControl;
    (function (FaultyControl) {
        FaultyControl["OnlyInvalidItems"] = "onlyInvalidItems";
        FaultyControl["EntireRecordIsRejected"] = "entireRecordIsRejected";
    })(FaultyControl = nir.FaultyControl || (nir.FaultyControl = {}));
    /** Gender enumeration */
    var Gender;
    (function (Gender) {
        Gender["Female"] = "female";
        Gender["Male"] = "male";
    })(Gender = nir.Gender || (nir.Gender = {}));
    /** IdType enumeration */
    var IdType;
    (function (IdType) {
        IdType["BusinessId"] = "businessId";
        IdType["PersonalIdentificationNumber"] = "personalIdentificationNumber";
        IdType["Vat"] = "vat";
        IdType["Giin"] = "giin";
        IdType["TaxIdentificationNumber"] = "taxIdentificationNumber";
        IdType["FinnishTradeRegistrationNumber"] = "finnishTradeRegistrationNumber";
        IdType["ForeignBusinessRegistrationNumber"] = "foreignBusinessRegistrationNumber";
        IdType["ForeignPersonalIdentificationNumber"] = "foreignPersonalIdentificationNumber";
        IdType["Other"] = "other";
    })(IdType = nir.IdType || (nir.IdType = {}));
    /** InsuranceCode enumeration */
    var InsuranceCode;
    (function (InsuranceCode) {
        InsuranceCode["SubjectToSocialInsuranceContributions"] = "subjectToSocialInsuranceContributions";
        InsuranceCode["SubjectToEarningsRelatedPensionInsuranceContribution"] = "subjectToEarningsRelatedPensionInsuranceContribution";
        InsuranceCode["SubjectToHealthInsuranceContribution"] = "subjectToHealthInsuranceContribution";
        InsuranceCode["SubjectToUnemploymentInsuranceContribution"] = "subjectToUnemploymentInsuranceContribution";
        InsuranceCode["SubjectToAccidentInsuranceAndOccupationalDiseaseInsuranceContribution"] = "subjectToAccidentInsuranceAndOccupationalDiseaseInsuranceContribution";
    })(InsuranceCode = nir.InsuranceCode || (nir.InsuranceCode = {}));
    /** Language enumeration */
    var Language;
    (function (Language) {
        Language["Finnish"] = "finnish";
        Language["Swedish"] = "swedish";
        Language["English"] = "english";
    })(Language = nir.Language || (nir.Language = {}));
    /** PayerType enumeration */
    var PayerType;
    (function (PayerType) {
        PayerType["PublicSector"] = "publicSector";
        PayerType["Household"] = "household";
        PayerType["TemporaryEmployer"] = "temporaryEmployer";
        PayerType["ForeignEmployer"] = "foreignEmployer";
        PayerType["State"] = "state";
        PayerType["UnincorporatedStateEnterpriseOrGovernmentalInstitution"] = "unincorporatedStateEnterpriseOrGovernmentalInstitution";
        PayerType["SpecialisedAgency"] = "specialisedAgency";
        PayerType["ForeignGroupCompany"] = "foreignGroupCompany";
    })(PayerType = nir.PayerType || (nir.PayerType = {}));
    /** PaymentType enumeration */
    var PaymentType;
    (function (PaymentType) {
        PaymentType["Monthly"] = "monthly";
        PaymentType["Hourly"] = "hourly";
        PaymentType["ContractPay"] = "contractPay";
    })(PaymentType = nir.PaymentType || (nir.PaymentType = {}));
    /** PensionActCode enumeration */
    var PensionActCode;
    (function (PensionActCode) {
        PensionActCode["EmployeesEarningsRelatedPensionInsurance"] = "employeesEarningsRelatedPensionInsurance";
        PensionActCode["PensionInsuranceForFarmers"] = "pensionInsuranceForFarmers";
        PensionActCode["PensionInsuranceForTheSelfEmployed"] = "pensionInsuranceForTheSelfEmployed";
    })(PensionActCode = nir.PensionActCode || (nir.PensionActCode = {}));
    /** PensionProvIdCode enumeration */
    var PensionProvIdCode;
    (function (PensionProvIdCode) {
        PensionProvIdCode["None"] = "none";
        PensionProvIdCode["Alandia"] = "alandia";
        PensionProvIdCode["Ilmarinen"] = "ilmarinen";
        PensionProvIdCode["Elo"] = "elo";
        PensionProvIdCode["Varma"] = "varma";
        PensionProvIdCode["Veritas"] = "veritas";
        PensionProvIdCode["Etera"] = "etera";
        PensionProvIdCode["Apteekkien"] = "apteekkien";
        PensionProvIdCode["Verso"] = "verso";
    })(PensionProvIdCode = nir.PensionProvIdCode || (nir.PensionProvIdCode = {}));
    /** ProfessionType enumeration */
    var ProfessionType;
    (function (ProfessionType) {
        ProfessionType["StatisticsFinland"] = "statisticsFinland";
        ProfessionType["Keva"] = "keva";
        ProfessionType["BankOfFinland"] = "bankOfFinland";
        ProfessionType["Trafi"] = "trafi";
    })(ProfessionType = nir.ProfessionType || (nir.ProfessionType = {}));
    /** RefPaymentType enumeration */
    var RefPaymentType;
    (function (RefPaymentType) {
        RefPaymentType["EarningsRelatedPensionProvider"] = "earningsRelatedPensionProvider";
    })(RefPaymentType = nir.RefPaymentType || (nir.RefPaymentType = {}));
    /** RemunerationCode enumeration */
    var RemunerationCode;
    (function (RemunerationCode) {
        RemunerationCode["DailyAllowance"] = "dailyAllowance";
        RemunerationCode["AccommodationBenefit"] = "accommodationBenefit";
        RemunerationCode["CarBenefit"] = "carBenefit";
        RemunerationCode["OtherBenefit"] = "otherBenefit";
    })(RemunerationCode = nir.RemunerationCode || (nir.RemunerationCode = {}));
    /** ResponsibilityCode enumeration */
    var ResponsibilityCode;
    (function (ResponsibilityCode) {
        ResponsibilityCode["ContentIssues"] = "contentIssues";
        ResponsibilityCode["TechnicalIssues"] = "technicalIssues";
    })(ResponsibilityCode = nir.ResponsibilityCode || (nir.ResponsibilityCode = {}));
    /** TermCode enumeration */
    var TermCode;
    (function (TermCode) {
        TermCode["UntilFurtherNotice"] = "untilFurtherNotice";
        TermCode["FixedTerm"] = "fixedTerm";
    })(TermCode = nir.TermCode || (nir.TermCode = {}));
    /** TransactionCode enumeration */
    var TransactionCode;
    (function (TransactionCode) {
        TransactionCode["Unknown"] = "unknown";
        TransactionCode["Ignored"] = "ignored";
        TransactionCode["TimeRatePay"] = "timeRatePay";
        TransactionCode["EveningWorkCompensation"] = "eveningWorkCompensation";
        TransactionCode["EveningShiftAllowance"] = "eveningShiftAllowance";
        TransactionCode["SaturdayPay"] = "saturdayPay";
        TransactionCode["HolidayBonus"] = "holidayBonus";
        TransactionCode["OtherCompensation"] = "otherCompensation";
        TransactionCode["SundayWorkCompensation"] = "sundayWorkCompensation";
        TransactionCode["CompensationForAccruedTimeOff"] = "compensationForAccruedTimeOff";
        TransactionCode["ContractPay"] = "contractPay";
        TransactionCode["AnnualHolidayCompensation"] = "annualHolidayCompensation";
        TransactionCode["OverTimeCompensation"] = "overTimeCompensation";
        TransactionCode["NightWorkAllowance"] = "nightWorkAllowance";
        TransactionCode["NightShiftCompensation"] = "nightShiftCompensation";
        TransactionCode["AccommodationBenefit"] = "accommodationBenefit";
        TransactionCode["MealAllowance"] = "mealAllowance";
        TransactionCode["CarBenefit"] = "carBenefit";
        TransactionCode["KilometreAllowanceTaxExempt"] = "kilometreAllowanceTaxExempt";
        TransactionCode["OtherTaxableBenefitForEmployees"] = "otherTaxableBenefitForEmployees";
        TransactionCode["OtherFringeBenefit"] = "otherFringeBenefit";
        TransactionCode["TelephoneBenefit"] = "telephoneBenefit";
        TransactionCode["DailyAllowance"] = "dailyAllowance";
        TransactionCode["MealBenefit"] = "mealBenefit";
        TransactionCode["NonWageCompensationForWork"] = "nonWageCompensationForWork";
        TransactionCode["TaxableReimburementOfExpenses"] = "taxableReimburementOfExpenses";
        TransactionCode["PrivateDayCareAllowanceWages"] = "privateDayCareAllowanceWages";
        TransactionCode["PrivateDayCareAllowanceNonWage"] = "privateDayCareAllowanceNonWage";
        TransactionCode["WithholdingTax"] = "withholdingTax";
        TransactionCode["WagesPaid"] = "wagesPaid";
        TransactionCode["OtherItemDeductibleFromNetWage"] = "otherItemDeductibleFromNetWage";
        TransactionCode["NetWage"] = "netWage";
        TransactionCode["EmployeesPensionInsuranceContribution"] = "employeesPensionInsuranceContribution";
        TransactionCode["EmployeesUnemploymentInsuranceContribution"] = "employeesUnemploymentInsuranceContribution";
        TransactionCode["Distraint"] = "distraint";
        TransactionCode["DeductionBeforeWithholding"] = "deductionBeforeWithholding";
        TransactionCode["WagesPaidBySubstitutePayerIncludingSocialInsurance"] = "wagesPaidBySubstitutePayerIncludingSocialInsurance";
        TransactionCode["WagesPaidBySubstitutePayerIncludingEarningsRelatedPensionInsurance"] = "wagesPaidBySubstitutePayerIncludingEarningsRelatedPensionInsurance";
        TransactionCode["WagesPaidBySubstitutePayerIncludingUnemploymentInsurance"] = "wagesPaidBySubstitutePayerIncludingUnemploymentInsurance";
        TransactionCode["WagesPaidBySubstitutePayerIncludingAccidentAndOccupationalDiseaseInsurance"] = "wagesPaidBySubstitutePayerIncludingAccidentAndOccupationalDiseaseInsurance";
        TransactionCode["WagesPaidBySubstitutePayerIncludingHealthInsurance"] = "wagesPaidBySubstitutePayerIncludingHealthInsurance";
        TransactionCode["KilometreAllowanceTaxable"] = "kilometreAllowanceTaxable";
        TransactionCode["LectureFee"] = "lectureFee";
        TransactionCode["KilometreAllowancePaidByNonProfitOrganisation"] = "kilometreAllowancePaidByNonProfitOrganisation";
    })(TransactionCode = nir.TransactionCode || (nir.TransactionCode = {}));
    /** WageUnitCode enumeration */
    var WageUnitCode;
    (function (WageUnitCode) {
        WageUnitCode["Hour"] = "hour";
        WageUnitCode["Day"] = "day";
        WageUnitCode["Week"] = "week";
        WageUnitCode["Period"] = "period";
    })(WageUnitCode = nir.WageUnitCode || (nir.WageUnitCode = {}));
    var EarningsPaymentStatus;
    (function (EarningsPaymentStatus) {
        EarningsPaymentStatus["New"] = "new";
        EarningsPaymentStatus["Succeeded"] = "succeeded";
        EarningsPaymentStatus["Canceled"] = "canceled";
        EarningsPaymentStatus["Error"] = "error";
    })(EarningsPaymentStatus = nir.EarningsPaymentStatus || (nir.EarningsPaymentStatus = {}));
    var TaxCardSnapshotType;
    (function (TaxCardSnapshotType) {
        TaxCardSnapshotType["Example"] = "example";
        TaxCardSnapshotType["NoTaxCard"] = "noTaxCard";
        TaxCardSnapshotType["SideIncome"] = "sideIncome";
        TaxCardSnapshotType["NoTaxPrepayment"] = "noTaxPrepayment";
        TaxCardSnapshotType["TaxCardA"] = "taxCardA";
        TaxCardSnapshotType["TaxCardB"] = "taxCardB";
        TaxCardSnapshotType["Freelancer"] = "freelancer";
        TaxCardSnapshotType["Steps"] = "steps";
        TaxCardSnapshotType["Others"] = "others";
    })(TaxCardSnapshotType = nir.TaxCardSnapshotType || (nir.TaxCardSnapshotType = {}));
    var ApiValidationErrorType;
    (function (ApiValidationErrorType) {
        ApiValidationErrorType["General"] = "general";
        ApiValidationErrorType["Required"] = "required";
        ApiValidationErrorType["Invalid"] = "invalid";
    })(ApiValidationErrorType = nir.ApiValidationErrorType || (nir.ApiValidationErrorType = {}));
})(nir = exports.nir || (exports.nir = {}));

},{}],75:[function(require,module,exports){
/* tslint:disable */
//----------------------
// <auto-generated>
//     Generated using the NSwag toolchain v10.6.6324.28497 (NJsonSchema v8.33.6323.36213) (http://NSwag.org)
// </auto-generated>
//----------------------
Object.defineProperty(exports, "__esModule", { value: true });
/** OAuthGrantType enumeration */
var OAuthGrantType;
(function (OAuthGrantType) {
    OAuthGrantType[OAuthGrantType["Undefined"] = "undefined"] = "Undefined";
    OAuthGrantType[OAuthGrantType["Authorization_code"] = "authorization_code"] = "Authorization_code";
    OAuthGrantType[OAuthGrantType["Password"] = "password"] = "Password";
    OAuthGrantType[OAuthGrantType["Client_credentials"] = "client_credentials"] = "Client_credentials";
    OAuthGrantType[OAuthGrantType["Refresh_token"] = "refresh_token"] = "Refresh_token";
    OAuthGrantType[OAuthGrantType["JwtBearer"] = "jwtBearer"] = "JwtBearer";
})(OAuthGrantType = exports.OAuthGrantType || (exports.OAuthGrantType = {}));
/** OAuthResponseType enumeration */
var OAuthResponseType;
(function (OAuthResponseType) {
    OAuthResponseType[OAuthResponseType["Undefined"] = "undefined"] = "Undefined";
    OAuthResponseType[OAuthResponseType["Code"] = "code"] = "Code";
    OAuthResponseType[OAuthResponseType["Token"] = "token"] = "Token";
})(OAuthResponseType = exports.OAuthResponseType || (exports.OAuthResponseType = {}));
/** OAuthTokenType enumeration */
var OAuthTokenType;
(function (OAuthTokenType) {
    OAuthTokenType[OAuthTokenType["Undefined"] = "undefined"] = "Undefined";
    OAuthTokenType[OAuthTokenType["Bearer"] = "bearer"] = "Bearer";
    OAuthTokenType[OAuthTokenType["Mac"] = "mac"] = "Mac";
})(OAuthTokenType = exports.OAuthTokenType || (exports.OAuthTokenType = {}));
/** OAuthError enumeration */
var OAuthError;
(function (OAuthError) {
    OAuthError[OAuthError["Undefined"] = "undefined"] = "Undefined";
    OAuthError[OAuthError["Invalid_request"] = "invalid_request"] = "Invalid_request";
    OAuthError[OAuthError["Unauthorized_client"] = "unauthorized_client"] = "Unauthorized_client";
    OAuthError[OAuthError["Access_denied"] = "access_denied"] = "Access_denied";
    OAuthError[OAuthError["Unsupported_response_type"] = "unsupported_response_type"] = "Unsupported_response_type";
    OAuthError[OAuthError["Invalid_scope"] = "invalid_scope"] = "Invalid_scope";
    OAuthError[OAuthError["Server_error"] = "server_error"] = "Server_error";
    OAuthError[OAuthError["Temporarily_unavailable"] = "temporarily_unavailable"] = "Temporarily_unavailable";
})(OAuthError = exports.OAuthError || (exports.OAuthError = {}));
/** OAuthSalaxyAuthorizeMode enumeration */
var OAuthSalaxyAuthorizeMode;
(function (OAuthSalaxyAuthorizeMode) {
    OAuthSalaxyAuthorizeMode[OAuthSalaxyAuthorizeMode["Undefined"] = "undefined"] = "Undefined";
    OAuthSalaxyAuthorizeMode[OAuthSalaxyAuthorizeMode["Sign_in"] = "sign_in"] = "Sign_in";
    OAuthSalaxyAuthorizeMode[OAuthSalaxyAuthorizeMode["Sign_up"] = "sign_up"] = "Sign_up";
})(OAuthSalaxyAuthorizeMode = exports.OAuthSalaxyAuthorizeMode || (exports.OAuthSalaxyAuthorizeMode = {}));

},{}],76:[function(require,module,exports){
/* tslint:disable */
/* eslint-disable */
//----------------------
// <auto-generated>
//     Generated using the NSwag toolchain v13.2.2.0 (NJsonSchema v10.1.4.0 (Newtonsoft.Json v11.0.0.0)) (http://NSwag.org)
// </auto-generated>
//----------------------
// ReSharper disable InconsistentNaming
Object.defineProperty(exports, "__esModule", { value: true });
/** AbcSection enumeration */
var AbcSection;
(function (AbcSection) {
    AbcSection["Undefined"] = "undefined";
    AbcSection["DoNotShow"] = "doNotShow";
    AbcSection["Employment"] = "employment";
    AbcSection["Insurance"] = "insurance";
    AbcSection["Salary"] = "salary";
    AbcSection["Examples"] = "examples";
    AbcSection["PalkkausGeneral"] = "palkkausGeneral";
    AbcSection["PalkkausInstructions"] = "palkkausInstructions";
    AbcSection["Blog"] = "blog";
    AbcSection["Press"] = "press";
    AbcSection["PersonEmployer"] = "personEmployer";
    AbcSection["HouseholdEmployer"] = "householdEmployer";
    AbcSection["Worker"] = "worker";
    AbcSection["Employee"] = "employee";
    AbcSection["Entrepreneur"] = "entrepreneur";
    AbcSection["Association"] = "association";
    AbcSection["BusinessOwner"] = "businessOwner";
    AbcSection["ProductLongDescription"] = "productLongDescription";
    AbcSection["DocumentTemplates"] = "documentTemplates";
    AbcSection["InstructionsAndExamples"] = "instructionsAndExamples";
})(AbcSection = exports.AbcSection || (exports.AbcSection = {}));
/** AbsenceCauseCode enumeration */
var AbsenceCauseCode;
(function (AbsenceCauseCode) {
    AbsenceCauseCode["UnpaidLeave"] = "unpaidLeave";
    AbsenceCauseCode["PersonalReason"] = "personalReason";
    AbsenceCauseCode["Illness"] = "illness";
    AbsenceCauseCode["PartTimeSickLeave"] = "partTimeSickLeave";
    AbsenceCauseCode["ParentalLeave"] = "parentalLeave";
    AbsenceCauseCode["SpecialMaternityLeave"] = "specialMaternityLeave";
    AbsenceCauseCode["Rehabilitation"] = "rehabilitation";
    AbsenceCauseCode["ChildIllness"] = "childIllness";
    AbsenceCauseCode["PartTimeChildCareLeave"] = "partTimeChildCareLeave";
    AbsenceCauseCode["Training"] = "training";
    AbsenceCauseCode["JobAlternationLeave"] = "jobAlternationLeave";
    AbsenceCauseCode["StudyLeave"] = "studyLeave";
    AbsenceCauseCode["IndustrialAction"] = "industrialAction";
    AbsenceCauseCode["InterruptionInWorkProvision"] = "interruptionInWorkProvision";
    AbsenceCauseCode["LeaveOfAbsence"] = "leaveOfAbsence";
    AbsenceCauseCode["MilitaryRefresherTraining"] = "militaryRefresherTraining";
    AbsenceCauseCode["MilitaryService"] = "militaryService";
    AbsenceCauseCode["LayOff"] = "layOff";
    AbsenceCauseCode["ChildCareLeave"] = "childCareLeave";
    AbsenceCauseCode["MidWeekHoliday"] = "midWeekHoliday";
    AbsenceCauseCode["AccruedHoliday"] = "accruedHoliday";
    AbsenceCauseCode["OccupationalAccident"] = "occupationalAccident";
    AbsenceCauseCode["AnnualLeave"] = "annualLeave";
    AbsenceCauseCode["PartTimeAbsenceDueToRehabilitation"] = "partTimeAbsenceDueToRehabilitation";
    AbsenceCauseCode["Other"] = "other";
})(AbsenceCauseCode = exports.AbsenceCauseCode || (exports.AbsenceCauseCode = {}));
/** AccountingReportRowType enumeration */
var AccountingReportRowType;
(function (AccountingReportRowType) {
    AccountingReportRowType["Debit"] = "debit";
    AccountingReportRowType["Credit"] = "credit";
    AccountingReportRowType["Total"] = "total";
    AccountingReportRowType["GroupHeader"] = "groupHeader";
    AccountingReportRowType["GroupTotal"] = "groupTotal";
    AccountingReportRowType["ChildRow"] = "childRow";
})(AccountingReportRowType = exports.AccountingReportRowType || (exports.AccountingReportRowType = {}));
/** AccountingReportTableType enumeration */
var AccountingReportTableType;
(function (AccountingReportTableType) {
    AccountingReportTableType["Classic"] = "classic";
    AccountingReportTableType["Simple"] = "simple";
    AccountingReportTableType["Mapped"] = "mapped";
})(AccountingReportTableType = exports.AccountingReportTableType || (exports.AccountingReportTableType = {}));
/** AgeGroupCode enumeration */
var AgeGroupCode;
(function (AgeGroupCode) {
    AgeGroupCode["A"] = "a";
    AgeGroupCode["B"] = "b";
    AgeGroupCode["C"] = "c";
    AgeGroupCode["U"] = "u";
})(AgeGroupCode = exports.AgeGroupCode || (exports.AgeGroupCode = {}));
/** AgeRange enumeration */
var AgeRange;
(function (AgeRange) {
    AgeRange["Unknown"] = "unknown";
    AgeRange["Age_15"] = "age_15";
    AgeRange["Age16"] = "age16";
    AgeRange["Age17"] = "age17";
    AgeRange["Age18_52"] = "age18_52";
    AgeRange["Age53_62"] = "age53_62";
    AgeRange["Age63_64"] = "age63_64";
    AgeRange["Age65_67"] = "age65_67";
    AgeRange["Age68AndOVer"] = "age68AndOVer";
})(AgeRange = exports.AgeRange || (exports.AgeRange = {}));
/** AllowanceCode enumeration */
var AllowanceCode;
(function (AllowanceCode) {
    AllowanceCode["MealAllowance"] = "mealAllowance";
    AllowanceCode["PartialDailyAllowance"] = "partialDailyAllowance";
    AllowanceCode["FullDailyAllowance"] = "fullDailyAllowance";
    AllowanceCode["InternationalDailyAllowance"] = "internationalDailyAllowance";
    AllowanceCode["TaxExemptReimbursementsAbroad"] = "taxExemptReimbursementsAbroad";
})(AllowanceCode = exports.AllowanceCode || (exports.AllowanceCode = {}));
/** AnnualLeavePaymentKind enumeration */
var AnnualLeavePaymentKind;
(function (AnnualLeavePaymentKind) {
    AnnualLeavePaymentKind["Undefined"] = "undefined";
    AnnualLeavePaymentKind["Planned"] = "planned";
    AnnualLeavePaymentKind["ManualSalary"] = "manualSalary";
    AnnualLeavePaymentKind["ManualCompensation"] = "manualCompensation";
    AnnualLeavePaymentKind["ManualBonus"] = "manualBonus";
    AnnualLeavePaymentKind["PaidCalc"] = "paidCalc";
    AnnualLeavePaymentKind["DraftCalc"] = "draftCalc";
})(AnnualLeavePaymentKind = exports.AnnualLeavePaymentKind || (exports.AnnualLeavePaymentKind = {}));
/** ApiTestErrorType enumeration */
var ApiTestErrorType;
(function (ApiTestErrorType) {
    ApiTestErrorType["Default"] = "default";
    ApiTestErrorType["UserFriendly"] = "userFriendly";
})(ApiTestErrorType = exports.ApiTestErrorType || (exports.ApiTestErrorType = {}));
/** ApiValidationErrorType enumeration */
var ApiValidationErrorType;
(function (ApiValidationErrorType) {
    ApiValidationErrorType["General"] = "general";
    ApiValidationErrorType["Required"] = "required";
    ApiValidationErrorType["Invalid"] = "invalid";
    ApiValidationErrorType["Warning"] = "warning";
})(ApiValidationErrorType = exports.ApiValidationErrorType || (exports.ApiValidationErrorType = {}));
/** AuthenticationMethod enumeration */
var AuthenticationMethod;
(function (AuthenticationMethod) {
    AuthenticationMethod["Undefined"] = "undefined";
    AuthenticationMethod["EmailPwdLocal"] = "emailPwdLocal";
    AuthenticationMethod["Facebook"] = "facebook";
    AuthenticationMethod["Google"] = "google";
    AuthenticationMethod["Microsoft"] = "microsoft";
    AuthenticationMethod["LinkedIn"] = "linkedIn";
    AuthenticationMethod["Auth0Database"] = "auth0Database";
    AuthenticationMethod["X509"] = "x509";
    AuthenticationMethod["Salaxy"] = "salaxy";
    AuthenticationMethod["Test"] = "test";
    AuthenticationMethod["InternalLocalhost"] = "internalLocalhost";
})(AuthenticationMethod = exports.AuthenticationMethod || (exports.AuthenticationMethod = {}));
/** AuthorizationStatus enumeration */
var AuthorizationStatus;
(function (AuthorizationStatus) {
    AuthorizationStatus["Undefined"] = "undefined";
    AuthorizationStatus["OK"] = "oK";
    AuthorizationStatus["AccessDenied"] = "accessDenied";
    AuthorizationStatus["ExpiredOauthToken"] = "expiredOauthToken";
    AuthorizationStatus["InvalidOAuthToken"] = "invalidOAuthToken";
    AuthorizationStatus["NoOauthToken"] = "noOauthToken";
})(AuthorizationStatus = exports.AuthorizationStatus || (exports.AuthorizationStatus = {}));
/** AuthorizationType enumeration */
var AuthorizationType;
(function (AuthorizationType) {
    AuthorizationType["None"] = "none";
    AuthorizationType["EmployerAuthorization"] = "employerAuthorization";
    AuthorizationType["WorkerContract"] = "workerContract";
    AuthorizationType["CompanyContract"] = "companyContract";
    AuthorizationType["Manual"] = "manual";
    AuthorizationType["Temporary"] = "temporary";
})(AuthorizationType = exports.AuthorizationType || (exports.AuthorizationType = {}));
/** AvatarPictureType enumeration */
var AvatarPictureType;
(function (AvatarPictureType) {
    AvatarPictureType["Icon"] = "icon";
    AvatarPictureType["Uploaded"] = "uploaded";
    AvatarPictureType["Gravatar"] = "gravatar";
})(AvatarPictureType = exports.AvatarPictureType || (exports.AvatarPictureType = {}));
/** BankPaymentType enumeration */
var BankPaymentType;
(function (BankPaymentType) {
    BankPaymentType["Unknown"] = "unknown";
    BankPaymentType["Error"] = "error";
    BankPaymentType["PaytrailBatch"] = "paytrailBatch";
    BankPaymentType["NetvisorPayment"] = "netvisorPayment";
    BankPaymentType["SalaryGrossPayment"] = "salaryGrossPayment";
    BankPaymentType["RefundPayment"] = "refundPayment";
    BankPaymentType["PartialRefundPayment"] = "partialRefundPayment";
    BankPaymentType["InsuranceGrossPayment"] = "insuranceGrossPayment";
    BankPaymentType["NetSalary"] = "netSalary";
    BankPaymentType["SalaryAdvance"] = "salaryAdvance";
    BankPaymentType["TaxAccount"] = "taxAccount";
    BankPaymentType["Tvr"] = "tvr";
    BankPaymentType["TvrRfnd"] = "tvrRfnd";
    BankPaymentType["PalkkausFees"] = "palkkausFees";
    BankPaymentType["BankFees"] = "bankFees";
    BankPaymentType["PaytrailFees"] = "paytrailFees";
    BankPaymentType["InsuranceLahiTapiola"] = "insuranceLahiTapiola";
    BankPaymentType["Tyel"] = "tyel";
    BankPaymentType["TyelEteraContract"] = "tyelEteraContract";
    BankPaymentType["TyelEteraTemp"] = "tyelEteraTemp";
    BankPaymentType["TyelEteraUnknown"] = "tyelEteraUnknown";
    BankPaymentType["TyelEloContract"] = "tyelEloContract";
    BankPaymentType["TyelEloTemp"] = "tyelEloTemp";
    BankPaymentType["TyelEloInitialImport"] = "tyelEloInitialImport";
    BankPaymentType["TyelVarmaContract"] = "tyelVarmaContract";
    BankPaymentType["TyelVarmaTemp"] = "tyelVarmaTemp";
    BankPaymentType["TyelIlmarinenContract"] = "tyelIlmarinenContract";
    BankPaymentType["TyelIlmarinenTemp"] = "tyelIlmarinenTemp";
    BankPaymentType["Union"] = "union";
    BankPaymentType["UnionRaksa"] = "unionRaksa";
    BankPaymentType["Foreclosure"] = "foreclosure";
    BankPaymentType["SaldoYearBegin"] = "saldoYearBegin";
    BankPaymentType["SaldoYearEnd"] = "saldoYearEnd";
})(BankPaymentType = exports.BankPaymentType || (exports.BankPaymentType = {}));
/** BenefitCode enumeration */
var BenefitCode;
(function (BenefitCode) {
    BenefitCode["AccommodationBenefit"] = "accommodationBenefit";
    BenefitCode["TelephoneBenefit"] = "telephoneBenefit";
    BenefitCode["MealBenefit"] = "mealBenefit";
    BenefitCode["OtherBenefits"] = "otherBenefits";
})(BenefitCode = exports.BenefitCode || (exports.BenefitCode = {}));
/** BlobFileType enumeration */
var BlobFileType;
(function (BlobFileType) {
    BlobFileType["Unknown"] = "unknown";
    BlobFileType["AuthorizationPdf"] = "authorizationPdf";
    BlobFileType["Avatar"] = "avatar";
    BlobFileType["TaxCard"] = "taxCard";
    BlobFileType["ExpensesReceipt"] = "expensesReceipt";
    BlobFileType["Raksaloki"] = "raksaloki";
    BlobFileType["Template"] = "template";
    BlobFileType["EInvoice"] = "eInvoice";
    BlobFileType["Temporary"] = "temporary";
    BlobFileType["Settings"] = "settings";
    BlobFileType["Messages"] = "messages";
    BlobFileType["MonthlyReport"] = "monthlyReport";
    BlobFileType["YearlyReport"] = "yearlyReport";
    BlobFileType["CalcReport"] = "calcReport";
})(BlobFileType = exports.BlobFileType || (exports.BlobFileType = {}));
/** BlobRepository enumeration */
var BlobRepository;
(function (BlobRepository) {
    BlobRepository["UserFiles"] = "userFiles";
    BlobRepository["VersionHistory"] = "versionHistory";
    BlobRepository["SystemFiles"] = "systemFiles";
    BlobRepository["Payload"] = "payload";
    BlobRepository["Reports"] = "reports";
    BlobRepository["CdnImages"] = "cdnImages";
    BlobRepository["GitContent"] = "gitContent";
    BlobRepository["FileSystemContent"] = "fileSystemContent";
})(BlobRepository = exports.BlobRepository || (exports.BlobRepository = {}));
/** CalcGroup enumeration */
var CalcGroup;
(function (CalcGroup) {
    CalcGroup["Undefined"] = "undefined";
    CalcGroup["BaseSalary"] = "baseSalary";
    CalcGroup["SalaryAdditions"] = "salaryAdditions";
    CalcGroup["Benefits"] = "benefits";
    CalcGroup["Expenses"] = "expenses";
    CalcGroup["Deductions"] = "deductions";
    CalcGroup["OtherNoPayment"] = "otherNoPayment";
    CalcGroup["Totals"] = "totals";
    CalcGroup["Disabled"] = "disabled";
})(CalcGroup = exports.CalcGroup || (exports.CalcGroup = {}));
/** CalculationFlag enumeration */
var CalculationFlag;
(function (CalculationFlag) {
    CalculationFlag["Exclude"] = "exclude";
    CalculationFlag["PensionInsurance"] = "pensionInsurance";
    CalculationFlag["AccidentInsurance"] = "accidentInsurance";
    CalculationFlag["UnemploymentInsurance"] = "unemploymentInsurance";
    CalculationFlag["HealthInsurance"] = "healthInsurance";
    CalculationFlag["InsurancesDeduction"] = "insurancesDeduction";
    CalculationFlag["NoTax"] = "noTax";
    CalculationFlag["Tax"] = "tax";
    CalculationFlag["TaxDeduction"] = "taxDeduction";
    CalculationFlag["CfNoPayment"] = "cfNoPayment";
    CalculationFlag["CfPayment"] = "cfPayment";
    CalculationFlag["CfDeduction"] = "cfDeduction";
    CalculationFlag["CfDeductionAtSalaxy"] = "cfDeductionAtSalaxy";
})(CalculationFlag = exports.CalculationFlag || (exports.CalculationFlag = {}));
/** CalculationResultRowType enumeration */
var CalculationResultRowType;
(function (CalculationResultRowType) {
    CalculationResultRowType["Undefined"] = "undefined";
    CalculationResultRowType["TotalBenefits"] = "totalBenefits";
    CalculationResultRowType["TotalExpenses"] = "totalExpenses";
    CalculationResultRowType["TotalSocialSecurityEmployer"] = "totalSocialSecurityEmployer";
    CalculationResultRowType["TotalSocialSecurityEmployerDebt"] = "totalSocialSecurityEmployerDebt";
    CalculationResultRowType["TotalSocialSecurityEmployerPayment"] = "totalSocialSecurityEmployerPayment";
    CalculationResultRowType["TotalPension"] = "totalPension";
    CalculationResultRowType["TotalPensionPayment"] = "totalPensionPayment";
    CalculationResultRowType["TotalPensionEmployer"] = "totalPensionEmployer";
    CalculationResultRowType["TotalPensionEmployerDebt"] = "totalPensionEmployerDebt";
    CalculationResultRowType["TotalPensionWorker"] = "totalPensionWorker";
    CalculationResultRowType["TotalUnemployment"] = "totalUnemployment";
    CalculationResultRowType["TotalUnemploymentPayment"] = "totalUnemploymentPayment";
    CalculationResultRowType["TotalUnemploymentEmployer"] = "totalUnemploymentEmployer";
    CalculationResultRowType["TotalUnemploymentEmployerDebt"] = "totalUnemploymentEmployerDebt";
    CalculationResultRowType["TotalUnemploymentWorker"] = "totalUnemploymentWorker";
    CalculationResultRowType["TotalPalkkaus"] = "totalPalkkaus";
    CalculationResultRowType["TotalSalary"] = "totalSalary";
    CalculationResultRowType["TotalTax"] = "totalTax";
    CalculationResultRowType["TotalTaxPayment"] = "totalTaxPayment";
    CalculationResultRowType["TotalPayment"] = "totalPayment";
    CalculationResultRowType["TotalWorkerPayment"] = "totalWorkerPayment";
})(CalculationResultRowType = exports.CalculationResultRowType || (exports.CalculationResultRowType = {}));
/** CalculationRowSource enumeration */
var CalculationRowSource;
(function (CalculationRowSource) {
    CalculationRowSource["SalaryPage"] = "salaryPage";
    CalculationRowSource["TesSelection"] = "tesSelection";
    CalculationRowSource["ManualRow"] = "manualRow";
})(CalculationRowSource = exports.CalculationRowSource || (exports.CalculationRowSource = {}));
/** CalculationRowType enumeration */
var CalculationRowType;
(function (CalculationRowType) {
    CalculationRowType["Unknown"] = "unknown";
    CalculationRowType["Salary"] = "salary";
    CalculationRowType["HourlySalary"] = "hourlySalary";
    CalculationRowType["MonthlySalary"] = "monthlySalary";
    CalculationRowType["TotalWorkerPayment"] = "totalWorkerPayment";
    CalculationRowType["TotalEmployerPayment"] = "totalEmployerPayment";
    CalculationRowType["Compensation"] = "compensation";
    CalculationRowType["Overtime"] = "overtime";
    CalculationRowType["TesWorktimeShortening"] = "tesWorktimeShortening";
    CalculationRowType["EveningAddition"] = "eveningAddition";
    CalculationRowType["NightimeAddition"] = "nightimeAddition";
    CalculationRowType["SaturdayAddition"] = "saturdayAddition";
    CalculationRowType["SundayWork"] = "sundayWork";
    CalculationRowType["OtherAdditions"] = "otherAdditions";
    CalculationRowType["AccomodationBenefit"] = "accomodationBenefit";
    CalculationRowType["MealBenefit"] = "mealBenefit";
    CalculationRowType["PhoneBenefit"] = "phoneBenefit";
    CalculationRowType["CarBenefit"] = "carBenefit";
    CalculationRowType["OtherBenefit"] = "otherBenefit";
    CalculationRowType["HolidayCompensation"] = "holidayCompensation";
    CalculationRowType["HolidayBonus"] = "holidayBonus";
    CalculationRowType["HolidaySalary"] = "holidaySalary";
    CalculationRowType["DailyAllowance"] = "dailyAllowance";
    CalculationRowType["DailyAllowanceHalf"] = "dailyAllowanceHalf";
    CalculationRowType["MealCompensation"] = "mealCompensation";
    CalculationRowType["MilageOwnCar"] = "milageOwnCar";
    CalculationRowType["ToolCompensation"] = "toolCompensation";
    CalculationRowType["Expenses"] = "expenses";
    CalculationRowType["MilageDaily"] = "milageDaily";
    CalculationRowType["MilageOther"] = "milageOther";
    CalculationRowType["UnionPayment"] = "unionPayment";
    CalculationRowType["Foreclosure"] = "foreclosure";
    CalculationRowType["Advance"] = "advance";
    CalculationRowType["ForeclosureByPalkkaus"] = "foreclosureByPalkkaus";
    CalculationRowType["PrepaidExpenses"] = "prepaidExpenses";
    CalculationRowType["OtherDeductions"] = "otherDeductions";
    CalculationRowType["ChildCareSubsidy"] = "childCareSubsidy";
    CalculationRowType["ChainsawReduction"] = "chainsawReduction";
    CalculationRowType["NonProfitOrg"] = "nonProfitOrg";
    CalculationRowType["SubsidisedCommute"] = "subsidisedCommute";
    CalculationRowType["IrIncomeType"] = "irIncomeType";
    CalculationRowType["Board"] = "board";
    CalculationRowType["Remuneration"] = "remuneration";
    CalculationRowType["OtherCompensation"] = "otherCompensation";
    CalculationRowType["WorkingTimeCompensation"] = "workingTimeCompensation";
    CalculationRowType["EmploymentTermination"] = "employmentTermination";
    CalculationRowType["Totals"] = "totals";
})(CalculationRowType = exports.CalculationRowType || (exports.CalculationRowType = {}));
/** CalculationRowUnit enumeration */
var CalculationRowUnit;
(function (CalculationRowUnit) {
    CalculationRowUnit["Undefined"] = "undefined";
    CalculationRowUnit["Count"] = "count";
    CalculationRowUnit["Percent"] = "percent";
    CalculationRowUnit["Days"] = "days";
    CalculationRowUnit["Kilometers"] = "kilometers";
    CalculationRowUnit["Hours"] = "hours";
})(CalculationRowUnit = exports.CalculationRowUnit || (exports.CalculationRowUnit = {}));
/** CalculationStatus enumeration */
var CalculationStatus;
(function (CalculationStatus) {
    CalculationStatus["Draft"] = "draft";
    CalculationStatus["PaymentStarted"] = "paymentStarted";
    CalculationStatus["PaymentSucceeded"] = "paymentSucceeded";
    CalculationStatus["PaymentCanceled"] = "paymentCanceled";
    CalculationStatus["PaymentError"] = "paymentError";
    CalculationStatus["PaymentWorkerCopy"] = "paymentWorkerCopy";
    CalculationStatus["WorkerRequested"] = "workerRequested";
    CalculationStatus["WorkerRequestAccepted"] = "workerRequestAccepted";
    CalculationStatus["WorkerRequestDeclined"] = "workerRequestDeclined";
    CalculationStatus["PaymentRefunded"] = "paymentRefunded";
    CalculationStatus["PayrollDraft"] = "payrollDraft";
    CalculationStatus["ProDraft"] = "proDraft";
    CalculationStatus["Template"] = "template";
})(CalculationStatus = exports.CalculationStatus || (exports.CalculationStatus = {}));
/** CarBenefitCode enumeration */
var CarBenefitCode;
(function (CarBenefitCode) {
    CarBenefitCode["LimitedCarBenefit"] = "limitedCarBenefit";
    CarBenefitCode["FullCarBenefit"] = "fullCarBenefit";
})(CarBenefitCode = exports.CarBenefitCode || (exports.CarBenefitCode = {}));
/** CompanyType enumeration */
var CompanyType;
(function (CompanyType) {
    CompanyType["Unknown"] = "unknown";
    CompanyType["FiOy"] = "fiOy";
    CompanyType["FiTm"] = "fiTm";
    CompanyType["FiRy"] = "fiRy";
    CompanyType["FiYy"] = "fiYy";
})(CompanyType = exports.CompanyType || (exports.CompanyType = {}));
/** ContractPartyType enumeration */
var ContractPartyType;
(function (ContractPartyType) {
    ContractPartyType["Person"] = "person";
    ContractPartyType["CustomContact"] = "customContact";
})(ContractPartyType = exports.ContractPartyType || (exports.ContractPartyType = {}));
/** EmploymentRelationType enumeration */
var EmploymentRelationType;
(function (EmploymentRelationType) {
    EmploymentRelationType["Undefined"] = "undefined";
    EmploymentRelationType["Salary"] = "salary";
    EmploymentRelationType["HourlySalary"] = "hourlySalary";
    EmploymentRelationType["MonthlySalary"] = "monthlySalary";
    EmploymentRelationType["Compensation"] = "compensation";
    EmploymentRelationType["BoardMember"] = "boardMember";
    EmploymentRelationType["Entrepreneur"] = "entrepreneur";
    EmploymentRelationType["Farmer"] = "farmer";
    EmploymentRelationType["EmployedByStateEmploymentFund"] = "employedByStateEmploymentFund";
    EmploymentRelationType["KeyEmployee"] = "keyEmployee";
    EmploymentRelationType["Athlete"] = "athlete";
    EmploymentRelationType["PerformingArtist"] = "performingArtist";
})(EmploymentRelationType = exports.EmploymentRelationType || (exports.EmploymentRelationType = {}));
/** EmploymentSalaryType enumeration */
var EmploymentSalaryType;
(function (EmploymentSalaryType) {
    EmploymentSalaryType["Unknown"] = "unknown";
    EmploymentSalaryType["HourlyPay"] = "hourlyPay";
    EmploymentSalaryType["MontlyPay"] = "montlyPay";
    EmploymentSalaryType["OtherPay"] = "otherPay";
})(EmploymentSalaryType = exports.EmploymentSalaryType || (exports.EmploymentSalaryType = {}));
/** EmploymentType enumeration */
var EmploymentType;
(function (EmploymentType) {
    EmploymentType["Unknown"] = "unknown";
    EmploymentType["Job"] = "job";
    EmploymentType["PartTime"] = "partTime";
    EmploymentType["FullTime"] = "fullTime";
})(EmploymentType = exports.EmploymentType || (exports.EmploymentType = {}));
/** EmploymentWorkHoursType enumeration */
var EmploymentWorkHoursType;
(function (EmploymentWorkHoursType) {
    EmploymentWorkHoursType["HoursPerDay"] = "hoursPerDay";
    EmploymentWorkHoursType["HoursPerWeek"] = "hoursPerWeek";
    EmploymentWorkHoursType["HourPerTwoWeeks"] = "hourPerTwoWeeks";
    EmploymentWorkHoursType["HourPerThreeWeeks"] = "hourPerThreeWeeks";
})(EmploymentWorkHoursType = exports.EmploymentWorkHoursType || (exports.EmploymentWorkHoursType = {}));
/** ESalaryPaymentStatus enumeration */
var ESalaryPaymentStatus;
(function (ESalaryPaymentStatus) {
    ESalaryPaymentStatus["Created"] = "created";
    ESalaryPaymentStatus["Shared"] = "shared";
    ESalaryPaymentStatus["Opened"] = "opened";
    ESalaryPaymentStatus["EmployerLinked"] = "employerLinked";
    ESalaryPaymentStatus["CalculationCreated"] = "calculationCreated";
    ESalaryPaymentStatus["PaymentStarted"] = "paymentStarted";
    ESalaryPaymentStatus["PaymentSucceeded"] = "paymentSucceeded";
    ESalaryPaymentStatus["PaymentCanceled"] = "paymentCanceled";
})(ESalaryPaymentStatus = exports.ESalaryPaymentStatus || (exports.ESalaryPaymentStatus = {}));
/** DateOfBirthAccuracy enumeration */
var DateOfBirthAccuracy;
(function (DateOfBirthAccuracy) {
    DateOfBirthAccuracy["Assumption"] = "assumption";
    DateOfBirthAccuracy["AgeBased"] = "ageBased";
    DateOfBirthAccuracy["AgeGroupBased"] = "ageGroupBased";
    DateOfBirthAccuracy["MonthCorrect"] = "monthCorrect";
    DateOfBirthAccuracy["Exact"] = "exact";
    DateOfBirthAccuracy["Verified"] = "verified";
})(DateOfBirthAccuracy = exports.DateOfBirthAccuracy || (exports.DateOfBirthAccuracy = {}));
/** EmployerType enumeration */
var EmployerType;
(function (EmployerType) {
    EmployerType["Unknown"] = "unknown";
    EmployerType["MiniEmployer"] = "miniEmployer";
    EmployerType["SmallEmployer"] = "smallEmployer";
    EmployerType["FullTimeEmployer"] = "fullTimeEmployer";
    EmployerType["TyelOwnContractEmployer"] = "tyelOwnContractEmployer";
})(EmployerType = exports.EmployerType || (exports.EmployerType = {}));
/** FrameworkAgreement enumeration */
var FrameworkAgreement;
(function (FrameworkAgreement) {
    FrameworkAgreement["NotDefined"] = "notDefined";
    FrameworkAgreement["Construction"] = "construction";
    FrameworkAgreement["Mll"] = "mll";
    FrameworkAgreement["ChildCare"] = "childCare";
    FrameworkAgreement["Cleaning"] = "cleaning";
    FrameworkAgreement["SantaClaus"] = "santaClaus";
    FrameworkAgreement["Entrepreneur"] = "entrepreneur";
    FrameworkAgreement["Other"] = "other";
})(FrameworkAgreement = exports.FrameworkAgreement || (exports.FrameworkAgreement = {}));
/** Gender enumeration */
var Gender;
(function (Gender) {
    Gender["Unknown"] = "unknown";
    Gender["Male"] = "male";
    Gender["Female"] = "female";
})(Gender = exports.Gender || (exports.Gender = {}));
/** HelttiIndustry enumeration */
var HelttiIndustry;
(function (HelttiIndustry) {
    HelttiIndustry["NotDefined"] = "notDefined";
    HelttiIndustry["I"] = "i";
    HelttiIndustry["J"] = "j";
    HelttiIndustry["K"] = "k";
    HelttiIndustry["M"] = "m";
    HelttiIndustry["O"] = "o";
    HelttiIndustry["N"] = "n";
    HelttiIndustry["P"] = "p";
    HelttiIndustry["Q"] = "q";
    HelttiIndustry["R"] = "r";
    HelttiIndustry["S"] = "s";
    HelttiIndustry["Other"] = "other";
})(HelttiIndustry = exports.HelttiIndustry || (exports.HelttiIndustry = {}));
/** HelttiProductPackage enumeration */
var HelttiProductPackage;
(function (HelttiProductPackage) {
    HelttiProductPackage["NotDefined"] = "notDefined";
    HelttiProductPackage["Small"] = "small";
    HelttiProductPackage["Medium"] = "medium";
    HelttiProductPackage["Large"] = "large";
})(HelttiProductPackage = exports.HelttiProductPackage || (exports.HelttiProductPackage = {}));
/** IncomeEarnerType enumeration */
var IncomeEarnerType;
(function (IncomeEarnerType) {
    IncomeEarnerType["EmployedByStateEmploymentFund"] = "employedByStateEmploymentFund";
    IncomeEarnerType["JointOwnerWithPayer"] = "jointOwnerWithPayer";
    IncomeEarnerType["PartialOwner"] = "partialOwner";
    IncomeEarnerType["KeyEmployee"] = "keyEmployee";
    IncomeEarnerType["LeasedEmployeeLivingAbroad"] = "leasedEmployeeLivingAbroad";
    IncomeEarnerType["PersonWorkingInFrontierDistrict"] = "personWorkingInFrontierDistrict";
    IncomeEarnerType["PersonWorkingAbroad"] = "personWorkingAbroad";
    IncomeEarnerType["Athlete"] = "athlete";
    IncomeEarnerType["PerformingArtist"] = "performingArtist";
    IncomeEarnerType["RestrictedPeriodInFinland"] = "restrictedPeriodInFinland";
    IncomeEarnerType["NetOfTaxContract"] = "netOfTaxContract";
    IncomeEarnerType["Organization"] = "organization";
    IncomeEarnerType["PersonWorkingOnAlandFerry"] = "personWorkingOnAlandFerry";
    IncomeEarnerType["EntrepreneurOrFarmerNoPensionRequired"] = "entrepreneurOrFarmerNoPensionRequired";
})(IncomeEarnerType = exports.IncomeEarnerType || (exports.IncomeEarnerType = {}));
/** Holiday enumeration */
var Holiday;
(function (Holiday) {
    Holiday["NewYearsDay"] = "newYearsDay";
    Holiday["Epiphany"] = "epiphany";
    Holiday["GoodFriday"] = "goodFriday";
    Holiday["EasterSunday"] = "easterSunday";
    Holiday["EasterSaturday"] = "easterSaturday";
    Holiday["EasterMonday"] = "easterMonday";
    Holiday["MayDay"] = "mayDay";
    Holiday["AscensionDay"] = "ascensionDay";
    Holiday["Pentecost"] = "pentecost";
    Holiday["MidsummerEve"] = "midsummerEve";
    Holiday["MidsummerDay"] = "midsummerDay";
    Holiday["AllSaintsDay"] = "allSaintsDay";
    Holiday["IndependenceDay"] = "independenceDay";
    Holiday["ChristmasEve"] = "christmasEve";
    Holiday["ChristmasDay"] = "christmasDay";
    Holiday["StStephensDay"] = "stStephensDay";
})(Holiday = exports.Holiday || (exports.Holiday = {}));
/** HolidayAccrualSource enumeration */
var HolidayAccrualSource;
(function (HolidayAccrualSource) {
    HolidayAccrualSource["Initial"] = "initial";
    HolidayAccrualSource["Manual"] = "manual";
    HolidayAccrualSource["CalcDraft"] = "calcDraft";
    HolidayAccrualSource["CalcPaid"] = "calcPaid";
})(HolidayAccrualSource = exports.HolidayAccrualSource || (exports.HolidayAccrualSource = {}));
/** HolidayBonusPaymentMethod enumeration */
var HolidayBonusPaymentMethod;
(function (HolidayBonusPaymentMethod) {
    HolidayBonusPaymentMethod["None"] = "none";
    HolidayBonusPaymentMethod["PayForHolidaySalary"] = "payForHolidaySalary";
    HolidayBonusPaymentMethod["PaySummerBonus"] = "paySummerBonus";
    HolidayBonusPaymentMethod["Pay24Days"] = "pay24Days";
    HolidayBonusPaymentMethod["PayAllBonus"] = "payAllBonus";
})(HolidayBonusPaymentMethod = exports.HolidayBonusPaymentMethod || (exports.HolidayBonusPaymentMethod = {}));
/** HolidayCode enumeration */
var HolidayCode;
(function (HolidayCode) {
    HolidayCode["Undefined"] = "undefined";
    HolidayCode["Permanent14Days"] = "permanent14Days";
    HolidayCode["Permanent35Hours"] = "permanent35Hours";
    HolidayCode["TemporaryTimeOff"] = "temporaryTimeOff";
    HolidayCode["HolidayCompensation"] = "holidayCompensation";
    HolidayCode["HolidayCompensationIncluded"] = "holidayCompensationIncluded";
    HolidayCode["NoHolidays"] = "noHolidays";
})(HolidayCode = exports.HolidayCode || (exports.HolidayCode = {}));
/** HolidayGroup enumeration */
var HolidayGroup;
(function (HolidayGroup) {
    HolidayGroup["Official"] = "official";
    HolidayGroup["NonBanking"] = "nonBanking";
    HolidayGroup["Holiday"] = "holiday";
})(HolidayGroup = exports.HolidayGroup || (exports.HolidayGroup = {}));
/** InsuranceCompany enumeration */
var InsuranceCompany;
(function (InsuranceCompany) {
    InsuranceCompany["None"] = "none";
    InsuranceCompany["L\u00E4hiTapiola"] = "l\u00E4hiTapiola";
    InsuranceCompany["Pohjola"] = "pohjola";
    InsuranceCompany["If"] = "if";
    InsuranceCompany["Fennia"] = "fennia";
    InsuranceCompany["AVakuutus"] = "aVakuutus";
    InsuranceCompany["Aktia"] = "aktia";
    InsuranceCompany["Pohjant\u00E4hti"] = "pohjant\u00E4hti";
    InsuranceCompany["Tryg"] = "tryg";
    InsuranceCompany["\u00C5lands"] = "\u00E5lands";
    InsuranceCompany["Turva"] = "turva";
    InsuranceCompany["Redarnas"] = "redarnas";
    InsuranceCompany["Folksam"] = "folksam";
    InsuranceCompany["Alandia"] = "alandia";
    InsuranceCompany["Other"] = "other";
    InsuranceCompany["Pending"] = "pending";
})(InsuranceCompany = exports.InsuranceCompany || (exports.InsuranceCompany = {}));
/** IrFlags enumeration */
var IrFlags;
(function (IrFlags) {
    IrFlags["NoMoney"] = "noMoney";
    IrFlags["OneOff"] = "oneOff";
    IrFlags["UnjustEnrichment"] = "unjustEnrichment";
})(IrFlags = exports.IrFlags || (exports.IrFlags = {}));
/** IrInsuranceExceptions enumeration */
var IrInsuranceExceptions;
(function (IrInsuranceExceptions) {
    IrInsuranceExceptions["IncludeAll"] = "includeAll";
    IrInsuranceExceptions["IncludePension"] = "includePension";
    IrInsuranceExceptions["IncludeHealthInsurance"] = "includeHealthInsurance";
    IrInsuranceExceptions["IncludeUnemployment"] = "includeUnemployment";
    IrInsuranceExceptions["IncludeAccidentInsurance"] = "includeAccidentInsurance";
    IrInsuranceExceptions["ExcludeAll"] = "excludeAll";
    IrInsuranceExceptions["ExcludePension"] = "excludePension";
    IrInsuranceExceptions["ExcludeHealthInsurance"] = "excludeHealthInsurance";
    IrInsuranceExceptions["ExcludeUnemployment"] = "excludeUnemployment";
    IrInsuranceExceptions["ExcludeAccidentInsurance"] = "excludeAccidentInsurance";
})(IrInsuranceExceptions = exports.IrInsuranceExceptions || (exports.IrInsuranceExceptions = {}));
/** IrRowSourceType enumeration */
var IrRowSourceType;
(function (IrRowSourceType) {
    IrRowSourceType["Manual"] = "manual";
    IrRowSourceType["Usecase"] = "usecase";
    IrRowSourceType["UsecaseV02"] = "usecaseV02";
})(IrRowSourceType = exports.IrRowSourceType || (exports.IrRowSourceType = {}));
/** LegalEntityType enumeration */
var LegalEntityType;
(function (LegalEntityType) {
    LegalEntityType["Undefined"] = "undefined";
    LegalEntityType["Person"] = "person";
    LegalEntityType["Company"] = "company";
    LegalEntityType["PersonCreatedByEmployer"] = "personCreatedByEmployer";
    LegalEntityType["Partner"] = "partner";
})(LegalEntityType = exports.LegalEntityType || (exports.LegalEntityType = {}));
/** LegacyTaxcardType enumeration */
var LegacyTaxcardType;
(function (LegacyTaxcardType) {
    LegacyTaxcardType["Example"] = "example";
    LegacyTaxcardType["NoTaxCard"] = "noTaxCard";
    LegacyTaxcardType["SideIncome"] = "sideIncome";
    LegacyTaxcardType["NoTaxPrepayment"] = "noTaxPrepayment";
    LegacyTaxcardType["TaxCardA"] = "taxCardA";
    LegacyTaxcardType["TaxCardB"] = "taxCardB";
    LegacyTaxcardType["Freelancer"] = "freelancer";
    LegacyTaxcardType["Steps"] = "steps";
    LegacyTaxcardType["Others"] = "others";
})(LegacyTaxcardType = exports.LegacyTaxcardType || (exports.LegacyTaxcardType = {}));
var MessageType;
(function (MessageType) {
    MessageType["Text"] = "text";
    MessageType["BlobFile"] = "blobFile";
    MessageType["Calculation"] = "calculation";
    MessageType["Payroll"] = "payroll";
    MessageType["WorkerAccount"] = "workerAccount";
    MessageType["Email"] = "email";
    MessageType["Sms"] = "sms";
})(MessageType = exports.MessageType || (exports.MessageType = {}));
/** OnboardingStatus enumeration */
var OnboardingStatus;
(function (OnboardingStatus) {
    OnboardingStatus["Created"] = "created";
    OnboardingStatus["Open"] = "open";
    OnboardingStatus["Done"] = "done";
    OnboardingStatus["Expired"] = "expired";
})(OnboardingStatus = exports.OnboardingStatus || (exports.OnboardingStatus = {}));
/** PalkkausCampaignPricing enumeration */
var PalkkausCampaignPricing;
(function (PalkkausCampaignPricing) {
    PalkkausCampaignPricing["None"] = "none";
    PalkkausCampaignPricing["CampaignFirstUse"] = "campaignFirstUse";
    PalkkausCampaignPricing["CampaignAfterFirstUse"] = "campaignAfterFirstUse";
    PalkkausCampaignPricing["CompanyFreeTrial"] = "companyFreeTrial";
})(PalkkausCampaignPricing = exports.PalkkausCampaignPricing || (exports.PalkkausCampaignPricing = {}));
/** PartnerSite enumeration */
var PartnerSite;
(function (PartnerSite) {
    PartnerSite["Unknown"] = "unknown";
    PartnerSite["Palkkaus"] = "palkkaus";
    PartnerSite["PalkkausIdentified"] = "palkkausIdentified";
    PartnerSite["PalkkausEmployerFillIn"] = "palkkausEmployerFillIn";
    PartnerSite["Example"] = "example";
    PartnerSite["Dev"] = "dev";
    PartnerSite["RefugeeJobs"] = "refugeeJobs";
    PartnerSite["Talkkarit"] = "talkkarit";
    PartnerSite["Raksa"] = "raksa";
    PartnerSite["Palkkaapakolainen"] = "palkkaapakolainen";
    PartnerSite["CareDotCom"] = "careDotCom";
    PartnerSite["Duunitori"] = "duunitori";
    PartnerSite["Mol"] = "mol";
})(PartnerSite = exports.PartnerSite || (exports.PartnerSite = {}));
/** PaymentMethod enumeration */
var PaymentMethod;
(function (PaymentMethod) {
    PaymentMethod["Undefined"] = "undefined";
    PaymentMethod["Sepa"] = "sepa";
    PaymentMethod["Siirto"] = "siirto";
    PaymentMethod["Test"] = "test";
})(PaymentMethod = exports.PaymentMethod || (exports.PaymentMethod = {}));
/** PaymentStatus enumeration */
var PaymentStatus;
(function (PaymentStatus) {
    PaymentStatus["New"] = "new";
    PaymentStatus["SentToBank"] = "sentToBank";
    PaymentStatus["BankTechApproval"] = "bankTechApproval";
    PaymentStatus["BankDelivered"] = "bankDelivered";
    PaymentStatus["BankPartialError"] = "bankPartialError";
    PaymentStatus["BankError"] = "bankError";
    PaymentStatus["Paid"] = "paid";
    PaymentStatus["Unknown"] = "unknown";
    PaymentStatus["Cancelled"] = "cancelled";
})(PaymentStatus = exports.PaymentStatus || (exports.PaymentStatus = {}));
/** PayrollStatus enumeration */
var PayrollStatus;
(function (PayrollStatus) {
    PayrollStatus["Draft"] = "draft";
    PayrollStatus["PaymentStarted"] = "paymentStarted";
    PayrollStatus["PaymentSucceeded"] = "paymentSucceeded";
    PayrollStatus["PaymentCanceled"] = "paymentCanceled";
    PayrollStatus["PaymentError"] = "paymentError";
    PayrollStatus["Template"] = "template";
})(PayrollStatus = exports.PayrollStatus || (exports.PayrollStatus = {}));
/** PensionCalculation enumeration */
var PensionCalculation;
(function (PensionCalculation) {
    PensionCalculation["Undefined"] = "undefined";
    PensionCalculation["Employee"] = "employee";
    PensionCalculation["Entrepreneur"] = "entrepreneur";
    PensionCalculation["Farmer"] = "farmer";
    PensionCalculation["PartialOwner"] = "partialOwner";
    PensionCalculation["Athlete"] = "athlete";
    PensionCalculation["Compensation"] = "compensation";
    PensionCalculation["BoardRemuneration"] = "boardRemuneration";
    PensionCalculation["SmallEntrepreneur"] = "smallEntrepreneur";
    PensionCalculation["SmallFarmer"] = "smallFarmer";
})(PensionCalculation = exports.PensionCalculation || (exports.PensionCalculation = {}));
/** PensionCompany enumeration */
var PensionCompany;
(function (PensionCompany) {
    PensionCompany["None"] = "none";
    PensionCompany["Etera"] = "etera";
    PensionCompany["Ilmarinen"] = "ilmarinen";
    PensionCompany["Elo"] = "elo";
    PensionCompany["PensionsAlandia"] = "pensionsAlandia";
    PensionCompany["Varma"] = "varma";
    PensionCompany["Veritas"] = "veritas";
    PensionCompany["Apteekkien"] = "apteekkien";
    PensionCompany["Verso"] = "verso";
    PensionCompany["Other"] = "other";
})(PensionCompany = exports.PensionCompany || (exports.PensionCompany = {}));
/** PeriodType enumeration */
var PeriodType;
(function (PeriodType) {
    PeriodType["Month"] = "month";
    PeriodType["Quarter"] = "quarter";
    PeriodType["Year"] = "year";
    PeriodType["Custom"] = "custom";
})(PeriodType = exports.PeriodType || (exports.PeriodType = {}));
/** PricingModel enumeration */
var PricingModel;
(function (PricingModel) {
    PricingModel["PalkkausFee"] = "palkkausFee";
    PricingModel["NoFee"] = "noFee";
    PricingModel["FixedFee"] = "fixedFee";
})(PricingModel = exports.PricingModel || (exports.PricingModel = {}));
/** ProductListFilter enumeration */
var ProductListFilter;
(function (ProductListFilter) {
    ProductListFilter["Available"] = "available";
    ProductListFilter["All"] = "all";
})(ProductListFilter = exports.ProductListFilter || (exports.ProductListFilter = {}));
/** ReportCategory enumeration */
var ReportCategory;
(function (ReportCategory) {
    ReportCategory["All"] = "all";
    ReportCategory["Monthly"] = "monthly";
    ReportCategory["Yearly"] = "yearly";
})(ReportCategory = exports.ReportCategory || (exports.ReportCategory = {}));
/** ReportType enumeration */
var ReportType;
(function (ReportType) {
    ReportType["Undefined"] = "undefined";
    ReportType["Example"] = "example";
    ReportType["MonthlyDetails"] = "monthlyDetails";
    ReportType["TaxMonthly4001"] = "taxMonthly4001";
    ReportType["MonthlyPension"] = "monthlyPension";
    ReportType["MonthlyLiikekirjuri"] = "monthlyLiikekirjuri";
    ReportType["MonthlyRapko"] = "monthlyRapko";
    ReportType["MonthlyAccounting"] = "monthlyAccounting";
    ReportType["YearlyDetails"] = "yearlyDetails";
    ReportType["YearEndReport"] = "yearEndReport";
    ReportType["YearlyWorkerSummary"] = "yearlyWorkerSummary";
    ReportType["TaxYearly7801"] = "taxYearly7801";
    ReportType["Unemployment"] = "unemployment";
    ReportType["Insurance"] = "insurance";
    ReportType["HouseholdDeduction"] = "householdDeduction";
    ReportType["TaxHouseholdDeduction14B"] = "taxHouseholdDeduction14B";
    ReportType["TaxHouseholdDeduction14BSpouseA"] = "taxHouseholdDeduction14BSpouseA";
    ReportType["TaxHouseholdDeduction14BSpouseB"] = "taxHouseholdDeduction14BSpouseB";
    ReportType["SalarySlip"] = "salarySlip";
    ReportType["SalarySlipPaid"] = "salarySlipPaid";
    ReportType["SalarySlipCopy"] = "salarySlipCopy";
    ReportType["EmployerReport"] = "employerReport";
    ReportType["PaymentReport"] = "paymentReport";
    ReportType["EarningsPaymentReport"] = "earningsPaymentReport";
    ReportType["EmployersSeparateReport"] = "employersSeparateReport";
    ReportType["EmploymentContract"] = "employmentContract";
})(ReportType = exports.ReportType || (exports.ReportType = {}));
/** Role enumeration */
var Role;
(function (Role) {
    Role["Undefined"] = "undefined";
    Role["Accountant"] = "accountant";
    Role["TrustedPartner"] = "trustedPartner";
    Role["AccountantCandidate"] = "accountantCandidate";
    Role["PricingPartner"] = "pricingPartner";
})(Role = exports.Role || (exports.Role = {}));
/** SalaryKind enumeration */
var SalaryKind;
(function (SalaryKind) {
    SalaryKind["Undefined"] = "undefined";
    SalaryKind["FixedSalary"] = "fixedSalary";
    SalaryKind["HourlySalary"] = "hourlySalary";
    SalaryKind["MonthlySalary"] = "monthlySalary";
    SalaryKind["Compensation"] = "compensation";
    SalaryKind["TotalWorkerPayment"] = "totalWorkerPayment";
    SalaryKind["TotalEmployerPayment"] = "totalEmployerPayment";
})(SalaryKind = exports.SalaryKind || (exports.SalaryKind = {}));
/** SalaryType enumeration */
var SalaryType;
(function (SalaryType) {
    SalaryType["Tyel"] = "tyel";
    SalaryType["Yel"] = "yel";
    SalaryType["Compensation"] = "compensation";
})(SalaryType = exports.SalaryType || (exports.SalaryType = {}));
/** SalaryPeriod enumeration */
var SalaryPeriod;
(function (SalaryPeriod) {
    SalaryPeriod["NotDefined"] = "notDefined";
    SalaryPeriod["Hourly"] = "hourly";
    SalaryPeriod["Monthly"] = "monthly";
    SalaryPeriod["Fixed"] = "fixed";
})(SalaryPeriod = exports.SalaryPeriod || (exports.SalaryPeriod = {}));
/** SalaryPerMonthRange enumeration */
var SalaryPerMonthRange;
(function (SalaryPerMonthRange) {
    SalaryPerMonthRange["Unknown"] = "unknown";
    SalaryPerMonthRange["NoPensionRequired"] = "noPensionRequired";
    SalaryPerMonthRange["Normal"] = "normal";
})(SalaryPerMonthRange = exports.SalaryPerMonthRange || (exports.SalaryPerMonthRange = {}));
/** SalaryPerYearRange enumeration */
var SalaryPerYearRange;
(function (SalaryPerYearRange) {
    SalaryPerYearRange["ZeroSalary"] = "zeroSalary";
    SalaryPerYearRange["NoReportingNecessary"] = "noReportingNecessary";
    SalaryPerYearRange["NoMonthlyReporting"] = "noMonthlyReporting";
    SalaryPerYearRange["Normal"] = "normal";
})(SalaryPerYearRange = exports.SalaryPerYearRange || (exports.SalaryPerYearRange = {}));
/** ServiceModel enumeration */
var ServiceModel;
(function (ServiceModel) {
    ServiceModel["Shared"] = "shared";
    ServiceModel["PartnerOnly"] = "partnerOnly";
})(ServiceModel = exports.ServiceModel || (exports.ServiceModel = {}));
/** SharingLink enumeration */
var SharingLink;
(function (SharingLink) {
    SharingLink["NoSharing"] = "noSharing";
    SharingLink["Unguessable"] = "unguessable";
    SharingLink["Short"] = "short";
})(SharingLink = exports.SharingLink || (exports.SharingLink = {}));
/** TaxCardIncomeType enumeration */
var TaxCardIncomeType;
(function (TaxCardIncomeType) {
    TaxCardIncomeType["Unknown"] = "unknown";
    TaxCardIncomeType["SalaxyCalculation"] = "salaxyCalculation";
    TaxCardIncomeType["PreviousEmployerSalaries"] = "previousEmployerSalaries";
    TaxCardIncomeType["ExternalSalaries"] = "externalSalaries";
})(TaxCardIncomeType = exports.TaxCardIncomeType || (exports.TaxCardIncomeType = {}));
/** TaxcardState enumeration */
var TaxcardState;
(function (TaxcardState) {
    TaxcardState["New"] = "new";
    TaxcardState["Waiting"] = "waiting";
    TaxcardState["Approved"] = "approved";
    TaxcardState["Rejected"] = "rejected";
    TaxcardState["EmployerAdded"] = "employerAdded";
    TaxcardState["EmployerApproved"] = "employerApproved";
    TaxcardState["VerifiedVero"] = "verifiedVero";
    TaxcardState["Replaced"] = "replaced";
    TaxcardState["Expired"] = "expired";
})(TaxcardState = exports.TaxcardState || (exports.TaxcardState = {}));
/** TaxcardKind enumeration */
var TaxcardKind;
(function (TaxcardKind) {
    TaxcardKind["Undefined"] = "undefined";
    TaxcardKind["NoTaxCard"] = "noTaxCard";
    TaxcardKind["DefaultYearly"] = "defaultYearly";
    TaxcardKind["Replacement"] = "replacement";
    TaxcardKind["Others"] = "others";
    TaxcardKind["Historical"] = "historical";
})(TaxcardKind = exports.TaxcardKind || (exports.TaxcardKind = {}));
/** TaxDeductionWorkCategories enumeration */
var TaxDeductionWorkCategories;
(function (TaxDeductionWorkCategories) {
    TaxDeductionWorkCategories["None"] = "none";
    TaxDeductionWorkCategories["Householdwork"] = "householdwork";
    TaxDeductionWorkCategories["Carework"] = "carework";
    TaxDeductionWorkCategories["HomeImprovement"] = "homeImprovement";
    TaxDeductionWorkCategories["OwnPropety"] = "ownPropety";
    TaxDeductionWorkCategories["RelativesProperty"] = "relativesProperty";
})(TaxDeductionWorkCategories = exports.TaxDeductionWorkCategories || (exports.TaxDeductionWorkCategories = {}));
/** TaxReportHandling enumeration */
var TaxReportHandling;
(function (TaxReportHandling) {
    TaxReportHandling["Default"] = "default";
    TaxReportHandling["NoZeroSalaryReport"] = "noZeroSalaryReport";
    TaxReportHandling["NoMonthlyReport"] = "noMonthlyReport";
})(TaxReportHandling = exports.TaxReportHandling || (exports.TaxReportHandling = {}));
/** TesSubtype enumeration */
var TesSubtype;
(function (TesSubtype) {
    TesSubtype["NotSelected"] = "notSelected";
    TesSubtype["ConstructionCarpenter"] = "constructionCarpenter";
    TesSubtype["ConstructionFloor"] = "constructionFloor";
    TesSubtype["ConstructionOther"] = "constructionOther";
    TesSubtype["ConstructionFreeContract"] = "constructionFreeContract";
})(TesSubtype = exports.TesSubtype || (exports.TesSubtype = {}));
/** TestEnum enumeration */
var TestEnum;
(function (TestEnum) {
    TestEnum["ValueZero"] = "valueZero";
    TestEnum["ValueOne"] = "valueOne";
    TestEnum["ValueTwo"] = "valueTwo";
    TestEnum["ValueThree"] = "valueThree";
    TestEnum["ValueFour"] = "valueFour";
    TestEnum["ValueFive"] = "valueFive";
    TestEnum["ValueSix"] = "valueSix";
    TestEnum["ValueSeven"] = "valueSeven";
    TestEnum["ValueEight"] = "valueEight";
    TestEnum["ValueNine"] = "valueNine";
    TestEnum["ValueTen"] = "valueTen";
})(TestEnum = exports.TestEnum || (exports.TestEnum = {}));
/** UnionPaymentType enumeration */
var UnionPaymentType;
(function (UnionPaymentType) {
    UnionPaymentType["NotSelected"] = "notSelected";
    UnionPaymentType["RaksaNormal"] = "raksaNormal";
    UnionPaymentType["RaksaUnemploymentOnly"] = "raksaUnemploymentOnly";
    UnionPaymentType["Other"] = "other";
})(UnionPaymentType = exports.UnionPaymentType || (exports.UnionPaymentType = {}));
/** Unit enumeration */
var Unit;
(function (Unit) {
    Unit["Undefined"] = "undefined";
    Unit["Hours"] = "hours";
    Unit["Days"] = "days";
    Unit["Weeks"] = "weeks";
    Unit["Period"] = "period";
    Unit["One"] = "one";
    Unit["Count"] = "count";
    Unit["Percent"] = "percent";
    Unit["Kilometers"] = "kilometers";
    Unit["Euro"] = "euro";
})(Unit = exports.Unit || (exports.Unit = {}));
/** VarmaPensionOrderAction enumeration */
var VarmaPensionOrderAction;
(function (VarmaPensionOrderAction) {
    VarmaPensionOrderAction["Undefined"] = "undefined";
    VarmaPensionOrderAction["NewYel"] = "newYel";
    VarmaPensionOrderAction["NewTyel"] = "newTyel";
    VarmaPensionOrderAction["Move"] = "move";
})(VarmaPensionOrderAction = exports.VarmaPensionOrderAction || (exports.VarmaPensionOrderAction = {}));
/** VarmaPensionOrderYelPayer enumeration */
var VarmaPensionOrderYelPayer;
(function (VarmaPensionOrderYelPayer) {
    VarmaPensionOrderYelPayer["Undefined"] = "undefined";
    VarmaPensionOrderYelPayer["Entrepreneur"] = "entrepreneur";
    VarmaPensionOrderYelPayer["Company"] = "company";
})(VarmaPensionOrderYelPayer = exports.VarmaPensionOrderYelPayer || (exports.VarmaPensionOrderYelPayer = {}));
/** WageBasis enumeration */
var WageBasis;
(function (WageBasis) {
    WageBasis["Undefined"] = "undefined";
    WageBasis["Monthly"] = "monthly";
    WageBasis["Hourly"] = "hourly";
    WageBasis["PerformanceBased"] = "performanceBased";
    WageBasis["Other"] = "other";
})(WageBasis = exports.WageBasis || (exports.WageBasis = {}));
/** WebSiteUserRole enumeration */
var WebSiteUserRole;
(function (WebSiteUserRole) {
    WebSiteUserRole["None"] = "none";
    WebSiteUserRole["Household"] = "household";
    WebSiteUserRole["Worker"] = "worker";
    WebSiteUserRole["Company"] = "company";
})(WebSiteUserRole = exports.WebSiteUserRole || (exports.WebSiteUserRole = {}));
/** YearEndAdminCheck enumeration */
var YearEndAdminCheck;
(function (YearEndAdminCheck) {
    YearEndAdminCheck["NotChecked"] = "notChecked";
    YearEndAdminCheck["Ok"] = "ok";
    YearEndAdminCheck["OkWithWarning"] = "okWithWarning";
    YearEndAdminCheck["Errors"] = "errors";
})(YearEndAdminCheck = exports.YearEndAdminCheck || (exports.YearEndAdminCheck = {}));
/** YearEndFeedbackCalculationType enumeration */
var YearEndFeedbackCalculationType;
(function (YearEndFeedbackCalculationType) {
    YearEndFeedbackCalculationType["Unknown"] = "unknown";
    YearEndFeedbackCalculationType["SalaxyPayment"] = "salaxyPayment";
    YearEndFeedbackCalculationType["External"] = "external";
    YearEndFeedbackCalculationType["Correction"] = "correction";
})(YearEndFeedbackCalculationType = exports.YearEndFeedbackCalculationType || (exports.YearEndFeedbackCalculationType = {}));
/** YearEndUserFeedback enumeration */
var YearEndUserFeedback;
(function (YearEndUserFeedback) {
    YearEndUserFeedback["NotChecked"] = "notChecked";
    YearEndUserFeedback["Ok"] = "ok";
    YearEndUserFeedback["OkWithModifications"] = "okWithModifications";
    YearEndUserFeedback["WillHandleMyself"] = "willHandleMyself";
    YearEndUserFeedback["NoYearlyReports"] = "noYearlyReports";
})(YearEndUserFeedback = exports.YearEndUserFeedback || (exports.YearEndUserFeedback = {}));
/** YtjCompanyType enumeration */
var YtjCompanyType;
(function (YtjCompanyType) {
    YtjCompanyType["NoCompanyType"] = "noCompanyType";
    YtjCompanyType["HousingCooperative"] = "housingCooperative";
    YtjCompanyType["Condominium"] = "condominium";
    YtjCompanyType["AsoAssociation"] = "asoAssociation";
    YtjCompanyType["OpenCompany"] = "openCompany";
    YtjCompanyType["Association"] = "association";
    YtjCompanyType["HypoAssociation"] = "hypoAssociation";
    YtjCompanyType["Ky"] = "ky";
    YtjCompanyType["Osuuskunta"] = "osuuskunta";
    YtjCompanyType["CooperativeBank"] = "cooperativeBank";
    YtjCompanyType["Oy"] = "oy";
    YtjCompanyType["Foundation"] = "foundation";
    YtjCompanyType["SavingsBank"] = "savingsBank";
    YtjCompanyType["FinancialAssociation"] = "financialAssociation";
    YtjCompanyType["StateEstablishment"] = "stateEstablishment";
    YtjCompanyType["InsuranceAssociation"] = "insuranceAssociation";
    YtjCompanyType["PrivateEntrepreneur"] = "privateEntrepreneur";
    YtjCompanyType["OtherAssociation"] = "otherAssociation";
    YtjCompanyType["SpecialPurposeAssociation"] = "specialPurposeAssociation";
    YtjCompanyType["ForestCareAssociation"] = "forestCareAssociation";
    YtjCompanyType["OtherFinancialAssociation"] = "otherFinancialAssociation";
    YtjCompanyType["TaxableGrouping"] = "taxableGrouping";
    YtjCompanyType["MutualInsuranceAssociation"] = "mutualInsuranceAssociation";
    YtjCompanyType["MunicipalEstablishment"] = "municipalEstablishment";
    YtjCompanyType["FederationOfMunicipalitiesEstablishment"] = "federationOfMunicipalitiesEstablishment";
    YtjCompanyType["AlandFederation"] = "alandFederation";
    YtjCompanyType["EuropeanCooperative"] = "europeanCooperative";
    YtjCompanyType["EuropeanCooperativeBank"] = "europeanCooperativeBank";
    YtjCompanyType["ReindeerHerdingCooperative"] = "reindeerHerdingCooperative";
    YtjCompanyType["Unknown"] = "unknown";
})(YtjCompanyType = exports.YtjCompanyType || (exports.YtjCompanyType = {}));
/** CarBenefitKind enumeration */
var CarBenefitKind;
(function (CarBenefitKind) {
    CarBenefitKind["Undefined"] = "undefined";
    CarBenefitKind["LimitedCarBenefit"] = "limitedCarBenefit";
    CarBenefitKind["FullCarBenefit"] = "fullCarBenefit";
})(CarBenefitKind = exports.CarBenefitKind || (exports.CarBenefitKind = {}));
/** UnionPaymentKind enumeration */
var UnionPaymentKind;
(function (UnionPaymentKind) {
    UnionPaymentKind["Undefined"] = "undefined";
    UnionPaymentKind["RaksaNormal"] = "raksaNormal";
    UnionPaymentKind["RaksaUnemploymentOnly"] = "raksaUnemploymentOnly";
    UnionPaymentKind["Other"] = "other";
})(UnionPaymentKind = exports.UnionPaymentKind || (exports.UnionPaymentKind = {}));
/** NonProfitOrgKind enumeration */
var NonProfitOrgKind;
(function (NonProfitOrgKind) {
    NonProfitOrgKind["Undefined"] = "undefined";
    NonProfitOrgKind["KilometreAllowance"] = "kilometreAllowance";
    NonProfitOrgKind["DailyAllowance"] = "dailyAllowance";
    NonProfitOrgKind["AccomodationAllowance"] = "accomodationAllowance";
})(NonProfitOrgKind = exports.NonProfitOrgKind || (exports.NonProfitOrgKind = {}));
/** SubsidisedCommuteKind enumeration */
var SubsidisedCommuteKind;
(function (SubsidisedCommuteKind) {
    SubsidisedCommuteKind["Undefined"] = "undefined";
    SubsidisedCommuteKind["NoDeduction"] = "noDeduction";
    SubsidisedCommuteKind["SingleDeduction"] = "singleDeduction";
    SubsidisedCommuteKind["PeriodicalDeduction"] = "periodicalDeduction";
})(SubsidisedCommuteKind = exports.SubsidisedCommuteKind || (exports.SubsidisedCommuteKind = {}));
/** MealBenefitKind enumeration */
var MealBenefitKind;
(function (MealBenefitKind) {
    MealBenefitKind["Undefined"] = "undefined";
    MealBenefitKind["CateringContract"] = "cateringContract";
    MealBenefitKind["MealTicket"] = "mealTicket";
    MealBenefitKind["TaxableAmount"] = "taxableAmount";
    MealBenefitKind["MealAllowance"] = "mealAllowance";
    MealBenefitKind["Institute"] = "institute";
    MealBenefitKind["Teacher"] = "teacher";
    MealBenefitKind["RestaurantWorker"] = "restaurantWorker";
})(MealBenefitKind = exports.MealBenefitKind || (exports.MealBenefitKind = {}));
/** DailyAllowanceKind enumeration */
var DailyAllowanceKind;
(function (DailyAllowanceKind) {
    DailyAllowanceKind["Undefined"] = "undefined";
    DailyAllowanceKind["FullDailyAllowance"] = "fullDailyAllowance";
    DailyAllowanceKind["PartialDailyAllowance"] = "partialDailyAllowance";
    DailyAllowanceKind["InternationalDailyAllowance"] = "internationalDailyAllowance";
    DailyAllowanceKind["MealAllowance"] = "mealAllowance";
})(DailyAllowanceKind = exports.DailyAllowanceKind || (exports.DailyAllowanceKind = {}));
/** IrIncomeTypeKind enumeration */
var IrIncomeTypeKind;
(function (IrIncomeTypeKind) {
    IrIncomeTypeKind["Undefined"] = "undefined";
})(IrIncomeTypeKind = exports.IrIncomeTypeKind || (exports.IrIncomeTypeKind = {}));
/** BoardKind enumeration */
var BoardKind;
(function (BoardKind) {
    BoardKind["Undefined"] = "undefined";
})(BoardKind = exports.BoardKind || (exports.BoardKind = {}));
/** RemunerationKind enumeration */
var RemunerationKind;
(function (RemunerationKind) {
    RemunerationKind["Undefined"] = "undefined";
    RemunerationKind["InitiativeFee"] = "initiativeFee";
    RemunerationKind["BonusPay"] = "bonusPay";
    RemunerationKind["Commission"] = "commission";
    RemunerationKind["PerformanceBonus"] = "performanceBonus";
    RemunerationKind["ShareIssueForEmployees"] = "shareIssueForEmployees";
    RemunerationKind["ProfitSharingBonus"] = "profitSharingBonus";
})(RemunerationKind = exports.RemunerationKind || (exports.RemunerationKind = {}));
/** OtherCompensationKind enumeration */
var OtherCompensationKind;
(function (OtherCompensationKind) {
    OtherCompensationKind["Undefined"] = "undefined";
    OtherCompensationKind["MeetingFee"] = "meetingFee";
    OtherCompensationKind["LectureFee"] = "lectureFee";
    OtherCompensationKind["PositionOfTrustCompensation"] = "positionOfTrustCompensation";
    OtherCompensationKind["AccruedTimeOffCompensation"] = "accruedTimeOffCompensation";
    OtherCompensationKind["MembershipOfGoverningBodyCompensation"] = "membershipOfGoverningBodyCompensation";
    OtherCompensationKind["MonetaryGiftForEmployees"] = "monetaryGiftForEmployees";
    OtherCompensationKind["UseCompensationAsEarnedIncome"] = "useCompensationAsEarnedIncome";
    OtherCompensationKind["UseCompensationAsCapitalIncome"] = "useCompensationAsCapitalIncome";
    OtherCompensationKind["OtherTaxableIncomeAsEarnedIncome"] = "otherTaxableIncomeAsEarnedIncome";
    OtherCompensationKind["StockOptionsAndGrants"] = "stockOptionsAndGrants";
    OtherCompensationKind["EmployeeInventionCompensation"] = "employeeInventionCompensation";
    OtherCompensationKind["CapitalIncomePayment"] = "capitalIncomePayment";
    OtherCompensationKind["WorkEffortBasedDividendsAsWage"] = "workEffortBasedDividendsAsWage";
    OtherCompensationKind["WorkEffortBasedDividendsAsNonWage"] = "workEffortBasedDividendsAsNonWage";
    OtherCompensationKind["EmployeeStockOption"] = "employeeStockOption";
    OtherCompensationKind["EmployeeStockOptionWithLowerPrice"] = "employeeStockOptionWithLowerPrice";
})(OtherCompensationKind = exports.OtherCompensationKind || (exports.OtherCompensationKind = {}));
/** WorkingTimeCompensationKind enumeration */
var WorkingTimeCompensationKind;
(function (WorkingTimeCompensationKind) {
    WorkingTimeCompensationKind["Undefined"] = "undefined";
    WorkingTimeCompensationKind["EmergencyWorkCompensation"] = "emergencyWorkCompensation";
    WorkingTimeCompensationKind["EveningWorkCompensation"] = "eveningWorkCompensation";
    WorkingTimeCompensationKind["EveningShiftAllowance"] = "eveningShiftAllowance";
    WorkingTimeCompensationKind["SaturdayPay"] = "saturdayPay";
    WorkingTimeCompensationKind["ExtraWorkPremium"] = "extraWorkPremium";
    WorkingTimeCompensationKind["OtherCompensation"] = "otherCompensation";
    WorkingTimeCompensationKind["WaitingTimeCompensation"] = "waitingTimeCompensation";
    WorkingTimeCompensationKind["SundayWorkCompensation"] = "sundayWorkCompensation";
    WorkingTimeCompensationKind["StandByCompensation"] = "standByCompensation";
    WorkingTimeCompensationKind["WeeklyRestCompensation"] = "weeklyRestCompensation";
    WorkingTimeCompensationKind["OvertimeCompensation"] = "overtimeCompensation";
    WorkingTimeCompensationKind["NightWorkAllowance"] = "nightWorkAllowance";
    WorkingTimeCompensationKind["NightShiftCompensation"] = "nightShiftCompensation";
})(WorkingTimeCompensationKind = exports.WorkingTimeCompensationKind || (exports.WorkingTimeCompensationKind = {}));
/** EmploymentTerminationKind enumeration */
var EmploymentTerminationKind;
(function (EmploymentTerminationKind) {
    EmploymentTerminationKind["Undefined"] = "undefined";
    EmploymentTerminationKind["NoticePeriodCompensation"] = "noticePeriodCompensation";
    EmploymentTerminationKind["MonetaryWorkingTimeBankCompensation"] = "monetaryWorkingTimeBankCompensation";
    EmploymentTerminationKind["TerminationAndLayOffDamages"] = "terminationAndLayOffDamages";
    EmploymentTerminationKind["VoluntaryTerminationCompensation"] = "voluntaryTerminationCompensation";
    EmploymentTerminationKind["PensionPaidByEmployer"] = "pensionPaidByEmployer";
})(EmploymentTerminationKind = exports.EmploymentTerminationKind || (exports.EmploymentTerminationKind = {}));
var Filter;
(function (Filter) {
    Filter["Undefined"] = "undefined";
    Filter["DoNotShow"] = "doNotShow";
    Filter["Employment"] = "employment";
    Filter["Insurance"] = "insurance";
    Filter["Salary"] = "salary";
    Filter["Examples"] = "examples";
    Filter["PalkkausGeneral"] = "palkkausGeneral";
    Filter["PalkkausInstructions"] = "palkkausInstructions";
    Filter["Blog"] = "blog";
    Filter["Press"] = "press";
    Filter["PersonEmployer"] = "personEmployer";
    Filter["HouseholdEmployer"] = "householdEmployer";
    Filter["Worker"] = "worker";
    Filter["Employee"] = "employee";
    Filter["Entrepreneur"] = "entrepreneur";
    Filter["Association"] = "association";
    Filter["BusinessOwner"] = "businessOwner";
    Filter["ProductLongDescription"] = "productLongDescription";
    Filter["DocumentTemplates"] = "documentTemplates";
    Filter["InstructionsAndExamples"] = "instructionsAndExamples";
})(Filter = exports.Filter || (exports.Filter = {}));
/** Status filter for the query. */
var Status;
(function (Status) {
    Status["Unread"] = "unread";
    Status["Read"] = "read";
    Status["PaymentStarted"] = "paymentStarted";
    Status["Paid"] = "paid";
    Status["Canceled"] = "canceled";
})(Status = exports.Status || (exports.Status = {}));
/** The party for which the messages are marked as read. */
var ReadBy;
(function (ReadBy) {
    ReadBy["Undefined"] = "undefined";
    ReadBy["Owner"] = "owner";
    ReadBy["OtherParty"] = "otherParty";
    ReadBy["System"] = "system";
})(ReadBy = exports.ReadBy || (exports.ReadBy = {}));
var PaymentTypes;
(function (PaymentTypes) {
    PaymentTypes["Unknown"] = "unknown";
    PaymentTypes["Error"] = "error";
    PaymentTypes["PaytrailBatch"] = "paytrailBatch";
    PaymentTypes["NetvisorPayment"] = "netvisorPayment";
    PaymentTypes["SalaryGrossPayment"] = "salaryGrossPayment";
    PaymentTypes["RefundPayment"] = "refundPayment";
    PaymentTypes["PartialRefundPayment"] = "partialRefundPayment";
    PaymentTypes["InsuranceGrossPayment"] = "insuranceGrossPayment";
    PaymentTypes["NetSalary"] = "netSalary";
    PaymentTypes["SalaryAdvance"] = "salaryAdvance";
    PaymentTypes["TaxAccount"] = "taxAccount";
    PaymentTypes["Tvr"] = "tvr";
    PaymentTypes["TvrRfnd"] = "tvrRfnd";
    PaymentTypes["PalkkausFees"] = "palkkausFees";
    PaymentTypes["BankFees"] = "bankFees";
    PaymentTypes["PaytrailFees"] = "paytrailFees";
    PaymentTypes["InsuranceLahiTapiola"] = "insuranceLahiTapiola";
    PaymentTypes["Tyel"] = "tyel";
    PaymentTypes["TyelEteraContract"] = "tyelEteraContract";
    PaymentTypes["TyelEteraTemp"] = "tyelEteraTemp";
    PaymentTypes["TyelEteraUnknown"] = "tyelEteraUnknown";
    PaymentTypes["TyelEloContract"] = "tyelEloContract";
    PaymentTypes["TyelEloTemp"] = "tyelEloTemp";
    PaymentTypes["TyelEloInitialImport"] = "tyelEloInitialImport";
    PaymentTypes["TyelVarmaContract"] = "tyelVarmaContract";
    PaymentTypes["TyelVarmaTemp"] = "tyelVarmaTemp";
    PaymentTypes["TyelIlmarinenContract"] = "tyelIlmarinenContract";
    PaymentTypes["TyelIlmarinenTemp"] = "tyelIlmarinenTemp";
    PaymentTypes["Union"] = "union";
    PaymentTypes["UnionRaksa"] = "unionRaksa";
    PaymentTypes["Foreclosure"] = "foreclosure";
    PaymentTypes["SaldoYearBegin"] = "saldoYearBegin";
    PaymentTypes["SaldoYearEnd"] = "saldoYearEnd";
})(PaymentTypes = exports.PaymentTypes || (exports.PaymentTypes = {}));
/** Minimum status level for the calculations: draft-paymentStarted-paymentSucceeded. The default level is paymentSucceeded. */
var MinStatus;
(function (MinStatus) {
    MinStatus["Draft"] = "draft";
    MinStatus["PaymentStarted"] = "paymentStarted";
    MinStatus["PaymentSucceeded"] = "paymentSucceeded";
    MinStatus["PaymentCanceled"] = "paymentCanceled";
    MinStatus["PaymentError"] = "paymentError";
    MinStatus["PaymentWorkerCopy"] = "paymentWorkerCopy";
    MinStatus["WorkerRequested"] = "workerRequested";
    MinStatus["WorkerRequestAccepted"] = "workerRequestAccepted";
    MinStatus["WorkerRequestDeclined"] = "workerRequestDeclined";
    MinStatus["PaymentRefunded"] = "paymentRefunded";
    MinStatus["PayrollDraft"] = "payrollDraft";
    MinStatus["ProDraft"] = "proDraft";
    MinStatus["Template"] = "template";
})(MinStatus = exports.MinStatus || (exports.MinStatus = {}));
var Flags;
(function (Flags) {
    Flags["NoMoney"] = "noMoney";
    Flags["OneOff"] = "oneOff";
    Flags["UnjustEnrichment"] = "unjustEnrichment";
})(Flags = exports.Flags || (exports.Flags = {}));
var InsuranceExceptions;
(function (InsuranceExceptions) {
    InsuranceExceptions["IncludeAll"] = "includeAll";
    InsuranceExceptions["IncludePension"] = "includePension";
    InsuranceExceptions["IncludeHealthInsurance"] = "includeHealthInsurance";
    InsuranceExceptions["IncludeUnemployment"] = "includeUnemployment";
    InsuranceExceptions["IncludeAccidentInsurance"] = "includeAccidentInsurance";
    InsuranceExceptions["ExcludeAll"] = "excludeAll";
    InsuranceExceptions["ExcludePension"] = "excludePension";
    InsuranceExceptions["ExcludeHealthInsurance"] = "excludeHealthInsurance";
    InsuranceExceptions["ExcludeUnemployment"] = "excludeUnemployment";
    InsuranceExceptions["ExcludeAccidentInsurance"] = "excludeAccidentInsurance";
})(InsuranceExceptions = exports.InsuranceExceptions || (exports.InsuranceExceptions = {}));
var DailyAllowance;
(function (DailyAllowance) {
    DailyAllowance["MealAllowance"] = "mealAllowance";
    DailyAllowance["PartialDailyAllowance"] = "partialDailyAllowance";
    DailyAllowance["FullDailyAllowance"] = "fullDailyAllowance";
    DailyAllowance["InternationalDailyAllowance"] = "internationalDailyAllowance";
    DailyAllowance["TaxExemptReimbursementsAbroad"] = "taxExemptReimbursementsAbroad";
})(DailyAllowance = exports.DailyAllowance || (exports.DailyAllowance = {}));
var WorkflowEventUi;
(function (WorkflowEventUi) {
    WorkflowEventUi["Default"] = "default";
    WorkflowEventUi["Primary"] = "primary";
    WorkflowEventUi["Success"] = "success";
    WorkflowEventUi["Info"] = "info";
    WorkflowEventUi["Warning"] = "warning";
    WorkflowEventUi["Danger"] = "danger";
})(WorkflowEventUi = exports.WorkflowEventUi || (exports.WorkflowEventUi = {}));
var Features;
(function (Features) {
    Features["None"] = "none";
    Features["IsActive"] = "isActive";
    Features["IsEditable"] = "isEditable";
    Features["IsRemovable"] = "isRemovable";
    Features["IsOnHold"] = "isOnHold";
})(Features = exports.Features || (exports.Features = {}));
var ICalculationDataStatus;
(function (ICalculationDataStatus) {
    ICalculationDataStatus["Draft"] = "draft";
    ICalculationDataStatus["PaymentStarted"] = "paymentStarted";
    ICalculationDataStatus["PaymentSucceeded"] = "paymentSucceeded";
    ICalculationDataStatus["PaymentCanceled"] = "paymentCanceled";
    ICalculationDataStatus["PaymentError"] = "paymentError";
    ICalculationDataStatus["PaymentWorkerCopy"] = "paymentWorkerCopy";
    ICalculationDataStatus["WorkerRequested"] = "workerRequested";
    ICalculationDataStatus["WorkerRequestAccepted"] = "workerRequestAccepted";
    ICalculationDataStatus["WorkerRequestDeclined"] = "workerRequestDeclined";
    ICalculationDataStatus["PaymentRefunded"] = "paymentRefunded";
    ICalculationDataStatus["PayrollDraft"] = "payrollDraft";
    ICalculationDataStatus["ProDraft"] = "proDraft";
    ICalculationDataStatus["Template"] = "template";
})(ICalculationDataStatus = exports.ICalculationDataStatus || (exports.ICalculationDataStatus = {}));
var EmploymentRelationInfoStatus;
(function (EmploymentRelationInfoStatus) {
    EmploymentRelationInfoStatus["Unknown"] = "unknown";
    EmploymentRelationInfoStatus["Primary"] = "primary";
    EmploymentRelationInfoStatus["SecondaryCurrent"] = "secondaryCurrent";
    EmploymentRelationInfoStatus["Archived"] = "archived";
})(EmploymentRelationInfoStatus = exports.EmploymentRelationInfoStatus || (exports.EmploymentRelationInfoStatus = {}));
var InvoiceHeaderStatus;
(function (InvoiceHeaderStatus) {
    InvoiceHeaderStatus["Unread"] = "unread";
    InvoiceHeaderStatus["Read"] = "read";
    InvoiceHeaderStatus["PaymentStarted"] = "paymentStarted";
    InvoiceHeaderStatus["Paid"] = "paid";
    InvoiceHeaderStatus["Canceled"] = "canceled";
})(InvoiceHeaderStatus = exports.InvoiceHeaderStatus || (exports.InvoiceHeaderStatus = {}));
var InvoiceStatusNotificationStatus;
(function (InvoiceStatusNotificationStatus) {
    InvoiceStatusNotificationStatus["Unread"] = "unread";
    InvoiceStatusNotificationStatus["Read"] = "read";
    InvoiceStatusNotificationStatus["PaymentStarted"] = "paymentStarted";
    InvoiceStatusNotificationStatus["Paid"] = "paid";
    InvoiceStatusNotificationStatus["Canceled"] = "canceled";
})(InvoiceStatusNotificationStatus = exports.InvoiceStatusNotificationStatus || (exports.InvoiceStatusNotificationStatus = {}));
var MessageFromParty;
(function (MessageFromParty) {
    MessageFromParty["Undefined"] = "undefined";
    MessageFromParty["Owner"] = "owner";
    MessageFromParty["OtherParty"] = "otherParty";
    MessageFromParty["System"] = "system";
})(MessageFromParty = exports.MessageFromParty || (exports.MessageFromParty = {}));
var ITaxcardDataKind;
(function (ITaxcardDataKind) {
    ITaxcardDataKind["Undefined"] = "undefined";
    ITaxcardDataKind["NoTaxCard"] = "noTaxCard";
    ITaxcardDataKind["DefaultYearly"] = "defaultYearly";
    ITaxcardDataKind["Replacement"] = "replacement";
    ITaxcardDataKind["Others"] = "others";
    ITaxcardDataKind["Historical"] = "historical";
})(ITaxcardDataKind = exports.ITaxcardDataKind || (exports.ITaxcardDataKind = {}));
var TestValuesEnumValue;
(function (TestValuesEnumValue) {
    TestValuesEnumValue["ValueZero"] = "valueZero";
    TestValuesEnumValue["ValueOne"] = "valueOne";
    TestValuesEnumValue["ValueTwo"] = "valueTwo";
    TestValuesEnumValue["ValueThree"] = "valueThree";
    TestValuesEnumValue["ValueFour"] = "valueFour";
    TestValuesEnumValue["ValueFive"] = "valueFive";
    TestValuesEnumValue["ValueSix"] = "valueSix";
    TestValuesEnumValue["ValueSeven"] = "valueSeven";
    TestValuesEnumValue["ValueEight"] = "valueEight";
    TestValuesEnumValue["ValueNine"] = "valueNine";
    TestValuesEnumValue["ValueTen"] = "valueTen";
})(TestValuesEnumValue = exports.TestValuesEnumValue || (exports.TestValuesEnumValue = {}));
var IWorkerDataType;
(function (IWorkerDataType) {
    IWorkerDataType["Undefined"] = "undefined";
    IWorkerDataType["Salary"] = "salary";
    IWorkerDataType["HourlySalary"] = "hourlySalary";
    IWorkerDataType["MonthlySalary"] = "monthlySalary";
    IWorkerDataType["Compensation"] = "compensation";
    IWorkerDataType["BoardMember"] = "boardMember";
    IWorkerDataType["Entrepreneur"] = "entrepreneur";
    IWorkerDataType["Farmer"] = "farmer";
    IWorkerDataType["EmployedByStateEmploymentFund"] = "employedByStateEmploymentFund";
    IWorkerDataType["KeyEmployee"] = "keyEmployee";
    IWorkerDataType["Athlete"] = "athlete";
    IWorkerDataType["PerformingArtist"] = "performingArtist";
})(IWorkerDataType = exports.IWorkerDataType || (exports.IWorkerDataType = {}));
var IWorkerDataPensionCalculation;
(function (IWorkerDataPensionCalculation) {
    IWorkerDataPensionCalculation["Undefined"] = "undefined";
    IWorkerDataPensionCalculation["Employee"] = "employee";
    IWorkerDataPensionCalculation["Entrepreneur"] = "entrepreneur";
    IWorkerDataPensionCalculation["Farmer"] = "farmer";
    IWorkerDataPensionCalculation["PartialOwner"] = "partialOwner";
    IWorkerDataPensionCalculation["Athlete"] = "athlete";
    IWorkerDataPensionCalculation["Compensation"] = "compensation";
    IWorkerDataPensionCalculation["BoardRemuneration"] = "boardRemuneration";
    IWorkerDataPensionCalculation["SmallEntrepreneur"] = "smallEntrepreneur";
    IWorkerDataPensionCalculation["SmallFarmer"] = "smallFarmer";
})(IWorkerDataPensionCalculation = exports.IWorkerDataPensionCalculation || (exports.IWorkerDataPensionCalculation = {}));

},{}],77:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Helpers for handling arrays.
 */
var Arrays = /** @class */ (function () {
    function Arrays() {
    }
    /**
     * Takes in an array or string or null and always returns an array.
     * If the incoming value is a string, splits it by commas. This is especaially useful for HTML attributes.
     * Note that null (or other falsy objects) are returned as an empty array.
     *
     * @param arrayCandidate - A string array or string that is split by comma.
     */
    Arrays.assureArray = function (arrayCandidate) {
        if (!arrayCandidate) {
            return [];
        }
        if (Array.isArray(arrayCandidate)) {
            return arrayCandidate;
        }
        return arrayCandidate.split(",");
    };
    /**
     * Calculates a sum of array items.
     * Null items will be added as zero.
     * @param array Array to sum
     * @param selector Selector for a number to sum.
     */
    Arrays.sum = function (array, selector) {
        return array.reduce(function (prev, current, ix) { return current ? (prev + (selector(current) || 0)) : 0; }, 0);
    };
    /**
     * Sequence generator function gets an array between two numbers (inclusive).
     * (commonly referred to as "range", e.g. Clojure, PHP etc)
     * @param start Start number of the sequence
     * @param stop End number of the sequence
     * @param step Step between the numbers, default is 1.
     * @example
     * Arrays.getRange(2019, 2023);
     * // [2019, 2020, 2021, 2022, 2023]
     */
    Arrays.getRange = function (start, stop, step) {
        if (step === void 0) { step = 1; }
        var range = function (start, stop, step) { return Array.from({ length: (stop - start) / step + 1 }, function (_, i) { return start + (i * step); }); };
        return range(start, stop, step);
    };
    return Arrays;
}());
exports.Arrays = Arrays;

},{}],78:[function(require,module,exports){
(function (global){
Object.defineProperty(exports, "__esModule", { value: true });
var momentImport = (typeof window !== "undefined" ? window['moment'] : typeof global !== "undefined" ? global['moment'] : null);
/** moment variable */
var moment = momentImport;
/**
 * Helpers for generating barcode values.
 * Using format Code 128 (Uniform Symbology Specification)
 * with Modulo 103 algorithm for generating checksum.
 *
 * @see http://www.finanssiala.fi/maksujenvalitys/dokumentit/Bank_bar_code_guide.pdf
 * @see http://www.finanssiala.fi/maksujenvalitys/dokumentit/Pankkiviivakoodi-opas.pdf
 */
var Barcodes = /** @class */ (function () {
    function Barcodes() {
    }
    /**
     * Creates a value for barcode labels. Does not calculate the checksum by default.
     * Most libraries, which generate barcode labels, add the checksum and start and stop sequences automatically,
     * and those are not needed to be calculated externally.
     *
     * @param iban - IBAN bank account number. Must be a Finnish IBAN. Can have whitespace.
     * @param ref - Reference number as a string. Either fully numeric (max len 20), or starting with RF (max len 2+23).
     *        Can have whitespace.
     * @param dueDate - Date as string in DD.MM.YYYY format. False fills values with zeros.
     * @param euroAmount - Euro amount. If string, e.g. 3030,33€, is converted to cents amount 303033.
     *        Alternative can be passed cents amount as number.
     * @param includeChecksum - Calculates and appends the checksum to the end of the barcode value.
     *
     * @return The barcode value (without start and end characters). The checksum is only calculated and appended to the value if the includeChecksum-parameter is true.
     */
    Barcodes.getValue = function (iban, ref, dueDate, euroAmount, includeChecksum) {
        // --- Sanitize params
        if (includeChecksum === void 0) { includeChecksum = false; }
        // Remove white space from IBAN and ref
        iban = iban.replace(/\s/g, "");
        ref = ref.replace(/\s/g, "");
        // Format date to YYMMDD
        if (dueDate) {
            dueDate = moment(dueDate, "DD.MM.YYYY").format("YYMMDD");
        }
        // Format amount
        var amountInCents = (typeof euroAmount === "string") ? euroAmount.replace(/[, ]+/g, "") : euroAmount.toString();
        // --- Build value string
        var bcVal = "";
        // #1 segment: 1 char for version number - if refNo starts with "RF" => 5, else => 4
        var versionNo = ref.substring(0, 2).toUpperCase() === "RF" ? "5" : "4";
        bcVal += versionNo;
        // #2 segment: 16 chars for IBAN numeric part
        bcVal += iban.substr(2);
        // #3 segment: 6 chars euro amount without cents
        var euros = amountInCents.slice(0, -2);
        while (euros.length < 6) {
            euros = "0" + euros;
        }
        bcVal += euros;
        // #4 segment: 2 chars cents amount
        var cents = amountInCents.slice(-2);
        bcVal += (cents.length === 1) ? "0" + cents : cents;
        // #5 segment, when version 4: 3 zeros followed by 20 char national ref no
        if (versionNo === "4") {
            bcVal += "000";
            var refNo = ref.substr(0); // Copy value
            while (refNo.length < 20) {
                refNo = "0" + refNo;
            }
            bcVal += refNo;
            // #5 segment, when version 5: 23 chars RF ref no's numeric part (RF04 9991 -> 04000000000000000009991)
        }
        else {
            bcVal += ref.substr(2, 2);
            var refNo = ref.substr(4);
            while (refNo.length < 21) {
                refNo = "0" + refNo;
            }
            bcVal += refNo;
        }
        // #6 segment: 6 chars due date in YYMMDD format. If false, fill with zeros.
        bcVal += (dueDate) ? dueDate : "000000";
        if (includeChecksum) {
            // #7 segment: 2 chars Modulo 103 checksum
            var modulo = this.modulo103(bcVal).toString();
            modulo = modulo.length === 1 ? "0" + modulo : modulo;
            bcVal += modulo;
        }
        return bcVal;
    };
    /**
     * Takes in 54 characters string value and calculates modulo 103 value.
     *
     * @param val - 54 characters long string of numbers
     *
     * @return A Number within range of 0-99. Reminder of dividing the sum total of weighted value pairs with 103.
     */
    Barcodes.modulo103 = function (val) {
        var pairs = val.match(/(..?)/g); // https://stackoverflow.com/questions/17286535/split-a-string-to-array-containing-pairs-of-two
        var total = 105;
        for (var i = 1; i <= 27; i++) {
            var num = Number(pairs[i - 1]);
            total += num * i;
        }
        return total % 103;
    };
    return Barcodes;
}());
exports.Barcodes = Barcodes;

}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})
},{}],79:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Utility for accessing brand specific style definitions.
 */
var Brand = /** @class */ (function () {
    function Brand() {
    }
    /**
     * Returns the brand color defined as a global variable.
     *
     * @param color - Named brand color to get.
     * @param format - Color format: hex like '#289548', rgb like 'rgb(40, 149, 72)' or rgba like 'rgba(40, 149, 72, 1.0'. Default value is hex.
     */
    Brand.getBrandColor = function (color, format) {
        if (format === void 0) { format = "hex"; }
        var value = Brand.getStylePropertyValue("--salaxy-brand-" + color);
        if (!value) {
            switch (color) {
                case "primary":
                    value = "#009fd8";
                    break;
                case "success":
                    value = "#289548";
                    break;
                case "info":
                    value = "#91d214";
                    break;
                case "warning":
                    value = "#ff911e";
                    break;
                case "danger":
                    value = "#d55552";
                    break;
            }
        }
        switch (format) {
            case "rgb":
                return Brand.hex2rgb(value);
            case "rgba":
                return Brand.hex2rgba(value);
            case "hex":
            default:
                return value;
        }
    };
    /**
     * Returns the css global style variable.
     * E.g. --salaxy-brand-primary
     * @param variableName - Variable name.
     */
    Brand.getStylePropertyValue = function (variableName) {
        var style = getComputedStyle(document.body);
        if (!style) {
            return null;
        }
        var value = style.getPropertyValue(variableName);
        if (!value) {
            return null;
        }
        value = value.trim();
        return value;
    };
    /**
     * Returns the hex color value as rgb css function.
     * For example:  value '#289548' as 'rgba(40, 149, 72)'
     *
     * @param hexValue - Hex value.
     */
    Brand.hex2rgb = function (hexValue) {
        var values = this.hex2rgbaValues(hexValue);
        if (!values) {
            return null;
        }
        return "rgb(" + values[0] + ", " + values[1] + ", " + values[2] + ")";
    };
    /**
     * Returns the hex color value as rgba css function.
     * For example:  value '#289548ff' as 'rgba(40, 149, 72, 1)'
     *
     * @param hexValue - Hex value.
     */
    Brand.hex2rgba = function (hexValue) {
        var values = this.hex2rgbaValues(hexValue);
        if (!values) {
            return null;
        }
        return "rgba(" + values[0] + ", " + values[1] + ", " + values[2] + ", " + values[3].toFixed(2) + ")";
    };
    /**
     * Returns the rgb value as hex string.
     * For example: 40, 149, 72 as #289548.
     *
     * @param r - red parameter.
     * @param g - green parameter.
     * @param b - blue parameter.
     */
    Brand.rgb2hex = function (r, g, b) {
        // tslint:disable-next-line
        return "#" + ((b | g << 8 | r << 16) | 1 << 24).toString(16).substring(1);
    };
    /**
     * Returns the rgba value as hex string.
     * For example: 40, 149, 72, 1 as #289548ff.
     *
     * @param r - red parameter.
     * @param g - green parameter.
     * @param b - blue parameter.
     * @param a - alpha parameter.
     */
    Brand.rgba2hex = function (r, g, b, a) {
        // tslint:disable-next-line
        var hexA = (Math.round(255 * a) | 1 << 8).toString(16).substring(1);
        return Brand.rgb2hex(r, g, b) + hexA;
    };
    Brand.hex2rgbaValues = function (hexValue) {
        if (!hexValue) {
            return null;
        }
        hexValue = hexValue.trim().toLowerCase();
        if (hexValue.length === 0) {
            return;
        }
        if (hexValue.charAt(0) === "#") {
            // remove #
            hexValue = hexValue.substring(1);
        }
        if (hexValue.length === 3) {
            // add alpha
            hexValue += "f";
        }
        if (hexValue.length === 4) {
            // convert to 8 digits
            hexValue =
                hexValue.charAt(0) +
                    hexValue.charAt(0) +
                    hexValue.charAt(1) +
                    hexValue.charAt(1) +
                    hexValue.charAt(2) +
                    hexValue.charAt(2) +
                    hexValue.charAt(3) +
                    hexValue.charAt(3);
        }
        if (hexValue.length === 6) {
            // add alpha
            hexValue += "ff";
        }
        if (hexValue.length !== 8) {
            // invalid length
            return null;
        }
        var r = parseInt(hexValue.substring(0, 2), 16);
        var g = parseInt(hexValue.substring(2, 4), 16);
        var b = parseInt(hexValue.substring(4, 6), 16);
        var a = ((0.0 + parseInt(hexValue.substring(6, 8), 16)) / 255.0);
        return [r, g, b, a];
    };
    return Brand;
}());
exports.Brand = Brand;

},{}],80:[function(require,module,exports){
/**
 * Namespace salaxy.util contains utility classes that are not related to Salaxy business logic,
 * but to general functionality: JavaScript programming, browsers etc.
 *
 * All implementation should be independent from the framework (Angular 1, Angular, jQuery etc.).
 * Only the following dependencies are accepted:
 *
 * - Moment.js (not currently added)
 * - (New dependencies must be approved by Matti & Olli)
 */
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Very simple cookie implementation - at the moment for token storage only.
 * Expand if needed for other use cases (see todo section in the docs).
 *
 * @todo Expand this class as necessary e.g. something like this: https://developer.mozilla.org/en-US/docs/Web/API/Document/cookie/Simple_document.cookie_framework
 * or this https://github.com/Booyanach/cookie-wrapper ... which unfortunately cannot be used at the moment, because they are GPL license.
 */
var Cookies = /** @class */ (function () {
    function Cookies() {
    }
    /**
     * Gets a cookie value by a key
     * @param cname - CName / key to look for.
     */
    Cookies.prototype.get = function (key) {
        var cookie = document.cookie;
        var cookieParts = cookie.split(";");
        for (var _i = 0, cookieParts_1 = cookieParts; _i < cookieParts_1.length; _i++) {
            var item = cookieParts_1[_i];
            var cookiePart = decodeURIComponent(item).trim();
            if (cookiePart.indexOf(key + "=") === 0) {
                return cookiePart.substring(key.length + 1);
            }
        }
        return null;
    };
    /**
     * Sets a cookie value for the specified CName
     * @param cname - CName for the cookie value. Name is uri encoded as a fallback, but generally, you should make sure this is a valid cname.
     * @param value - Value to set for the cookie. Value is uri encoded.
     * @param expirationDays - Days until the cookie expires.
     * Set this to null or 0 to not set the expiration date at all.
     * This defaults the behavior where cookie is deleted when browser is closed.
     */
    Cookies.prototype.setCookie = function (cname, value, expirationDays) {
        cname = encodeURIComponent(cname);
        value = encodeURIComponent(value);
        if (expirationDays && expirationDays > 0) {
            var d = new Date();
            d.setTime(d.getTime() + (expirationDays * 24 * 60 * 60 * 1000));
            var expires = "expires=" + d.toUTCString();
            document.cookie = cname + "=" + value + ";" + expires + ";path=/";
        }
        else {
            document.cookie = cname + "=" + value + ";path=/";
        }
    };
    return Cookies;
}());
exports.Cookies = Cookies;

},{}],81:[function(require,module,exports){
(function (global){
Object.defineProperty(exports, "__esModule", { value: true });
var momentImport = (typeof window !== "undefined" ? window['moment'] : typeof global !== "undefined" ? global['moment'] : null);
var logic_1 = require("../logic");
var model_1 = require("../model");
var Years_1 = require("./Years");
/**
 * Import the moment for puposes of this library.
 * @hidden
 */
var moment = momentImport;
/**
 * Date parsing, formatting and other operations within the Salaxy framework.
 * We use ISO 8601 as our Date format even inside JavaScript objects.
 * This is because of the following reasons:
 *
 * 1. Generally, we do not want to use JavaScript Date because it presents so many problems.
 * 2. However, we do not want to force our library consumers using Moment (or some other Date/Time library).
 * 3. We store dates in JSON as ISO 8601 date strings - this is universally the best practice
 * 4. ISO 8601 provides a way to present a date without time and most importantly timezone information
 * 5. ISO 8601 date also works best for most UI components (because of similar reasons as above).
 *
 * Implementation uses MomentJS, but we should avoid using MomentJS outside this library as much as possible.
 * This library is only for Dates. Time / DateTime functionality should be in separate library if necessary.
 */
var Dates = /** @class */ (function () {
    function Dates() {
    }
    /**
     * Gets an object and returns it as the date format that is stored in the data structure with ISO 8601 format.
     *
     * @param datelyObject - Object that should be converted to Salaxy date: A string, JS Date object, Moment etc.
     *
     * @return The date in simplest possible ISO 8601 compliant format "YYYY-MM-DD", null if empty, not valid date etc.
     */
    Dates.asDate = function (datelyObject) {
        var asMoment = this.asMoment(datelyObject);
        return asMoment ? asMoment.format("YYYY-MM-DD") : null;
    };
    /**
     * Gets a date based on year, month and day (1-based).
     * NOTE: Unlike Date() constructor or Moment() constructor, all numbers are 1-based:
     * (2017, 2, 2) results to "2017-02-02" and not "2017-01-01T22:00:00.000Z" like in those constructors.
     *
     * @param year Year component of the date or "today" for today's year.
     * @param month Month component of the date (1-12) or "today" for today's month.
     * @param day Day of month component of the date (1-31) or "today" for today's day of month.
     */
    Dates.getDate = function (year, month, day) {
        year = (year === "today") ? Dates.getTodayMoment().year() : year;
        month = (month === "today") ? Dates.getTodayMoment().month() : (month - 1);
        day = (day === "today") ? Dates.getTodayMoment().date() : day;
        if (!day || month == null || month < 0 || month > 11 || !year) {
            return null;
        }
        return this.asDate([year, month, day]);
    };
    /**
     * Converts the date to a JavaScript Date. Please note, that also time part is returned.
     * @param  datelyObject - Object that should be converted: A string, JS Date object, Moment etc.
     *
     * @return JavaScript date corresponding to input or null.
     */
    Dates.asJSDate = function (datelyObject) {
        var asMoment = this.asMoment(datelyObject);
        return asMoment ? asMoment.toDate() : null;
    };
    /**
     * Checks whether a string is in ISO format.
     *
     * @param isoDate Value that is evaluated.
     * @param required If set to true, the value is required. If required is null the false will be returned.
     *
     * @return True if the given date is in the correct format.
     */
    Dates.isValidDateTime = function (isoDate, required) {
        if (required === void 0) { required = false; }
        if (!isoDate) {
            return !required;
        }
        return moment(isoDate, moment.ISO_8601).isValid();
    };
    /** Get the date of today as ISO 8601 string format (YYYY-MM-DD)  */
    Dates.getToday = function () {
        return this.asDate(this.getTodayMoment());
    };
    /** Get the date of today as moment object. */
    Dates.getTodayMoment = function () {
        return moment(0, "HH");
    };
    /**
     * Gets the dately object as a Moment. If empty, not valid etc., returns null.
     * If the object is already a returns the given objectg (no clone).
     *
     * @param datelyObject Object that should be converted to Moment: A string, JS Date object, Moment, array of numbers etc.
     * @param allowInvalid If true, returns also invalid moment object. By default returns null, if the dately object is parsed as invalid moment.
     *
     *  @return A Moment object or null.
     */
    Dates.asMoment = function (datelyObject, allowInvalid) {
        if (allowInvalid === void 0) { allowInvalid = false; }
        if (!datelyObject) {
            return null;
        }
        if (moment.isMoment(datelyObject)) {
            if (datelyObject.isValid() || allowInvalid) {
                return datelyObject;
            }
            return null;
        }
        return this.getMoment(datelyObject, allowInvalid);
    };
    /**
     * Gets the dately object as a Moment. If empty, not valid etc., returns null.
     * If the object is already a Moment, clones it.
     *
     * @param datelyObject Object that should be converted to Moment: A string, JS Date object, Moment, array of numbers etc.
     * @param allowInvalid If true, returns also invalid moment object. By default returns null, if the dately object is parsed as invalid moment.
     *
     *  @return A Moment object or null.
     */
    Dates.getMoment = function (datelyObject, allowInvalid) {
        if (allowInvalid === void 0) { allowInvalid = false; }
        if (!datelyObject) {
            return null;
        }
        var asMoment;
        if (moment.isMoment(datelyObject)) {
            asMoment = datelyObject.clone();
        }
        else {
            if (moment.isDate(datelyObject) || Number.isInteger(datelyObject) || Array.isArray(datelyObject)) {
                asMoment = moment(datelyObject);
            }
            else if (datelyObject === "today") {
                asMoment = this.getTodayMoment();
            }
            else if (datelyObject === "yesterday") {
                asMoment = this.getTodayMoment().add(-1, "day");
            }
            else if (datelyObject === "tomorrow") {
                asMoment = this.getTodayMoment().add(1, "day");
            }
            else if (datelyObject === "salaryDate") {
                asMoment = moment(logic_1.SalaryDateLogic.CalculateSalaryDate());
            }
            else {
                asMoment = moment(datelyObject, moment.ISO_8601);
            }
        }
        if (asMoment.isValid() || allowInvalid) {
            return asMoment;
        }
        return null;
    };
    /**
     * Returns the duration  object. If parameter is empty or null, defaults to Today (not Now).
     *
     * @param startDatelyObject Duration start that is parsed using getMoment().
     * Null before conversion defaults to today. Invalid objects result to invalid duration.
     * @param endDatelyObject Duration start that is parsed using getMoment().
     * Null before conversion defaults to today. Invalid objects result to invalid duration.
     *
     * @return A Duration object, which may also be invalid
     */
    Dates.getDuration = function (startDatelyObject, endDatelyObject) {
        startDatelyObject = this.asMoment(startDatelyObject, true) || this.getTodayMoment();
        endDatelyObject = this.asMoment(endDatelyObject, true) || this.getTodayMoment();
        return moment.duration(endDatelyObject.diff(startDatelyObject));
    };
    /**
     * Gets a date range based on start and end dates.
     * Days count is calculated using getWorkdays() (Add parameter if you need other day count methods).
     *
     * @param start DateRange start that should be converted to Salaxy date: A string, JS Date object, Moment etc.
     * @param end DateRange end that should be converted to Salaxy date: A string, JS Date object, Moment etc.
     *
     * @return DateRange based on start and end dates.
     */
    Dates.getDateRange = function (start, end) {
        var result = {
            start: this.asDate(start),
            end: this.asDate(end),
        };
        result.daysCount = this.getWorkdays(result.start, result.end).length;
        return result;
    };
    /**
     * Gets the workdays between two dates including both days.
     * Returns empty array if there is no start or if end is before start.
     * Returns 1 day if there is no end: we assume that the user selected just one day.
     *
     * @param startDate A dately value as the start date (a string, JS Date object, Moment etc.).
     * @param endDate Corresponding end date.
     * @param holidayGroup The holiday group for defining which days not to count as working day. The default group is Holiday.
     *
     * @return The work days between the two dates (inclusive).
     */
    Dates.getWorkdays = function (startDate, endDate, holidayGroup) {
        if (holidayGroup === void 0) { holidayGroup = model_1.HolidayGroup.Holiday; }
        startDate = this.asDate(startDate);
        endDate = this.asDate(endDate) || startDate;
        if (!startDate) {
            return [];
        }
        var result = [];
        while (startDate <= endDate) {
            if (this.isWorkday(startDate, holidayGroup)) {
                result.push(startDate);
            }
            startDate = this.asDate(this.getMoment(startDate).add(1, "day"));
        }
        return result;
    };
    /**
     * Gets the vacation days (6 day week Mon-Sat) between two dates including both days.
     * Returns empty array if there is no start or if end is before start.
     * Returns 1 day if there is no end: we assume that the user selected just one day.
     *
     * @param startDate A dately value as the start date (a string, JS Date object, Moment etc.).
     * @param endDate Corresponding end date.
     * @param holidayGroup The holiday group for defining which days not to count as working day. The default group is Holiday.
     *
     * @return The work days between the two dates (inclusive).
     */
    Dates.getVacationDays = function (startDate, endDate, holidayGroup) {
        if (holidayGroup === void 0) { holidayGroup = model_1.HolidayGroup.Holiday; }
        startDate = this.asDate(startDate);
        endDate = this.asDate(endDate) || startDate;
        if (!startDate) {
            return [];
        }
        var result = [];
        while (startDate <= endDate) {
            if (this.isVacationday(startDate, holidayGroup)) {
                result.push(startDate);
            }
            startDate = this.asDate(this.getMoment(startDate).add(1, "day"));
        }
        return result;
    };
    /**
     * Output one formatted date, or a formatted range of two dates.
     *
     * @param startDate A dately value as the start date (a string, JS Date object, Moment etc.). Can be an empty value if endDate is not empty.
     * @param endDate Corresponding end date. Can be an empty value, in which case only start date will output.
     *
     * @return A Simple date string e.g. "12.11.2019". Or a date range string with possible formats:
     *         "12. - 25.11.2019", "12.11. - 02.12.2019", "12.11.2019 - 12.01.2020", or "- 12.01.2020".
     */
    Dates.getFormattedDate = function (startDate, endDate) {
        var formatFull = "DD.MM.YYYY";
        if (!startDate && endDate) {
            return "- " + this.asMoment(endDate).format(formatFull);
        }
        var start = this.asMoment(startDate);
        var end = this.asMoment(endDate);
        if (end && !start.isSame(end)) {
            var formatMonthDay = "DD.MM.";
            var formatDay = "DD.";
            var sameYear = start.year() === end.year();
            var sameMonth = start.month() === end.month();
            return start.format(sameYear ? sameMonth ? formatDay : formatMonthDay : formatFull) + " - " + end.format(formatFull);
        }
        return start ? start.format(formatFull) : "-";
    };
    /**
     * Formats a dately object using MomentJs formatting:
     * e.g. "DD.MM.YYYY"
     * https://momentjs.com/docs/#/displaying/format/
     */
    Dates.format = function (date, format, nullValue) {
        if (nullValue === void 0) { nullValue = null; }
        var asMoment = this.asMoment(date);
        return asMoment ? asMoment.format(format) : nullValue;
    };
    /**
     * Gets the month as 1-based number: 1-12.
     *
     * @param datelyObject - Object that represents month: A string, JS Date object, Moment etc.
     * Special string "today" can be used for fetching today's date.
     *
     * @return Month between 1-12 or null if the object is not a dately object.
     */
    Dates.getMonth = function (datelyObject) {
        var asMoment = this.asMoment(datelyObject);
        return asMoment ? asMoment.month() + 1 : null;
    };
    /**
     * Gets the year of a date or today.
     *
     * @param datelyObject - Object that represents month: A string, JS Date object, Moment etc.
     * Special string "today" can be used for fetching today's date.
     *
     * @return Year, e.g. 2019 or null if the object is not a dately object.
     */
    Dates.getYear = function (datelyObject) {
        var asMoment = this.asMoment(datelyObject);
        return asMoment ? asMoment.year() : null;
    };
    /**
     * Returns true if the given dately object is a holiday.
     * Please note that the weekend days are not by default holidays
     *
     * @param datelyObject - Object that should be converted to date: A string, JS Date object, Moment etc.
     * @param holidayGroup - The holiday group for defining which days to count as holiday day. The default group is Holiday.
     *
     * @return True, if the given dately object is a holiday.
     */
    Dates.isHoliday = function (datelyObject, holidayGroup) {
        if (holidayGroup === void 0) { holidayGroup = model_1.HolidayGroup.Holiday; }
        var moment = this.asMoment(datelyObject);
        if (!moment) {
            return false;
        }
        if (!holidayGroup) {
            return false;
        }
        var holidays = Years_1.Years.getYearlyHolidays(moment);
        for (var holiday in holidays) {
            if (holidays.hasOwnProperty(holiday)) {
                var holidayDate = holidays[holiday];
                if (this.asDate(holidayDate.date) === this.asDate(moment) &&
                    holidayDate.holidayGroups.find(function (x) { return x === holidayGroup; })) {
                    return true;
                }
            }
        }
        return false;
    };
    /**
     * Returns true if the given dately object is a working day (5 day week).
     * The day must not be Saturday or Sunday or not any day in the given holiday categoria.
     *
     * @param datelyObject - Object that should be converted to date: A string, JS Date object, Moment etc.
     * @param holidayGroup - The holiday group for defining which days to count as holiday day. The default group is Holiday.
     *
     * @return True, if the given dately object is a working day.
     */
    Dates.isWorkday = function (datelyObject, holidayGroup) {
        if (holidayGroup === void 0) { holidayGroup = model_1.HolidayGroup.Holiday; }
        var moment = this.asMoment(datelyObject);
        if (!moment) {
            return false;
        }
        if (moment.isoWeekday() === 6 || // Saturday
            moment.isoWeekday() === 7) { // Sunday
            return false;
        }
        if (!holidayGroup) {
            return true;
        }
        return !this.isHoliday(moment, holidayGroup);
    };
    /**
     * Returns true if the given dately object is a vacation day (6 day week).
     * The day must not be Sunday or not any day in the given holiday categoria.
     *
     * @param datelyObject - Object that should be converted to date: A string, JS Date object, Moment etc.
     * @param holidayGroup - The holiday group for defining which days to count as holiday day. The default group is Holiday.
     *
     * @return True, if the given dately object is a working day.
     */
    Dates.isVacationday = function (datelyObject, holidayGroup) {
        if (holidayGroup === void 0) { holidayGroup = model_1.HolidayGroup.Holiday; }
        var moment = this.asMoment(datelyObject);
        if (!moment) {
            return false;
        }
        if (moment.isoWeekday() === 7) { // Sunday
            return false;
        }
        if (!holidayGroup) {
            return true;
        }
        return !this.isHoliday(moment, holidayGroup);
    };
    /**
     * Adds given amount of working days to given day.
     *
     * @param datelyObject - Object that should be converted to date: A string, JS Date object, Moment etc.
     * @param days - Working days to add (positive or negative number).
     * If zero or not set, returns datelyObject or next workday if datelyObject is not a workday.
     * @param holidayGroup - The holiday group for defining which days to count as holiday day. The default group is Holiday.
     *
     * @return New working day with amount of given working days ahead.
     */
    Dates.addWorkdays = function (datelyObject, days, holidayGroup) {
        if (holidayGroup === void 0) { holidayGroup = model_1.HolidayGroup.Holiday; }
        var newMoment = this.getMoment(datelyObject);
        if (!newMoment) {
            return null;
        }
        if (!days) {
            while (true) {
                if (this.isWorkday(newMoment, holidayGroup)) {
                    return this.asDate(newMoment);
                }
                newMoment.add(1, "days");
            }
        }
        var count = 0;
        var step = days > 0 ? 1 : -1;
        while (true) {
            newMoment.add(step, "days");
            if (this.isWorkday(newMoment, holidayGroup)) {
                count += step;
                if (count === days) {
                    return this.asDate(newMoment);
                }
            }
        }
    };
    return Dates;
}());
exports.Dates = Dates;

}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})
},{"../logic":66,"../model":73,"./Years":89}],82:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Utility class for comparing objects.
 * The implementation is based on fast-deep-equal: https://github.com/epoberezkin/fast-deep-equal
 * Modified to static method and re-written in typescript.
 */
var DeepEqual = /** @class */ (function () {
    function DeepEqual() {
    }
    /**
     * Compares objects a and b.
     * Returns true if the objects are equal using value-to-value comparison.
     *
     * @param a - Any object.
     * @param b - Any object to compare with.
     */
    DeepEqual.equal = function (a, b) {
        if (a === b) {
            return true;
        }
        if (a && b && typeof a === "object" && typeof b === "object") {
            var arrA = DeepEqual.isArray(a);
            var arrB = DeepEqual.isArray(b);
            var i = void 0;
            var length_1;
            var key = void 0;
            if (arrA && arrB) {
                // both are arrays
                length_1 = a.length;
                if (length_1 !== b.length) {
                    // different length
                    return false;
                }
                for (i = length_1; i-- !== 0;) {
                    if (!DeepEqual.equal(a[i], b[i])) {
                        // members are not equal
                        return false;
                    }
                }
                // all members are equal
                return true;
            }
            if (arrA !== arrB) {
                // either a or be is an array, not both
                return false;
            }
            var dateA = a instanceof Date;
            var dateB = b instanceof Date;
            if (dateA !== dateB) {
                // either a or b is a date, not both
                return false;
            }
            if (dateA && dateB) {
                // both are dates, test times equality
                return a.getTime() === b.getTime();
            }
            var regexpA = a instanceof RegExp;
            var regexpB = b instanceof RegExp;
            if (regexpA !== regexpB) {
                // either a or b is RegExp, not both
                return false;
            }
            if (regexpA && regexpB) {
                // both are RegExp, test string equality
                return a.toString() === b.toString();
            }
            var keys = DeepEqual.keyList(a);
            length_1 = keys.length;
            if (length_1 !== DeepEqual.keyList(b).length) {
                // a and b have different number of properties
                return false;
            }
            for (i = length_1; i-- !== 0;) {
                if (!DeepEqual.hasProp.call(b, keys[i])) {
                    // b does not have the same properties as a
                    return false;
                }
            }
            for (i = length_1; i-- !== 0;) {
                key = keys[i];
                if (!DeepEqual.equal(a[key], b[key])) {
                    // property has not the same value
                    return false;
                }
            }
            // both objects are equal
            return true;
        }
        // return false, except both are NaN
        return a !== a && b !== b;
    };
    DeepEqual.isArray = Array.isArray;
    DeepEqual.keyList = Object.keys;
    DeepEqual.hasProp = Object.prototype.hasOwnProperty;
    return DeepEqual;
}());
exports.DeepEqual = DeepEqual;

},{}],83:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Helpers for handling Iban bank account numbers
 */
var Iban = /** @class */ (function () {
    function Iban() {
    }
    /**
     * Format an Iban number in 4 digits segments and trim out other than alphanum characters.
     * @param value - String value to format
     * @return string value
     */
    Iban.formatIban = function (value) {
        // Remove special character.
        var trimmed = value.toUpperCase().replace(/[^0-9A-Z]/g, "");
        // Format into four characters segments
        var numbers = [];
        for (var i = 0; i < trimmed.length; i += 4) {
            numbers.push(trimmed.substr(i, 4));
        }
        return numbers.join(" ");
    };
    return Iban;
}());
exports.Iban = Iban;

},{}],84:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Helpers for handling numbers: Mathematical operations, parsing and formatting numbers in our supported languages etc.
 */
var Numeric = /** @class */ (function () {
    function Numeric() {
    }
    /**
     * Parses a user input to a float taking into consideration the Finnish culture.
     * Main case is that decimal separator is usually a comma (,).
     * If there is both comma (,) and point (.) in the same string, NaN is returned.
     * Whitespaces are removed and if string contains commas they are replaced with points before conversion to Number.
     *
     * @param numCandidate - text that should be converted to a number if possible.
     */
    Numeric.parseNumber = function (numCandidate) {
        if (numCandidate == null || typeof (numCandidate) === "number") {
            return numCandidate;
        }
        if (typeof (numCandidate) === "string") {
            if (numCandidate.indexOf(",") >= 0 && numCandidate.indexOf(".") >= 0) {
                return Number.NaN;
            }
            numCandidate = numCandidate.replace(/\s/, "");
            return Number(numCandidate.replace(",", "."));
        }
        return Number(numCandidate);
    };
    /**
     * Formats a number as a euro price. Uses comma as decimal separator.
     * @param value - Numeric value to format
     * @param addSuffix - If true (default), adds the €-suffix.
     * @param nullChar The character or string for null or Nan value, the default is '-'.
     */
    Numeric.formatPrice = function (value, addSuffix, nullChar) {
        // TODO: Add localization for English language (dot instead of comma as decimal separator).
        // TODO: Add thousand separator?
        if (addSuffix === void 0) { addSuffix = true; }
        if (nullChar === void 0) { nullChar = "-"; }
        return Numeric.formatNumber(value, 2, (addSuffix ? "€" : ""), nullChar);
    };
    /**
     * Rounds a JavaScript number in a reliable way.
     *
     * @param value Number that is rounded. If null given, returns null.
     * @param decimals Number of decimals after the decimal separator. Default is 2 as in money.
     * @returns Number properly rounded, Null/undefined as null, Non-numeric values return Number.NaN
     */
    Numeric.round = function (value, decimals) {
        if (decimals === void 0) { decimals = 2; }
        // Source: http://www.jacklmoore.com/notes/rounding-in-javascript/
        return value == null ? null : Number(Math.round((value + "e" + decimals)) + "e-" + decimals);
    };
    /**
     * Fixes floating point problems in typical number.toString() scenarios.
     * E.g. `console.debug((0.07 * 100).toString());` returns "7.000000000000001".
     * Null/undefined returns empty string, numbers fixed and otherwise toString() is called.
     * @param value Number to show as string.
     * @returns Number rounded to specified number of decimals. Null/undefined returns empty string.
     * @example
     * console.debug(Numeric.toString(0.07 * 100)); // returns "7"
     * console.debug((0.07 * 100).toString());      // returns "7.000000000000001"
     */
    Numeric.toString = function (value) {
        if (value == null) {
            return "";
        }
        return value.toFixed ? parseFloat(value.toFixed(10)).toString() : value.toString();
    };
    /**
     * Fixes floating point problems in typical number.toFixed() scenarios.
     * E.g. `console.debug((1.005).toFixed(2));` returns "1.00"
     * @param value Number to show as string. Supports null/undefined, but otherwise should be a number.
     * @param fractionDigits Number of digits after the decimal point. Must be in the range 0 - 20, inclusive.
     * @returns Number rounded to specified number of decimals. Null/undefined returns empty string.
     * @example
     * console.debug(Numeric.toFixed(1.005, 2)) // returns "1.01"
     * console.debug((1.005).toFixed(2))        // returns 1.00
     */
    Numeric.toFixed = function (value, fractionDigits) {
        if (fractionDigits === void 0) { fractionDigits = 0; }
        value = Numeric.round(value, fractionDigits);
        return value == null ? "" : value.toFixed(fractionDigits);
    };
    /**
     * Rounds a JavaScript number in a reliable way in percentage format.
     *
     * @param value Number that is rounded.
     * @param decimals Number of decimals after the decimal separator. Default is 2 as in money.
     * If decimals is null, no rounding is done.
     * @param addSuffix If true, adds '%' sign at the end.
     * @param nullChar The character or string for null or Nan value, the default is '-'.
     */
    Numeric.formatPercent = function (value, decimals, addSuffix, nullChar) {
        if (decimals === void 0) { decimals = 2; }
        if (addSuffix === void 0) { addSuffix = true; }
        if (nullChar === void 0) { nullChar = "-"; }
        return Numeric.formatNumber(value, decimals, (addSuffix ? "%" : ""), nullChar);
    };
    /**
     * Rounds a JavaScript number and formats it using comma as a separator and optional suffix.
     *
     * @param value Number that is rounded.
     * @param decimals Number of decimals after the decimal separator. Default is 2 as in money. If decimals is null, no rounding is done.
     * @param suffix The suffix to add to the number.
     * @param nullChar The character or string for null or Nan value, the default is '-'.
     */
    Numeric.formatNumber = function (value, decimals, suffix, nullChar) {
        if (decimals === void 0) { decimals = 2; }
        if (suffix === void 0) { suffix = ""; }
        if (nullChar === void 0) { nullChar = "-"; }
        var asFloat = parseFloat(value);
        if (isNaN(asFloat)) {
            return nullChar;
        }
        var asFixed = Numeric.toFixed(asFloat, decimals);
        return asFixed.replace(/\./, ",") + suffix;
    };
    /**
     * Checks if the given object is a number.
     * @param numberCandidate Object to check
     */
    Numeric.isNumber = function (numberCandidate) {
        return !isNaN(parseFloat(numberCandidate)) && isFinite(numberCandidate);
    };
    return Numeric;
}());
exports.Numeric = Numeric;

},{}],85:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/** Provides helpers for handling OData queries */
var OData = /** @class */ (function () {
    function OData() {
    }
    /**
     * Gets the result from Ajax result (json) to strongly typed result.
     * @param data Result data coming from the ajax call.
     * This may be either an OData object with count and next page link or just an array depending on the call.
     */
    OData.getODataResult = function (data) {
        var result = {
            items: [],
        };
        if (data.items) {
            result.items = data.items;
            result.count = data.count || null;
            result.nextPageLink = data.nextPageLink || null;
        }
        else if (Array.isArray(data)) {
            result.items = data;
            result.count = null;
            result.nextPageLink = null;
        }
        else {
            throw Error("Unexpected result: " + typeof (data));
        }
        return result;
    };
    /**
     * Gets the URL including the query string using the provided OData query options.
     * @param baseUrl Base URL of the service to which the query is added.
     * If null, the returned URL is the query string part starting with the question mark
     * ...or if none of the options is set, returns just an empty string.
     * @param queryOptions options based on which the query is constructed.
     */
    OData.getUrl = function (baseUrl, queryOptions) {
        queryOptions = queryOptions || {};
        baseUrl = (baseUrl || "").trim();
        var queries = [];
        if (queryOptions.$count) {
            queries.push("$count=true");
        }
        if (queryOptions.$expand) {
            queries.push("$expand=" + queryOptions.$expand);
        }
        if (queryOptions.$filter) {
            queries.push("$filter=" + queryOptions.$filter);
        }
        if (queryOptions.$orderby) {
            queries.push("$orderby=" + queryOptions.$orderby);
        }
        if (queryOptions.$select) {
            queries.push("$select=" + queryOptions.$select);
        }
        if (queryOptions.$skip) {
            queries.push("$skip=" + queryOptions.$skip);
        }
        if (queryOptions.$top) {
            queries.push("$top=" + queryOptions.$top);
        }
        if (queryOptions.$search) {
            var search = queryOptions.$search + (/\*$/.test(queryOptions.$search) ? "" : "*");
            queries.push("$search=" + encodeURIComponent(search));
        }
        return baseUrl + (queries.length === 0 ? "" : (baseUrl.indexOf("?") >= 0 ? "&" : "?") + queries.join("&"));
    };
    return OData;
}());
exports.OData = OData;

},{}],86:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Helpers for performing operations with objects
 */
var Objects = /** @class */ (function () {
    function Objects() {
    }
    /**
     * Uses JSON Serialization / Deserialization to deep clone an object.
     * @param value Object to clone
     * @returns A cloned object.
     */
    Objects.cloneJson = function (value) {
        return JSON.parse(JSON.stringify(value));
    };
    /**
     * Extends one object with another using Intersection types.
     * https://www.typescriptlang.org/docs/handbook/advanced-types.html
     * @param first First object.
     * @param second Second object.
     */
    Objects.extend = function (first, second) {
        var result = {};
        for (var id in first) {
            if (first.hasOwnProperty(id)) {
                result[id] = first[id];
            }
        }
        for (var id in second) {
            if (second.hasOwnProperty(id) && !result.hasOwnProperty(id)) {
                result[id] = second[id];
            }
        }
        return result;
    };
    return Objects;
}());
exports.Objects = Objects;

},{}],87:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Helper class for JWT tokens.
 * TODO: move this to core (with base64)
 */
var Token = /** @class */ (function () {
    function Token() {
    }
    /**
     * Validates the JWT token. Please note that the method does not check the signature.
     * Returns:
     * noToken - the token is null,
     * invalid - the token has invalid format, or some payload values (e.g. exp) are missing,
     * expired - the token has expired,
     * ok - token is valid.
     */
    Token.validate = function (token) {
        if (!token) {
            return "noToken";
        }
        var payload = this.parsePayload(token);
        if (!payload || !payload.exp) {
            return "invalid";
        }
        if (payload.exp * 1000 <= new Date().getTime()) {
            return "expired";
        }
        return "ok";
    };
    /**
     * Decodes and parses the payload from the string formatted token.
     * @param token Token as a string.
     * @return Payload of the token as JSON object.
     */
    Token.parsePayload = function (token) {
        var tokenParts = token.split(".");
        if (tokenParts.length === 3) {
            var payload = tokenParts[1];
            payload = Base64.decode(unescape(payload));
            var data = JSON.parse(payload);
            return data;
        }
        return null;
    };
    /**
     * Decodes and parses the header from the string formatted token.
     * @param token Token as a string.
     * @return Payload of the token as JSON object.
     */
    Token.parseHeader = function (token) {
        var tokenParts = token.split(".");
        if (tokenParts.length === 3) {
            var payload = tokenParts[0];
            payload = Base64.decode(unescape(payload));
            var data = JSON.parse(payload);
            return data;
        }
        return null;
    };
    return Token;
}());
exports.Token = Token;

},{}],88:[function(require,module,exports){
(function (global){
Object.defineProperty(exports, "__esModule", { value: true });
var model_1 = require("../model");
var momentImport = (typeof window !== "undefined" ? window['moment'] : typeof global !== "undefined" ? global['moment'] : null);
/** moment variable */
var moment = momentImport;
/**
 * Provides base methods for validation.
 * These are typically used in user interface validator components.
 */
var Validation = /** @class */ (function () {
    function Validation() {
    }
    /**
     * Returns true if the given value is a valid Finnish Personal ID (HETU / SSN).
     * Checks the format and checksum.
     * @param value Candidate for Finnish Personal ID.
     */
    Validation.isPersonalIdFi = function (value) {
        if (!value) {
            return true;
        }
        var pattern = /^(\d{6})([\+\-A])(\d{3})([a-zA-Z0-9\*])$/;
        var groups = pattern.exec(value);
        if (!groups) {
            return false;
        }
        var date = groups[1];
        var centenry = groups[2];
        var person = groups[3];
        var checksum = groups[4];
        var cc = centenry === "-" ? "19" : "20";
        var parsedDate = moment(date.substr(0, 4) + cc + date.substr(4, 2), "DDMMYYYY", true);
        if (!parsedDate.isValid()) {
            return false;
        }
        if (checksum === "*") {
            return true;
        }
        var checksumLetters = "0123456789ABCDEFHJKLMNPRSTUVWXY";
        var calculatedChecksum = checksumLetters[parseInt(date + person, 10) % 31];
        return calculatedChecksum === checksum.toUpperCase();
    };
    /**
     * Returns true if the value is a valid e-mail.
     * Currently uses a simple regex (source?).
     * @param value E-mail candidate.
     */
    Validation.isEmail = function (value) {
        var regExp = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
        return regExp.test(value);
    };
    /**
     * Returns true if the value is a valid mobile phone number: 5-16 numbers and spaces (5-18 if there is a "+" in the beginning).
     * Currently uses a naive regex, but we could extend this to take into account the regional differences.
     * @param value Mobile phone number candidate.
     */
    Validation.isMobilePhone = function (value) {
        // TODO: Check lengths.
        var regExp = /^(\+[\d ]{1,3}[\d ]{4,15})$|^([\d ]{5,16})$/;
        return regExp.test(value);
    };
    /**
     * Returns true if the value is a valid currency amount with maximum two decimals.
     * @param value Currency amount candidate
     */
    Validation.isCurrency = function (value) {
        var regExp = /^\d+(([.]|[,])\d{1,2})?$/;
        return regExp.test(value);
    };
    /**
     * Returns true if the value is a valid number.
     * @param value Number candidate
     */
    Validation.isNumber = function (value) {
        var regExp = /^\d+(([.]|[,])\d+)?$/;
        return regExp.test(value);
    };
    /**
     * Returns true if the value is a valid integer.
     * @param value Number candidate
     */
    Validation.isInteger = function (value) {
        var regExp = /^\d+$/;
        return regExp.test(value);
    };
    /**
     * Returns true if the value is a valid tax percent amount with maximum one decimal.
     * @param value Tax percent candidate
     */
    Validation.isTaxPercent = function (value) {
        var regExp = /^\d{1,2}(([.]|[,])\d{1})?$/;
        return regExp.test(value);
    };
    /**
     * Returns true if the value is a valid SMS verification code.
     * SMS verification code is 6 digits.
     * @param value Verification code candidate.
     */
    Validation.isSmsVerificationCode = function (value) {
        var regExp = /^\d{6}$/;
        return regExp.test(value);
    };
    /** Returns true if the value is a valid Finnish Postal code: 5 numbers. */
    Validation.isPostalCodeFi = function (value) {
        var regExp = /^\d{5}$/;
        return regExp.test(value);
    };
    /**
     * Returns true if the value is a valid Finnish Company ID. If the format is not correct, will return false.
     * @param companyIdCandidate String to validate / format
     * @param allowStarAsChecksum If true, allows the checksum character (the last char) to be an asterix (*).
     * @return boolean
     */
    Validation.formatCompanyIdFi = function (companyIdCandidate, allowStarAsChecksum) {
        if (allowStarAsChecksum === void 0) { allowStarAsChecksum = true; }
        if (!companyIdCandidate) {
            return false;
        }
        companyIdCandidate = companyIdCandidate.toUpperCase().trim().replace("-", "").replace("–", "").replace("—", ""); // dash, n-dash, m-dash
        if (companyIdCandidate.substr(0, 2) === "FI") {
            companyIdCandidate = companyIdCandidate.substr(2);
        }
        if (companyIdCandidate.length === 7) {
            // Some old companies may have 6+1 numbers
            companyIdCandidate = "0" + companyIdCandidate;
        }
        if (companyIdCandidate.length !== 8) {
            return false;
        }
        var multipliers = [7, 9, 10, 5, 8, 4, 2];
        var total = 0;
        for (var i = 0; i < 7; i++) {
            var num = Number(companyIdCandidate.charAt(i));
            if (num < 0 || num > 9) {
                return false;
            }
            total += num * multipliers[i];
        }
        var modulo = total % 11;
        if (modulo === 1) {
            return false;
        }
        var checksum = modulo === 0 ? 0 : (11 - modulo);
        return (allowStarAsChecksum && companyIdCandidate.charAt(7) === "*") || Number(companyIdCandidate[7]) === checksum;
    };
    /**
     * Returns true if the value is a valid IBAN number.
     * Checks for the country specific length as well as checksum.
     * @param value IBAN number number candidate.
     */
    Validation.isIban = function (value) {
        // Source: https://stackoverflow.com/questions/21928083/iban-validation-check
        var CODE_LENGTHS = {
            AD: 24, AE: 23, AT: 20, AZ: 28, BA: 20, BE: 16, BG: 22, BH: 22, BR: 29,
            CH: 21, CR: 21, CY: 28, CZ: 24, DE: 22, DK: 18, DO: 28, EE: 20, ES: 24,
            FI: 18, FO: 18, FR: 27, GB: 22, GI: 23, GL: 18, GR: 27, GT: 28, HR: 21,
            HU: 28, IE: 22, IL: 23, IS: 26, IT: 27, JO: 30, KW: 30, KZ: 20, LB: 28,
            LI: 21, LT: 20, LU: 20, LV: 21, MC: 27, MD: 24, ME: 22, MK: 19, MR: 27,
            MT: 31, MU: 30, NL: 18, NO: 15, PK: 24, PL: 28, PS: 29, PT: 25, QA: 29,
            RO: 24, RS: 22, SA: 24, SE: 24, SI: 19, SK: 24, SM: 27, TN: 24, TR: 26,
        };
        var iban = String(value).toUpperCase().replace(/[^A-Z0-9]/g, ""); // keep only alphanumeric characters
        var code = iban.match(/^([A-Z]{2})(\d{2})([A-Z\d]+)$/); // match and capture (1) the country code, (2) the check digits, and (3) the rest
        // check syntax and length
        if (!code || iban.length !== CODE_LENGTHS[code[1]]) {
            return false;
        }
        // rearrange country code and check digits, and convert chars to ints
        var digits = (code[3] + code[1] + code[2]).replace(/[A-Z]/g, function (letter) {
            return (letter.charCodeAt(0) - 55);
        });
        // final check
        return Validation.mod97(digits) === 1;
    };
    /**
     * Returns PensionCompany for the given pension contract number.
     * @param value - Pension contract number.
     */
    Validation.isPensionContractNumber = function (value) {
        if (value == null) {
            return null;
        }
        var regExp = null;
        if (value.startsWith("7") || value.startsWith("8")) {
            regExp = /^(\d{5})\-?(\d{4})([a-zA-Z0-9\*])$/;
        }
        else {
            regExp = /^(\d{2})\-?(\d{7})([a-zA-Z0-9\*])$/;
        }
        var result = regExp.exec(value);
        if (!result) {
            return null;
        }
        var company = result[1];
        var contract = result[2];
        var check = result[3];
        var checksumLetters = "0123456789ABCDEFHJKLMNPRSTUVWXY";
        var calculatedChecksum = checksumLetters[parseInt(company + contract, 10) % 31];
        if (calculatedChecksum !== check) {
            return null;
        }
        switch (company) {
            case "80009":
                return model_1.PensionCompany.Apteekkien;
            case "80008":
                return model_1.PensionCompany.Verso;
            case "54":
                return model_1.PensionCompany.Elo;
            case "90":
                return model_1.PensionCompany.Etera;
            case "46":
                return model_1.PensionCompany.Ilmarinen;
            case "40":
                return model_1.PensionCompany.PensionsAlandia;
            case "55":
                return model_1.PensionCompany.Varma;
            case "56":
                return model_1.PensionCompany.Veritas;
        }
        return null;
    };
    /**
     * Returns PensionCompany for the given *temporary* pension contract number.
     * @param value - TemporaryPension contract number.
     */
    Validation.isTemporaryPensionContractNumber = function (value) {
        if (value == null) {
            return null;
        }
        switch (value) {
            case "55-3999990D":
                return model_1.PensionCompany.Varma;
            case "46-3000000V":
                return model_1.PensionCompany.Ilmarinen;
            case "54-0000000U":
                return model_1.PensionCompany.Elo;
            case "56-0049990P":
                return model_1.PensionCompany.Veritas;
        }
        return null;
    };
    Validation.mod97 = function (value) {
        var checksum = value.slice(0, 2);
        for (var offset = 2; offset < value.length; offset += 7) {
            var fragment = String(checksum) + value.substring(offset, offset + 7);
            checksum = parseInt(fragment, 10) % 97;
        }
        return checksum;
    };
    return Validation;
}());
exports.Validation = Validation;

}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})
},{"../model":73}],89:[function(require,module,exports){
Object.defineProperty(exports, "__esModule", { value: true });
var Dates_1 = require("./Dates");
var codegen_1 = require("../codegen");
var codegen_2 = require("../codegen");
/**
 * Helper for yearly changing sidecost percentages and holidays.
 */
var Years = /** @class */ (function () {
    function Years() {
    }
    /**
     * Gets salary calculation parameters that are changing yearly and holidays of the year.
     * The method is designed for the end-of-year and as such it only supports 2 years:
     * the current / previous year (from Jan to Nov) OR current / next year (in approx. December).
     *
     * @param forDate - Dately object (JavaScript date, ISO string formatted date, or moment) for which the numbers are fetched.
     *
     * @return The yearly changing numbers if year supported. Error if year not supported.
     */
    Years.getYearlyChangingNumbers = function (forYear) {
        var year = Dates_1.Dates.asMoment(forYear).year();
        var numbers = codegen_1.yearlyChangingNumbersYears.find(function (x) { return x.year === year; });
        if (!numbers) {
            throw new Error("Year " + year + " not supported.");
        }
        numbers.holidays = this.getYearlyHolidays(forYear);
        return numbers;
    };
    /**
     * Gets holidays for the given year.
     *
     * @param forDate - Dately object (JavaScript date, ISO string formatted date, or moment) for which the holidays are fetched.
     *
     * @return The holidays for the given year.
     */
    Years.getYearlyHolidays = function (forYear) {
        var year = Dates_1.Dates.asMoment(forYear).year();
        var yearlyHolidays = codegen_2.yearlyHolidaysYears.find(function (x) { return x.year === year; });
        if (!yearlyHolidays) {
            throw new Error("Year " + year + " not supported.");
        }
        return yearlyHolidays.holidays;
    };
    return Years;
}());
exports.Years = Years;

},{"../codegen":39,"./Dates":81}],90:[function(require,module,exports){
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
__export(require("./Arrays"));
__export(require("./Barcodes"));
__export(require("./Brand"));
__export(require("./Cookies"));
__export(require("./Dates"));
__export(require("./DeepEqual"));
__export(require("./Iban"));
__export(require("./Numeric"));
__export(require("./Objects"));
__export(require("./OData"));
__export(require("./Token"));
__export(require("./Validation"));
__export(require("./Years"));

},{"./Arrays":77,"./Barcodes":78,"./Brand":79,"./Cookies":80,"./Dates":81,"./DeepEqual":82,"./Iban":83,"./Numeric":84,"./OData":85,"./Objects":86,"./Token":87,"./Validation":88,"./Years":89}]},{},["@salaxy/core"]);
